@@ -24,7 +24,6 @@
 
 #include "SConsumer.hpp"
 
-#include <core/runtime/Runtime.hpp>
 #include <core/spyLog.hpp>
 
 #include <service/extension/Factory.hpp>
@@ -38,9 +37,8 @@ SIGHT_REGISTER_PLUGIN("ExTimeLine::Plugin");
 
 //-----------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
