@@ -25,7 +25,7 @@
 #include "activity/config.hpp"
 #include "activity/extension/Activity.hpp"
 
-#include <data/ActivitySeries.hpp>
+#include <data/Activity.hpp>
 
 namespace sight::activity
 {
@@ -40,65 +40,64 @@ public:
     typedef activity::extension::ActivityAppConfigParamsType ParametersType;
 
     ACTIVITY_API ActivityMsg(
-        const data::ActivitySeries::sptr& series,
+        const data::Activity::sptr& activity,
         const activity::extension::ActivityInfo& info,
         const ParametersType& parameters
     );
 
     ACTIVITY_API virtual ~ActivityMsg()
-    {
-    }
+    = default;
 
     /// Return if the activity can be closed
-    bool isClosable() const
+    [[nodiscard]] bool isClosable() const
     {
         return m_closable;
     }
 
     /// Return activity title
-    const std::string& getTitle() const
+    [[nodiscard]] const std::string& getTitle() const
     {
         return m_title;
     }
 
     /// Return tab identifier
-    const std::string& getTabID() const
+    [[nodiscard]] const std::string& getTabID() const
     {
         return m_tabID;
     }
 
     /// Return appConfig identifier
-    const std::string& getAppConfigID() const
+    [[nodiscard]] const std::string& getAppConfigID() const
     {
         return m_appConfigID;
     }
 
     /// Return tab information
-    const std::string& getTabInfo() const
+    [[nodiscard]] const std::string& getTabInfo() const
     {
         return m_tabInfo;
     }
 
     /// Return activity icon path
-    const std::string& getIconPath() const
+    [[nodiscard]] const std::string& getIconPath() const
     {
         return m_iconPath;
     }
 
     /// Return tooltip
-    const std::string& getToolTip() const
+    [[nodiscard]] const std::string& getToolTip() const
     {
         return m_tooltip;
     }
 
-    /// Return activity series
-    const data::ActivitySeries::sptr& getActivitySeries() const
+    /// Return activity
+    [[nodiscard]] const data::Activity::sptr& getActivity() const
     {
-        return m_series;
+        return m_activity;
     }
 
     /// Return the map of the string association to replace in config
-    const std::map<std::string, std::string>& getReplacementMap() const
+    [[nodiscard]] const std::map<std::string, std::string>& getReplacementMap() const
     {
         return m_replacementMap;
     }
@@ -106,7 +105,7 @@ public:
 private:
 
     /// Flag if activity is closable.
-    bool m_closable;
+    bool m_closable {true};
 
     /// Activity title
     std::string m_title;
@@ -126,8 +125,8 @@ private:
     /// tab tooltip
     std::string m_tooltip;
 
-    /// activity series
-    data::ActivitySeries::sptr m_series;
+    /// activity
+    data::Activity::sptr m_activity;
 
     /// map containing string to replace in activity configuration.
     std::map<std::string, std::string> m_replacementMap;
