@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,30 +25,18 @@
 #include "activity/IActivityValidator.hpp"
 #include "activity/IValidator.hpp"
 
-#include <core/runtime/Module.hpp>
-#include <core/runtime/operations.hpp>
-#include <core/tools/dateAndTime.hpp>
-#include <core/tools/UUID.hpp>
+#include <activity/builder/data.hpp>
+
+#include <core/runtime/runtime.hpp>
 
 #include <data/Composite.hpp>
 #include <data/mt/locked_ptr.hpp>
-#include <data/String.hpp>
+
+#include <boost/range/iterator_range_core.hpp>
 
 namespace sight::activity
 {
 
-//-----------------------------------------------------------------------------
-
-IActivityLauncher::IActivityLauncher()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-IActivityLauncher::~IActivityLauncher()
-{
-}
-
 //------------------------------------------------------------------------------
 
 void IActivityLauncher::parseConfiguration(const ConfigurationType& config, const InOutMapType& inouts)
@@ -56,32 +44,36 @@ void IActivityLauncher::parseConfiguration(const ConfigurationType& config, cons
     m_mainActivityId = config.get<std::string>("mainActivity.<xmlattr>.id", "");
     SIGHT_DEBUG_IF("main activity 'id' is not defined", m_mainActivityId.empty());
 
-    const auto inoutsCfg = config.equal_range("inout");
-    for(auto itCfg = inoutsCfg.first ; itCfg != inoutsCfg.second ; ++itCfg)
+    if(const auto inoutsCfg = config.get_child_optional("inout"); inoutsCfg.has_value())
     {
-        const std::string key = itCfg->second.get<std::string>("<xmlattr>.key");
-        SIGHT_ASSERT("Missing 'key' tag.", !key.empty());
-
-        const std::string uid = itCfg->second.get<std::string>("<xmlattr>.uid");
-        SIGHT_ASSERT("Missing 'uid' tag.", !uid.empty());
-
-        const bool optional = itCfg->second.get<bool>("<xmlattr>.optional", false);
-        const auto it       = inouts.find({key, std::nullopt});
-        SIGHT_ASSERT("Inout '" + key + "' is not found.", it != inouts.end());
-        auto obj = it->second.lock();
-        ParameterType param;
-        param.replace = key;
-        if(optional)
+        const auto group = inoutsCfg->get<std::string>("<xmlattr>.group");
+        if(group == "data")
         {
-            param.by = uid;
-        }
-        else
-        {
-            SIGHT_ASSERT("Object key '" + key + "'with uid '" + uid + "' does not exists.", obj);
-            param.by = obj->getID();
-        }
+            std::size_t i = 0;
+            for(const auto& itCfg : boost::make_iterator_range(inoutsCfg->equal_range("key")))
+            {
+                const auto key = itCfg.second.get<std::string>("<xmlattr>.name");
+                SIGHT_ASSERT("Missing 'name' tag.", !key.empty());
 
-        m_parameters.push_back(param);
+                const auto uid = itCfg.second.get<std::string>("<xmlattr>.uid");
+                SIGHT_ASSERT("Missing 'uid' tag.", !uid.empty());
+
+                const bool optional = itCfg.second.get<bool>("<xmlattr>.optional", false);
+                const auto& objId   = inouts[i++];
+                ParameterType param;
+                param.replace = key;
+                if(optional)
+                {
+                    param.by = uid;
+                }
+                else
+                {
+                    param.by = objId;
+                }
+
+                m_parameters.push_back(param);
+            }
+        }
     }
 
     ConfigurationType configParams = config.get_child("parameters");
@@ -89,8 +81,8 @@ void IActivityLauncher::parseConfiguration(const ConfigurationType& config, cons
     const auto paramsCfg = configParams.equal_range("parameter");
     for(auto itParams = paramsCfg.first ; itParams != paramsCfg.second ; ++itParams)
     {
-        const std::string replace = itParams->second.get<std::string>("<xmlattr>.replace");
-        std::string by            = itParams->second.get<std::string>("<xmlattr>.by", "");
+        const auto replace = itParams->second.get<std::string>("<xmlattr>.replace");
+        std::string by     = itParams->second.get<std::string>("<xmlattr>.by", "");
         if(by.empty())
         {
             by = itParams->second.get<std::string>("<xmlattr>.uid");
@@ -111,23 +103,19 @@ void IActivityLauncher::parseConfiguration(const ConfigurationType& config, cons
 //------------------------------------------------------------------------------
 
 std::pair<bool, std::string> IActivityLauncher::validateActivity(
-    const data::ActivitySeries::csptr& activitySeries
-) const
+    const data::Activity::csptr& activity
+)
 {
     bool isValid = true;
     std::string message;
-    // Applies validator on activity series to check the data
+    // Applies validator on activity to check the data
     activity::extension::ActivityInfo info;
-    info = activity::extension::Activity::getDefault()->getInfo(activitySeries->getActivityConfigId());
+    info = activity::extension::Activity::getDefault()->getInfo(activity->getActivityConfigId());
 
     // load activity module
-    std::shared_ptr<core::runtime::Module> module = core::runtime::findModule(info.bundleId);
-    if(!module->isStarted())
-    {
-        module->start();
-    }
+    core::runtime::startModule(info.bundleId);
 
-    for(std::string validatorImpl : info.validatorsImpl)
+    for(const std::string& validatorImpl : info.validatorsImpl)
     {
         /// Process activity validator
         activity::IValidator::sptr validator = activity::validator::factory::New(validatorImpl);
@@ -136,7 +124,7 @@ std::pair<bool, std::string> IActivityLauncher::validateActivity(
             activity::IActivityValidator::dynamicCast(validator);
         SIGHT_ASSERT("Validator '" + validatorImpl + "' instantiation failed", activityValidator);
 
-        activity::IValidator::ValidationType validation = activityValidator->validate(activitySeries);
+        activity::IValidator::ValidationType validation = activityValidator->validate(activity);
         if(!validation.first)
         {
             message += "\n" + validation.second;
@@ -146,7 +134,7 @@ std::pair<bool, std::string> IActivityLauncher::validateActivity(
 
     if(!isValid)
     {
-        message = "The activity '" + info.title + "' can not be launched:\n" + message;
+        message = std::string("The activity '") + info.title + "' can not be launched:\n" + message;
     }
 
     return std::make_pair(isValid, message);
@@ -154,20 +142,19 @@ std::pair<bool, std::string> IActivityLauncher::validateActivity(
 
 //------------------------------------------------------------------------------
 
-data::ActivitySeries::sptr IActivityLauncher::createMainActivity() const
+data::Activity::sptr IActivityLauncher::createMainActivity() const
 {
     activity::extension::ActivityInfo info;
     info = activity::extension::Activity::getDefault()->getInfo(m_mainActivityId);
 
-    data::ActivitySeries::sptr actSeries = data::ActivitySeries::New();
-    if(info.requirements.size() > 0)
+    auto activity = data::Activity::New();
+    if(!info.requirements.empty())
     {
-        data::Composite::sptr data = actSeries->getData();
-        for(activity::extension::ActivityRequirement req : info.requirements)
+        for(const auto& req : info.requirements)
         {
             if((req.minOccurs == 0 && req.maxOccurs == 0) || req.create)
             {
-                (*data)[req.name] = data::factory::New(req.type);
+                (*activity)[req.name] = sight::activity::detail::data::create(req.type, req.objectConfig);
             }
             else
             {
@@ -176,15 +163,9 @@ data::ActivitySeries::sptr IActivityLauncher::createMainActivity() const
         }
     }
 
-    actSeries->setModality("OT");
-    actSeries->setInstanceUID("activity." + core::tools::UUID::generateUUID());
+    activity->setActivityConfigId(info.id);
 
-    const boost::posix_time::ptime now = boost::posix_time::second_clock::local_time();
-    actSeries->setDate(core::tools::getDate(now));
-    actSeries->setTime(core::tools::getTime(now));
-    actSeries->setActivityConfigId(info.id);
-
-    return actSeries;
+    return activity;
 }
 
 } // namespace sight::activity
