@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,9 +25,7 @@
 #include "activity/config.hpp"
 #include "activity/extension/Activity.hpp"
 
-#include <data/ActivitySeries.hpp>
-#include <data/mt/weak_ptr.hpp>
-#include <data/Series.hpp>
+#include <data/Activity.hpp>
 
 #include <boost/property_tree/ptree.hpp>
 
@@ -47,14 +45,13 @@ public:
     typedef activity::extension::ActivityAppConfigParam ParameterType;
     typedef activity::extension::ActivityAppConfigParamsType ParametersType;
     typedef std::map<std::string, std::string> ReplaceMapType;
-    typedef std::map<std::pair<std::string, std::optional<std::size_t> >,
-                     data::mt::weak_ptr<data::Object> > InOutMapType;
+    typedef std::vector<std::string> InOutMapType;
 
     /// Constructor. Do nothing.
-    ACTIVITY_API IActivityLauncher();
+    ACTIVITY_API IActivityLauncher() = default;
 
     /// Destructor. Do nothing.
-    ACTIVITY_API virtual ~IActivityLauncher();
+    ACTIVITY_API virtual ~IActivityLauncher() = default;
 
 protected:
 
@@ -64,16 +61,16 @@ protected:
         const InOutMapType& inouts = InOutMapType()
     );
 
-    /// Create the activity series given in 'mainActivity' configuration
-    ACTIVITY_API virtual data::ActivitySeries::sptr createMainActivity() const;
+    /// Create the activity given in 'mainActivity' configuration
+    [[nodiscard]] ACTIVITY_API virtual data::Activity::sptr createMainActivity() const;
 
     /**
      * @brief Check if the activity is valid by calling the activity validator.
      * @return Return true if the given activity is valid
      */
-    ACTIVITY_API std::pair<bool, std::string> validateActivity(
-        const data::ActivitySeries::csptr& activitySeries
-    ) const;
+    static ACTIVITY_API std::pair<bool, std::string> validateActivity(
+        const data::Activity::csptr& activity
+    );
 
     std::string m_mainActivityId; ///< configuration id of the main activity
 
