@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,7 +24,7 @@
 
 #include "activity/IObjectValidator.hpp"
 
-#include <data/ActivitySeries.hpp>
+#include <data/Activity.hpp>
 #include <data/Composite.hpp>
 #include <data/Vector.hpp>
 
@@ -33,8 +33,7 @@ namespace sight::activity
 
 //------------------------------------------------------------------------------
 
-IValidator::ValidationType IActivityValidator::checkRequirements(const data::ActivitySeries::csptr& activity)
-const
+IValidator::ValidationType IActivityValidator::checkRequirements(const data::Activity::csptr& activity)
 {
     IValidator::ValidationType validation;
     validation.first  = true;
@@ -43,15 +42,13 @@ const
     activity::extension::ActivityInfo info;
     info = activity::extension::Activity::getDefault()->getInfo(activity->getActivityConfigId());
 
-    data::Composite::csptr composite = activity->getData();
-
-    for(activity::extension::ActivityRequirement req : info.requirements)
+    for(const activity::extension::ActivityRequirement& req : info.requirements)
     {
         if((req.minOccurs == 1 && req.maxOccurs == 1)
            || (req.minOccurs == 0 && req.maxOccurs == 0)
            || req.create) // One object is required
         {
-            data::Object::csptr obj = composite->at<data::Object>(req.name);
+            data::Object::csptr obj = activity->get(req.name);
             if(!obj)
             {
                 validation.first   = false;
@@ -64,7 +61,7 @@ const
             }
             else
             {
-                IValidator::ValidationType val = this->checkObject(obj, req.validator);
+                IValidator::ValidationType val = sight::activity::IActivityValidator::checkObject(obj, req.validator);
                 if(!val.first)
                 {
                     validation.first   = false;
@@ -74,7 +71,7 @@ const
         }
         else if(req.container == "vector")
         {
-            data::Vector::csptr vector = composite->at<data::Vector>(req.name);
+            data::Vector::csptr vector = data::Vector::dynamicConstCast(activity->get(req.name));
             if(!vector)
             {
                 validation.first   = false;
@@ -82,7 +79,7 @@ const
             }
             else
             {
-                unsigned int nbObj = static_cast<unsigned int>(vector->size());
+                auto nbObj = static_cast<unsigned int>(vector->size());
                 if(nbObj < req.minOccurs)
                 {
                     validation.first   = false;
@@ -119,7 +116,10 @@ const
 
                     if(isValid)
                     {
-                        IValidator::ValidationType val = this->checkObject(vector, req.validator);
+                        IValidator::ValidationType val = sight::activity::IActivityValidator::checkObject(
+                            vector,
+                            req.validator
+                        );
                         if(!val.first)
                         {
                             validation.first   = false;
@@ -131,7 +131,7 @@ const
         }
         else // container == composite
         {
-            data::Composite::csptr currentComposite = composite->at<data::Composite>(req.name);
+            auto currentComposite = data::Composite::dynamicConstCast(activity->get(req.name));
             if(!currentComposite)
             {
                 validation.first   = false;
@@ -140,7 +140,7 @@ const
             }
             else
             {
-                unsigned int nbObj = static_cast<unsigned int>(currentComposite->size());
+                auto nbObj = static_cast<unsigned int>(currentComposite->size());
                 if(nbObj < req.minOccurs)
                 {
                     validation.first   = false;
@@ -157,13 +157,13 @@ const
                 {
                     bool isValid = true;
 
-                    for(auto elt : *currentComposite)
+                    for(const auto& elt : *currentComposite)
                     {
                         std::string key        = elt.first;
                         data::Object::sptr obj = elt.second;
                         activity::extension::ActivityRequirementKey reqKey;
                         bool keyIsFound = false;
-                        for(activity::extension::ActivityRequirementKey keyElt : req.keys)
+                        for(const activity::extension::ActivityRequirementKey& keyElt : req.keys)
                         {
                             if(key == keyElt.key)
                             {
@@ -197,7 +197,10 @@ const
 
                     if(isValid)
                     {
-                        IValidator::ValidationType val = this->checkObject(currentComposite, req.validator);
+                        IValidator::ValidationType val = sight::activity::IActivityValidator::checkObject(
+                            currentComposite,
+                            req.validator
+                        );
                         if(!val.first)
                         {
                             validation.first   = false;
@@ -217,7 +220,7 @@ const
 IValidator::ValidationType IActivityValidator::checkObject(
     const data::Object::csptr& object,
     const std::string& validatorImpl
-) const
+)
 {
     activity::IValidator::ValidationType validation;
     validation.first  = true;
