@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,8 +26,6 @@
 
 #include <core/BaseObject.hpp>
 #include <core/mt/types.hpp>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/EConfigurationElement.hpp>
 
 #include <boost/property_tree/ptree.hpp>
 
@@ -40,37 +38,33 @@ namespace sight
 namespace data
 {
 
-class ActivitySeries;
+class Activity;
 class Vector;
 
-}
+} // namespace data
 
 namespace core::runtime
 {
 
-struct Extension;
+class Extension;
 
-}
+} // namespace core::runtime
 
-namespace activity
+namespace activity::extension
 {
 
-namespace extension
-{
-
-typedef boost::property_tree::ptree ConfigType;
+using ConfigType = boost::property_tree::ptree;
 
 struct ACTIVITY_CLASS_API ActivityAppConfigParam
 {
     ActivityAppConfigParam()
-    {
-    }
+    = default;
 
     ACTIVITY_API ActivityAppConfigParam(const ConfigType& config);
 
     //------------------------------------------------------------------------------
 
-    bool isObjectPath() const
+    [[nodiscard]] bool isObjectPath() const
     {
         return (by.substr(0, 1) == "@") || (by.substr(0, 1) == "!");
     }
@@ -84,8 +78,7 @@ using ActivityAppConfigParamsType = std::vector<ActivityAppConfigParam>;
 struct ACTIVITY_CLASS_API ActivityAppConfig
 {
     ActivityAppConfig()
-    {
-    }
+    = default;
 
     ACTIVITY_API ActivityAppConfig(const ConfigType& config);
 
@@ -96,8 +89,7 @@ struct ACTIVITY_CLASS_API ActivityAppConfig
 struct ACTIVITY_CLASS_API ActivityRequirementKey
 {
     ActivityRequirementKey()
-    {
-    }
+    = default;
 
     ACTIVITY_API ActivityRequirementKey(const ConfigType& config);
 
@@ -107,23 +99,44 @@ struct ACTIVITY_CLASS_API ActivityRequirementKey
 struct ACTIVITY_CLASS_API ActivityRequirement
 {
     ActivityRequirement()
-    {
-    }
+    = default;
 
     ACTIVITY_API ActivityRequirement(const ConfigType& config);
 
     typedef std::vector<ActivityRequirementKey> KeyType;
 
-    std::string name;        /// parameter name
-    std::string type;        /// parameter type (ie. data::ImageSeries)
-    std::string container;   /// data container if maxOccurs > 1 ("vector" or "composite", default: "composite")
-    std::string description; /// parameter description
-    std::string validator;   /// Implementation of data validator
-    unsigned int minOccurs;  /// minimum number of data required
-    unsigned int maxOccurs;  /// maximum number of data required
-    bool create;             /// True if the data must be created if it is not present (only if minOccurs = 0 and
-                             /// maxOccurs = 1)
-    KeyType keys;            /// Parameter key if the container == "composite"
+    /// parameter name
+    std::string name;
+
+    /// parameter type (ie. data::ImageSeries)
+    std::string type;
+
+    /// data container if maxOccurs > 1 ("vector" or "composite", default: "composite")
+    std::string container;
+
+    /// parameter description
+    std::string description;
+
+    /// Implementation of data validator
+    std::string validator;
+
+    /// minimum number of data required
+    unsigned int minOccurs {};
+
+    /// maximum number of data required
+    unsigned int maxOccurs {};
+
+    /// True if the data must be created if it is not present (only if minOccurs = 0 and maxOccurs = 1)
+    bool create {};
+
+    /// True if data must be reset before activity launch (only if the data has been created by the activity)
+    bool reset {};
+
+    /// Parameter key if the container == "composite"
+    KeyType keys;
+
+    /// Child configuration, used for instance when invoking object parsers
+    ConfigType objectConfig;
 };
 
 /**
@@ -137,7 +150,7 @@ struct ACTIVITY_CLASS_API ActivityRequirement
  * - \b icon : path to the icon activity
  * - \b requirements : required elements to launch specified activity (must be present in vector selection)
  *   - \b requirement : a required element
- *     - \b name : element key in ActivitySeries composite
+ *     - \b name : element key in Activity composite
  *     - \b type : object type
  *     - \b minOccurs (optional, default value = 1) : minimal number of object (with specified type) in vector
  *     - \b maxOccurs (optional, default value = 1) : maximal number of object (with specified type) in vector
@@ -146,10 +159,13 @@ struct ACTIVITY_CLASS_API ActivityRequirement
  *       parameters
  *     - \b create (optional) : true if the data must be created if it is not present (only available if minOccurs = 0
  *       and maxOccurs = 1)
+ *     - \b reset (optional) : true if the data must be reset if the activity is reloaded (only available if
+ *                             create = true or minOccurs = 0)
+ *       and maxOccurs = 1)
  *     - \b desc (optional) : description of the requirement
  *     - \b validator (optional) : validate the current data
- * - \b builder (optional): implementation of builder associate to the activity, the builder creates ActivitySeries.
- *   - default builder is activity::builder::ActivitySeries
+ * - \b builder (optional): implementation of builder associate to the activity, the builder creates Activity.
+ *   - default builder is activity::builder::Activity
  * - \b validator (optional): check if specified activity can be launched with selected objects
  * - \b validators (optional) : defines validators implementations instantiated to validate activity launch
  *   -  \b validator : implementation name for a validator
@@ -185,7 +201,7 @@ struct ACTIVITY_CLASS_API ActivityRequirement
  * create="true" />
             <!--# ...-->
         </requirements>
-        <builder>activity::builder::ActivitySeries</builder>
+        <builder>activity::builder::Activity</builder>
         <validators>
             <validator>activity::validator::RelatedStudy</validator>
         </validators>
@@ -206,12 +222,11 @@ struct ACTIVITY_CLASS_API ActivityInfo
     typedef std::map<std::string, unsigned int> DataCountType;
 
     ActivityInfo()
-    {
-    }
+    = default;
 
     ACTIVITY_API ActivityInfo(const SPTR(core::runtime::Extension)& ext);
 
-    ACTIVITY_API bool usableWith(DataCountType dataCount) const;
+    [[nodiscard]] ACTIVITY_API bool usableWith(DataCountType dataCount) const;
 
     std::string id;
     std::string title;
@@ -250,7 +265,7 @@ public:
     ACTIVITY_API static Activity::sptr getDefault();
 
     /// Destructor
-    ACTIVITY_API virtual ~Activity();
+    ACTIVITY_API ~Activity() override;
 
     /**
      * @brief Parse module information to retrieve config parameters declaration
@@ -264,7 +279,7 @@ public:
      * @brief Get the parameters associated to extension id.
      * @note This method is thread safe.
      **/
-    ACTIVITY_API const ActivityInfo getInfo(const std::string& extensionId) const;
+    ACTIVITY_API ActivityInfo getInfo(const std::string& extensionId) const;
 
     /**
      * @brief Tests if we have information about operator
@@ -275,7 +290,7 @@ public:
     /**
      * @brief Get the number of vector objects in the same type.
      */
-    ACTIVITY_API ActivityInfo::DataCountType getDataCount(const CSPTR(data::Vector)& data) const;
+    static ACTIVITY_API ActivityInfo::DataCountType getDataCount(const CSPTR(data::Vector)& data);
 
     /**
      * @brief Get all infos
@@ -302,15 +317,15 @@ public:
     ACTIVITY_API void clearRegistry();
 
     ACTIVITY_API std::tuple<ActivityInfo, std::map<std::string, std::string> > getInfoAndReplacementMap(
-        const data::ActivitySeries& activitySeries,
+        const data::Activity& activity,
         const ActivityAppConfigParamsType& parameters = ActivityAppConfigParamsType()
     ) const;
 
-    ACTIVITY_API std::map<std::string, std::string> getReplacementMap(
-        const data::ActivitySeries& activitySeries,
+    static ACTIVITY_API std::map<std::string, std::string> getReplacementMap(
+        const data::Activity& activity,
         const ActivityInfo& info,
         const ActivityAppConfigParamsType& parameters = ActivityAppConfigParamsType()
-    ) const;
+    );
 
 protected:
 
@@ -329,8 +344,6 @@ protected:
     static Activity::sptr s_activity;
 };
 
-} // namespace extension
-
-} // namespace activity
+} // namespace activity::extension
 
 } // namespace sight
