@@ -24,9 +24,8 @@
 
 #include <activity/extension/Activity.hpp>
 
-#include <core/runtime/Extension.hpp>
-#include <core/runtime/Module.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
 #include <data/Image.hpp>
 #include <data/ImageSeries.hpp>
@@ -39,10 +38,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::activity::ut::ActivityRegistryTest);
 
-namespace sight::activity
-{
-
-namespace ut
+namespace sight::activity::ut
 {
 
 struct ActivityRegistryTestPimpl
@@ -77,7 +73,7 @@ void ActivityRegistryTest::tearDown()
 
 //------------------------------------------------------------------------------
 
-struct activities_less_than_key
+struct ActivitiesLessThanKey
 {
     //------------------------------------------------------------------------------
 
@@ -98,9 +94,9 @@ void ActivityRegistryTest::registryTest()
     activity::extension::Activity::ActivitiesType activities;
 
     // 1 image
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(4), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry1"), activities.at(0).id);
@@ -109,9 +105,9 @@ void ActivityRegistryTest::registryTest()
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry7"), activities.at(3).id);
 
     // 2 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(3), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry3"), activities.at(0).id);
@@ -119,92 +115,92 @@ void ActivityRegistryTest::registryTest()
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry6"), activities.at(2).id);
 
     // 3 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(1), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
 
     // 4 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry5"), activities.at(1).id);
 
     // 5 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry5"), activities.at(1).id);
 
     // 6 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry5"), activities.at(1).id);
 
     // 7 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry5"), activities.at(1).id);
 
     // 8 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry5"), activities.at(1).id);
 
     // 9 images
-    v->getContainer().push_back(data::Image::New());
+    v->push_back(data::Image::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(1), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry4"), activities.at(0).id);
 
     // 9 images, 1 mesh
-    v->getContainer().push_back(data::Mesh::New());
+    v->push_back(data::Mesh::New());
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(0), activities.size());
 
     // 1 images, 1 mesh
-    v->getContainer().clear();
-    v->getContainer().push_back(data::Image::New());
-    v->getContainer().push_back(data::Mesh::New());
+    v->clear();
+    v->push_back(data::Image::New());
+    v->push_back(data::Mesh::New());
 
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), activities.size());
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry2"), activities.at(0).id);
     CPPUNIT_ASSERT_EQUAL(std::string("TestRegistry7"), activities.at(1).id);
 
     // 1 images, 2 mesh, 1 ImageSeries, 1 ModelSeries
-    v->getContainer().push_back(data::Mesh::New());
-    v->getContainer().push_back(data::ImageSeries::New());
-    v->getContainer().push_back(data::ModelSeries::New());
+    v->push_back(data::Mesh::New());
+    v->push_back(data::ImageSeries::New());
+    v->push_back(data::ModelSeries::New());
 
     activities = m_pimpl->activities->getInfos(v);
-    std::sort(activities.begin(), activities.end(), activities_less_than_key());
+    std::sort(activities.begin(), activities.end(), ActivitiesLessThanKey());
 
     CPPUNIT_ASSERT_EQUAL(std::size_t(1), activities.size());
     const activity::extension::ActivityInfo& info = activities[0];
@@ -216,6 +212,4 @@ void ActivityRegistryTest::registryTest()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::activity
+} // namespace sight::activity::ut
