@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,11 +26,10 @@
 #include <activity/IActivityValidator.hpp>
 #include <activity/IValidator.hpp>
 
-#include <core/runtime/Extension.hpp>
-#include <core/runtime/Module.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
-#include <data/ActivitySeries.hpp>
+#include <data/Activity.hpp>
 #include <data/Boolean.hpp>
 #include <data/Composite.hpp>
 #include <data/Float.hpp>
@@ -49,10 +48,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::activity::ut::DefaultActivityTest);
 
-namespace sight::activity
-{
-
-namespace ut
+namespace sight::activity::ut
 {
 
 //------------------------------------------------------------------------------
@@ -86,14 +82,11 @@ void DefaultActivityTest::requirementsTest()
         activity::IActivityValidator::dynamicCast(validator);
     CPPUNIT_ASSERT(activityValidator);
 
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::New();
-    activitySeries->setActivityConfigId("TestValidator0");
+    data::Activity::sptr activity = data::Activity::New();
+    activity->setActivityConfigId("TestValidator0");
 
     activity::IValidator::ValidationType validation;
 
-    data::Composite::sptr data = data::Composite::New();
-    activitySeries->setData(data);
-
     data::ImageSeries::sptr imageSeries  = data::ImageSeries::New();
     data::ImageSeries::sptr imageSeries2 = data::ImageSeries::New();
     data::ModelSeries::sptr modelSeries  = data::ModelSeries::New();
@@ -103,21 +96,21 @@ void DefaultActivityTest::requirementsTest()
 
     {
         // Empty data should NOT be valid
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Empty data should NOT be valid", false, validation.first);
     }
     {
         // data with only an image should NOT be valid
-        (*data)["imageSeries"] = imageSeries;
+        (*activity)["imageSeries"] = imageSeries;
 
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("data with only an image should NOT be valid", false, validation.first);
     }
     {
         // data with an image and an empty model composite should be valid
-        (*data)["modelSeries"] = modelCompo;
+        (*activity)["modelSeries"] = modelCompo;
 
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and an empty model composite should be valid",
             true,
@@ -128,7 +121,7 @@ void DefaultActivityTest::requirementsTest()
         // data with an image and a model in the composite should be valid
         (*modelCompo)["key1"] = modelSeries;
 
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and a model in the composite should be valid",
             true,
@@ -139,7 +132,7 @@ void DefaultActivityTest::requirementsTest()
         // data with an image and two models in the composite should be valid
         (*modelCompo)["key2"] = modelSeries2;
 
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and two models in the composite should be valid",
             true,
@@ -150,7 +143,7 @@ void DefaultActivityTest::requirementsTest()
         // data with an image and 3 models in the composite should NOT be valid
         (*modelCompo)["key3"] = modelSeries2;
 
-        validation = activityValidator->checkRequirements(activitySeries);
+        validation = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and 3 models in the composite should NOT be valid",
             false,
@@ -159,9 +152,9 @@ void DefaultActivityTest::requirementsTest()
     }
     {
         // data with an image and an image in the model composite should NOT be valid
-        modelCompo->getContainer().erase("key3");
+        modelCompo->erase("key3");
         (*modelCompo)["key2"] = imageSeries;
-        validation            = activityValidator->checkRequirements(activitySeries);
+        validation            = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and an image in the model composite should NOT be valid",
             false,
@@ -170,9 +163,9 @@ void DefaultActivityTest::requirementsTest()
     }
     {
         // data with a null image and a model in the composite should NOT be valid
-        modelCompo->getContainer().erase("key2");
-        (*data)["imageSeries"] = nullptr;
-        validation             = activityValidator->checkRequirements(activitySeries);
+        modelCompo->erase("key2");
+        (*activity)["imageSeries"] = nullptr;
+        validation                 = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with a null image and a model in the composite should NOT be valid",
             false,
@@ -181,9 +174,9 @@ void DefaultActivityTest::requirementsTest()
     }
     {
         // data with a null image and a wrong key in the model composite should NOT be valid
-        (*modelCompo)["myKey"] = modelSeries2;
-        (*data)["imageSeries"] = imageSeries;
-        validation             = activityValidator->checkRequirements(activitySeries);
+        (*modelCompo)["myKey"]     = modelSeries2;
+        (*activity)["imageSeries"] = imageSeries;
+        validation                 = activityValidator->checkRequirements(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with a null image and a wrong key in the model composite should NOT be valid",
             false,
@@ -209,7 +202,7 @@ void DefaultActivityTest::objectTest()
     data::Image::sptr img1 = data::Image::New();
     data::Image::sptr img2 = data::Image::New();
     data::Image::sptr img3 = data::Image::New();
-    utestData::generator::Image::generateRandomImage(img1, core::tools::Type::create<std::uint8_t>());
+    utestData::generator::Image::generateRandomImage(img1, core::Type::UINT8);
     utestData::generator::Image::generateImage(
         img2,
         img1->getSize(),
@@ -218,15 +211,15 @@ void DefaultActivityTest::objectTest()
         img1->getType(),
         data::Image::PixelFormat::GRAY_SCALE
     );
-    utestData::generator::Image::generateRandomImage(img3, core::tools::Type::create<std::uint8_t>());
+    utestData::generator::Image::generateRandomImage(img3, core::Type::UINT8);
 
     data::Vector::sptr vector = data::Vector::New();
-    vector->getContainer().push_back(img1);
-    vector->getContainer().push_back(img2);
+    vector->push_back(img1);
+    vector->push_back(img2);
 
     data::Vector::sptr vector2 = data::Vector::New();
-    vector2->getContainer().push_back(img1);
-    vector2->getContainer().push_back(img3);
+    vector2->push_back(img1);
+    vector2->push_back(img3);
 
     {
         // An empty validator implementation should be valid
@@ -274,14 +267,11 @@ void DefaultActivityTest::validatorTest()
         activity::IActivityValidator::dynamicCast(validator);
     CPPUNIT_ASSERT(activityValidator);
 
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::New();
-    activitySeries->setActivityConfigId("TestValidator0");
+    data::Activity::sptr activity = data::Activity::New();
+    activity->setActivityConfigId("TestValidator0");
 
     activity::IValidator::ValidationType validation;
 
-    data::Composite::sptr data = data::Composite::New();
-    activitySeries->setData(data);
-
     data::ImageSeries::sptr imageSeries  = data::ImageSeries::New();
     data::ImageSeries::sptr imageSeries2 = data::ImageSeries::New();
     data::ModelSeries::sptr modelSeries  = data::ModelSeries::New();
@@ -289,27 +279,25 @@ void DefaultActivityTest::validatorTest()
     data::ModelSeries::sptr modelSeries3 = data::ModelSeries::New();
     data::Composite::sptr modelCompo     = data::Composite::New();
 
-    data::Image::sptr img = data::Image::New();
-    utestData::generator::Image::generateRandomImage(img, core::tools::Type::create<std::uint8_t>());
-    imageSeries->setImage(img);
+    utestData::generator::Image::generateRandomImage(imageSeries, core::Type::UINT8);
 
     {
         // Empty data should NOT be valid
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Empty data should NOT be valid", false, validation.first);
     }
     {
         // data with only an image should NOT be valid
-        (*data)["imageSeries"] = imageSeries;
+        (*activity)["imageSeries"] = imageSeries;
 
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("data with only an image should NOT be valid", false, validation.first);
     }
     {
         // data with an image and an empty model composite should be valid
-        (*data)["modelSeries"] = modelCompo;
+        (*activity)["modelSeries"] = modelCompo;
 
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and an empty model composite should be valid",
             true,
@@ -320,7 +308,7 @@ void DefaultActivityTest::validatorTest()
         // data with an image and a model in the composite should be valid
         (*modelCompo)["key1"] = modelSeries;
 
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and a model in the composite should be valid",
             true,
@@ -331,7 +319,7 @@ void DefaultActivityTest::validatorTest()
         // data with an image and two models in the composite should be valid
         (*modelCompo)["key2"] = modelSeries2;
 
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and two models in the composite should be valid",
             true,
@@ -342,7 +330,7 @@ void DefaultActivityTest::validatorTest()
         // data with an image and 3 models in the composite should NOT be valid
         (*modelCompo)["key3"] = modelSeries2;
 
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and 3 models in the composite should NOT be valid",
             false,
@@ -351,9 +339,9 @@ void DefaultActivityTest::validatorTest()
     }
     {
         // data with an image and an image in the model composite should NOT be valid
-        modelCompo->getContainer().erase("key3");
+        modelCompo->erase("key3");
         (*modelCompo)["key2"] = imageSeries;
-        validation            = activityValidator->validate(activitySeries);
+        validation            = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with an image and an image in the model composite should NOT be valid",
             false,
@@ -362,9 +350,9 @@ void DefaultActivityTest::validatorTest()
     }
     {
         // data with a null image and a model in the composite should NOT be valid
-        modelCompo->getContainer().erase("key2");
-        (*data)["imageSeries"] = nullptr;
-        validation             = activityValidator->validate(activitySeries);
+        modelCompo->erase("key2");
+        (*activity)["imageSeries"] = nullptr;
+        validation                 = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with a null image and a model in the composite should NOT be valid",
             false,
@@ -373,9 +361,9 @@ void DefaultActivityTest::validatorTest()
     }
     {
         // data with a null image and a wrong key in the model composite should NOT be valid
-        (*modelCompo)["myKey"] = modelSeries2;
-        (*data)["imageSeries"] = imageSeries;
-        validation             = activityValidator->validate(activitySeries);
+        (*modelCompo)["myKey"]     = modelSeries2;
+        (*activity)["imageSeries"] = imageSeries;
+        validation                 = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "data with a null image and a wrong key in the model composite should NOT be valid",
             false,
@@ -396,14 +384,11 @@ void DefaultActivityTest::bigActivityTest()
         activity::IActivityValidator::dynamicCast(validator);
     CPPUNIT_ASSERT(activityValidator);
 
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::New();
-    activitySeries->setActivityConfigId("TestValidator1");
+    data::Activity::sptr activity = data::Activity::New();
+    activity->setActivityConfigId("TestValidator1");
 
     activity::IValidator::ValidationType validation;
 
-    data::Composite::sptr data = data::Composite::New();
-    activitySeries->setData(data);
-
     data::ImageSeries::sptr imageSeries1 = data::ImageSeries::New();
     data::ImageSeries::sptr imageSeries2 = data::ImageSeries::New();
     data::ImageSeries::sptr imageSeries3 = data::ImageSeries::New();
@@ -426,81 +411,73 @@ void DefaultActivityTest::bigActivityTest()
     data::Vector::sptr modelVector = data::Vector::New();
     data::Vector::sptr imageVector = data::Vector::New();
 
-    data::Image::sptr img1 = data::Image::New();
-    data::Image::sptr img2 = data::Image::New();
-    data::Image::sptr img3 = data::Image::New();
-    utestData::generator::Image::generateRandomImage(img1, core::tools::Type::create<std::uint8_t>());
-    utestData::generator::Image::generateRandomImage(img2, core::tools::Type::create<std::uint8_t>());
+    utestData::generator::Image::generateRandomImage(imageSeries1, core::Type::UINT8);
+    utestData::generator::Image::generateRandomImage(imageSeries2, core::Type::UINT8);
     utestData::generator::Image::generateImage(
-        img3,
-        img2->getSize(),
-        img2->getSpacing(),
-        img2->getOrigin(),
-        img2->getType(),
+        imageSeries3,
+        imageSeries2->getSize(),
+        imageSeries2->getSpacing(),
+        imageSeries2->getOrigin(),
+        imageSeries2->getType(),
         data::Image::PixelFormat::GRAY_SCALE
     );
-    imageSeries1->setImage(img1);
-    imageSeries2->setImage(img2);
-    imageSeries3->setImage(img3);
 
-    modelVector->getContainer().push_back(modelSeries2);
-    modelVector->getContainer().push_back(modelSeries3);
-    imageVector->getContainer().push_back(imageSeries2);
-    imageVector->getContainer().push_back(imageSeries3);
+    modelVector->push_back(modelSeries2);
+    modelVector->push_back(modelSeries3);
+    imageVector->push_back(imageSeries2);
+    imageVector->push_back(imageSeries3);
 
-    (*data)["imageSeries"]          = imageSeries1;
-    (*data)["modelSeries"]          = modelSeries1;
-    (*data)["vectorImage"]          = imageVector;
-    (*data)["vectorModel"]          = modelVector;
-    (*data)["transformationMatrix"] = matrix;
-    (*data)["float"]                = floatObj;
-    (*data)["int"]                  = intObj;
-    (*data)["boolean"]              = boolObj;
-    (*data)["String"]               = compoStr;
+    (*activity)["imageSeries"]          = imageSeries1;
+    (*activity)["modelSeries"]          = modelSeries1;
+    (*activity)["vectorImage"]          = imageVector;
+    (*activity)["vectorModel"]          = modelVector;
+    (*activity)["transformationMatrix"] = matrix;
+    (*activity)["float"]                = floatObj;
+    (*activity)["int"]                  = intObj;
+    (*activity)["boolean"]              = boolObj;
+    (*activity)["String"]               = compoStr;
 
     {
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Activity with correct data should be valid", true, validation.first);
     }
     {
-        data->getContainer().erase("int");
-        validation = activityValidator->validate(activitySeries);
+        activity->erase("int");
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "Activity without an autogenerated data should NOT be valid",
             false,
             validation.first
         );
-        (*data)["int"] = intObj;
+        (*activity)["int"] = intObj;
     }
     {
-        data->getContainer().erase("transformationMatrix");
-        validation = activityValidator->validate(activitySeries);
+        activity->erase("transformationMatrix");
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "Activity without an autocreated data should NOT be valid",
             false,
             validation.first
         );
-        (*data)["transformationMatrix"] = matrix;
+        (*activity)["transformationMatrix"] = matrix;
     }
     {
-        validation = activityValidator->validate(activitySeries);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE("Activity with correct data should be valid", true, validation.first);
     }
     {
         const data::Image::Spacing spacing = {45., 45., 45.};
-        img3->setSpacing(spacing);
-        validation = activityValidator->validate(activitySeries);
+        imageSeries3->setSpacing(spacing);
+        validation = activityValidator->validate(activity);
         CPPUNIT_ASSERT_EQUAL_MESSAGE(
             "Activity with different image properties data should NOT be valid",
             false,
             validation.first
         );
-        img3->setSpacing(img2->getSpacing());
+        imageSeries3->setSpacing(imageSeries2->getSpacing());
     }
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::activity
+} // namespace sight::activity::ut
