@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2021 IRCAD France
+ * Copyright (C) 2016-2022 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,7 +29,7 @@
 #include <core/runtime/Extension.hpp>
 #include <core/runtime/Module.hpp>
 
-#include <data/ActivitySeries.hpp>
+#include <data/Activity.hpp>
 #include <data/Composite.hpp>
 #include <data/ImageSeries.hpp>
 #include <data/ModelSeries.hpp>
@@ -42,10 +42,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::activity::ut::ImagePropertiesTest);
 
-namespace sight::activity
-{
-
-namespace ut
+namespace sight::activity::ut
 {
 
 //------------------------------------------------------------------------------
@@ -64,6 +61,18 @@ void ImagePropertiesTest::tearDown()
 
 //------------------------------------------------------------------------------
 
+static data::ImageSeries::sptr imageToImageSeries(const data::Object::sptr& obj)
+{
+    auto img = data::Image::dynamicCast(obj);
+    auto res = data::ImageSeries::New();
+    res->resize(img->getSize(), img->getType(), img->getPixelFormat());
+    res->setSpacing(img->getSpacing());
+    res->setOrigin(img->getOrigin());
+    return res;
+}
+
+//------------------------------------------------------------------------------
+
 void ImagePropertiesTest::propertiesTest()
 {
     activity::IValidator::sptr validator =
@@ -76,12 +85,12 @@ void ImagePropertiesTest::propertiesTest()
     {
         data::Image::sptr img1 = data::Image::New();
         data::Image::sptr img2 = data::Image::New();
-        utestData::generator::Image::generateRandomImage(img1, core::tools::Type::create<std::uint8_t>());
-        utestData::generator::Image::generateRandomImage(img2, core::tools::Type::create<std::uint8_t>());
+        utestData::generator::Image::generateRandomImage(img1, core::Type::UINT8);
+        utestData::generator::Image::generateRandomImage(img2, core::Type::UINT8);
 
         data::Vector::sptr vector = data::Vector::New();
-        vector->getContainer().push_back(img1);
-        vector->getContainer().push_back(img2);
+        vector->push_back(img1);
+        vector->push_back(img2);
 
         activity::IValidator::ValidationType validation;
 
@@ -92,7 +101,12 @@ void ImagePropertiesTest::propertiesTest()
         (*composite)["img1"] = img1;
         (*composite)["img2"] = img2;
 
-        validation = objValidator->validate(vector);
+        validation = objValidator->validate(composite);
+        CPPUNIT_ASSERT_EQUAL(false, validation.first);
+
+        auto seriesVector = data::Vector::New();
+        std::ranges::transform(*vector, std::back_inserter(*seriesVector), imageToImageSeries);
+        validation = objValidator->validate(activity::extension::ActivityInfo {}, seriesVector);
         CPPUNIT_ASSERT_EQUAL(false, validation.first);
     }
 
@@ -100,7 +114,7 @@ void ImagePropertiesTest::propertiesTest()
         data::Image::sptr img1 = data::Image::New();
         data::Image::sptr img2 = data::Image::New();
 
-        utestData::generator::Image::generateRandomImage(img1, core::tools::Type::create<std::uint8_t>());
+        utestData::generator::Image::generateRandomImage(img1, core::Type::UINT8);
 
         utestData::generator::Image::generateImage(
             img2,
@@ -112,8 +126,8 @@ void ImagePropertiesTest::propertiesTest()
         );
 
         data::Vector::sptr vector = data::Vector::New();
-        vector->getContainer().push_back(img1);
-        vector->getContainer().push_back(img2);
+        vector->push_back(img1);
+        vector->push_back(img2);
 
         activity::IValidator::ValidationType validation;
 
@@ -124,13 +138,16 @@ void ImagePropertiesTest::propertiesTest()
         (*composite)["img1"] = img1;
         (*composite)["img2"] = img2;
 
-        validation = objValidator->validate(vector);
+        validation = objValidator->validate(composite);
+        CPPUNIT_ASSERT_EQUAL(true, validation.first);
+
+        auto seriesVector = data::Vector::New();
+        std::ranges::transform(*vector, std::back_inserter(*seriesVector), imageToImageSeries);
+        validation = objValidator->validate(activity::extension::ActivityInfo {}, seriesVector);
         CPPUNIT_ASSERT_EQUAL(true, validation.first);
     }
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::activity
+} // namespace sight::activity::ut
