@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,32 +29,28 @@
 #include <data/ImageSeries.hpp>
 #include <data/Vector.hpp>
 
-namespace sight::activity
+namespace sight::activity::validator
 {
 
-namespace validator
-{
-
-fwActivitiesValidatorRegisterMacro(sight::activity::validator::ImageProperties);
+SIGHT_REGISTER_ACTIVITY_VALIDATOR(sight::activity::validator::ImageProperties);
 
 auto fCompare = [](double a, double b){return std::abs(a - b) < 0.00001;};
 
 //-----------------------------------------------------------------------------
 
-ImageProperties::ImageProperties(activity::IValidator::Key)
+ImageProperties::ImageProperties(activity::IValidator::Key /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
 ImageProperties::~ImageProperties()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 IValidator::ValidationType ImageProperties::validate(
-    const activity::extension::ActivityInfo&,
+    const activity::extension::ActivityInfo& /*unused*/,
     const data::Vector::csptr& currentSelection
 ) const
 {
@@ -67,29 +63,25 @@ IValidator::ValidationType ImageProperties::validate(
 
         data::ImageSeries::sptr imgSeries0 = data::ImageSeries::dynamicCast((*currentSelection)[0]);
         SIGHT_ASSERT("Failed to retrieve an image series", imgSeries0);
-        data::Image::sptr img0 = imgSeries0->getImage();
-        SIGHT_ASSERT("Failed to retrieve image from image series", img0);
 
-        data::Image::Size size       = img0->getSize();
-        data::Image::Spacing spacing = img0->getSpacing();
-        data::Image::Origin origin   = img0->getOrigin();
+        data::Image::Size size       = imgSeries0->getSize();
+        data::Image::Spacing spacing = imgSeries0->getSpacing();
+        data::Image::Origin origin   = imgSeries0->getOrigin();
 
-        data::Vector::ContainerType::const_iterator it;
+        data::Vector::container_type::const_iterator it;
         for(it = currentSelection->begin() + 1 ; it != currentSelection->end() ; ++it)
         {
             data::ImageSeries::sptr imgSeries = data::ImageSeries::dynamicCast(*it);
             SIGHT_ASSERT("Failed to retrieve an image series", imgSeries);
-            data::Image::sptr img = imgSeries->getImage();
-            SIGHT_ASSERT("Failed to retrieve an image data", img);
 
-            if(size != img->getSize()
-               || !std::equal(spacing.begin(), spacing.end(), img->getSpacing().begin(), fCompare)
-               || !std::equal(origin.begin(), origin.end(), img->getOrigin().begin(), fCompare))
+            if(size != imgSeries->getSize()
+               || !std::equal(spacing.begin(), spacing.end(), imgSeries->getSpacing().begin(), fCompare)
+               || !std::equal(origin.begin(), origin.end(), imgSeries->getOrigin().begin(), fCompare))
             {
                 std::string errorMsg = "Images in selection have not the same properties :\n";
-                errorMsg += (size != img->getSize()) ? "- size\n" : "";
-                errorMsg += (spacing != img->getSpacing()) ? "- spacing\n" : "";
-                errorMsg += (origin != img->getOrigin()) ? "- origin" : "";
+                errorMsg += (size != imgSeries->getSize()) ? "- size\n" : "";
+                errorMsg += (spacing != imgSeries->getSpacing()) ? "- spacing\n" : "";
+                errorMsg += (origin != imgSeries->getOrigin()) ? "- origin" : "";
 
                 validation.first  = false;
                 validation.second = errorMsg;
@@ -123,14 +115,9 @@ IValidator::ValidationType ImageProperties::validate(const data::Object::csptr&
 
     if(vector)
     {
-        for(data::Object::sptr obj : *vector)
+        for(const data::Object::sptr& obj : *vector)
         {
-            data::ImageSeries::csptr imgSeries = data::ImageSeries::dynamicConstCast(obj);
-            data::Image::csptr img             = data::Image::dynamicConstCast(obj);
-            if(imgSeries)
-            {
-                img = imgSeries->getImage();
-            }
+            const auto img = data::Image::dynamicConstCast(obj);
 
             if(img)
             {
@@ -167,14 +154,9 @@ IValidator::ValidationType ImageProperties::validate(const data::Object::csptr&
     }
     else if(composite)
     {
-        for(auto elt : *composite)
+        for(const auto& elt : *composite)
         {
-            data::ImageSeries::sptr imgSeries = data::ImageSeries::dynamicCast(elt.second);
-            data::Image::sptr img             = data::Image::dynamicCast(elt.second);
-            if(imgSeries)
-            {
-                img = imgSeries->getImage();
-            }
+            const auto img = data::Image::dynamicCast(elt.second);
 
             if(img)
             {
@@ -220,6 +202,4 @@ IValidator::ValidationType ImageProperties::validate(const data::Object::csptr&
 
 //-----------------------------------------------------------------------------
 
-} // namespace validator
-
-} // namespace sight::activity
+} // namespace sight::activity::validator
