@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2022 IRCAD France
  * Copyright (C) 2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,8 +28,7 @@ namespace sight::core
 //-----------------------------------------------------------------------------
 
 BaseObject::~BaseObject()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
