@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,37 +20,18 @@
  *
  ***********************************************************************/
 
-#ifdef DEBUG
-#include "core/spyLog.hpp"
-#endif
+#include "core/com/Signals.hpp"
 
 #include "core/com/SignalBase.hpp"
-#include "core/com/Signals.hpp"
 
 namespace sight::core::com
 {
 
-Signals::Signals()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-Signals::~Signals()
-{
-#if 0
-    for(SignalMapType::value_type elem : m_signals)
-    {
-        SIGHT_ASSERT("Signal '" << elem.first << "' has connected slots", elem.second->numConnections() == 0);
-    }
-#endif
-}
-
 //-----------------------------------------------------------------------------
 
 Signals& Signals::operator()(const SignalKeyType& key, const SignalBase::sptr& Signal)
 {
-    m_signals.insert(SignalMapType::value_type(key, Signal));
+    m_signals.insert({key, Signal});
     return *this;
 }
 
@@ -58,14 +39,14 @@ Signals& Signals::operator()(const SignalKeyType& key, const SignalBase::sptr& S
 
 SignalBase::sptr Signals::operator[](const SignalKeyType& key) const
 {
-    SignalMapType::const_iterator it = m_signals.find(key);
+    auto it = m_signals.find(key);
 
     if(it != m_signals.end())
     {
         return it->second;
     }
 
-    return SignalBase::sptr();
+    return {};
 }
 
 //-----------------------------------------------------------------------------
@@ -73,7 +54,7 @@ SignalBase::sptr Signals::operator[](const SignalKeyType& key) const
 Signals::SignalKeyContainerType Signals::getSignalKeys() const
 {
     Signals::SignalKeyContainerType SignalKeys;
-    for(SignalMapType::value_type elem : m_signals)
+    for(const auto& elem : m_signals)
     {
         SignalKeys.push_back(elem.first);
     }
@@ -83,17 +64,10 @@ Signals::SignalKeyContainerType Signals::getSignalKeys() const
 
 //-----------------------------------------------------------------------------
 
-Signals::Signals(const Signals&)
+Signals::Signals(const Signals& /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
-Signals& Signals::operator=(const Signals&)
-{
-    return *this;
-}
-
-//-----------------------------------------------------------------------------
-
 } // namespace sight::core::com
