@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,32 +24,17 @@
 
 #include "core/com/Slot.hpp"
 #include "core/com/Slot.hxx"
+
 #include <core/thread/Worker.hpp>
 
 namespace sight::core::com
 {
 
-Slots::Slots()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-Slots::~Slots()
-{
-#if 0
-    for(SlotMapType::value_type elem : m_slots)
-    {
-        SIGHT_ASSERT("Slot '" << elem.first << "' has connected signals", elem.second->numConnections() == 0);
-    }
-#endif
-}
-
 //-----------------------------------------------------------------------------
 
 void Slots::setWorker(const core::thread::Worker::sptr& worker)
 {
-    for(SlotMapType::value_type elem : m_slots)
+    for(const auto& elem : m_slots)
     {
         elem.second->setWorker(worker);
     }
@@ -57,24 +42,24 @@ void Slots::setWorker(const core::thread::Worker::sptr& worker)
 
 //-----------------------------------------------------------------------------
 
-Slots& Slots::operator()(const SlotKeyType& key, const SlotBase::sptr& slot)
+Slots& Slots::operator()(const key_t& key, const SlotBase::sptr& slot)
 {
-    m_slots.insert(SlotMapType::value_type(key, slot));
+    m_slots.insert({key, slot});
     return *this;
 }
 
 //-----------------------------------------------------------------------------
 
-SlotBase::sptr Slots::operator[](const SlotKeyType& key) const
+SlotBase::sptr Slots::operator[](const key_t& key) const
 {
-    SlotMapType::const_iterator it = m_slots.find(key);
+    auto it = m_slots.find(key);
 
     if(it != m_slots.end())
     {
         return it->second;
     }
 
-    return SlotBase::sptr();
+    return {};
 }
 
 //-----------------------------------------------------------------------------
@@ -82,7 +67,7 @@ SlotBase::sptr Slots::operator[](const SlotKeyType& key) const
 Slots::SlotKeyContainerType Slots::getSlotKeys() const
 {
     Slots::SlotKeyContainerType slotKeys;
-    for(SlotMapType::value_type elem : m_slots)
+    for(const auto& elem : m_slots)
     {
         slotKeys.push_back(elem.first);
     }
@@ -92,17 +77,10 @@ Slots::SlotKeyContainerType Slots::getSlotKeys() const
 
 //-----------------------------------------------------------------------------
 
-Slots::Slots(const Slots&)
+Slots::Slots(const Slots& /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
-Slots& Slots::operator=(const Slots&)
-{
-    return *this;
-}
-
-//-----------------------------------------------------------------------------
-
 } // namespace sight::core::com
