@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -19,26 +19,20 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE Wclass memaccess
+
 #pragma once
 
 #include "core/config.hpp"
 
 #include <algorithm>
+#include <cstring>
 #include <memory>
 #include <string>
 
 namespace sight::core::crypto
 {
 
-/// Zeroes the pointed memory
-/// @param p memory address
-/// @param n length to zero
-inline void cleanse(void* p, std::size_t n) noexcept
-{
-    // "volatile" guard from unwanted optimization
-    std::fill_n(static_cast<volatile char*>(p), n, 0);
-}
-
 /// This class is an implementation of basic_string Allocator. Its main feature is secure deletion of allocated data
 /// See https://en.cppreference.com/w/cpp/named_req/Allocator
 template<typename T>
@@ -48,25 +42,25 @@ struct allocator
     using propagate_on_container_move_assignment =
         typename std::allocator_traits<std::allocator<T> >::propagate_on_container_move_assignment;
 
-    inline constexpr allocator() = default;
+    constexpr allocator() = default;
 
     template<class U>
-    inline constexpr allocator(const allocator<U>&) noexcept
+    constexpr allocator(const allocator<U>& /*unused*/) noexcept
     {
     }
 
     //------------------------------------------------------------------------------
 
-    inline constexpr static T* allocate(std::size_t n)
+    constexpr static T* allocate(std::size_t n)
     {
         return std::allocator<T> {}.allocate(n);
     }
 
     //------------------------------------------------------------------------------
 
-    inline static void deallocate(T* p, std::size_t n) noexcept
+    constexpr static void deallocate(T* p, std::size_t n) noexcept
     {
-        cleanse(p, n * sizeof(T));
+        std::fill_n(((volatile char*) p), sizeof(T) * n, static_cast<char>(0));
         std::allocator<T> {}.deallocate(p, n);
     }
 };
@@ -74,7 +68,7 @@ struct allocator
 //------------------------------------------------------------------------------
 
 template<typename T, typename U>
-inline constexpr bool operator==(allocator<T>, allocator<U>) noexcept
+constexpr bool operator==(allocator<T> /*unused*/, allocator<U> /*unused*/) noexcept
 {
     return true;
 }
@@ -82,20 +76,31 @@ inline constexpr bool operator==(allocator<T>, allocator<U>) noexcept
 //------------------------------------------------------------------------------
 
 template<typename T, typename U>
-inline constexpr bool operator!=(allocator<T>, allocator<U>) noexcept
+constexpr bool operator!=(allocator<T> /*unused*/, allocator<U> /*unused*/) noexcept
 {
     return false;
 }
 
 using secure_string = std::basic_string<char, std::char_traits<char>, allocator<char> >;
 
-} // sight::core::crypto
+} // namespace sight::core::crypto
 
 // Zeroes the strings own memory on destruction
 template<>
+#if defined(WIN32)
+constexpr sight::core::crypto::secure_string::~basic_string() noexcept
+#elif (_GLIBCXX_RELEASE >= 12)
+constexpr sight::core::crypto::secure_string::~basic_string()
+#else
 inline sight::core::crypto::secure_string::~basic_string()
+#endif
 {
     clear();
     shrink_to_fit();
-    sight::core::crypto::cleanse(this, sizeof(*this));
+
+    // The "metadata" of the container is cleansed here, not its content
+    volatile char* const p = (volatile char*) (this);
+
+    // NOLINTNEXTLINE(bugprone-sizeof-container)
+    std::fill_n(p, sizeof(*this), static_cast<char>(0));
 }
