@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -128,7 +128,7 @@ public:
      *
      * @param name The name of the job.
      */
-    CORE_API IJob(const std::string& name = "");
+    CORE_API IJob(std::string name = "");
 
     /// Default destructor.
     CORE_API virtual ~IJob();
@@ -175,7 +175,7 @@ public:
      *
      * @return A boolean: true if cancel have been requested.
      */
-    CORE_API const bool& cancelRequested() const;
+    CORE_API bool cancelRequested() const;
 
     /**
      * @brief Returns a callback on job canceling status.
@@ -250,9 +250,9 @@ protected:
      * @name Not implemented
      * @{ */
     IJob(IJob&);
-    IJob& operator=(IJob&);
-    IJob(IJob&&);
-    IJob& operator=(IJob&&);
+    IJob& operator=(const IJob&);
+    IJob(IJob&&) noexcept;
+    IJob& operator=(IJob&&) noexcept;
     /**  @} */
 
     /// Run an instantiated job
@@ -264,16 +264,6 @@ protected:
     /// Finish the job without mutex lock: set the state to finished or canceled.
     CORE_API void finishNoLock();
 
-    /**
-     * @brief Return callback to finish the job.
-     *
-     * @return A callback
-     */
-    // workaround because of vs2010 issue : http://goo.gl/WHEkQ5
-    // this is fixed in vs2012 : http://goo.gl/tvO3g7
-    // TODO : remove when compiler is up to date
-    CORE_API std::function<void()> finishCallback();
-
     /// Getter on the state without mutex lock
     CORE_API State getStateNoLock() const;
 
@@ -384,16 +374,16 @@ protected:
     Logs m_logs;
 
     /// Number of work units already reached.
-    std::uint64_t m_doneWorkUnits;
+    std::uint64_t m_doneWorkUnits {0};
 
     /// Number of work units to reach to complete the job.
-    std::uint64_t m_totalWorkUnits;
+    std::uint64_t m_totalWorkUnits {0};
 
     /// Determines if cancellation has been requested. The job is/will be canceling if true.
-    bool m_cancelRequested;
+    bool m_cancelRequested {false};
 
     /// Determines if the job can be cancelled. The job is cancelable if true.
-    bool m_cancelable;
+    bool m_cancelable {true};
 
     /// Container of cancel callbacks. Cancel callbacks will be run when job is canceling.
     CancelHookSeq m_cancelHooks;
@@ -414,7 +404,7 @@ protected:
     SharedFuture m_runFuture;
 
     /// Job's state
-    State m_state;
+    State m_state {WAITING};
 };
 
 } //namespace sight::core::jobs
