@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,17 +33,12 @@
 namespace sight::core::memory
 {
 
-namespace stream
-{
-
-namespace in
+namespace stream::in
 {
 
 class IFactory;
 
-}
-
-}
+} // namespace stream::in
 
 /**
  * @brief   Define Base class for Sight buffers
@@ -75,6 +70,12 @@ public:
     SIGHT_DECLARE_CLASS(BufferObject, core::BaseObject, new BufferObject);
     SIGHT_ALLOW_SHARED_FROM_THIS();
 
+    /// Returns a auto-deleted BufferObject
+    static sptr New(bool autoDelete)
+    {
+        return std::make_shared<BufferObject>(autoDelete);
+    }
+
     /// return the sub class classname : an alias of this->getClassname
     std::string className() const
     {
@@ -105,8 +106,14 @@ public:
 
         typedef typename std::conditional_t<std::is_const_v<T>, const void*, void*> BufferType;
 
-        LockBase()  = default;
-        ~LockBase() = default;
+        LockBase() = default;
+        inline ~LockBase()
+        {
+            // Resetting the counter in the destructor **BEFORE** resetting BufferObject shared pointer is required !
+            // Otherwise, the lock count assert in the destruction of the buffer, in
+            // BufferManager::::unregisterBufferImpl() will be triggered.
+            m_count.reset();
+        }
 
         /**
          * @brief Build a lock on object 'bo'
@@ -116,12 +123,13 @@ public:
          * @param bo BufferObject to lock
          */
         LockBase(const SPTR(T)& bo) :
+            m_count(bo->m_count.lock()),
             m_bufferObject(bo)
         {
             SIGHT_ASSERT("Can't lock NULL object", bo);
 
             core::mt::ScopedLock lock(bo->m_lockDumpMutex);
-            m_count = bo->m_count.lock();
+
             if(!m_count)
             {
                 m_count     = bo->m_bufferManager->lockBuffer(&(bo->m_buffer)).get();
@@ -132,7 +140,7 @@ public:
         /**
          * @brief Returns BufferObject's buffer pointer
          */
-        typename LockBase<T>::BufferType getBuffer() const
+        [[nodiscard]] typename LockBase<T>::BufferType getBuffer() const
         {
             return m_bufferObject->m_buffer;
         }
@@ -169,14 +177,14 @@ public:
      *
      * Register the buffer to an existing buffer manager.
      */
-    CORE_API BufferObject();
+    CORE_API BufferObject(bool autoDelete = false);
 
     /**
      * @brief BufferObject destructor
      *
      * unregister the buffer from the buffer manager.
      */
-    CORE_API virtual ~BufferObject();
+    CORE_API ~BufferObject() override;
 
     /**
      * @brief Buffer allocation
@@ -229,7 +237,8 @@ public:
         core::memory::BufferManager::BufferType buffer,
         SizeType size,
         const core::memory::BufferAllocationPolicy::sptr& policy =
-        core::memory::BufferMallocPolicy::New()
+        core::memory::BufferMallocPolicy::New(),
+        bool autoDelete = false
     );
 
     /**
@@ -265,7 +274,7 @@ public:
     /**
      * @brief Returns the number of locks on the BufferObject
      */
-    long lockCount() const
+    std::int64_t lockCount() const
     {
         return m_count.use_count();
     }
@@ -273,7 +282,7 @@ public:
     /**
      * @brief Returns true if the buffer has any lock
      */
-    long isLocked() const
+    bool isLocked() const
     {
         return lockCount() != 0;
     }
@@ -325,9 +334,9 @@ public:
 
 protected:
 
-    core::memory::BufferManager::BufferType m_buffer;
+    core::memory::BufferManager::BufferType m_buffer {nullptr};
 
-    SizeType m_size;
+    SizeType m_size {0};
 
     mutable WeakCounterType m_count;
     mutable core::mt::Mutex m_lockDumpMutex;
@@ -336,6 +345,8 @@ protected:
     core::memory::BufferManager::sptr m_bufferManager;
 
     core::memory::BufferAllocationPolicy::sptr m_allocPolicy;
+
+    bool m_autoDelete {false};
 };
 
-} // namespace sight::core
+} // namespace sight::core::memory
