@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,39 +24,21 @@
 
 #include "core/memory/exception/BadCast.hpp"
 
-#include <boost/spirit/include/phoenix_operator.hpp>
+#include <boost/phoenix/operator.hpp>
 #include <boost/spirit/include/qi.hpp>
 
+#include <array>
 #include <sstream>
 
 namespace sight::core::memory
 {
 
-const std::uint64_t ByteSize::Bytes = 1;
-
-// SI units
-const std::uint64_t ByteSize::KB = 1000LL;
-const std::uint64_t ByteSize::MB = 1000000LL;
-const std::uint64_t ByteSize::GB = 1000000000LL;
-const std::uint64_t ByteSize::TB = 1000000000000LL;
-const std::uint64_t ByteSize::PB = 1000000000000000LL;
-
-// IEC units
-const std::uint64_t ByteSize::KiB = 1LL << 10;
-const std::uint64_t ByteSize::MiB = 1LL << 20;
-const std::uint64_t ByteSize::GiB = 1LL << 30;
-const std::uint64_t ByteSize::TiB = 1LL << 40;
-const std::uint64_t ByteSize::PiB = 1LL << 50;
-
-ByteSize::ByteSize() :
-    m_size(0)
-{
-}
+ByteSize::ByteSize()
+= default;
 
 //------------------------------------------------------------------------------
 
-ByteSize::ByteSize(SizeType size, UnitType unit) :
-    m_size(0)
+ByteSize::ByteSize(SizeType size, UnitType unit)
 {
     SIGHT_ASSERT(
         "Bad Unit",
@@ -68,8 +50,7 @@ ByteSize::ByteSize(SizeType size, UnitType unit) :
 
 //------------------------------------------------------------------------------
 
-ByteSize::ByteSize(double size, UnitType unit) :
-    m_size(0)
+ByteSize::ByteSize(double size, UnitType unit)
 {
     SIGHT_ASSERT(
         "Bad Unit",
@@ -186,6 +167,9 @@ std::string ByteSize::unitToString(ByteSize::UnitType unit)
         case TB:
             return "TB";
 
+        case PB:
+            return "PB";
+
         case KiB:
             return "KiB";
 
@@ -197,14 +181,14 @@ std::string ByteSize::unitToString(ByteSize::UnitType unit)
 
         case TiB:
             return "TiB";
-    }
 
-    SIGHT_ASSERT(
-        "Bad Unit",
-        (unit == Bytes) || (unit == KB) || (unit == MB) || (unit == GB) || (unit == TB) || (unit == PB)
-        || (unit == KiB) || (unit == MiB) || (unit == GiB) || (unit == TiB) || (unit == PiB)
-    );
-    return "?";
+        case PiB:
+            return "PiB";
+
+        default:
+            SIGHT_ASSERT("Bad Unit", false);
+            return "?";
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -292,7 +276,7 @@ bool ByteSize::parseSize(const std::string& s, SizeType& size)
 
 //------------------------------------------------------------------------------
 
-std::string ByteSize::getSizeAsString(UnitType unit)
+std::string ByteSize::getSizeAsString(UnitType unit) const
 {
     SIGHT_ASSERT(
         "Bad Unit",
@@ -318,28 +302,29 @@ std::string ByteSize::getSizeAsString(UnitType unit)
 
 //------------------------------------------------------------------------------
 
-std::string ByteSize::getHumanReadableSize(StandardType standard)
+std::string ByteSize::getHumanReadableSize(StandardType standard) const
 {
-    static UnitType si[]                = {Bytes, KB, MB, GB, TB, PB};
-    static UnitType iec[]               = {Bytes, KiB, MiB, GiB, TiB, PiB};
-    const std::size_t sizeOfStandardSet = 5;
+    static const std::array si {Bytes, KB, MB, GB, TB, PB};
+    static const std::array iec {Bytes, KiB, MiB, GiB, TiB, PiB};
+    static_assert(si.size() == iec.size());
+    const std::size_t sizeOfStandardSet = si.size();
 
-    UnitType* unitSet = iec;
+    const auto* unitSet = &iec;
     if(standard == SI)
     {
-        unitSet = si;
+        unitSet = &si;
     }
 
-    std::size_t i;
+    std::size_t i = 0;
     for(i = 1 ; i < sizeOfStandardSet ; ++i)
     {
-        if(m_size < unitSet[i])
+        if(m_size < (*unitSet)[i])
         {
             break;
         }
     }
 
-    return getSizeAsString(unitSet[i - 1]);
+    return getSizeAsString((*unitSet)[i - 1]);
 }
 
 //------------------------------------------------------------------------------
