@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,12 +23,10 @@
 #pragma once
 
 #include "core/config.hpp"
+
 #include <core/Exception.hpp>
 
-namespace sight::core::memory
-{
-
-namespace exception
+namespace sight::core::memory::exception
 {
 
 /**
@@ -42,6 +40,4 @@ struct CORE_CLASS_API Memory : core::Exception
     }
 };
 
-} // namespace exception
-
-} // namespace sight::core::memory
+} // namespace sight::core::memory::exception
