@@ -24,21 +24,14 @@
 
 #include <boost/thread/locks.hpp>
 #include <boost/thread/mutex.hpp>
-#include <boost/thread/recursive_mutex.hpp>
 #include <boost/thread/shared_mutex.hpp>
 
-namespace sight::core
-{
-
-namespace mt
+namespace sight::core::mt
 {
 
 typedef boost::mutex Mutex;
 typedef boost::unique_lock<Mutex> ScopedLock;
 
-typedef boost::recursive_mutex RecursiveMutex;
-typedef boost::unique_lock<RecursiveMutex> RecursiveScopedLock;
-
 /// Defines a single writer, multiple readers mutex.
 typedef boost::shared_mutex ReadWriteMutex;
 /**
@@ -62,6 +55,4 @@ typedef boost::upgrade_lock<ReadWriteMutex> ReadToWriteLock;
  */
 typedef boost::upgrade_to_unique_lock<ReadWriteMutex> UpgradeToWriteLock;
 
-} //namespace mt
-
-} //namespace sight::core
+} // namespace sight::core::mt
