@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,7 +26,6 @@ namespace sight::core::runtime
 {
 
 IExecutable::~IExecutable()
-{
-}
+= default;
 
 } // namespace sight::core::runtime
