@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,19 +28,6 @@ namespace sight::core::runtime
 {
 
 IPlugin::~IPlugin()
-{
-}
-
-//------------------------------------------------------------------------------
-
-void IPlugin::initialize()
-{
-}
-
-//------------------------------------------------------------------------------
-
-void IPlugin::uninitialize()
-{
-}
+= default;
 
 } // namespace sight::core::runtime
