@@ -40,23 +40,13 @@ struct CORE_CLASS_API IPlugin : public IExecutable
     /**
      * @brief   Destructor : does nothing.
      */
-    CORE_API virtual ~IPlugin();
+    CORE_API ~IPlugin() override;
 
     /**
      * @brief   Notifies the plugin about its start.
      */
     virtual void start() = 0;
 
-    /**
-     * @brief   Notifies the plugin about its initialisation.
-     */
-    CORE_API virtual void initialize();
-
-    /**
-     * @brief   Notifies the plugin about its deinitialization.
-     */
-    CORE_API virtual void uninitialize();
-
     /**
      * @brief   Notifies the plugin about its stop.
      */
