@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,6 @@
 
 #include "core/runtime/Plugin.hpp"
 
-#include "core/runtime/ConfigurationElement.hpp"
-
 namespace sight::core::runtime
 {
 
@@ -36,12 +34,6 @@ std::shared_ptr<Module> Plugin::getModule() const noexcept
 
 //------------------------------------------------------------------------------
 
-void Plugin::setInitializationData(const ConfigurationElement::sptr) noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void Plugin::setModule(std::shared_ptr<Module> module) noexcept
 {
     m_module = module;
