@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,7 @@
 
 #include "core/runtime/detail/Executable.hpp"
 
-#include "core/runtime/ConfigurationElement.hpp"
-
-namespace sight::core::runtime
+namespace sight::core::runtime::detail
 {
 
 //------------------------------------------------------------------------------
@@ -36,13 +34,6 @@ std::shared_ptr<Module> Executable::getModule() const
 
 //------------------------------------------------------------------------------
 
-const ConfigurationElement::sptr Executable::getInitializationData() const
-{
-    return m_initializationData;
-}
-
-//------------------------------------------------------------------------------
-
 void Executable::setModule(std::shared_ptr<Module> module)
 {
     m_module = module;
@@ -50,11 +41,4 @@ void Executable::setModule(std::shared_ptr<Module> module)
 
 //------------------------------------------------------------------------------
 
-void Executable::setInitializationData(const ConfigurationElement::sptr element)
-{
-    m_initializationData = element;
-}
-
-//------------------------------------------------------------------------------
-
-} // namespace sight::core::runtime
+} // namespace sight::core::runtime::detail
