@@ -22,7 +22,6 @@
 
 #include "core/runtime/detail/Runtime.hpp"
 
-#include "core/runtime/ConfigurationElement.hpp"
 #include "core/runtime/detail/ExtensionPoint.hpp"
 #include "core/runtime/detail/io/ModuleDescriptorReader.hpp"
 #include "core/runtime/detail/Module.hpp"
@@ -31,6 +30,7 @@
 #include "core/runtime/IExecutable.hpp"
 #include "core/runtime/IPlugin.hpp"
 #include "core/runtime/Profile.hpp"
+#include "core/runtime/runtime.hpp"
 
 #include <core/tools/Os.hpp>
 
@@ -39,10 +39,7 @@
 #include <filesystem>
 #include <functional>
 
-namespace sight::core::runtime
-{
-
-namespace detail
+namespace sight::core::runtime::detail
 {
 
 #ifdef WIN32
@@ -59,15 +56,34 @@ std::shared_ptr<Runtime> Runtime::m_instance;
 
 Runtime::Runtime()
 {
-    // The lib location is 'SIGHT_DIR/lib/sight_core.dll'
-    m_workingPath = boost::dll::this_line_location().parent_path().parent_path().string();
+    // Here we try to find the location of the root of a Sight install
+
+    // In most cases, we can rely on finding sight_core library and then go upward in the filesystem tree
+    // The lib location looks like 'SIGHT_DIR/lib/<arch>/libsight_core.*', where arch is optional
+    const std::string corePath = boost::dll::this_line_location().generic_string();
+    const std::string libPrefix("/" MODULE_LIB_PREFIX "/");
+    auto it = std::search(corePath.rbegin(), corePath.rend(), libPrefix.rbegin(), libPrefix.rend());
+
+    if(it == corePath.rend())
+    {
+        // But if we link statically, for instance linking with sight_core as an object library, then
+        // boost::dll::this_line_location() will return the location of the current executable
+        // In this case, we know that have to locate the bin directory instead of the library directory
+        const std::string binPrefix("/" MODULE_BIN_PREFIX "/");
+        it = std::search(corePath.rbegin(), corePath.rend(), binPrefix.rbegin(), binPrefix.rend());
+        SIGHT_FATAL_IF("Failed to locate Sight runtime. We tried to guess it from: " + corePath, it == corePath.rend());
+    }
+
+    const auto dist = std::distance(it, corePath.rend());
+    const std::filesystem::path libPath(corePath.begin(), corePath.begin() + dist - 1);
+    m_workingPath = libPath.parent_path().make_preferred();
+    SIGHT_INFO("Located Sight runtime in folder: " + m_workingPath.string());
 }
 
 //------------------------------------------------------------------------------
 
 Runtime::~Runtime()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -78,18 +94,15 @@ void Runtime::addModule(std::shared_ptr<Module> module)
     std::for_each(
         module->extensionsBegin(),
         module->extensionsEnd(),
-        std::bind(&Runtime::addExtension, this, std::placeholders::_1)
-    );
+        [this](auto e){addExtension(e);});
     std::for_each(
         module->extensionPointsBegin(),
         module->extensionPointsEnd(),
-        std::bind(&Runtime::addExtensionPoint, this, std::placeholders::_1)
-    );
+        [this](auto&& PH1, auto&& ...){addExtensionPoint(std::forward<decltype(PH1)>(PH1));});
     std::for_each(
         module->executableFactoriesBegin(),
         module->executableFactoriesEnd(),
-        std::bind(&Runtime::addExecutableFactory, this, std::placeholders::_1)
-    );
+        [this](auto&& PH1, auto&& ...){addExecutableFactory(std::forward<decltype(PH1)>(PH1));});
 }
 
 //------------------------------------------------------------------------------
@@ -99,18 +112,15 @@ void Runtime::unregisterModule(std::shared_ptr<Module> module)
     std::for_each(
         module->executableFactoriesBegin(),
         module->executableFactoriesEnd(),
-        std::bind(&Runtime::unregisterExecutableFactory, this, std::placeholders::_1)
-    );
+        [this](auto&& PH1, auto&& ...){unregisterExecutableFactory(std::forward<decltype(PH1)>(PH1));});
     std::for_each(
         module->extensionPointsBegin(),
         module->extensionPointsEnd(),
-        std::bind(&Runtime::unregisterExtensionPoint, this, std::placeholders::_1)
-    );
+        [this](auto&& PH1, auto&& ...){unregisterExtensionPoint(std::forward<decltype(PH1)>(PH1));});
     std::for_each(
         module->extensionsBegin(),
         module->extensionsEnd(),
-        std::bind(&Runtime::unregisterExtension, this, std::placeholders::_1)
-    );
+        [this](auto&& PH1, auto&& ...){unregisterExtension(std::forward<decltype(PH1)>(PH1));});
     m_modules.erase(module);
 }
 
@@ -130,17 +140,22 @@ void Runtime::addModules(const std::filesystem::path& repository)
     try
     {
         const auto modules = core::runtime::detail::io::ModuleDescriptorReader::createModules(repository);
-        std::for_each(modules.begin(), modules.end(), std::bind(&Runtime::addModule, this, std::placeholders::_1));
+        std::for_each(
+            modules.begin(),
+            modules.end(),
+            [this](auto&& PH1, auto&& ...)
+            {
+                addModule(std::forward<decltype(PH1)>(PH1));
+            });
         const auto libRepoStr = std::regex_replace(
             repository.lexically_normal().string(),
             s_MATCH_MODULE_PATH,
             MODULE_LIB_PREFIX
         );
-        m_repositories.push_back(
-            std::make_pair(
-                std::filesystem::weakly_canonical(std::filesystem::path(libRepoStr)),
-                repository
-            )
+        m_repositories.emplace_back(
+            std::filesystem::weakly_canonical(std::filesystem::path(libRepoStr)),
+            repository
+
         );
     }
     catch(const std::exception& exception)
@@ -170,7 +185,7 @@ void Runtime::unregisterExecutableFactory(std::shared_ptr<ExecutableFactory> fac
 {
     // Ensures no registered factory has the same identifier.
     const std::string type(factory->getType());
-    SIGHT_WARN_IF("ExecutableFactory Type " + type + " not found.", this->findExecutableFactory(type) == 0);
+    SIGHT_WARN_IF("ExecutableFactory Type " + type + " not found.", this->findExecutableFactory(type) == nullptr);
 
     // Removes the executable factory.
     m_executableFactories.erase(factory);
@@ -196,11 +211,11 @@ std::shared_ptr<ExecutableFactory> Runtime::findExecutableFactory(const std::str
 
 //------------------------------------------------------------------------------
 
-void Runtime::addExtension(std::shared_ptr<Extension> extension)
+void Runtime::addExtension(std::shared_ptr<detail::Extension> extension)
 {
     // Asserts no registered extension has the same identifier.
     const std::string identifier(filterID(extension->getIdentifier()));
-    if(!identifier.empty() && this->findExtension(identifier) != 0)
+    if(!identifier.empty() && this->findExtension(identifier) != nullptr)
     {
         throw RuntimeException(identifier + ": identifier already used by a registered extension.");
     }
@@ -211,13 +226,13 @@ void Runtime::addExtension(std::shared_ptr<Extension> extension)
 
 //------------------------------------------------------------------------------
 
-void Runtime::unregisterExtension(std::shared_ptr<Extension> extension)
+void Runtime::unregisterExtension(std::shared_ptr<detail::Extension> extension)
 {
     // Asserts no registered extension has the same identifier.
     const std::string identifier(filterID(extension->getIdentifier()));
     SIGHT_WARN_IF(
         "Extension " + identifier + " not found.",
-        !identifier.empty() && this->findExtension(identifier) == 0
+        !identifier.empty() && this->findExtension(identifier) == nullptr
     );
 
     // Removes the extension.
@@ -226,21 +241,21 @@ void Runtime::unregisterExtension(std::shared_ptr<Extension> extension)
 
 //------------------------------------------------------------------------------
 
-Runtime::ExtensionContainer Runtime::getExtensions()
+Runtime::ExtensionContainer Runtime::getExtensions() const
 {
     return m_extensions;
 }
 
 //------------------------------------------------------------------------------
 
-Runtime::ExtensionIterator Runtime::extensionsBegin()
+Runtime::ExtensionIterator Runtime::extensionsBegin() const
 {
     return m_extensions.begin();
 }
 
 //------------------------------------------------------------------------------
 
-Runtime::ExtensionIterator Runtime::extensionsEnd()
+Runtime::ExtensionIterator Runtime::extensionsEnd() const
 {
     return m_extensions.end();
 }
@@ -266,7 +281,7 @@ void Runtime::unregisterExtensionPoint(std::shared_ptr<ExtensionPoint> point)
 {
     // Asserts no registered extension point has the same identifier.
     const std::string identifier(filterID(point->getIdentifier()));
-    SIGHT_WARN_IF("ExtensionPoint " + identifier + " not found.", this->findExtensionPoint(identifier) == 0);
+    SIGHT_WARN_IF("ExtensionPoint " + identifier + " not found.", this->findExtensionPoint(identifier) == nullptr);
 
     m_extensionPoints.erase(point);
 }
@@ -279,8 +294,8 @@ std::shared_ptr<core::runtime::Module> Runtime::findModule(const std::string& id
 
     const std::string id = filterID(identifier);
 
-    std::shared_ptr<Module> resModule;
-    for(const std::shared_ptr<Module>& module : m_modules)
+    std::shared_ptr<core::runtime::Module> resModule;
+    for(const auto& module : m_modules)
     {
         if(module->getIdentifier() == id)
         {
@@ -294,14 +309,14 @@ std::shared_ptr<core::runtime::Module> Runtime::findModule(const std::string& id
 
 //------------------------------------------------------------------------------
 
-std::shared_ptr<Module> Runtime::findEnabledModule(const std::string& identifier) const
+std::shared_ptr<core::runtime::Module> Runtime::findEnabledModule(const std::string& identifier) const
 {
     SIGHT_ASSERT("Module identifier should not be empty", !identifier.empty());
 
     const std::string id = filterID(identifier);
 
-    std::shared_ptr<Module> resModule;
-    for(const std::shared_ptr<Module>& module : m_modules)
+    std::shared_ptr<core::runtime::Module> resModule;
+    for(const auto& module : m_modules)
     {
         if(module->getIdentifier() == id && module->isEnabled())
         {
@@ -315,29 +330,23 @@ std::shared_ptr<Module> Runtime::findEnabledModule(const std::string& identifier
 
 //------------------------------------------------------------------------------
 
-Runtime* Runtime::getDefault()
+Runtime& Runtime::get()
 {
-    if(m_instance.get() == nullptr)
+    if(m_instance == nullptr)
     {
         m_instance = std::make_shared<Runtime>();
     }
 
-    return m_instance.get();
+    auto* runtime = m_instance.get();
+    return *runtime;
 }
 
 //------------------------------------------------------------------------------
 
-Runtime& Runtime::get()
-{
-    return *Runtime::getDefault();
-}
-
-//------------------------------------------------------------------------------
-
-std::shared_ptr<Extension> Runtime::findExtension(const std::string& identifier) const
+std::shared_ptr<core::runtime::Extension> Runtime::findExtension(const std::string& identifier) const
 {
     const std::string id = filterID(identifier);
-    std::shared_ptr<Extension> resExtension;
+    std::shared_ptr<core::runtime::Extension> resExtension;
     for(const ExtensionContainer::value_type& extension : m_extensions)
     {
         if(extension->getIdentifier() == id && extension->isEnabled())
@@ -352,9 +361,9 @@ std::shared_ptr<Extension> Runtime::findExtension(const std::string& identifier)
 
 //------------------------------------------------------------------------------
 
-core::runtime::Runtime::ModuleContainer Runtime::getModules()
+core::runtime::detail::Runtime::ModuleContainer Runtime::getModules() const
 {
-    core::runtime::Runtime::ModuleContainer modules;
+    ModuleContainer modules;
     std::copy(m_modules.begin(), m_modules.end(), std::inserter(modules, modules.begin()));
     return modules;
 }
@@ -393,7 +402,7 @@ std::shared_ptr<ExtensionPoint> Runtime::findExtensionPoint(const std::string& i
 
 //------------------------------------------------------------------------------
 
-IExecutable* Runtime::createExecutableInstance(const std::string& type)
+IExecutable* Runtime::createExecutableInstance(const std::string& type) const
 {
     std::shared_ptr<ExecutableFactory> factory;
 
@@ -413,52 +422,4 @@ IExecutable* Runtime::createExecutableInstance(const std::string& type)
 
 //------------------------------------------------------------------------------
 
-IExecutable* Runtime::createExecutableInstance(
-    const std::string& type,
-    ConfigurationElement::sptr configurationElement
-)
-{
-    std::shared_ptr<ExecutableFactory> factory;
-
-    // Retrieves the executable factory.
-    factory = this->findExecutableFactory(type);
-
-    // If there is no factory has been found, it is possible that
-    // it has not been registered since the module of the given configuration element
-    // is not started.
-    // So we start that module and look for the executable factory one more type.
-    if(factory == nullptr)
-    {
-        configurationElement->getModule()->start();
-        factory = this->findExecutableFactory(type);
-    }
-
-    // If we still have not found any executable factory, then notify the problem.
-    if(factory == nullptr)
-    {
-        throw RuntimeException(type + ": no executable factory found for that type.");
-    }
-
-    // Creates the executable instance
-    IExecutable* result(nullptr);
-    try
-    {
-        factory->getModule()->start();
-        result = factory->createExecutable();
-        result->setInitializationData(configurationElement);
-    }
-    catch(const std::exception& e)
-    {
-        std::string message("Unable to create an executable instance. ");
-        throw RuntimeException(message + e.what());
-    }
-
-    // Job's done.
-    return result;
-}
-
-//------------------------------------------------------------------------------
-
-} // namespace detail
-
-} // namespace sight::core::runtime
+} // namespace sight::core::runtime::detail
