@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,16 +22,19 @@
 
 #include "core/runtime/detail/io/ModuleDescriptorReader.hpp"
 
-#include "core/runtime/ConfigurationElement.hpp"
 #include "core/runtime/detail/dl/Library.hpp"
 #include "core/runtime/detail/ExtensionPoint.hpp"
 #include "core/runtime/detail/io/Validator.hpp"
 #include "core/runtime/detail/Module.hpp"
 #include "core/runtime/Extension.hpp"
-#include "core/runtime/operations.hpp"
+#include "core/runtime/path.hpp"
+#include "core/runtime/runtime.hpp"
+
+#include <core/runtime/helper.hpp>
 
 #include <boost/algorithm/string/replace.hpp>
 #include <boost/algorithm/string/trim.hpp>
+#include <boost/dll.hpp>
 
 #include <libxml/parser.h>
 #include <libxml/xinclude.h>
@@ -41,45 +44,69 @@
 #include <sstream>
 #include <string>
 
-namespace sight::core::runtime
+namespace sight::core::runtime::detail::io
 {
 
-namespace detail
-{
-
-namespace io
-{
-
-std::string ModuleDescriptorReader::CLASS("class");
-std::string ModuleDescriptorReader::EXTENSION("extension");
-std::string ModuleDescriptorReader::EXTENSION_POINT("extension-point");
-std::string ModuleDescriptorReader::ID("id");
-std::string ModuleDescriptorReader::IMPLEMENTS("implements");
-std::string ModuleDescriptorReader::LIBRARY("library");
-std::string ModuleDescriptorReader::NAME("name");
-std::string ModuleDescriptorReader::PLUGIN("plugin");
-std::string ModuleDescriptorReader::REQUIREMENT("requirement");
-std::string ModuleDescriptorReader::SCHEMA("schema");
-std::string ModuleDescriptorReader::POINT("point");
+static const std::string EXTENSION("extension");
+static const std::string EXTENSION_POINT("extension-point");
+static const std::string ID("id");
+static const std::string IMPLEMENTS("implements");
+static const std::string LIBRARY("library");
+static const std::string PLUGIN("plugin");
+static const std::string PRIORITY("priority");
+static const std::string REQUIREMENT("requirement");
+static const std::string SCHEMA("schema");
+static const std::string POINT("point");
 
 //------------------------------------------------------------------------------
 
-const ModuleDescriptorReader::ModuleContainer ModuleDescriptorReader::createModules(
+ModuleDescriptorReader::ModuleContainer ModuleDescriptorReader::createModules(
     const std::filesystem::path& location
 )
 {
-    // Normalizes the path.
-    std::filesystem::path normalizedPath(std::filesystem::weakly_canonical(location));
+    std::filesystem::path normalizedPath(location);
+
+    if(normalizedPath.is_relative())
+    {
+        // Assume we are relative to the location of the executable path
+        // Otherwise, weakly_canonical will make it relative to the current dir,
+        // which forces us to `cd` in the correct directory in the launcher script
+        const auto currentPath = boost::dll::program_location().parent_path().string();
+        normalizedPath = currentPath / normalizedPath;
+    }
+
+    normalizedPath = std::filesystem::weakly_canonical(normalizedPath);
 
     // Asserts that the repository is a valid directory path.
-    if(std::filesystem::exists(normalizedPath) == false
-       || std::filesystem::is_directory(normalizedPath) == false)
+    if(!std::filesystem::exists(normalizedPath)
+       || !std::filesystem::is_directory(normalizedPath))
     {
         throw RuntimeException("'" + normalizedPath.string() + "': not a directory.");
     }
 
-    // Walk through the repository entries.
     ModuleContainer modules;
+    const auto loadModuleFn =
+        [&](const std::filesystem::path& path)
+        {
+            try
+            {
+                SPTR(Module) module = ModuleDescriptorReader::createModule(path);
+                if(module)
+                {
+                    modules.push_back(module);
+                }
+            }
+            catch(const RuntimeException& runtimeException)
+            {
+                SIGHT_DEBUG("'" << path.string() << "': skipped. " << runtimeException.what());
+            }
+            catch(const core::Exception& exception)
+            {
+                SIGHT_DEBUG("'" << path.string() << "': skipped. " << exception.what());
+            }
+        };
+
+    // Walk through the repository entries.
     std::filesystem::directory_iterator currentEntry(normalizedPath);
     std::filesystem::directory_iterator endEntry;
     for( ; currentEntry != endEntry ; ++currentEntry)
@@ -88,25 +115,17 @@ const ModuleDescriptorReader::ModuleContainer ModuleDescriptorReader::createModu
 
         if(std::filesystem::is_directory(entryPath))
         {
-            try
-            {
-                SPTR(Module) module = ModuleDescriptorReader::createModule(entryPath);
-                if(module)
-                {
-                    modules.push_back(module);
-                }
-            }
-            catch(const RuntimeException& runtimeException)
-            {
-                SIGHT_DEBUG("'" << entryPath.string() << "': skipped. " << runtimeException.what());
-            }
-            catch(const core::Exception& exception)
-            {
-                SIGHT_DEBUG("'" << entryPath.string() << "': skipped. " << exception.what());
-            }
+            loadModuleFn(entryPath);
         }
     }
 
+    // If nothing can be found in the subfolders, give a try with the current folder
+    // This is sometimes used in unit-test to load a specific module instead of a set of modules
+    if(modules.empty())
+    {
+        loadModuleFn(normalizedPath);
+    }
+
     return modules;
 }
 
@@ -117,7 +136,7 @@ std::shared_ptr<Module> ModuleDescriptorReader::createModule(const std::filesyst
     std::shared_ptr<detail::Module> module;
 
     std::filesystem::path descriptorLocation(location / "plugin.xml");
-    if(std::filesystem::exists(descriptorLocation) == false)
+    if(!std::filesystem::exists(descriptorLocation))
     {
         throw core::Exception(std::string("'plugin.xml': file not found in ") + location.string());
     }
@@ -126,7 +145,7 @@ std::shared_ptr<Module> ModuleDescriptorReader::createModule(const std::filesyst
     auto pluginXSDLocation = core::runtime::getLibraryResourceFilePath("core/plugin.xsd");
 
     Validator validator(pluginXSDLocation);
-    if(validator.validate(descriptorLocation) == false)
+    if(!validator.validate(descriptorLocation))
     {
         throw RuntimeException("Invalid module descriptor file. " + validator.getErrorLog());
     }
@@ -148,7 +167,7 @@ std::shared_ptr<Module> ModuleDescriptorReader::createModule(const std::filesyst
             throw RuntimeException("Unable to manage xinclude !");
         }
 
-        if(xmlStrcmp(rootNode->name, (const xmlChar*) PLUGIN.c_str()) != 0)
+        if(xmlStrcmp(rootNode->name, reinterpret_cast<const xmlChar*>(PLUGIN.c_str())) != 0)
         {
             throw RuntimeException("Unexpected XML element");
         }
@@ -159,7 +178,7 @@ std::shared_ptr<Module> ModuleDescriptorReader::createModule(const std::filesyst
 
         if(!completeLocation.is_absolute())
         {
-            completeLocation = core::runtime::Runtime::getDefault()->getWorkingPath() / location;
+            completeLocation = core::runtime::getWorkingPath() / location;
         }
 
         module = processPlugin(rootNode, completeLocation);
@@ -167,67 +186,79 @@ std::shared_ptr<Module> ModuleDescriptorReader::createModule(const std::filesyst
         // Job's done!
         xmlFreeDoc(document);
     }
-    catch(std::exception& exception)
+    catch(std::exception& /*exception*/)
     {
         xmlFreeDoc(document);
-        throw exception;
+        throw;
     }
     return module;
 }
 
 //-----------------------------------------------------------------------------
 
-ConfigurationElement::sptr ModuleDescriptorReader::processConfigurationElement(
-    xmlNodePtr node,
-    const std::shared_ptr<Module> module
-)
+void ModuleDescriptorReader::processConfiguration(xmlNodePtr node, core::runtime::config_t& parentConfig)
 {
     // Creates the configuration element.
-    const std::string nodeName((const char*) node->name);
-    ConfigurationElement::sptr configurationElement(ConfigurationElement::New(module, nodeName));
+    const std::string nodeName(reinterpret_cast<const char*>(node->name));
+    core::runtime::config_t config;
 
     // Processes all attributes.
-    xmlAttrPtr curAttr;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    xmlAttrPtr curAttr = nullptr;
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        const std::string attrName((const char*) curAttr->name);
-        const std::string value((const char*) curAttr->children->content);
+        const std::string attrName(reinterpret_cast<const char*>(curAttr->name));
+        const std::string value(reinterpret_cast<const char*>(curAttr->children->content));
+        config.add("<xmlattr>." + attrName, value);
+    }
 
-        configurationElement->setAttributeValue(attrName, value);
+    if(nodeName == "service")
+    {
+        curAttr = nullptr;
     }
 
     // Process child nodes.
-    xmlNodePtr curChild = node->children;
-    for(curChild = node->children ; curChild != 0 ; curChild = curChild->next)
+    std::string value;
+    core::runtime::config_t children;
+    for(xmlNodePtr curChild = node->children ; curChild != nullptr ; curChild = curChild->next)
     {
-        if(curChild->type == XML_TEXT_NODE && !xmlIsBlankNode(curChild))
+        if(curChild->type == XML_TEXT_NODE && (xmlIsBlankNode(curChild) == 0))
         {
-            std::string value((const char*) curChild->content);
+            std::string content(reinterpret_cast<const char*>(curChild->content));
             // Even whitespace (non XML_TEXT_NODE) are considered as valid XML_TEXT_NODE
             SIGHT_WARN_IF(
-                "Module : " << (module ? module->getIdentifier() : "<None>") << ", node: " << nodeName << ", blanks in xml nodes can result in unexpected behaviour. Consider using <![CDATA[ ... ]]>.",
-                (value.find("\n") != std::string::npos || value.find("\t") != std::string::npos)
+                "Node: " << nodeName
+                << ", blanks in xml nodes can result in unexpected behaviour. Consider using <![CDATA[ ... ]]>.",
+                (content.find('\n') != std::string::npos || content.find('\t') != std::string::npos)
             );
 
-            configurationElement->setValue(configurationElement->getValue() + value);
+            value += content;
             continue;
         }
-        else if(curChild->type == XML_CDATA_SECTION_NODE)
+
+        if(curChild->type == XML_CDATA_SECTION_NODE)
         {
-            const std::string value((const char*) curChild->content);
-            configurationElement->setValue(configurationElement->getValue() + value);
+            value += std::string(reinterpret_cast<const char*>(curChild->content));
             continue;
         }
-        else if(curChild->type == XML_ELEMENT_NODE)
+
+        if(curChild->type == XML_ELEMENT_NODE)
         {
-            ConfigurationElement::sptr element(processConfigurationElement(curChild, module));
-            configurationElement->addConfigurationElement(element);
+            processConfiguration(curChild, config);
             continue;
         }
     }
 
-    // Job's done.
-    return configurationElement;
+    if(!children.empty())
+    {
+        config.add_child(nodeName, children);
+    }
+
+    if(!value.empty())
+    {
+        config.put_value<std::string>(value);
+    }
+
+    parentConfig.add_child(nodeName, config);
 }
 
 //------------------------------------------------------------------------------
@@ -238,38 +269,44 @@ std::shared_ptr<Extension> ModuleDescriptorReader::processExtension(
 )
 {
     // Processes all extension attributes.
-    xmlAttrPtr curAttr;
+    xmlAttrPtr curAttr = nullptr;
     std::string point;
     std::string identifier;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) ID.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(ID.c_str())) == 0)
         {
-            identifier = (const char*) curAttr->children->content;
+            identifier = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
 
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) IMPLEMENTS.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(IMPLEMENTS.c_str())) == 0)
         {
-            point = (const char*) curAttr->children->content;
+            point = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
     }
 
+    if(point == "sight::service::extension::AppConfig")
+    {
+        curAttr = nullptr;
+    }
+
     // Creates the extension instance.
     std::shared_ptr<Extension> extension = std::make_shared<Extension>(module, identifier, point, node);
 
     // Processes child nodes which are configuration elements.
-    xmlNodePtr curChild;
-    for(curChild = node->children ; curChild != 0 ; curChild = curChild->next)
+    xmlNodePtr curChild = nullptr;
+    core::runtime::config_t config;
+    for(curChild = node->children ; curChild != nullptr ; curChild = curChild->next)
     {
         if(curChild->type == XML_ELEMENT_NODE)
         {
-            ConfigurationElement::sptr element(processConfigurationElement(curChild, module));
-            extension->addConfigurationElement(element);
+            processConfiguration(curChild, config);
         }
     }
 
+    extension->setConfig(config);
     // Job's done.
     return extension;
 }
@@ -282,20 +319,20 @@ ModuleDescriptorReader::PointExtensionsPairType ModuleDescriptorReader::processP
 )
 {
     // Creates the extension instance.
-    xmlAttrPtr curAttr;
+    xmlAttrPtr curAttr = nullptr;
     std::string schema;
     std::string identifier;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) ID.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(ID.c_str())) == 0)
         {
-            identifier = (const char*) curAttr->children->content;
+            identifier = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
 
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) SCHEMA.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(SCHEMA.c_str())) == 0)
         {
-            schema = (const char*) curAttr->children->content;
+            schema = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
     }
@@ -304,21 +341,21 @@ ModuleDescriptorReader::PointExtensionsPairType ModuleDescriptorReader::processP
 
     // Processes child nodes which declare identifier as extensions.
     std::vector<std::shared_ptr<Extension> > extensionContainer;
-    xmlNodePtr curChild;
-    for(curChild = node->children ; curChild != 0 ; curChild = curChild->next)
+    xmlNodePtr curChild = nullptr;
+    for(curChild = node->children ; curChild != nullptr ; curChild = curChild->next)
     {
         if(curChild->type == XML_ELEMENT_NODE)
         {
-            if(xmlStrcmp(curChild->name, (const xmlChar*) IMPLEMENTS.c_str()) == 0)
+            if(xmlStrcmp(curChild->name, reinterpret_cast<const xmlChar*>(IMPLEMENTS.c_str())) == 0)
             {
-                std::string extensionId = (const char*) curChild->children->content;
+                std::string extensionId = reinterpret_cast<const char*>(curChild->children->content);
                 auto extension          = std::make_shared<Extension>(module, identifier, extensionId, curChild);
                 extensionContainer.push_back(extension);
             }
         }
     }
 
-    return PointExtensionsPairType(extensionPoint, extensionContainer);
+    return {extensionPoint, extensionContainer};
 }
 
 //------------------------------------------------------------------------------
@@ -329,20 +366,20 @@ std::shared_ptr<ExtensionPoint> ModuleDescriptorReader::processExtensionPoint(
 )
 {
     // Processes all extension attributes.
-    xmlAttrPtr curAttr;
+    xmlAttrPtr curAttr = nullptr;
     std::string identifier;
     std::string schema;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) ID.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(ID.c_str())) == 0)
         {
-            identifier = (const char*) curAttr->children->content;
+            identifier = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
 
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) SCHEMA.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(SCHEMA.c_str())) == 0)
         {
-            schema = (const char*) curAttr->children->content;
+            schema = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
     }
@@ -364,14 +401,13 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
     // Creates the module.
     std::shared_ptr<detail::Module> module;
     // Processes all plugin attributes.
-    xmlAttrPtr curAttr;
+    xmlAttrPtr curAttr = nullptr;
     std::string moduleIdentifier;
-    std::string pluginClass;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) ID.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(ID.c_str())) == 0)
         {
-            moduleIdentifier = (const char*) curAttr->children->content;
+            moduleIdentifier = reinterpret_cast<const char*>(curAttr->children->content);
             moduleIdentifier = filterID(moduleIdentifier);
             continue;
         }
@@ -379,45 +415,51 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
 
     SIGHT_ASSERT("module identifier is empty", !moduleIdentifier.empty());
 
-    if(core::runtime::Runtime::getDefault()->findModule(moduleIdentifier))
+    if(core::runtime::findModule(moduleIdentifier))
     {
         return module;
     }
 
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    bool createLibrary = false;
+    int priority       = 0;
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) LIBRARY.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(LIBRARY.c_str())) == 0)
         {
-            if(xmlStrcmp(curAttr->children->content, (const xmlChar*) "true") == 0)
-            {
-                // Deduce the library name from the plugin name
-                std::string libname = boost::algorithm::replace_all_copy(moduleIdentifier, "::", "_");
-                boost::algorithm::trim_left_if(libname, [](auto x){return x == '_';});
+            createLibrary = (xmlStrcmp(curAttr->children->content, reinterpret_cast<const xmlChar*>("true")) == 0);
+        }
 
-                SIGHT_INFO("Plugin " + moduleIdentifier + " holds library " + libname);
-
-                // Creates the library
-                // If we have a library, deduce the plugin name
-                pluginClass = moduleIdentifier + "::Plugin";
-
-                module = std::make_shared<Module>(location, moduleIdentifier, pluginClass);
-
-                auto library = std::make_shared<dl::Library>(libname);
-                module->setLibrary(library);
-
-                break;
-            }
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(PRIORITY.c_str())) == 0)
+        {
+            priority = std::stoi(reinterpret_cast<const char*>(curAttr->children->content));
         }
     }
 
-    if(module == nullptr)
+    if(createLibrary)
+    {
+        // Deduce the library name from the plugin name
+        std::string libname = boost::algorithm::replace_all_copy(moduleIdentifier, "::", "_");
+        boost::algorithm::trim_left_if(libname, [](auto x){return x == '_';});
+
+        SIGHT_INFO(std::string("Plugin ") + moduleIdentifier + " holds library " + libname);
+
+        // Creates the library
+        // If we have a library, deduce the plugin name
+        const std::string pluginClass = moduleIdentifier + "::Plugin";
+
+        module = std::make_shared<Module>(location, moduleIdentifier, pluginClass, priority);
+
+        auto library = std::make_shared<dl::Library>(libname);
+        module->setLibrary(library);
+    }
+    else
     {
         module = std::make_shared<Module>(location, moduleIdentifier);
     }
 
     // Processes all child nodes.
-    xmlNodePtr curChild;
-    for(curChild = node->children ; curChild != 0 ; curChild = curChild->next)
+    xmlNodePtr curChild = nullptr;
+    for(curChild = node->children ; curChild != nullptr ; curChild = curChild->next)
     {
         // Skip non element nodes.
         if(curChild->type != XML_ELEMENT_NODE)
@@ -426,7 +468,7 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
         }
 
         // Extension declaration.
-        if(xmlStrcmp(curChild->name, (const xmlChar*) EXTENSION.c_str()) == 0)
+        if(xmlStrcmp(curChild->name, reinterpret_cast<const xmlChar*>(EXTENSION.c_str())) == 0)
         {
             std::shared_ptr<Extension> extension(processExtension(curChild, module));
             module->addExtension(extension);
@@ -434,7 +476,7 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
         }
 
         // Extension point declaration.
-        if(xmlStrcmp(curChild->name, (const xmlChar*) EXTENSION_POINT.c_str()) == 0)
+        if(xmlStrcmp(curChild->name, reinterpret_cast<const xmlChar*>(EXTENSION_POINT.c_str())) == 0)
         {
             std::shared_ptr<ExtensionPoint> point(processExtensionPoint(curChild, module));
             module->addExtensionPoint(point);
@@ -442,14 +484,14 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
         }
 
         // Requirement declaration.
-        if(xmlStrcmp(curChild->name, (const xmlChar*) REQUIREMENT.c_str()) == 0)
+        if(xmlStrcmp(curChild->name, reinterpret_cast<const xmlChar*>(REQUIREMENT.c_str())) == 0)
         {
             const std::string requirement(processRequirement(curChild));
             module->addRequirement(requirement);
         }
 
         // Point declaration.
-        if(xmlStrcmp(curChild->name, (const xmlChar*) POINT.c_str()) == 0)
+        if(xmlStrcmp(curChild->name, reinterpret_cast<const xmlChar*>(POINT.c_str())) == 0)
         {
             SIGHT_FATAL("This xml element  ( <point ... > </point> ) is deprecated (" + location.string() + ")");
         }
@@ -461,16 +503,16 @@ std::shared_ptr<detail::Module> ModuleDescriptorReader::processPlugin(
 
 //------------------------------------------------------------------------------
 
-const std::string ModuleDescriptorReader::processRequirement(xmlNodePtr node)
+std::string ModuleDescriptorReader::processRequirement(xmlNodePtr node)
 {
     // Processes all requirement attributes.
-    xmlAttrPtr curAttr;
+    xmlAttrPtr curAttr = nullptr;
     std::string identifier;
-    for(curAttr = node->properties ; curAttr != 0 ; curAttr = curAttr->next)
+    for(curAttr = node->properties ; curAttr != nullptr ; curAttr = curAttr->next)
     {
-        if(xmlStrcmp(curAttr->name, (const xmlChar*) ID.c_str()) == 0)
+        if(xmlStrcmp(curAttr->name, reinterpret_cast<const xmlChar*>(ID.c_str())) == 0)
         {
-            identifier = (const char*) curAttr->children->content;
+            identifier = reinterpret_cast<const char*>(curAttr->children->content);
             continue;
         }
     }
@@ -487,8 +529,4 @@ const std::string ModuleDescriptorReader::processRequirement(xmlNodePtr node)
 
 //------------------------------------------------------------------------------
 
-} // namespace io
-
-} // namespace detail
-
-} // namespace sight::core::runtime
+} // namespace sight::core::runtime::detail::io
