@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <sstream>
 
-namespace sight::core
-{
-
-namespace ut
+namespace sight::core::ut
 {
 
 class DemanglerTest : public CPPUNIT_NS::TestFixture
@@ -41,12 +38,10 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void classNameTest();
+    static void classNameTest();
 };
 
-} //namespace ut
-
-} //namespace sight::core
+} // namespace sight::core::ut
