@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core
-{
-
-namespace ut
+namespace sight::core::ut
 {
 
 class FactoryRegistryTest : public CPPUNIT_NS::TestFixture
@@ -42,15 +39,13 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void pointerTest();
-    void valueTest();
-    void argTest();
-    void threadSafetyTest();
+    static void pointerTest();
+    static void valueTest();
+    static void argTest();
+    static void threadSafetyTest();
 };
 
-} //namespace ut
-
-} //namespace sight::core
+} // namespace sight::core::ut
