@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::com
-{
-
-namespace ut
+namespace sight::core::com::ut
 {
 
 class SignalsTest : public CPPUNIT_NS::TestFixture
@@ -43,13 +40,11 @@ private:
 
 public:
 
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void buildTest();
-    void hasSignalsTest();
+    static void buildTest();
+    static void hasSignalsTest();
 };
 
-} //namespace ut
-
-} //namespace sight::core::com
+} // namespace sight::core::com::ut
