@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::com
-{
-
-namespace ut
+namespace sight::core::com::ut
 {
 
 class UtilTest : public CPPUNIT_NS::TestFixture
@@ -43,14 +40,12 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void autoBindTest();
-    void convertFunctionTypeTest();
-    void removeLastArgTest();
+    static void autoBindTest();
+    static void convertFunctionTypeTest();
+    static void removeLastArgTest();
 };
 
-} //namespace ut
-
-} //namespace sight::core::com
+} // namespace sight::core::com::ut
