@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::memory
-{
-
-namespace ut
+namespace sight::core::memory::ut
 {
 
 class BufferManagerTest : public CPPUNIT_NS::TestFixture
@@ -35,18 +32,22 @@ class BufferManagerTest : public CPPUNIT_NS::TestFixture
 CPPUNIT_TEST_SUITE(BufferManagerTest);
 CPPUNIT_TEST(allocateTest);
 CPPUNIT_TEST(memoryInfoTest);
+CPPUNIT_TEST(swapTest);
+CPPUNIT_TEST(dumpRestoreTest);
+CPPUNIT_TEST(dumpPolicyTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void allocateTest();
-    void memoryInfoTest();
+    static void allocateTest();
+    static void memoryInfoTest();
+    static void swapTest();
+    static void dumpRestoreTest();
+    static void dumpPolicyTest();
 };
 
-} // namespace ut
-
-} // namespace sight::core::memory
+} // namespace sight::core::memory::ut
