@@ -39,10 +39,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::core::memory::ut::BufferObjectTest);
 
-namespace sight::core::memory
-{
-
-namespace ut
+namespace sight::core::memory::ut
 {
 
 //------------------------------------------------------------------------------
@@ -62,7 +59,7 @@ void BufferObjectTest::tearDown()
 //------------------------------------------------------------------------------
 
 template<typename T>
-bool isPointedValueConst(T)
+bool isPointedValueConst(T /*unused*/)
 {
     return std::is_const<typename std::remove_pointer<T>::type>::value;
 }
@@ -75,23 +72,23 @@ void BufferObjectTest::allocateTest()
     core::memory::BufferObject::sptr bo = core::memory::BufferObject::New();
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     bo->allocate(SIZE);
 
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     // We need to wait before checking that the buffer was unlocked because all buffer operations are done on a worker.
     // The actual buffer ref count might still be owned (as a std::promise) by the worker task when we reach this point.
     fwTestWaitMacro(bo->lockCount() == 0);
-    CPPUNIT_ASSERT_EQUAL(static_cast<long>(0), bo->lockCount());
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(0), bo->lockCount());
 
     {
         core::memory::BufferObject::Lock lock(bo->lock());
         fwTestWaitMacro(bo->lockCount() == 1);
-        CPPUNIT_ASSERT_EQUAL(static_cast<long>(1), bo->lockCount());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(1), bo->lockCount());
         char* buf = static_cast<char*>(lock.getBuffer());
 
         for(std::size_t i = 0 ; i < SIZE ; ++i)
@@ -111,40 +108,40 @@ void BufferObjectTest::allocateTest()
     }
 
     fwTestWaitMacro(bo->lockCount() == 0);
-    CPPUNIT_ASSERT_EQUAL(static_cast<long>(0), bo->lockCount());
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(0), bo->lockCount());
 
     {
         core::memory::BufferObject::Lock lock(bo->lock());
 
         fwTestWaitMacro(bo->lockCount() == 1);
-        CPPUNIT_ASSERT_EQUAL(static_cast<long>(1), bo->lockCount());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(1), bo->lockCount());
         core::memory::BufferObject::Lock lock2(bo->lock());
         fwTestWaitMacro(bo->lockCount() == 2);
-        CPPUNIT_ASSERT_EQUAL(static_cast<long>(2), bo->lockCount());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(2), bo->lockCount());
         core::memory::BufferObject::csptr cbo = bo;
         core::memory::BufferObject::ConstLock clock(cbo->lock());
         fwTestWaitMacro(bo->lockCount() == 3);
-        CPPUNIT_ASSERT_EQUAL(static_cast<long>(3), bo->lockCount());
+        CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(3), bo->lockCount());
         CPPUNIT_ASSERT(isPointedValueConst(clock.getBuffer()));
         CPPUNIT_ASSERT(isPointedValueConst(cbo->lock().getBuffer()));
     }
 
     fwTestWaitMacro(bo->lockCount() == 0);
-    CPPUNIT_ASSERT_EQUAL(static_cast<long>(0), bo->lockCount());
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(0), bo->lockCount());
 
     bo->destroy();
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     bo->allocate(SIZE, core::memory::BufferNewPolicy::New());
 
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     {
         core::memory::BufferObject::Lock lock(bo->lock());
@@ -168,20 +165,20 @@ void BufferObjectTest::allocateTest()
 
     bo->destroy();
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     CPPUNIT_ASSERT_THROW(bo->allocate(std::numeric_limits<std::size_t>::max() / 2), core::memory::exception::Memory);
 
     bo->allocate(SIZE);
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     CPPUNIT_ASSERT_THROW(bo->reallocate(std::numeric_limits<std::size_t>::max() / 2), core::memory::exception::Memory);
 
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     const std::size_t SMALLER_REALLOC_SIZE = 1024;
     const std::size_t BIGGER_REALLOC_SIZE  = SIZE + 1024;
@@ -189,17 +186,17 @@ void BufferObjectTest::allocateTest()
     bo->reallocate(SMALLER_REALLOC_SIZE);
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SMALLER_REALLOC_SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     bo->reallocate(BIGGER_REALLOC_SIZE);
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(BIGGER_REALLOC_SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     bo->destroy();
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     CPPUNIT_ASSERT_THROW(bo->allocate(150, core::memory::BufferNoAllocPolicy::New()), core::memory::exception::Memory);
     // CPPUNIT_ASSERT_THROW( bo->reallocate(150), core::memory::exception::Memory);
@@ -213,18 +210,18 @@ void BufferObjectTest::allocateZeroTest()
     core::memory::BufferObject::sptr bo = core::memory::BufferObject::New();
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     bo->allocate(0);
 
     CPPUNIT_ASSERT(bo->isEmpty());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() == NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() == nullptr);
 
     bo->allocate(SIZE);
 
     CPPUNIT_ASSERT(!bo->isEmpty());
     CPPUNIT_ASSERT_EQUAL(static_cast<core::memory::BufferObject::SizeType>(SIZE), bo->getSize());
-    CPPUNIT_ASSERT(bo->lock().getBuffer() != NULL);
+    CPPUNIT_ASSERT(bo->lock().getBuffer() != nullptr);
 
     bo->destroy();
 }
@@ -243,7 +240,7 @@ void stressLock(core::memory::BufferObject::sptr bo, int nbLocks, int nbTest)
         }
 
         fwTestWaitMacro(bo->lockCount() >= 3);
-        CPPUNIT_ASSERT(bo->lockCount() >= static_cast<long>(3));
+        CPPUNIT_ASSERT(bo->lockCount() >= static_cast<std::int64_t>(3));
 
         m_locks.clear();
     }
@@ -257,17 +254,15 @@ void BufferObjectTest::lockThreadedStressTest()
 
     boost::thread_group group;
 
-    group.create_thread(std::bind(&stressLock, bo, 800, 600));
-    group.create_thread(std::bind(&stressLock, bo, 600, 800));
-    group.create_thread(std::bind(&stressLock, bo, 452, 692));
-    group.create_thread(std::bind(&stressLock, bo, 253, 345));
+    group.create_thread([bo](auto&& ...){return stressLock(bo, 800, 600);});
+    group.create_thread([bo](auto&& ...){return stressLock(bo, 600, 800);});
+    group.create_thread([bo](auto&& ...){return stressLock(bo, 452, 692);});
+    group.create_thread([bo](auto&& ...){return stressLock(bo, 253, 345);});
 
     group.join_all();
 
     fwTestWaitMacro(bo->lockCount() == 0);
-    CPPUNIT_ASSERT_EQUAL(static_cast<long>(0), bo->lockCount());
+    CPPUNIT_ASSERT_EQUAL(static_cast<std::int64_t>(0), bo->lockCount());
 }
 
-} // namespace ut
-
-} // namespace sight::core::memory
+} // namespace sight::core::memory::ut
