@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,10 +36,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::core::thread::ut::WorkerTest);
 
-namespace sight::core::thread
-{
-
-namespace ut
+namespace sight::core::thread::ut
 {
 
 static utest::Exception e(""); // force link with fwTest
@@ -62,9 +59,9 @@ void WorkerTest::tearDown()
 
 struct TestHandler
 {
-    TestHandler()
+    TestHandler() :
+        m_constructorThreadId(core::thread::getCurrentThreadId())
     {
-        m_constructorThreadId = core::thread::getCurrentThreadId();
     }
 
     //------------------------------------------------------------------------------
@@ -108,9 +105,9 @@ void WorkerTest::basicTest()
 
         TestHandler handler;
         handler.setWorkerId(worker->getThreadId());
-        worker->post(std::bind(&TestHandler::nextStep, &handler));
-        worker->post(std::bind(&TestHandler::nextStep, &handler));
-        worker->post(std::bind(&TestHandler::nextStep, &handler));
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStep();});
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStep();});
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStep();});
 
         worker->stop();
         CPPUNIT_ASSERT_EQUAL(3, handler.m_step.load());
@@ -122,9 +119,9 @@ void WorkerTest::basicTest()
 
         TestHandler handler;
         handler.setWorkerId(worker->getThreadId());
-        worker->post(std::bind(&TestHandler::nextStepNoSleep, &handler));
-        worker->post(std::bind(&TestHandler::nextStepNoSleep, &handler));
-        worker->post(std::bind(&TestHandler::nextStepNoSleep, &handler));
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStepNoSleep();});
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStepNoSleep();});
+        worker->post([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStepNoSleep();});
 
         worker->stop();
         CPPUNIT_ASSERT_EQUAL(3, handler.m_step.load());
@@ -145,7 +142,7 @@ void WorkerTest::timerTest()
 
     std::chrono::milliseconds duration = std::chrono::milliseconds(100);
 
-    timer->setFunction(std::bind(&TestHandler::nextStepNoSleep, &handler));
+    timer->setFunction([ObjectPtr = &handler](auto&& ...){ObjectPtr->nextStepNoSleep();});
     timer->setDuration(duration);
 
     CPPUNIT_ASSERT(!timer->isRunning());
@@ -234,7 +231,7 @@ void WorkerTest::timerTest()
 
     // Be a bit tolerant, we have no 100% guarantee that timer will perform the requested number of ticks
     CPPUNIT_ASSERT_GREATEREQUAL(20, handler.m_step.load());
-    CPPUNIT_ASSERT_LESSEQUAL(26, handler.m_step.load());
+    CPPUNIT_ASSERT_LESSEQUAL(30, handler.m_step.load());
 
     duration = std::chrono::milliseconds(50);
     timer->setDuration(duration);
@@ -248,8 +245,8 @@ void WorkerTest::timerTest()
     }
 
     // Be a bit tolerant, we have no 100% guarantee that timer will perform the requested number of ticks
-    CPPUNIT_ASSERT_GREATEREQUAL(45, handler.m_step.load());
-    CPPUNIT_ASSERT_LESSEQUAL(51, handler.m_step.load());
+    CPPUNIT_ASSERT_GREATEREQUAL(40, handler.m_step.load());
+    CPPUNIT_ASSERT_LESSEQUAL(60, handler.m_step.load());
 
     timer->stop();
 
@@ -294,9 +291,9 @@ void WorkerTest::timerTest()
         duration = std::chrono::milliseconds(10);
         timer2->setFunction(
             [duration]()
-                {
-                    std::this_thread::sleep_for(duration * 90);
-                });
+            {
+                std::this_thread::sleep_for(duration * 90);
+            });
 
         timer2->setDuration(duration);
 
@@ -374,6 +371,4 @@ void WorkerTest::registryTest()
 
 //-----------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::core::thread
+} // namespace sight::core::thread::ut
