@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,32 +24,26 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::thread
-{
-
-namespace ut
+namespace sight::core::thread::ut
 {
 
 class WorkerTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE(WorkerTest);
 CPPUNIT_TEST(basicTest);
-// Disable timerTest because it fails randomly on a busy computer (see #253)
-//CPPUNIT_TEST( timerTest );
+CPPUNIT_TEST(timerTest);
 CPPUNIT_TEST(registryTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void basicTest();
-    void timerTest();
-    void registryTest();
+    static void basicTest();
+    static void timerTest();
+    static void registryTest();
 };
 
-} //namespace ut
-
-} //namespace sight::core::thread
+} // namespace sight::core::thread::ut
