@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::tools
-{
-
-namespace ut
+namespace sight::core::tools::ut
 {
 
 class FwIDTest : public CPPUNIT_NS::TestFixture
@@ -42,18 +39,16 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void objectFwIDTest();
+    static void objectFwIDTest();
 
-    void concurrentAccessOnFwIDMapTest();
+    static void concurrentAccessOnFwIDMapTest();
 
 private:
 
-    void runFwIDCreation();
+    static void runFwIDCreation();
 };
 
-} // namespace ut
-
-} // namespace sight::core::tools
+} // namespace sight::core::tools::ut
