@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,27 +24,26 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::core::tools
-{
-
-namespace ut
+namespace sight::core::tools::ut
 {
 
 class TypeTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE(TypeTest);
 CPPUNIT_TEST(typeTest);
+CPPUNIT_TEST(typeToStringTest);
+CPPUNIT_TEST(typeSwitchTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void typeTest();
+    static void typeTest();
+    static void typeToStringTest();
+    static void typeSwitchTest();
 };
 
-} // namespace ut
-
-} // namespace sight::core::tools
+} // namespace sight::core::tools::ut
