@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,8 +30,7 @@ Failed::Failed(const std::string& message) noexcept :
 {
 }
 
-Failed::~Failed() noexcept
-{
-}
+Failed::~Failed() noexcept =
+    default;
 
 } // namespace sight::core::tools
