@@ -35,7 +35,7 @@ namespace sight::data
  *
  * Boolean object is essentially used as a field in other objects.
  */
-class DATA_CLASS_API Boolean : public GenericField<bool>
+class DATA_CLASS_API Boolean final : public GenericField<bool>
 {
 public:
 
@@ -57,15 +57,21 @@ public:
     /**
      * @brief Destructor.
      */
-    DATA_API virtual ~Boolean() noexcept;
+    DATA_API ~Boolean() noexcept override = default;
 
     /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
-
-protected:
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
 };
 
 } // namespace sight::data
