@@ -27,6 +27,7 @@
 #include "data/timeline/Buffer.hpp"
 
 #include <boost/array.hpp>
+#include <boost/pool/pool.hpp>
 #include <boost/pool/poolfwd.hpp>
 
 namespace sight::data
@@ -40,7 +41,7 @@ class DATA_CLASS_API BufferTL : public TimeLine
 {
 public:
 
-    SIGHT_DECLARE_CLASS(BufferTL, Object);
+    SIGHT_DECLARE_CLASS(BufferTL, TimeLine);
 
     typedef core::HiResClock::HiResClockType TimestampType;
     typedef std::map<TimestampType, SPTR(timeline::Buffer)> TimelineType;
@@ -54,7 +55,7 @@ public:
     DATA_API BufferTL(Object::Key key);
 
     /// Destructor
-    DATA_API virtual ~BufferTL();
+    DATA_API ~BufferTL() override;
 
     /// Check if the type of an object is compatible with this timeline
     DATA_API virtual bool isObjectValid(const CSPTR(timeline::Object)& obj) const = 0;
@@ -64,13 +65,13 @@ public:
      * @param timestamp timestamp used to find the closest object
      * @param direction direction to find the closest object (PAST, FUTURE, BOTH)
      */
-    DATA_API virtual CSPTR(timeline::Object) getClosestObject(
+    DATA_API CSPTR(timeline::Object) getClosestObject(
         core::HiResClock::HiResClockType timestamp,
         DirectionType direction = BOTH
     ) const override;
 
     /// Return the object matching the specified timestamp, returns NULL if object is not found
-    DATA_API virtual CSPTR(timeline::Object) getObject(core::HiResClock::HiResClockType timestamp)
+    DATA_API CSPTR(timeline::Object) getObject(core::HiResClock::HiResClockType timestamp)
     const override;
 
     /// Clear the timeline
