@@ -41,7 +41,7 @@ namespace sight::data
  * and the second one contains pointList
  *
  */
-class DATA_CLASS_API CalibrationInfo : public Object
+class DATA_CLASS_API CalibrationInfo final : public Object
 {
 public:
 
@@ -73,14 +73,9 @@ public:
 
     ///Constructor
     DATA_API CalibrationInfo(Object::Key key);
+
     ///Destructor
-    DATA_API ~CalibrationInfo();
-
-    /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
-
-    /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    DATA_API ~CalibrationInfo() noexcept override = default;
 
     /**
      * @brief add an Image and a pointList into CalibrationInfo
@@ -145,6 +140,20 @@ public:
 
     /// @}
 
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
+
+    /// Defines deep copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
+
 protected:
 
     ///List of Image
