@@ -111,15 +111,12 @@ public:
     DATA_API Camera(Object::Key key);
 
     /// Destructor
-    DATA_API virtual ~Camera() noexcept;
+    DATA_API ~Camera() noexcept override = default;
 
     DATA_API static PixelFormat getPixelFormat(const std::string& name);
 
     DATA_API static std::string getPixelFormatName(PixelFormat format);
 
-    /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
-
     /**@name Signals API
      * @{
      */
@@ -273,18 +270,6 @@ public:
         m_cameraSource = cameraSource;
     }
 
-    /// Gets the human-readable description of the camera (only available in SourceType DEVICE mode).
-    std::string getDescription() const
-    {
-        return m_description;
-    }
-
-    /// Sets the human-readable description of the camera (only available in SourceType DEVICE mode).
-    void setDescription(const std::string& description)
-    {
-        m_description = description;
-    }
-
     /// Gets the device name of the camera (only available in SourceType DEVICE mode).
     std::string getCameraID() const
     {
@@ -370,40 +355,48 @@ public:
     DATA_API bool operator!=(const Camera& other) const noexcept;
     /// @}
 
-protected:
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
+
+protected:
 
     //! Width video resolution
-    std::size_t m_width;
+    std::size_t m_width {0};
 
     //! Height video resolution
-    std::size_t m_height;
+    std::size_t m_height {0};
 
     /// Intrinsic parameters [fx, fy, cx, cy]
-    IntrinsecType m_intrinsic;
+    IntrinsecType m_intrinsic {};
 
     /// Image distortion coefficients (radial and tangential distortions, [k1, k2, p1, p2, k3])
-    DistArrayType m_distortionCoefficient;
+    DistArrayType m_distortionCoefficient {};
 
     /// Skew coefficient (angle between the x and y pixel axes)
-    double m_skew;
+    double m_skew {0.};
 
     //! Flag if data is calibrated
-    bool m_isCalibrated;
-
-    //! Human-readable description of the camera.
-    std::string m_description;
+    bool m_isCalibrated {false};
 
     //! Device name of the camera, unique ID to identify the camera and may not be human-readable.
     std::string m_cameraID;
 
     //! Maximum frame rate in frames per second.
-    float m_maxFrameRate;
+    float m_maxFrameRate {30.F};
 
     //! Color format of a video frame.
-    PixelFormat m_pixelFormat;
+    PixelFormat m_pixelFormat {INVALID};
 
     //! Video source file
     std::filesystem::path m_videoFile;
@@ -412,10 +405,10 @@ protected:
     std::string m_streamUrl;
 
     //! Camera source (file, stream or device)
-    SourceType m_cameraSource;
+    SourceType m_cameraSource {UNKNOWN};
 
     //! Used for depth sensor: scale of the depth values (default: 1.)
-    double m_scale;
+    double m_scale {1.};
 };
 
 //-----------------------------------------------------------------------------
