@@ -34,7 +34,7 @@ namespace sight::data
 
 //------------------------------------------------------------------------------
 
-Color::Color(data::Object::Key)
+Color::Color(data::Object::Key /*unused*/)
 {
     m_vRGBA.fill(1.0);
 }
@@ -55,40 +55,40 @@ Color::sptr Color::New(
 
 //------------------------------------------------------------------------------
 
-Color::~Color()
+void Color::shallowCopy(const Object::csptr& source)
 {
+    const auto& other = dynamicConstCast(source);
+
+    SIGHT_THROW_EXCEPTION_IF(
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
+        ),
+        !bool(other)
+    );
+
+    m_vRGBA = other->m_vRGBA;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void Color::shallowCopy(const Object::csptr& _source)
+void Color::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    Color::csptr other = Color::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
-    m_vRGBA = other->m_vRGBA;
-}
 
-//------------------------------------------------------------------------------
-
-void Color::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
-{
-    Color::csptr other = Color::dynamicConstCast(_source);
-    SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
-        ),
-        !bool(other)
-    );
-    this->fieldDeepCopy(_source, cache);
     m_vRGBA = other->m_vRGBA;
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -109,10 +109,13 @@ void Color::setRGBA(const std::string& hexaColor)
         && (hexaColor.length() == 7 || hexaColor.length() == 9)
     );
 
-    const std::string redString = hexaColor.substr(1, 2);
+    const std::string redString   = hexaColor.substr(1, 2);
     const std::string greenString = hexaColor.substr(3, 2);
-    const std::string blueString = hexaColor.substr(5, 2);
-    std::int32_t r, g, b, a = 255;
+    const std::string blueString  = hexaColor.substr(5, 2);
+    std::int32_t r                = 0;
+    std::int32_t g                = 0;
+    std::int32_t b                = 0;
+    std::int32_t a                = 255;
 
     std::istringstream iss;
     iss.str(redString);
@@ -133,10 +136,10 @@ void Color::setRGBA(const std::string& hexaColor)
     }
 
     this->setRGBA(
-        static_cast<float>(r) / 255.0f,
-        static_cast<float>(g) / 255.0f,
-        static_cast<float>(b) / 255.0f,
-        static_cast<float>(a) / 255.0f
+        static_cast<float>(r) / 255.0F,
+        static_cast<float>(g) / 255.0F,
+        static_cast<float>(b) / 255.0F,
+        static_cast<float>(a) / 255.0F
     );
 }
 
@@ -207,7 +210,7 @@ bool Color::operator==(const Color& other) const noexcept
     }
 
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
