@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,55 +35,47 @@ namespace sight::data
 {
 
 DicomSeries::DicomSeries(data::Object::Key _key) :
-    Series(_key),
-    m_numberOfInstances(0),
-    m_firstInstanceNumber(0)
+    Series(_key)
 {
 }
 
 //------------------------------------------------------------------------------
 
-DicomSeries::~DicomSeries()
+void DicomSeries::shallowCopy(const Object::csptr& source)
 {
-}
+    const auto& other = dynamicConstCast(source);
 
-//------------------------------------------------------------------------------
-
-void DicomSeries::shallowCopy(const data::Object::csptr& _source)
-{
-    DicomSeries::csptr other = DicomSeries::dynamicConstCast(_source);
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy " + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
 
-    this->data::Series::shallowCopy(_source);
-
     m_numberOfInstances   = other->m_numberOfInstances;
     m_dicomContainer      = other->m_dicomContainer;
     m_SOPClassUIDs        = other->m_SOPClassUIDs;
     m_computedTagValues   = other->m_computedTagValues;
     m_firstInstanceNumber = other->m_firstInstanceNumber;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void DicomSeries::cachedDeepCopy(const data::Object::csptr& _source, DeepCopyCacheType& cache)
+void DicomSeries::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    DicomSeries::csptr other = DicomSeries::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy " + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
 
-    this->data::Series::cachedDeepCopy(_source, cache);
-
     m_numberOfInstances   = other->m_numberOfInstances;
     m_SOPClassUIDs        = other->m_SOPClassUIDs;
     m_computedTagValues   = other->m_computedTagValues;
@@ -97,7 +89,7 @@ void DicomSeries::cachedDeepCopy(const data::Object::csptr& _source, DeepCopyCac
 
         if(!bufferSrc->isEmpty())
         {
-            core::memory::BufferObject::sptr bufferDest = core::memory::BufferObject::New();
+            auto bufferDest = core::memory::BufferObject::New(true);
             core::memory::BufferObject::Lock lockerDest(bufferDest);
 
             bufferDest->allocate(bufferSrc->getSize());
@@ -109,6 +101,8 @@ void DicomSeries::cachedDeepCopy(const data::Object::csptr& _source, DeepCopyCac
             m_dicomContainer[elt.first] = bufferDest;
         }
     }
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -126,8 +120,8 @@ void DicomSeries::addDicomPath(std::size_t _instanceIndex, const std::filesystem
         !std::filesystem::exists(_path)
     );
 
-    core::memory::BufferObject::sptr buffer = core::memory::BufferObject::New();
-    const auto buffSize                     = std::filesystem::file_size(_path);
+    auto buffer         = core::memory::BufferObject::New(true);
+    const auto buffSize = std::filesystem::file_size(_path);
     buffer->setIStreamFactory(
         std::make_shared<core::memory::stream::in::Raw>(_path),
         static_cast<core::memory::BufferObject::SizeType>(buffSize),
@@ -187,7 +181,7 @@ bool DicomSeries::operator==(const DicomSeries& other) const noexcept
     }
 
     // Super class last
-    return Series::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
