@@ -33,39 +33,45 @@ namespace sight::data
 
 //------------------------------------------------------------------------------
 
-Float::Float(data::Object::Key) noexcept
+Float::Float(data::Object::Key /*unused*/) noexcept
 {
 }
 
 //------------------------------------------------------------------------------
-void Float::shallowCopy(const Object::csptr& _source)
+void Float::shallowCopy(const Object::csptr& source)
 {
-    Float::csptr other = Float::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
+
     m_value = other->m_value;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void Float::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
+void Float::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    Float::csptr other = Float::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldDeepCopy(_source, cache);
+
     m_value = other->m_value;
+
+    BaseClass::deepCopy(other, cache);
 }
 
 } // namespace sight::data
