@@ -40,16 +40,9 @@ class DATA_CLASS_API GenericFieldBase : public Object
 {
 public:
 
-    SIGHT_DECLARE_CLASS(GenericFieldBase);
+    SIGHT_DECLARE_CLASS(GenericFieldBase, Object);
 
-    DATA_API virtual bool operator==(const GenericFieldBase& lf) const = 0;
-    DATA_API virtual bool operator!=(const GenericFieldBase& lf) const = 0;
-    DATA_API virtual bool operator<(const GenericFieldBase& lf) const  = 0;
-    DATA_API virtual bool operator>(const GenericFieldBase& lf) const  = 0;
-    DATA_API virtual bool operator<=(const GenericFieldBase& lf) const = 0;
-    DATA_API virtual bool operator>=(const GenericFieldBase& lf) const = 0;
-
-    DATA_API friend std::ostream& operator<<(std::ostream&, const GenericFieldBase&);
+    DATA_API friend std::ostream& operator<<(std::ostream& /*_os*/, const GenericFieldBase& /*lf*/);
 
     DATA_API virtual std::string toString() const               = 0;
     DATA_API virtual void fromString(const std::string& _value) = 0;
