@@ -34,7 +34,7 @@ namespace sight::data
  * @brief   This class contains an integer value.
  * Integer object is essentially used as a field in other objects.
  */
-class DATA_CLASS_API Integer : public GenericField<std::int64_t>
+class DATA_CLASS_API Integer final : public GenericField<std::int64_t>
 {
 public:
 
@@ -56,15 +56,21 @@ public:
     /**
      * @brief Destructor.
      */
-    DATA_API virtual ~Integer() noexcept;
+    DATA_API ~Integer() noexcept override = default;
 
     /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
-
-protected:
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
 };
 
 } // namespace sight::data
