@@ -34,48 +34,48 @@ namespace sight::data
 
 //------------------------------------------------------------------------------
 
-Line::Line(data::Object::Key)
+Line::Line(data::Object::Key /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-Line::~Line()
+void Line::shallowCopy(const Object::csptr& source)
 {
-}
+    const auto& other = dynamicConstCast(source);
 
-//------------------------------------------------------------------------------
-
-void Line::shallowCopy(const Object::csptr& _source)
-{
-    Line::csptr other = Line::dynamicConstCast(_source);
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
+
     m_position  = other->m_position;
     m_direction = other->m_direction;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void Line::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
+void Line::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    Line::csptr other = Line::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldDeepCopy(_source, cache);
+
     m_position  = data::Object::copy(other->m_position, cache);
     m_direction = data::Object::copy(other->m_direction, cache);
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -97,7 +97,7 @@ bool Line::operator==(const Line& other) const noexcept
     }
 
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
