@@ -34,72 +34,66 @@ namespace sight::data
 
 Matrix4::Matrix4()
 {
-    m_vCoefficients = s_IDENTITY;
+    *this = s_IDENTITY;
 }
 
 //------------------------------------------------------------------------------
 
-Matrix4::Matrix4(data::Object::Key)
+Matrix4::Matrix4(std::initializer_list<value_type> init_list)
 {
-    m_vCoefficients = s_IDENTITY;
+    SIGHT_ASSERT("16 values should be provided to the constructor  of the matrix", init_list.size() == this->size());
+    std::copy(init_list.begin(), init_list.end(), this->begin());
 }
 
 //------------------------------------------------------------------------------
 
-Matrix4::~Matrix4()
+Matrix4::Matrix4(data::Object::Key /*unused*/)
 {
+    *this = s_IDENTITY;
+}
+
+//------------------------------------------------------------------------------
+Matrix4& Matrix4::operator=(std::initializer_list<value_type> init_list)
+{
+    SIGHT_ASSERT("16 values should be provided to the constructor  of the matrix", init_list.size() == this->size());
+    std::copy(init_list.begin(), init_list.end(), this->begin());
+    return *this;
 }
 
 //-----------------------------------------------------------------------------
 
-void Matrix4::shallowCopy(const Object::csptr& _source)
+void Matrix4::shallowCopy(const Object::csptr& source)
 {
-    Matrix4::csptr other = Matrix4::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
-    m_vCoefficients = other->m_vCoefficients;
-}
 
-//-----------------------------------------------------------------------------
-
-void Matrix4::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
-{
-    Matrix4::csptr other = Matrix4::dynamicConstCast(_source);
-    SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
-        ),
-        !bool(other)
-    );
-    this->fieldDeepCopy(_source, cache);
-    m_vCoefficients = other->m_vCoefficients;
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-bool Matrix4::operator==(const Matrix4& other) const noexcept
+void Matrix4::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    if(!core::tools::is_equal(m_vCoefficients, other.m_vCoefficients))
-    {
-        return false;
-    }
+    const auto& other = dynamicConstCast(source);
 
-    // Super class last
-    return Object::operator==(other);
+    SIGHT_THROW_EXCEPTION_IF(
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
+        ),
+        !bool(other)
+    );
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
 
-bool Matrix4::operator!=(const Matrix4& other) const noexcept
-{
-    return !(*this == other);
-}
-
 } // namespace sight::data
