@@ -34,9 +34,8 @@
 namespace sight::data
 {
 
-#define POINT_REALLOC_STEP 1000
-#define CELL_REALLOC_STEP 1000
-#define CELLDATA_REALLOC_STEP 1000
+constexpr int POINT_REALLOC_STEP    = 1000;
+constexpr int CELLDATA_REALLOC_STEP = 1000;
 
 SIGHT_REGISTER_DATA(sight::data::Mesh);
 
@@ -66,7 +65,7 @@ const core::com::Signals::SignalKeyType Mesh::s_CELL_TEX_COORDS_MODIFIED_SIG  =
 
 //------------------------------------------------------------------------------
 
-Mesh::Mesh(data::Object::Key)
+Mesh::Mesh(data::Object::Key /*unused*/)
 {
     newSignal<signal_t>(s_VERTEX_MODIFIED_SIG);
     newSignal<signal_t>(s_POINT_COLORS_MODIFIED_SIG);
@@ -76,52 +75,48 @@ Mesh::Mesh(data::Object::Key)
     newSignal<signal_t>(s_POINT_TEX_COORDS_MODIFIED_SIG);
     newSignal<signal_t>(s_CELL_TEX_COORDS_MODIFIED_SIG);
 
-    std::for_each(m_points.begin(), m_points.end(), [](auto& array){array = data::Array::New();});
-    std::for_each(m_cells.begin(), m_cells.end(), [](auto& array){array = data::Array::New();});
+    std::ranges::for_each(m_points, [](auto& array){array = data::Array::New();});
+    std::ranges::for_each(m_cells, [](auto& array){array = data::Array::New();});
 }
 
 //------------------------------------------------------------------------------
 
-Mesh::~Mesh()
+void Mesh::shallowCopy(const Object::csptr& source)
 {
-}
+    const auto& other = dynamicConstCast(source);
 
-//------------------------------------------------------------------------------
-
-void Mesh::shallowCopy(const Object::csptr& _source)
-{
-    Mesh::csptr other = Mesh::dynamicConstCast(_source);
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
 
     m_numPoints  = other->m_numPoints;
     m_attributes = other->m_attributes;
     m_numCells   = other->m_numCells;
     m_cellType   = other->m_cellType;
 
-    std::copy(other->m_points.begin(), other->m_points.end(), m_points.begin());
-    std::copy(other->m_cells.begin(), other->m_cells.end(), m_cells.begin());
+    std::copy(other->m_points.cbegin(), other->m_points.cend(), m_points.begin());
+    std::copy(other->m_cells.cbegin(), other->m_cells.cend(), m_cells.begin());
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void Mesh::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
+void Mesh::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    Mesh::csptr other = Mesh::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !other
     );
-    this->fieldDeepCopy(_source, cache);
 
     m_numPoints  = other->m_numPoints;
     m_attributes = other->m_attributes;
@@ -137,6 +132,8 @@ void Mesh::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache
     {
         m_cells[i] = data::Object::copy(other->m_cells[i], cache);
     }
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -149,47 +146,63 @@ std::size_t Mesh::reserve(Mesh::size_t nbPts, Mesh::size_t nbCells, CellType cel
 
     m_points[static_cast<std::size_t>(PointAttribute::POSITION)]->resize(
         {3, nbPts},
-        core::tools::Type::create<position_t>()
+        core::Type::get<position_t>()
     );
 
     m_attributes = m_attributes | arrayMask;
 
-    // TODO sight 22.0: Add a second dimension on the array to replace the deprecated component
-
     // Test attributes mask, if present resize corresponding array, if not check if array needs to be cleared.
-    if(static_cast<int>(arrayMask & Attributes::POINT_COLORS))
+    if(static_cast<int>(arrayMask & Attributes::POINT_COLORS) != 0)
     {
-        m_points[static_cast<std::size_t>(PointAttribute::COLORS)]->resize({4, nbPts}, core::tools::Type::s_UINT8);
+        m_points[static_cast<std::size_t>(PointAttribute::COLORS)]->resize(
+            {4, nbPts},
+            core::Type(core::Type::UINT8)
+        );
     }
 
-    if(static_cast<int>(arrayMask & Attributes::POINT_NORMALS))
+    if(static_cast<int>(arrayMask & Attributes::POINT_NORMALS) != 0)
     {
-        m_points[static_cast<std::size_t>(PointAttribute::NORMALS)]->resize({3, nbPts}, core::tools::Type::s_FLOAT);
+        m_points[static_cast<std::size_t>(PointAttribute::NORMALS)]->resize(
+            {3, nbPts},
+            core::Type(core::Type::FLOAT)
+        );
     }
 
-    if(static_cast<int>(arrayMask & Attributes::POINT_TEX_COORDS))
+    if(static_cast<int>(arrayMask & Attributes::POINT_TEX_COORDS) != 0)
     {
-        m_points[static_cast<std::size_t>(PointAttribute::TEX_COORDS)]->resize({2, nbPts}, core::tools::Type::s_FLOAT);
+        m_points[static_cast<std::size_t>(PointAttribute::TEX_COORDS)]->resize(
+            {2, nbPts},
+            core::Type(core::Type::FLOAT)
+        );
     }
 
     m_cells[static_cast<std::size_t>(CellAttribute::INDEX)]->resize(
         {getCellSize(), nbCells},
-        core::tools::Type::create<cell_t>()
+        core::Type::get<cell_t>()
     );
 
-    if(static_cast<int>(arrayMask & Attributes::CELL_COLORS))
+    if(static_cast<int>(arrayMask & Attributes::CELL_COLORS) != 0)
     {
-        m_cells[static_cast<std::size_t>(CellAttribute::COLORS)]->resize({4, nbCells}, core::tools::Type::s_UINT8);
+        m_cells[static_cast<std::size_t>(CellAttribute::COLORS)]->resize(
+            {4, nbCells},
+            core::Type(core::Type::UINT8)
+        );
     }
 
-    if(static_cast<int>(arrayMask & Attributes::CELL_NORMALS))
+    if(static_cast<int>(arrayMask & Attributes::CELL_NORMALS) != 0)
     {
-        m_cells[static_cast<std::size_t>(CellAttribute::NORMALS)]->resize({3, nbCells}, core::tools::Type::s_FLOAT);
+        m_cells[static_cast<std::size_t>(CellAttribute::NORMALS)]->resize(
+            {3, nbCells},
+            core::Type(core::Type::FLOAT)
+        );
     }
 
-    if(static_cast<int>(arrayMask & Attributes::CELL_TEX_COORDS))
+    if(static_cast<int>(arrayMask & Attributes::CELL_TEX_COORDS) != 0)
     {
-        m_cells[static_cast<std::size_t>(CellAttribute::TEX_COORDS)]->resize({2, nbCells}, core::tools::Type::s_FLOAT);
+        m_cells[static_cast<std::size_t>(CellAttribute::TEX_COORDS)]->resize(
+            {2, nbCells},
+            core::Type(core::Type::FLOAT)
+        );
     }
 
     return this->getAllocatedSizeInBytes();
@@ -215,32 +228,32 @@ bool Mesh::shrinkToFit()
     m_points[static_cast<std::size_t>(PointAttribute::POSITION)]->resize({3, m_numPoints});
     m_cells[static_cast<std::size_t>(CellAttribute::INDEX)]->resize({getCellSize(), m_numCells});
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_COLORS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_COLORS) != 0U)
     {
         m_points[static_cast<std::size_t>(PointAttribute::COLORS)]->resize({4, std::size_t(m_numPoints)});
     }
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_NORMALS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_NORMALS) != 0U)
     {
         m_points[static_cast<std::size_t>(PointAttribute::NORMALS)]->resize({3, std::size_t(m_numPoints)});
     }
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_TEX_COORDS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::POINT_TEX_COORDS) != 0U)
     {
         m_points[static_cast<std::size_t>(PointAttribute::TEX_COORDS)]->resize({2, std::size_t(m_numPoints)});
     }
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_COLORS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_COLORS) != 0U)
     {
         m_cells[static_cast<std::size_t>(CellAttribute::COLORS)]->resize({4, std::size_t(m_numCells)});
     }
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_NORMALS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_NORMALS) != 0U)
     {
         m_cells[static_cast<std::size_t>(CellAttribute::NORMALS)]->resize({3, std::size_t(m_numCells)});
     }
 
-    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_TEX_COORDS))
+    if(static_cast<std::uint8_t>(m_attributes & Attributes::CELL_TEX_COORDS) != 0U)
     {
         m_cells[static_cast<std::size_t>(CellAttribute::TEX_COORDS)]->resize({2, std::size_t(m_numCells)});
     }
@@ -274,8 +287,8 @@ void Mesh::truncate(Mesh::size_t nbPts, Mesh::size_t nbCells)
 
 void Mesh::clear()
 {
-    std::for_each(m_points.begin(), m_points.end(), [](auto& array){array->clear();});
-    std::for_each(m_cells.begin(), m_cells.end(), [](auto& array){array->clear();});
+    std::ranges::for_each(m_points, [](auto& array){array->clear();});
+    std::ranges::for_each(m_cells, [](auto& array){array->clear();});
 
     // Reset nbPoints, nbCells & cellsDataSize.
     m_numPoints = 0;
@@ -290,9 +303,8 @@ std::size_t Mesh::getDataSizeInBytes() const
 {
     std::size_t size = 0;
 
-    std::for_each(
-        m_points.begin(),
-        m_points.end(),
+    std::ranges::for_each(
+        m_points,
         [&](auto& array)
         {
             const auto numComponents = array->empty() ? 1 : array->getSize()[0];
@@ -300,9 +312,8 @@ std::size_t Mesh::getDataSizeInBytes() const
                                        * static_cast<std::size_t>(m_numPoints);
         });
 
-    std::for_each(
-        m_cells.begin(),
-        m_cells.end(),
+    std::ranges::for_each(
+        m_cells,
         [&](auto& array)
         {
             const auto numComponents = array->empty() ? 1 : array->getSize()[0];
@@ -319,15 +330,15 @@ std::size_t Mesh::getAllocatedSizeInBytes() const
 {
     std::size_t size = 0;
 
-    std::for_each(m_points.begin(), m_points.end(), [&](auto& array){size += array->getSizeInBytes();});
-    std::for_each(m_cells.begin(), m_cells.end(), [&](auto& array){size += array->getSizeInBytes();});
+    std::ranges::for_each(m_points, [&](auto& array){size += array->getSizeInBytes();});
+    std::ranges::for_each(m_cells, [&](auto& array){size += array->getSizeInBytes();});
 
     return size;
 }
 
 //------------------------------------------------------------------------------
 
-Mesh::point_t Mesh::pushPoint(const position_t p[3])
+Mesh::point_t Mesh::pushPoint(const std::array<position_t, 3>& p)
 {
     const auto nbPoints = m_numPoints;
 
@@ -336,12 +347,12 @@ Mesh::point_t Mesh::pushPoint(const position_t p[3])
 
     if(allocatedPts <= nbPoints)
     {
-        positions->resize({3, allocatedPts + POINT_REALLOC_STEP}, core::tools::Type::create<position_t>(), true);
+        positions->resize({3, allocatedPts + POINT_REALLOC_STEP}, core::Type::get<position_t>(), true);
         if(this->has<data::Mesh::Attributes::POINT_COLORS>())
         {
             m_points[static_cast<std::size_t>(PointAttribute::COLORS)]->resize(
                 {4, allocatedPts + POINT_REALLOC_STEP},
-                core::tools::Type::create<color_t>(),
+                core::Type::get<color_t>(),
                 true
             );
         }
@@ -350,7 +361,7 @@ Mesh::point_t Mesh::pushPoint(const position_t p[3])
         {
             m_points[static_cast<std::size_t>(PointAttribute::NORMALS)]->resize(
                 {3, allocatedPts + POINT_REALLOC_STEP},
-                core::tools::Type::create<normal_t>(),
+                core::Type::get<normal_t>(),
                 true
             );
         }
@@ -359,7 +370,7 @@ Mesh::point_t Mesh::pushPoint(const position_t p[3])
         {
             m_points[static_cast<std::size_t>(PointAttribute::TEX_COORDS)]->resize(
                 {2, allocatedPts + POINT_REALLOC_STEP},
-                core::tools::Type::create<texcoord_t>(),
+                core::Type::get<texcoord_t>(),
                 true
             );
         }
@@ -375,40 +386,36 @@ Mesh::point_t Mesh::pushPoint(const position_t p[3])
 
 Mesh::point_t Mesh::pushPoint(position_t x, position_t y, position_t z)
 {
-    const data::Mesh::position_t p[3] = {x, y, z};
-    return this->pushPoint(p);
+    return this->pushPoint({x, y, z});
 }
 
 //------------------------------------------------------------------------------
 
 Mesh::cell_t Mesh::pushCell(point_t idPt)
 {
-    point_t point[1] = {idPt};
-    return this->pushCell(point, 1);
+    std::vector pointIds = {idPt};
+    return this->pushCell(pointIds);
 }
 
 //------------------------------------------------------------------------------
 
 Mesh::cell_t Mesh::pushCell(point_t idP1, point_t idP2)
 {
-    const point_t p[2] = {idP1, idP2};
-    return this->pushCell(p, 2);
+    return this->pushCell({idP1, idP2});
 }
 
 //------------------------------------------------------------------------------
 
 Mesh::cell_t Mesh::pushCell(point_t idP1, point_t idP2, point_t idP3)
 {
-    const point_t p[3] = {idP1, idP2, idP3};
-    return this->pushCell(p, 3);
+    return this->pushCell({idP1, idP2, idP3});
 }
 
 //------------------------------------------------------------------------------
 
 Mesh::cell_t Mesh::pushCell(point_t idP1, point_t idP2, point_t idP3, point_t idP4)
 {
-    const point_t p[4] = {idP1, idP2, idP3, idP4};
-    return this->pushCell(p, 4);
+    return this->pushCell({idP1, idP2, idP3, idP4});
 }
 
 //------------------------------------------------------------------------------
@@ -443,12 +450,12 @@ Mesh::cell_t Mesh::pushCell(const point_t* pointIds, std::size_t nbPoints)
     const auto cellSize          = getCellSize();
     if(allocatedCellData <= m_numCells)
     {
-        cells->resize({cellSize, allocatedCellData + CELLDATA_REALLOC_STEP}, core::tools::Type::create<cell_t>());
+        cells->resize({cellSize, allocatedCellData + CELLDATA_REALLOC_STEP}, core::Type::get<cell_t>());
         if(this->has<data::Mesh::Attributes::CELL_COLORS>())
         {
             m_cells[static_cast<std::size_t>(CellAttribute::COLORS)]->resize(
                 {4, allocatedCellData + CELLDATA_REALLOC_STEP},
-                core::tools::Type::create<color_t>(),
+                core::Type::get<color_t>(),
                 true
             );
         }
@@ -457,7 +464,7 @@ Mesh::cell_t Mesh::pushCell(const point_t* pointIds, std::size_t nbPoints)
         {
             m_cells[static_cast<std::size_t>(CellAttribute::NORMALS)]->resize(
                 {3, allocatedCellData + CELLDATA_REALLOC_STEP},
-                core::tools::Type::create<normal_t>(),
+                core::Type::get<normal_t>(),
                 true
             );
         }
@@ -466,7 +473,7 @@ Mesh::cell_t Mesh::pushCell(const point_t* pointIds, std::size_t nbPoints)
         {
             m_cells[static_cast<std::size_t>(CellAttribute::TEX_COORDS)]->resize(
                 {2, allocatedCellData + CELLDATA_REALLOC_STEP},
-                core::tools::Type::create<texcoord_t>(),
+                core::Type::get<texcoord_t>(),
                 true
             );
         }
@@ -475,7 +482,7 @@ Mesh::cell_t Mesh::pushCell(const point_t* pointIds, std::size_t nbPoints)
     for(std::size_t i = 0 ; i < nbPoints ; ++i)
     {
         const point_t cellValue = pointIds[i];
-        cells->at<cell_t>(m_numCells * cellSize + i) = cellValue;
+        cells->at<cell_t>(static_cast<std::size_t>(m_numCells) * cellSize + i) = cellValue;
     }
 
     ++m_numCells;
@@ -484,12 +491,12 @@ Mesh::cell_t Mesh::pushCell(const point_t* pointIds, std::size_t nbPoints)
 
 //------------------------------------------------------------------------------
 
-void Mesh::setPoint(point_t id, const data::Mesh::position_t p[3])
+void Mesh::setPoint(point_t id, const std::array<position_t, 3>& p)
 {
     auto& points = m_points[static_cast<std::size_t>(PointAttribute::POSITION)];
-    points->at<position_t>(3 * id)     = p[0];
-    points->at<position_t>(3 * id + 1) = p[1];
-    points->at<position_t>(3 * id + 2) = p[2];
+    points->at<position_t>(3LL * id)     = p[0];
+    points->at<position_t>(3LL * id + 1) = p[1];
+    points->at<position_t>(3LL * id + 2) = p[2];
 }
 
 //------------------------------------------------------------------------------
@@ -501,32 +508,29 @@ void Mesh::setPoint(
     data::Mesh::position_t z
 )
 {
-    const data::Mesh::position_t p[3] = {x, y, z};
-    this->setPoint(id, p);
+    this->setPoint(id, {x, y, z});
 }
 
 //------------------------------------------------------------------------------
 
 void Mesh::setCell(cell_t id, point_t idPt)
 {
-    const point_t p[1] = {idPt};
-    this->setCell(id, p, 12);
+    std::vector pointIds = {idPt};
+    this->setCell(id, pointIds);
 }
 
 //------------------------------------------------------------------------------
 
 void Mesh::setCell(cell_t id, point_t idP1, point_t idP2)
 {
-    const point_t p[2] = {idP1, idP2};
-    this->setCell(id, p, 2);
+    this->setCell(id, {idP1, idP2});
 }
 
 //------------------------------------------------------------------------------
 
 void Mesh::setCell(cell_t id, point_t idP1, point_t idP2, point_t idP3)
 {
-    const point_t p[3] = {idP1, idP2, idP3};
-    this->setCell(id, p, 3);
+    this->setCell(id, {idP1, idP2, idP3});
 }
 
 //------------------------------------------------------------------------------
@@ -539,8 +543,7 @@ void Mesh::setCell(
     point_t idP4
 )
 {
-    const point_t p[4] = {idP1, idP2, idP3, idP4};
-    this->setCell(id, p, 4);
+    this->setCell(id, {idP1, idP2, idP3, idP4});
 }
 
 //------------------------------------------------------------------------------
@@ -570,7 +573,7 @@ void Mesh::setCell(cell_t id, const point_t* pointIds, std::size_t nbPoints)
     for(std::size_t i = 0 ; i < nbPoints ; ++i)
     {
         const cell_t cellValue = pointIds[i];
-        cells->at<cell_t>(getCellSize() * id + i) = cellValue;
+        cells->at<cell_t>(static_cast<std::size_t>(getCellSize()) * id + i) = cellValue;
     }
 }
 
@@ -592,10 +595,10 @@ void Mesh::setPointColor(
 )
 {
     auto& colors = m_points[static_cast<std::size_t>(PointAttribute::COLORS)];
-    colors->at<color_t>(4 * id)     = r;
-    colors->at<color_t>(4 * id + 1) = g;
-    colors->at<color_t>(4 * id + 2) = b;
-    colors->at<color_t>(4 * id + 3) = a;
+    colors->at<color_t>(4LL * id)     = r;
+    colors->at<color_t>(4LL * id + 1) = g;
+    colors->at<color_t>(4LL * id + 2) = b;
+    colors->at<color_t>(4LL * id + 3) = a;
 }
 
 //------------------------------------------------------------------------------
@@ -616,10 +619,10 @@ void Mesh::setCellColor(
 )
 {
     auto& colors = m_cells[static_cast<std::size_t>(CellAttribute::COLORS)];
-    colors->at<color_t>(4 * id)     = r;
-    colors->at<color_t>(4 * id + 1) = g;
-    colors->at<color_t>(4 * id + 2) = b;
-    colors->at<color_t>(4 * id + 3) = a;
+    colors->at<color_t>(4LL * id)     = r;
+    colors->at<color_t>(4LL * id + 1) = g;
+    colors->at<color_t>(4LL * id + 2) = b;
+    colors->at<color_t>(4LL * id + 3) = a;
 }
 
 //------------------------------------------------------------------------------
@@ -639,9 +642,9 @@ void Mesh::setPointNormal(
 )
 {
     auto& normals = m_points[static_cast<std::size_t>(PointAttribute::NORMALS)];
-    normals->at<normal_t>(3 * id)     = nx;
-    normals->at<normal_t>(3 * id + 1) = ny;
-    normals->at<normal_t>(3 * id + 2) = nz;
+    normals->at<normal_t>(3LL * id)     = nx;
+    normals->at<normal_t>(3LL * id + 1) = ny;
+    normals->at<normal_t>(3LL * id + 2) = nz;
 }
 
 //------------------------------------------------------------------------------
@@ -661,9 +664,9 @@ void Mesh::setCellNormal(
 )
 {
     auto& normals = m_cells[static_cast<std::size_t>(CellAttribute::NORMALS)];
-    normals->at<normal_t>(3 * id)     = nx;
-    normals->at<normal_t>(3 * id + 1) = ny;
-    normals->at<normal_t>(3 * id + 2) = nz;
+    normals->at<normal_t>(3LL * id)     = nx;
+    normals->at<normal_t>(3LL * id + 1) = ny;
+    normals->at<normal_t>(3LL * id + 2) = nz;
 }
 
 //------------------------------------------------------------------------------
@@ -682,8 +685,8 @@ void Mesh::setPointTexCoord(
 )
 {
     auto& texCoords = m_points[static_cast<std::size_t>(PointAttribute::TEX_COORDS)];
-    texCoords->at<texcoord_t>(2 * id)     = u;
-    texCoords->at<texcoord_t>(2 * id + 1) = v;
+    texCoords->at<texcoord_t>(2LL * id)     = u;
+    texCoords->at<texcoord_t>(2LL * id + 1) = v;
 }
 
 //------------------------------------------------------------------------------
@@ -702,8 +705,8 @@ void Mesh::setCellTexCoord(
 )
 {
     auto& texCoords = m_cells[static_cast<std::size_t>(CellAttribute::TEX_COORDS)];
-    texCoords->at<texcoord_t>(2 * id)     = u;
-    texCoords->at<texcoord_t>(2 * id + 1) = v;
+    texCoords->at<texcoord_t>(2LL * id)     = u;
+    texCoords->at<texcoord_t>(2LL * id + 1) = v;
 }
 
 //------------------------------------------------------------------------------
@@ -738,7 +741,7 @@ bool Mesh::operator==(const Mesh& other) const noexcept
     }
 
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
