@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,13 +20,12 @@
  *
  ***********************************************************************/
 
-//FIXME :This needs to be include first for GCC
-#include <core/com/Signal.hpp>
-#include <core/com/Signal.hxx>
-//
-#include "data/factory/new.hpp"
 #include "data/Object.hpp"
 
+#include "data/factory/new.hpp"
+
+#include <core/com/Signal.hxx>
+
 #include <functional>
 
 namespace sight::data
@@ -51,16 +50,10 @@ Object::Object()
 
 //------------------------------------------------------------------------------
 
-Object::~Object()
-{
-}
-
-//------------------------------------------------------------------------------
-
 data::Object::sptr Object::getField(const FieldNameType& name, data::Object::sptr defaultValue) const
 {
-    data::Object::sptr object         = defaultValue;
-    FieldMapType::const_iterator iter = m_fields.find(name);
+    data::Object::sptr object = defaultValue;
+    auto iter                 = m_fields.find(name);
     if(iter != m_fields.end())
     {
         object = iter->second;
@@ -92,8 +85,7 @@ Object::FieldNameVectorType Object::getFieldNames() const
         m_fields.begin(),
         m_fields.end(),
         std::back_inserter(names),
-        std::bind(&FieldMapType::value_type::first, std::placeholders::_1)
-    );
+        [](const auto& e){return e.first;});
     return names;
 }
 
@@ -119,7 +111,7 @@ void Object::setFields(const FieldMapType& fieldMap)
 
 void Object::removeField(const FieldNameType& name)
 {
-    FieldMapType::const_iterator iter = m_fields.find(name);
+    auto iter = m_fields.find(name);
     SIGHT_ASSERT("Field " << name << " not found.", iter != m_fields.end());
     if(iter != m_fields.end())
     {
@@ -127,93 +119,75 @@ void Object::removeField(const FieldNameType& name)
     }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
-void Object::fieldShallowCopy(const data::Object::csptr& source)
+void Object::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    this->setFields(source->getFields());
-}
+    SIGHT_ASSERT("Cache shall not be null !", cache);
 
-//-----------------------------------------------------------------------------
+    // Copy members
+    m_description = source->m_description;
 
-void Object::deepCopy(const data::Object::csptr& source)
-{
-    DeepCopyCacheType cache;
-    return this->cachedDeepCopy(source, cache);
-}
-
-//-----------------------------------------------------------------------------
-
-void Object::fieldDeepCopy(const data::Object::csptr& source)
-{
-    DeepCopyCacheType cache;
-    return this->fieldDeepCopy(source, cache);
-}
-
-//-----------------------------------------------------------------------------
-
-void Object::fieldDeepCopy(const data::Object::csptr& source, DeepCopyCacheType& cache)
-{
+    // Deep copy fields
     m_fields.clear();
-    const data::Object::FieldMapType& sourceFields = source->getFields();
-    for(const data::Object::FieldMapType::value_type& elt : sourceFields)
+
+    for(const auto& [key, value] : source->m_fields)
     {
-        this->setField(elt.first, data::Object::copy(elt.second, cache));
+        m_fields.insert_or_assign(key, Object::copy(value, cache));
     }
 }
 
 //-----------------------------------------------------------------------------
 
-void Object::shallowCopy(const data::Object::csptr& source)
+void Object::shallowCopy(const Object::csptr& source)
 {
-    SIGHT_NOT_USED(source);
-    SIGHT_FATAL("shallowCopy not implemented for : " + this->getClassname());
+    // Copy members
+    m_description = source->m_description;
+
+    // Shallow copy fields
+    m_fields = source->m_fields;
 }
 
 //-----------------------------------------------------------------------------
 
-data::Object::sptr Object::copy(const data::Object::csptr& source)
+data::Object::sptr Object::copy(const data::Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    DeepCopyCacheType cache;
-    return Object::copy(source, cache);
-}
+    SIGHT_ASSERT("Cache shall not be null !", cache);
 
-//-----------------------------------------------------------------------------
-
-data::Object::sptr Object::copy(const data::Object::csptr& source, Object::DeepCopyCacheType& cache)
-{
-    data::Object::sptr obj;
-
-    if(source)
+    if(!source)
     {
-        DeepCopyCacheType::const_iterator cacheItem = cache.find(source);
-
-        if(cacheItem == cache.end())
-        {
-            obj = data::factory::New(source->getClassname());
-            SIGHT_ASSERT("Could not create object of type : " + source->getClassname(), obj);
-            cache.insert(DeepCopyCacheType::value_type(source, obj));
-            obj->cachedDeepCopy(source, cache);
-        }
-        else
-        {
-            obj = cacheItem->second;
-        }
+        return nullptr;
     }
 
-    return obj;
+    // Check if the object is already in the cache
+    if(const auto& it = cache->find(source); it != cache->cend())
+    {
+        return it->second;
+    }
+
+    // Not found in cache, we crete a new copy
+    auto object_copy = data::factory::New(source->getClassname());
+    SIGHT_ASSERT("Could not create object of type : " + source->getClassname(), object_copy);
+
+    // Add the object to the cache
+    cache->insert_or_assign(source, object_copy);
+
+    // Copy the object
+    object_copy->deepCopy(source, cache);
+
+    return object_copy;
 }
 
 //-----------------------------------------------------------------------------
 
 bool Object::operator==(const Object& other) const noexcept
 {
-    if(!core::tools::is_equal(m_fields, other.m_fields))
+    if(m_description != other.m_description)
     {
         return false;
     }
 
-    return true;
+    return core::tools::is_equal(m_fields, other.m_fields);
 }
 
 //------------------------------------------------------------------------------
