@@ -39,7 +39,7 @@ namespace sight::data
  * @brief   This class defines a list of planes.
  * @see     Point
  */
-class DATA_CLASS_API PlaneList : public Object
+class DATA_CLASS_API PlaneList final : public Object
 {
 public:
 
@@ -54,10 +54,7 @@ public:
     DATA_API PlaneList(Object::Key key);
 
     /// Destructor
-    DATA_API virtual ~PlaneList();
-
-    /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
+    DATA_API ~PlaneList() noexcept override = default;
 
     /** @{
      *  @brief get/set container of all planes
@@ -92,10 +89,21 @@ public:
     DATA_API bool operator!=(const PlaneList& other) const noexcept;
     /// @}
 
-protected:
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
+
+protected:
 
     //! Planes container
     PlaneListContainer m_vPlanes;
