@@ -37,7 +37,7 @@ namespace sight::data
 static constexpr std::string_view field_label_id = "m_labelId";
 //------------------------------------------------------------------------------
 
-Point::Point(data::Object::Key)
+Point::Point(data::Object::Key /*unused*/)
 {
     m_vCoord[0] = 0.0;
     m_vCoord[1] = 0.0;
@@ -88,40 +88,40 @@ Point::sptr Point::New(const Point::sptr& p)
 
 //------------------------------------------------------------------------------
 
-Point::~Point()
+void Point::shallowCopy(const Object::csptr& source)
 {
+    const auto& other = dynamicConstCast(source);
+
+    SIGHT_THROW_EXCEPTION_IF(
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
+        ),
+        !bool(other)
+    );
+
+    m_vCoord = other->m_vCoord;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void Point::shallowCopy(const Object::csptr& _source)
+void Point::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    Point::csptr other = Point::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
-    m_vCoord = other->m_vCoord;
-}
 
-//------------------------------------------------------------------------------
-
-void Point::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
-{
-    Point::csptr other = Point::dynamicConstCast(_source);
-    SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
-        ),
-        !bool(other)
-    );
-    this->fieldDeepCopy(_source, cache);
     m_vCoord = other->m_vCoord;
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -156,7 +156,7 @@ bool Point::operator==(const Point& other) const noexcept
     }
 
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
@@ -166,4 +166,24 @@ bool Point::operator!=(const Point& other) const noexcept
     return !(*this == other);
 }
 
+//------------------------------------------------------------------------------
+
+std::ostream& operator<<(std::ostream& out, const Point& p)
+{
+    out << "{";
+    bool first = true;
+    for(double e : p.getCoord())
+    {
+        if(!first)
+        {
+            out << ", ";
+        }
+
+        out << e;
+        first = false;
+    }
+
+    return out << "}";
+}
+
 } // namespace sight::data
