@@ -39,7 +39,7 @@ namespace sight::data
  * @brief   This class defines a list of points.
  * @see     Point
  */
-class DATA_CLASS_API PointList : public Object
+class DATA_CLASS_API PointList final : public Object
 {
 public:
 
@@ -55,11 +55,7 @@ public:
     /**
      * @brief Destructor
      */
-    DATA_API virtual ~PointList();
-    /**
-     * @brief Defines shallow copy
-     */
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
+    DATA_API ~PointList() noexcept override = default;
 
     /**
      * @brief Gets point vector
@@ -115,12 +111,21 @@ public:
     DATA_API bool operator!=(const PointList& other) const noexcept;
     /// @}
 
-protected:
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
-    /**
-     * @brief Defines deep copy
-     */
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// Defines deep copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
+
+protected:
 
     /**
      * @brief Points container
@@ -171,4 +176,6 @@ inline void PointList::clear()
     this->m_vPoints.clear();
 }
 
+DATA_API std::ostream& operator<<(std::ostream& out, const PointList& pl);
+
 } // end namespace sight::data
