@@ -39,52 +39,47 @@ const core::com::Signals::SignalKeyType ResectionDB::s_SAFE_PART_ADDED_SIG = "sa
 
 //------------------------------------------------------------------------------
 
-ResectionDB::ResectionDB(data::Object::Key)
+ResectionDB::ResectionDB(data::Object::Key /*unused*/) :
+    m_sigSafePartAdded(SafePartAddedSignalType::New()),
+    m_sigResectionAdded(ResectionAddedSignalType::New())
 {
-    m_sigResectionAdded = ResectionAddedSignalType::New();
-    m_sigSafePartAdded  = SafePartAddedSignalType::New();
-
     m_signals(s_RESECTION_ADDED_SIG, m_sigResectionAdded)
         (s_SAFE_PART_ADDED_SIG, m_sigSafePartAdded);
 }
 
 //------------------------------------------------------------------------------
 
-ResectionDB::~ResectionDB()
+void ResectionDB::shallowCopy(const Object::csptr& source)
 {
-}
+    const auto& other = dynamicConstCast(source);
 
-//------------------------------------------------------------------------------
-
-void ResectionDB::shallowCopy(const Object::csptr& _source)
-{
-    ResectionDB::csptr other = ResectionDB::dynamicConstCast(_source);
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldShallowCopy(_source);
 
     m_safeResection = other->m_safeResection;
     m_resections    = other->m_resections;
+
+    BaseClass::shallowCopy(other);
 }
 
 //------------------------------------------------------------------------------
 
-void ResectionDB::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache)
+void ResectionDB::deepCopy(const Object::csptr& source, const std::unique_ptr<DeepCopyCacheType>& cache)
 {
-    ResectionDB::csptr other = ResectionDB::dynamicConstCast(_source);
+    const auto& other = dynamicConstCast(source);
+
     SIGHT_THROW_EXCEPTION_IF(
-        data::Exception(
-            "Unable to copy" + (_source ? _source->getClassname() : std::string("<NULL>"))
-            + " to " + this->getClassname()
+        Exception(
+            "Unable to copy " + (source ? source->getClassname() : std::string("<NULL>"))
+            + " to " + getClassname()
         ),
         !bool(other)
     );
-    this->fieldDeepCopy(_source, cache);
 
     m_safeResection = data::Object::copy(other->m_safeResection, cache);
 
@@ -93,6 +88,8 @@ void ResectionDB::cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType
     {
         m_resections.push_back(data::Object::copy(resection, cache));
     }
+
+    BaseClass::deepCopy(other, cache);
 }
 
 //------------------------------------------------------------------------------
@@ -120,7 +117,7 @@ bool ResectionDB::operator==(const ResectionDB& other) const noexcept
     }
 
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
