@@ -37,7 +37,7 @@ namespace sight::data
  *
  * @see     Resection
  */
-class DATA_CLASS_API ResectionDB : public Object
+class DATA_CLASS_API ResectionDB final : public Object
 {
 public:
 
@@ -50,10 +50,7 @@ public:
     DATA_API ResectionDB(Object::Key key);
 
     /// Destructor
-    DATA_API virtual ~ResectionDB();
-
-    /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
+    DATA_API ~ResectionDB() noexcept override = default;
 
     typedef std::vector<Resection::sptr> ResectionContainerType;
 
@@ -111,10 +108,21 @@ public:
     DATA_API bool operator!=(const ResectionDB& other) const noexcept;
     /// @}
 
-protected:
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
+
+protected:
 
     Resection::sptr m_safeResection;
 
