@@ -51,7 +51,7 @@ public:
     DATA_API StructureTraitsDictionary(Object::Key key);
 
     /// Destructor. Does nothing.
-    DATA_API virtual ~StructureTraitsDictionary();
+    DATA_API ~StructureTraitsDictionary() noexcept override = default;
 
     /**
      * @brief Add a structure in dictionary
@@ -76,19 +76,25 @@ public:
     /// sets the entire structures map
     DATA_API void setStructureTraitsMap(const StructureTraitsMapType& structureTraitsMap);
 
-    /// Defines shallow copy
-    DATA_API void shallowCopy(const Object::csptr& _source) override;
-
     /// Equality comparison operators
     /// @{
     DATA_API bool operator==(const StructureTraitsDictionary& other) const noexcept;
     DATA_API bool operator!=(const StructureTraitsDictionary& other) const noexcept;
     /// @}
 
-protected:
+    /// Defines shallow copy
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param[in] source the source object to copy
+    DATA_API void shallowCopy(const Object::csptr& source) override;
 
     /// Defines deep copy
-    DATA_API void cachedDeepCopy(const Object::csptr& _source, DeepCopyCacheType& cache) override;
+    /// @throws data::Exception if an errors occurs during copy
+    /// @param source source object to copy
+    /// @param cache cache used to deduplicate pointers
+    DATA_API void deepCopy(
+        const Object::csptr& source,
+        const std::unique_ptr<DeepCopyCacheType>& cache = std::make_unique<DeepCopyCacheType>()
+    ) override;
 
 private:
 
