@@ -33,7 +33,7 @@ const core::com::Signals::SignalKeyType TimeLine::s_CLEARED_SIG        = "object
 
 //------------------------------------------------------------------------------
 
-TimeLine::TimeLine(data::Object::Key)
+TimeLine::TimeLine(data::Object::Key /*unused*/)
 {
     newSignal<ObjectPushedSignalType>(s_OBJECT_PUSHED_SIG);
     newSignal<ObjectRemovedSignalType>(s_OBJECT_REMOVED_SIG);
@@ -43,15 +43,14 @@ TimeLine::TimeLine(data::Object::Key)
 //------------------------------------------------------------------------------
 
 TimeLine::~TimeLine()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 bool TimeLine::operator==(const TimeLine& other) const noexcept
 {
     // Super class last
-    return Object::operator==(other);
+    return BaseClass::operator==(other);
 }
 
 //------------------------------------------------------------------------------
