@@ -20,6 +20,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE
+
 #include "ArrayTest.hpp"
 
 #include <data/Array.hpp>
@@ -28,10 +30,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::ArrayTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //-----------------------------------------------------------------------------
@@ -62,7 +61,7 @@ void ArrayTest::allocation()
 
     data::Array::SizeType size = {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
     CPPUNIT_ASSERT(array->getBuffer() != nullptr);
     CPPUNIT_ASSERT(!array->empty());
 
@@ -74,23 +73,23 @@ void ArrayTest::allocation()
         data::Array::OffsetType stride = {4, 40};
         CPPUNIT_ASSERT(array->getStrides() == stride);
     }
-    CPPUNIT_ASSERT_EQUAL(core::tools::Type::s_UINT32, array->getType());
-    CPPUNIT_ASSERT_EQUAL(static_cast<unsigned char>(4), array->getType().sizeOf());
+    CPPUNIT_ASSERT_EQUAL(core::Type::UINT32, array->getType());
+    CPPUNIT_ASSERT_EQUAL(static_cast<size_t>(4), array->getType().size());
 
     array->clear();
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(0), array->getSizeInBytes());
     CPPUNIT_ASSERT(array->empty());
     CPPUNIT_ASSERT(array->getBuffer() == nullptr);
-    CPPUNIT_ASSERT_EQUAL(core::tools::Type::s_UNSPECIFIED_TYPE, array->getType());
+    CPPUNIT_ASSERT_EQUAL(core::Type::NONE, array->getType());
 
-    std::uint16_t* buffer = new std::uint16_t[1000];
+    auto* buffer = new std::uint16_t[1000];
 
     for(std::uint16_t i = 0 ; i < 1000 ; i++)
     {
         buffer[i] = i;
     }
 
-    array->setBuffer(buffer, false, size, core::tools::Type::s_UINT16, core::memory::BufferNewPolicy::New());
+    array->setBuffer(buffer, false, size, core::Type::UINT16, core::memory::BufferNewPolicy::New());
 
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2), array->getElementSizeInBytes());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2 * 10 * 100), array->getSizeInBytes());
@@ -119,7 +118,7 @@ void ArrayTest::resize()
 
     data::Array::SizeType size {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
     auto lock = array->dump_lock();
 
     CPPUNIT_ASSERT(array->getBuffer() != nullptr);
@@ -184,7 +183,7 @@ void ArrayTest::resize()
 
     newSize = {2, 10, 100};
 
-    array->resize(newSize, core::tools::Type::s_UINT16, false);
+    array->resize(newSize, core::Type::UINT16, false);
     CPPUNIT_ASSERT(newSize == array->getSize());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2), array->getElementSizeInBytes());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2 * 100 * 10 * 2), array->getSizeInBytes());
@@ -208,7 +207,7 @@ void ArrayTest::reallocate()
 
     data::Array::SizeType size = {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
     auto lock = array->dump_lock();
 
     std::uint32_t count = 0;
@@ -248,7 +247,7 @@ void ArrayTest::reallocate()
     CPPUNIT_ASSERT_EQUAL(value2, array->at<std::uint32_t>({99, 99}));
 
     newSize = {2, 100, 100};
-    array->resize(newSize, core::tools::Type::s_UINT32, true);
+    array->resize(newSize, core::Type::UINT32, true);
     CPPUNIT_ASSERT(newSize == array->getSize());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(4 * 2 * 100 * 100), array->getSizeInBytes());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::uint32_t>(0), array->at<std::uint32_t>({0, 0, 0}));
@@ -286,7 +285,7 @@ void ArrayTest::reallocate()
     CPPUNIT_ASSERT_EQUAL(static_cast<std::uint32_t>(238), array->at<std::uint32_t>({8, 23}));
 
     newSize = {2, 10, 100};
-    array->resize(newSize, core::tools::Type::s_UINT16, true);
+    array->resize(newSize, core::Type::UINT16, true);
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2), array->getElementSizeInBytes());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::size_t>(2 * 10 * 100 * 2), array->getSizeInBytes());
     CPPUNIT_ASSERT_EQUAL(static_cast<std::uint32_t>(0), array->at<std::uint32_t>({0, 0, 0}));
@@ -318,7 +317,7 @@ void ArrayTest::copy()
 
     data::Array::SizeType size = {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
     auto arrayLock = array->dump_lock();
     CPPUNIT_ASSERT(array->getBuffer() != nullptr);
 
@@ -405,7 +404,7 @@ void ArrayTest::dumpLockTest()
 {
     data::Array::SizeType size = {10, 100};
     data::Array::sptr array    = data::Array::New();
-    array->resize({12, 15}, core::tools::Type::s_INT16, true);
+    array->resize({12, 15}, core::Type::INT16, true);
 
     CPPUNIT_ASSERT_THROW(array->getBuffer(), data::Exception);
 
@@ -422,7 +421,7 @@ void ArrayTest::bufferAccessTest()
 
     data::Array::SizeType size = {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
 
     {
         CPPUNIT_ASSERT_THROW(array->getBuffer(), core::Exception);
@@ -509,7 +508,7 @@ void ArrayTest::constArrayTest()
 
     data::Array::SizeType size = {10, 100};
 
-    array->resize(size, core::tools::Type::s_UINT32, true);
+    array->resize(size, core::Type::UINT32, true);
     auto lock = array->dump_lock();
 
     std::uint32_t count = 0;
@@ -552,7 +551,7 @@ void ArrayTest::constArrayTest()
 void ArrayTest::emptyIteratorTest()
 {
     data::Array::sptr array = data::Array::New();
-    array->resize({10, 100}, core::tools::Type::s_UINT32);
+    array->resize({10, 100}, core::Type::UINT32);
     auto lock = array->dump_lock();
 
     std::uint32_t count = 0;
@@ -593,10 +592,11 @@ void ArrayTest::equalityTest()
     // Fill array1
     const data::Array::SizeType size {10, 10};
 
-    array1->resize(size, core::tools::Type::s_UINT32, true);
+    array1->resize(size, core::Type::UINT32, true);
     auto lock = array1->dump_lock();
 
     std::uint32_t count = 0;
+    // NOLINTNEXTLINE(modernize-loop-convert)
     for(auto it = array1->begin<std::uint32_t>(), end = array1->end<std::uint32_t>() ; it != end ; ++it)
     {
         *it = count++;
@@ -605,10 +605,11 @@ void ArrayTest::equalityTest()
     CPPUNIT_ASSERT(*array1 != *array2);
 
     // Fill array2
-    array2->resize(size, core::tools::Type::s_UINT32, true);
+    array2->resize(size, core::Type::UINT32, true);
     auto lock2 = array2->dump_lock();
 
     count = 666;
+    // NOLINTNEXTLINE(modernize-loop-convert)
     for(auto it = array2->begin<std::uint32_t>(), end = array2->end<std::uint32_t>() ; it != end ; ++it)
     {
         *it = count++;
@@ -617,6 +618,7 @@ void ArrayTest::equalityTest()
     CPPUNIT_ASSERT(*array1 != *array2);
 
     count = 0;
+    // NOLINTNEXTLINE(modernize-loop-convert)
     for(auto it = array2->begin<std::uint32_t>(), end = array2->end<std::uint32_t>() ; it != end ; ++it)
     {
         *it = count++;
@@ -630,8 +632,98 @@ void ArrayTest::equalityTest()
     CPPUNIT_ASSERT(*array1 == *array3);
 }
 
+//------------------------------------------------------------------------------
+
+void ArrayTest::swapTest()
+{
+    auto array1 = data::Array::New();
+    array1->resize({3}, core::Type::UINT32, true);
+    auto lock1         = array1->dump_lock();
+    std::uint8_t count = 1;
+    // NOLINTNEXTLINE(modernize-loop-convert)
+    for(auto it = array1->begin<std::uint32_t>(), end = array1->end<std::uint32_t>() ; it != end ; ++it)
+    {
+        *it = count++;
+    }
+
+    auto array2 = data::Array::New();
+    array2->resize({6}, core::Type::INT16, true);
+    auto lock2 = array2->dump_lock();
+    // NOLINTNEXTLINE(modernize-loop-convert)
+    for(auto it = array2->begin<std::int16_t>(), end = array2->end<std::int16_t>() ; it != end ; ++it)
+    {
+        *it = count++;
+    }
+
+    count = 1;
+    std::size_t i = 0;
+    for(auto it = array1->begin<std::uint32_t>(), end = array1->end<std::uint32_t>() ; it != end ; ++it, ++i)
+    {
+        CPPUNIT_ASSERT_MESSAGE("i=" + std::to_string(i), *it == count++);
+    }
+
+    i = 0;
+    for(auto it = array2->begin<std::int16_t>(), end = array2->end<std::int16_t>() ; it != end ; ++it, ++i)
+    {
+        CPPUNIT_ASSERT_MESSAGE("i=" + std::to_string(i), *it == count++);
+    }
+
+    array1->swap(array2);
+
+    count = 1;
+    i     = 0;
+    for(auto it = array2->begin<std::uint32_t>(), end = array2->end<std::uint32_t>() ; it != end ; ++it, ++i)
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("i=" + std::to_string(i), static_cast<std::uint32_t>(count++), *it);
+    }
+
+    i = 0;
+    for(auto it = array1->begin<std::int16_t>(), end = array1->end<std::int16_t>() ; it != end ; ++it, ++i)
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("i=" + std::to_string(i), static_cast<std::int16_t>(count++), *it);
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void ArrayTest::resizeNonOwnerTest()
+{
+    auto array   = data::Array::New();
+    auto* buffer = new std::uint32_t[3];
+    array->setBuffer(buffer, false, {3}, core::Type::UINT32);
+    CPPUNIT_ASSERT_THROW(array->resize({6}, core::Type::UINT32, true), data::Exception);
+    delete[] buffer;
+}
+
+//------------------------------------------------------------------------------
+
+void ArrayTest::setBufferObjectNullThenResizeTest()
+{
+    auto array = data::Array::New();
+    /* TODO: fix crash
+       array->setBufferObject(nullptr);
+       array->resize({2}, core::Type::UINT8);
+     */
+}
+
+//------------------------------------------------------------------------------
+
+void ArrayTest::atTest()
+{
+    auto array = data::Array::New();
+    array->resize({3}, core::Type::UINT32, true);
+
+    for(std::uint32_t i = 0 ; i < 3 ; i++)
+    {
+        array->at<std::uint32_t>(i) = i + 1;
+    }
+
+    for(std::uint32_t i = 0 ; i < 3 ; i++)
+    {
+        CPPUNIT_ASSERT_EQUAL(i + 1, array->at<std::uint32_t>(i));
+    }
+}
+
 //-----------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
