@@ -27,10 +27,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::BooleanTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -71,6 +68,4 @@ void BooleanTest::methode1()
     CPPUNIT_ASSERT(*p1 == *p2);
 }
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
