@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2022 IRCAD France
  * Copyright (C) 2014-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class CameraTest : public CPPUNIT_NS::TestFixture
@@ -36,19 +33,23 @@ CPPUNIT_TEST_SUITE(CameraTest);
 CPPUNIT_TEST(paramTest);
 CPPUNIT_TEST(shallowCopyTest);
 CPPUNIT_TEST(deepCopyTest);
+CPPUNIT_TEST(equalityTest);
+CPPUNIT_TEST(getPixelFormatTest);
+CPPUNIT_TEST(getPixelFormatNameTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void paramTest();
-    void shallowCopyTest();
-    void deepCopyTest();
+    static void paramTest();
+    static void shallowCopyTest();
+    static void deepCopyTest();
+    static void equalityTest();
+    static void getPixelFormatTest();
+    static void getPixelFormatNameTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
