@@ -33,10 +33,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::ColorTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -58,10 +55,10 @@ void ColorTest::tearDown()
 void ColorTest::methode1()
 {
     //-----------test values
-    const float R = 0.2f;
-    const float G = 0.8f;
-    const float B = 0.5f;
-    const float A = 0.6f;
+    const float R = 0.2F;
+    const float G = 0.8F;
+    const float B = 0.5F;
+    const float A = 0.6F;
 
     auto color = data::Color::New(R, G, B, A);
 
@@ -79,10 +76,10 @@ void ColorTest::methode1()
 void ColorTest::methode2()
 {
     //-----------test values
-    const float R = 0.2f;
-    const float G = 0.8f;
-    const float B = 0.5f;
-    const float A = 0.6f;
+    const float R = 0.2F;
+    const float G = 0.8F;
+    const float B = 0.5F;
+    const float A = 0.6F;
 
     auto color = data::Color::New();
 
@@ -113,10 +110,10 @@ void ColorTest::methode3()
     // fuchsia string value
     const std::string fuchsia = "#FF006E";
     // fuchsia float values
-    const float R = 1.f;
-    const float G = 0.f;
-    const float B = 110.f / 255.f;
-    const float A = 1.f;
+    const float R = 1.F;
+    const float G = 0.F;
+    const float B = 110.F / 255.F;
+    const float A = 1.F;
 
     data::Color::sptr color = data::Color::New();
 
@@ -134,6 +131,34 @@ void ColorTest::methode3()
     CPPUNIT_ASSERT(*color == *color2);
 }
 
-} //namespace ut
+//------------------------------------------------------------------------------
 
-} //namespace sight::data
+void ColorTest::equalityTest()
+{
+    auto color1 = data::Color::New();
+    auto color2 = data::Color::New();
+
+    CPPUNIT_ASSERT(*color1 == *color2 && !(*color1 != *color2));
+
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(...) \
+    color1->setRGBA(__VA_ARGS__); \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "The colors should be different when the first is set with " #__VA_ARGS__, \
+        *color1 != *color2 && !(*color1 == *color2) \
+    ); \
+    color2->setRGBA(color1->getRGBA()); \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "The colors should be equal when both are set with " #__VA_ARGS__, \
+        *color1 == *color2 && !(*color1 != *color2) \
+    );
+
+    TEST(1, 0, 0, 0);
+    TEST(0, 1, 0, 0);
+    TEST(0, 0, 1, 0);
+    TEST(0, 0, 0, 1);
+
+    #undef TEST
+}
+
+} // namespace sight::data::ut
