@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class ColorTest : public CPPUNIT_NS::TestFixture
@@ -38,19 +35,19 @@ private:
     CPPUNIT_TEST(methode1);
     CPPUNIT_TEST(methode2);
     CPPUNIT_TEST(methode3);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void methode1();
-    void methode2();
-    void methode3();
+    static void methode1();
+    static void methode2();
+    static void methode3();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
