@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,8 @@
 
 #include "DicomSeriesTest.hpp"
 
-#include <core/tools/System.hpp>
-#include <core/tools/Type.hpp>
+#include <core/os/TempPath.hpp>
+#include <core/Type.hpp>
 
 #include <data/Array.hpp>
 
@@ -33,10 +33,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::DicomSeriesTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -62,11 +59,9 @@ void DicomSeriesTest::dicomTest()
     CPPUNIT_ASSERT(m_series);
 
     //Create Path
-    const std::filesystem::path path = core::tools::System::getTemporaryFolder() / "dicomTest";
-    std::filesystem::create_directories(path);
-    const std::string filename = path.string() + "/" + "file";
+    core::os::TempFile tmpFile;
     std::ofstream file;
-    file.open(filename.c_str(), std::ofstream::out);
+    file.open(tmpFile, std::ofstream::out);
     file << "42";
     file.close();
 
@@ -77,7 +72,7 @@ void DicomSeriesTest::dicomTest()
     CPPUNIT_ASSERT_EQUAL(nb_instances, m_series->numInstances());
 
     //Paths
-    m_series->addDicomPath(42, filename);
+    m_series->addDicomPath(42, tmpFile);
     CPPUNIT_ASSERT(m_series->isInstanceAvailable(42));
 
     //Binaries
@@ -93,43 +88,46 @@ void DicomSeriesTest::equalityTest()
     auto dicomSeries1 = data::DicomSeries::New();
     auto dicomSeries2 = data::DicomSeries::New();
 
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
 
     dicomSeries1->setNumberOfInstances(666);
-    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2 && !(*dicomSeries1 == *dicomSeries2));
     dicomSeries2->setNumberOfInstances(dicomSeries1->numInstances());
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
 
     dicomSeries1->setSOPClassUIDs({"1", "2", "3"});
-    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2 && !(*dicomSeries1 == *dicomSeries2));
     dicomSeries2->setSOPClassUIDs(dicomSeries1->getSOPClassUIDs());
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
 
     dicomSeries1->setComputedTagValues({{"4", "4"}, {"5", "5"}, {"6", "6"}});
-    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2 && !(*dicomSeries1 == *dicomSeries2));
     dicomSeries2->setComputedTagValues(dicomSeries1->getComputedTagValues());
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
 
     auto bufferObject = core::memory::BufferObject::New();
     bufferObject->allocate(2);
-    auto lock   = bufferObject->lock();
-    auto buffer = reinterpret_cast<char*>(lock.getBuffer());
+    auto lock    = bufferObject->lock();
+    auto* buffer = reinterpret_cast<char*>(lock.getBuffer());
     buffer[0] = 'a';
     buffer[1] = '\0';
 
     dicomSeries1->setDicomContainer({{7, bufferObject}});
-    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2 && !(*dicomSeries1 == *dicomSeries2));
     dicomSeries2->setDicomContainer(dicomSeries1->getDicomContainer());
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
+
+    dicomSeries1->setFirstInstanceNumber(1);
+    CPPUNIT_ASSERT(*dicomSeries1 != *dicomSeries2 && !(*dicomSeries1 == *dicomSeries2));
+    dicomSeries2->setFirstInstanceNumber(dicomSeries1->getFirstInstanceNumber());
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries2 && !(*dicomSeries1 != *dicomSeries2));
 
     // Test also deepcopy, just for fun
     auto dicomSeries3 = data::DicomSeries::New();
     dicomSeries3->deepCopy(dicomSeries1);
-    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries3);
+    CPPUNIT_ASSERT(*dicomSeries1 == *dicomSeries3 && !(*dicomSeries1 != *dicomSeries3));
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
