@@ -26,10 +26,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class DicomSeriesTest : public CPPUNIT_NS::TestFixture
@@ -42,17 +39,15 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
     void dicomTest();
-    void equalityTest();
+    static void equalityTest();
 
 private:
 
     data::DicomSeries::sptr m_series;
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
