@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class FrameTLTest : public CPPUNIT_NS::TestFixture
@@ -38,19 +35,19 @@ public:
     CPPUNIT_TEST(initTest);
     CPPUNIT_TEST(pushTest);
     CPPUNIT_TEST(copyTest);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void initTest();
-    void pushTest();
-    void copyTest();
+    static void initTest();
+    static void pushTest();
+    static void copyTest();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
