@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class ImageSeriesTest : public CPPUNIT_NS::TestFixture
@@ -37,22 +34,22 @@ class ImageSeriesTest : public CPPUNIT_NS::TestFixture
 CPPUNIT_TEST_SUITE(ImageSeriesTest);
 CPPUNIT_TEST(imageTest);
 CPPUNIT_TEST(equalityTest);
+CPPUNIT_TEST(resizeTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
     void imageTest();
-    void equalityTest();
+    static void equalityTest();
+    static void resizeTest();
 
 private:
 
     ImageSeries::sptr m_series;
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
