@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class ImageTest : public CPPUNIT_NS::TestFixture
@@ -48,29 +45,29 @@ private:
     CPPUNIT_TEST(benchmarkIterator);
     CPPUNIT_TEST(imageDeepCopy);
     CPPUNIT_TEST(emptyIteratorTest);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void testGetterSetter();
-    void testAllocation();
-    void testReallocation();
-    void testSetGetPixel();
-    void testSetGetPixelRGBA();
-    void testIterator();
-    void testRGBIterator();
-    void testBGRIterator();
-    void testRGBAIterator();
-    void testBGRAIterator();
-    void benchmarkIterator();
-    void imageDeepCopy();
-    void emptyIteratorTest();
+    static void testGetterSetter();
+    static void testAllocation();
+    static void testReallocation();
+    static void testSetGetPixel();
+    static void testSetGetPixelRGBA();
+    static void testIterator();
+    static void testRGBIterator();
+    static void testBGRIterator();
+    static void testRGBAIterator();
+    static void testBGRAIterator();
+    static void benchmarkIterator();
+    static void imageDeepCopy();
+    static void emptyIteratorTest();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
