@@ -28,10 +28,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::LandmarksTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -56,12 +53,12 @@ void LandmarksTest::copyTest()
     const std::string GROUP1                = "group_1";
     const std::string GROUP2                = "group_2";
     const std::string GROUP3                = "group_3";
-    const data::Landmarks::ColorType COLOR1 = {{1.f, 0.0f, 0.0f, 1.0f}};
-    const data::Landmarks::ColorType COLOR2 = {{0.f, 1.0f, 0.0f, 1.0f}};
-    const data::Landmarks::ColorType COLOR3 = {{0.f, 0.0f, 1.0f, 1.0f}};
-    const data::Landmarks::SizeType SIZE1   = 3.45f;
-    const data::Landmarks::SizeType SIZE2   = 7.5f;
-    const data::Landmarks::SizeType SIZE3   = 1.3f;
+    const data::Landmarks::ColorType COLOR1 = {{1.F, 0.0F, 0.0F, 1.0F}};
+    const data::Landmarks::ColorType COLOR2 = {{0.F, 1.0F, 0.0F, 1.0F}};
+    const data::Landmarks::ColorType COLOR3 = {{0.F, 0.0F, 1.0F, 1.0F}};
+    const data::Landmarks::SizeType SIZE1   = 3.45F;
+    const data::Landmarks::SizeType SIZE2   = 7.5F;
+    const data::Landmarks::SizeType SIZE3   = 1.3F;
     const data::Landmarks::Shape SHAPE1     = data::Landmarks::Shape::SPHERE;
     const data::Landmarks::Shape SHAPE2     = data::Landmarks::Shape::CUBE;
     const data::Landmarks::Shape SHAPE3     = data::Landmarks::Shape::SPHERE;
@@ -150,12 +147,12 @@ void LandmarksTest::groupTest()
     const std::string GROUP2                = "group_2";
     const std::string GROUP3                = "group_3";
     const std::string NO_GROUP              = "no_group";
-    const data::Landmarks::ColorType COLOR1 = {{1.f, 0.0f, 0.0f, 1.0f}};
-    const data::Landmarks::ColorType COLOR2 = {{0.f, 1.0f, 0.0f, 1.0f}};
-    const data::Landmarks::ColorType COLOR3 = {{0.f, 0.0f, 1.0f, 1.0f}};
-    const data::Landmarks::SizeType SIZE1   = 3.45f;
-    const data::Landmarks::SizeType SIZE2   = 7.5f;
-    const data::Landmarks::SizeType SIZE3   = 1.3f;
+    const data::Landmarks::ColorType COLOR1 = {{1.F, 0.0F, 0.0F, 1.0F}};
+    const data::Landmarks::ColorType COLOR2 = {{0.F, 1.0F, 0.0F, 1.0F}};
+    const data::Landmarks::ColorType COLOR3 = {{0.F, 0.0F, 1.0F, 1.0F}};
+    const data::Landmarks::SizeType SIZE1   = 3.45F;
+    const data::Landmarks::SizeType SIZE2   = 7.5F;
+    const data::Landmarks::SizeType SIZE3   = 1.3F;
     const data::Landmarks::Shape SHAPE1     = data::Landmarks::Shape::SPHERE;
     const data::Landmarks::Shape SHAPE2     = data::Landmarks::Shape::CUBE;
     const data::Landmarks::Shape SHAPE3     = data::Landmarks::Shape::SPHERE;
@@ -359,7 +356,7 @@ void LandmarksTest::pointsTest()
 
     data::Landmarks::PointType& point = landmarks->getPoint(GROUP1, 0);
     point[2] = 18.6;
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(18.6, landmarks->getPoint(GROUP1, 0)[2], 0.000001);
+    CPPUNIT_ASSERT_EQUAL(18.6, landmarks->getPoint(GROUP1, 0)[2]);
 
     // check clear points
     CPPUNIT_ASSERT_NO_THROW(landmarks->clearPoints(GROUP1));
@@ -369,6 +366,42 @@ void LandmarksTest::pointsTest()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
+void LandmarksTest::equalityTest()
+{
+    auto landmarks1 = data::Landmarks::New();
+    auto landmarks2 = data::Landmarks::New();
 
-} //namespace sight::data
+    CPPUNIT_ASSERT(*landmarks1 == *landmarks2 && !(*landmarks1 != *landmarks2));
+
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(op) \
+    landmarks1->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "The landmarks must be different when using " #op " on the first landmarks", \
+        *landmarks1 != *landmarks2 && !(*landmarks1 == *landmarks2) \
+    ); \
+    landmarks2->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "The landmarks must be equal when using " #op " on the both landmarks", \
+        *landmarks1 == *landmarks2 && !(*landmarks1 != *landmarks2) \
+    );
+
+    TEST(addGroup("1"));
+    TEST(renameGroup("1", "2"));
+    TEST(setGroupColor("2", {0, 1, 1, 1}));
+    TEST(setGroupColor("2", {0, 0, 1, 1}));
+    TEST(setGroupColor("2", {0, 0, 0, 1}));
+    TEST(setGroupColor("2", {0, 0, 0, 0}));
+    TEST(setGroupSize("2", 2));
+    TEST(setGroupShape("2", data::Landmarks::Shape::CUBE));
+    TEST(setGroupVisibility("2", false));
+    TEST(addPoint("2", {1, 2, 3}));
+    TEST(clearPoints("2"));
+    TEST(removeGroup("2"));
+
+    #undef TEST
+}
+
+//------------------------------------------------------------------------------
+
+} // namespace sight::data::ut
