@@ -34,10 +34,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::MaterialTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -60,10 +57,10 @@ void MaterialTest::methode1()
 {
     //-----------test values
     data::Color::sptr ambient_color = data::Color::New();
-    ambient_color->setRGBA(0.5f, 0.5f, 0.5f, 0.5f);
+    ambient_color->setRGBA(0.5F, 0.5F, 0.5F, 0.5F);
 
     data::Color::sptr diffuse_color = data::Color::New();
-    diffuse_color->setRGBA(0.8f, 0.2f, 0.5f, 0.4f);
+    diffuse_color->setRGBA(0.8F, 0.2F, 0.5F, 0.4F);
 
     auto material = data::Material::New();
 
@@ -81,6 +78,42 @@ void MaterialTest::methode1()
     CPPUNIT_ASSERT(*material == *material2);
 }
 
-} //namespace ut
+//------------------------------------------------------------------------------
 
-} //namespace sight::data
+void MaterialTest::equalityTest()
+{
+    auto material1 = data::Material::New();
+    auto material2 = data::Material::New();
+
+    CPPUNIT_ASSERT(*material1 == *material2 && !(*material1 != *material2));
+
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(op) \
+    material1->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "Materials should be different when using " #op " on the first one", \
+        *material1 != *material2 && !(*material1 == *material2) \
+    ); \
+    material2->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "Materials should be equal when using " #op " on both", \
+        *material1 == *material2 && !(*material1 != *material2) \
+    );
+
+    TEST(setAmbient(data::Color::New(1, 0, 0)));
+    TEST(setAmbient(data::Color::New(0, 1, 0)));
+    TEST(setAmbient(data::Color::New(0, 0, 1)));
+    TEST(setDiffuse(data::Color::New(1, 0, 0)));
+    TEST(setDiffuse(data::Color::New(0, 1, 0)));
+    TEST(setDiffuse(data::Color::New(0, 0, 1)));
+    TEST(setDiffuseTexture(data::Image::New()));
+    TEST(setShadingMode(data::Material::AMBIENT));
+    TEST(setRepresentationMode(data::Material::POINT));
+    TEST(setOptionsMode(data::Material::NORMALS));
+    TEST(setDiffuseTextureFiltering(data::Material::LINEAR));
+    TEST(setDiffuseTextureWrapping(data::Material::CLAMP));
+
+    #undef TEST
+}
+
+} // namespace sight::data::ut
