@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class Matrix4Test : public CPPUNIT_NS::TestFixture
@@ -37,20 +34,20 @@ private:
     CPPUNIT_TEST_SUITE(Matrix4Test);
     CPPUNIT_TEST(getterSetterByCoef);
     CPPUNIT_TEST(getterSetterByArray);
-    CPPUNIT_TEST(getterSetterByMatrix);
+    CPPUNIT_TEST(rowMatrixAccessor);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void getterSetterByCoef();
-    void getterSetterByArray();
-    void getterSetterByMatrix();
+    static void getterSetterByCoef();
+    static void getterSetterByArray();
+    static void rowMatrixAccessor();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
