@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,16 +22,11 @@
 
 #pragma once
 
-#include "iterator.hpp"
-
 #include <cppunit/extensions/HelperMacros.h>
 
 #include <limits>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class MeshTest : public CPPUNIT_NS::TestFixture
@@ -45,6 +40,7 @@ private:
     CPPUNIT_TEST(iteratorTest);
     CPPUNIT_TEST(iteratorCopyTest);
     CPPUNIT_TEST(benchmarkIterator);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
     const float EPSILON = std::numeric_limits<float>::epsilon();
@@ -52,17 +48,16 @@ private:
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
     void insertion();
-    void copy();
-    void allocationTest();
+    static void copy();
+    static void allocationTest();
     void iteratorTest();
-    void iteratorCopyTest();
-    void benchmarkIterator();
+    static void iteratorCopyTest();
+    static void benchmarkIterator();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
