@@ -22,7 +22,7 @@
 
 #include "ModelSeriesTest.hpp"
 
-#include <core/tools/Type.hpp>
+#include <core/Type.hpp>
 
 #include <data/Mesh.hpp>
 #include <data/Reconstruction.hpp>
@@ -32,10 +32,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::data::ut::ModelSeriesTest);
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 //------------------------------------------------------------------------------
@@ -147,6 +144,32 @@ void ModelSeriesTest::shallowCopyTest()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
+void ModelSeriesTest::equalityTest()
+{
+    auto series1 = data::ModelSeries::New();
+    auto series2 = data::ModelSeries::New();
 
-} //namespace sight::data
+    CPPUNIT_ASSERT(*series1 == *series2 && !(*series1 != *series2));
+
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(op) \
+    series1->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "Series must be different when using " #op " on the first one", \
+        *series1 != *series2 && !(*series1 == *series2) \
+    ); \
+    series2->op; \
+    CPPUNIT_ASSERT_MESSAGE( \
+        "Series must be equal when using " #op " on both", \
+        *series1 == *series2 && !(*series1 != *series2) \
+    );
+
+    TEST(setReconstructionDB({data::Reconstruction::New()}));
+    TEST(setDicomReference(data::DicomSeries::New()));
+
+    #undef TEST
+}
+
+//------------------------------------------------------------------------------
+
+} // namespace sight::data::ut
