@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class ModelSeriesTest : public CPPUNIT_NS::TestFixture
@@ -38,23 +35,23 @@ CPPUNIT_TEST_SUITE(ModelSeriesTest);
 CPPUNIT_TEST(modelTest);
 CPPUNIT_TEST(deepCopyTest);
 CPPUNIT_TEST(shallowCopyTest);
+CPPUNIT_TEST(equalityTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
     void modelTest();
     void deepCopyTest();
     void shallowCopyTest();
+    static void equalityTest();
 
 private:
 
     ModelSeries::sptr m_series;
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
