@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::data
-{
-
-namespace ut
+namespace sight::data::ut
 {
 
 class ReconstructionTest : public CPPUNIT_NS::TestFixture
@@ -37,18 +34,18 @@ private:
     CPPUNIT_TEST_SUITE(ReconstructionTest);
     CPPUNIT_TEST(methode1);
     CPPUNIT_TEST(image);
+    CPPUNIT_TEST(equalityTest);
     CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void methode1();
-    void image();
+    static void methode1();
+    static void image();
+    static void equalityTest();
 };
 
-} //namespace ut
-
-} //namespace sight::data
+} // namespace sight::data::ut
