@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,4 +31,4 @@ namespace sight::data
 typedef std::string DicomValueType;
 typedef std::vector<DicomValueType> DicomValuesType;
 
-} // Namespace fwMedData.
+} // namespace sight::data
