@@ -1,7 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
- * Copyright (C) 2012-2020 IHU Strasbourg
+ * Copyright (C) 2022-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -20,24 +19,20 @@
  *
  ***********************************************************************/
 
-#include "service/IAppConfigManager.hpp"
+#include "IAppConfigManager.hpp"
 
-#include "service/AppConfigManager.hpp"
+#include "service/detail/AppConfigManager.hpp"
 
 namespace sight::service
 {
 
-//------------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 
-IAppConfigManager::sptr IAppConfigManager::New()
+SPTR(IAppConfigManager) IAppConfigManager::New()
 {
-    FW_DEPRECATED_MSG(
-        "sight::service::IAppConfigManager is no longer supported, use service::AppConfigManager",
-        "22.0"
-    );
-    return service::AppConfigManager::New();
+    return service::detail::AppConfigManager::New();
 }
 
-//------------------------------------------------------------------------------
+//-----------------------------------------------------------------------------
 
 } // namespace sight::service
