@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2022 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,14 +28,12 @@ namespace sight::service
 //-----------------------------------------------------------------------------
 
 IGenerator::IGenerator()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 IGenerator::~IGenerator()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
