@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,14 +25,6 @@
 namespace sight::service
 {
 
-IXMLParser::IXMLParser()
-{
-}
-
-IXMLParser::~IXMLParser()
-{
-}
-
 //------------------------------------------------------------------------------
 
 void IXMLParser::starting()
@@ -55,24 +47,18 @@ void IXMLParser::configuring()
 
 void IXMLParser::updating()
 {
-    core::runtime::ConfigurationElement::Iterator configEltIter;
-    for(configEltIter = this->m_configuration->begin() ; !(configEltIter == this->m_configuration->end()) ;
-        ++configEltIter)
-    {
-        SIGHT_ASSERT("ACH => still used ?", (*configEltIter)->getName() != "object");
-    }
 }
 
 //-----------------------------------------------------------------------------
 
-void IXMLParser::setObjectConfig(core::runtime::ConfigurationElement::csptr _cfgElem)
+void IXMLParser::setObjectConfig(const IService::config_t& _cfgElem)
 {
     m_cfg = _cfgElem;
 }
 
 //-----------------------------------------------------------------------------
 
-void IXMLParser::createConfig(core::tools::Object::sptr)
+void IXMLParser::createConfig(core::tools::Object::sptr /*unused*/)
 {
 }
 
