@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,14 +22,9 @@
 
 #include "service/extension/Config.hpp"
 
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/helper.hpp>
-#include <core/runtime/Runtime.hpp>
+#include <core/runtime/runtime.hpp>
 
-namespace sight::service
-{
-
-namespace extension
+namespace sight::service::extension
 {
 
 const std::string Config::CONFIG_EXT_POINT = "sight::service::extension::Config";
@@ -45,43 +40,25 @@ Config::sptr Config::getDefault()
 
 //-----------------------------------------------------------------------------
 
-Config::~Config()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void Config::parseBundleInformation()
 {
-    typedef std::shared_ptr<core::runtime::Extension> ExtensionType;
+    using ExtensionType = std::shared_ptr<core::runtime::Extension>;
 
     std::vector<ExtensionType> extElements;
     extElements = core::runtime::getAllExtensionsForPoint(CONFIG_EXT_POINT);
-    for(ExtensionType ext : extElements)
+    for(const ExtensionType& ext : extElements)
     {
-        // Get id
-        SIGHT_ASSERT("Missing id element", ext->hasConfigurationElement("id"));
-        std::string id = ext->findConfigurationElement("id")->getValue();
+        const auto& cfg = ext->getConfig();
 
-        // Get service
-        std::string service = "";
-        if(ext->hasConfigurationElement("service"))
-        {
-            service = ext->findConfigurationElement("service")->getValue();
-        }
-
-        // Get desc
-        std::string desc = "No description available";
-        if(ext->hasConfigurationElement("desc"))
-        {
-            desc = ext->findConfigurationElement("desc")->getValue();
-        }
+        const auto configId = cfg.get<std::string>("id");
+        const auto desc     = cfg.get<std::string>("desc", "No description available");
+        const auto service  = cfg.get<std::string>("service", "");
 
         // Get config
-        core::runtime::ConfigurationElement::csptr config = ext->findConfigurationElement("config");
+        const auto config = cfg.get_child("config");
 
         // Add service config info
-        this->addServiceConfigInfo(id, service, desc, config);
+        this->addServiceConfigInfo(configId, service, desc, config);
     }
 }
 
@@ -92,7 +69,7 @@ void Config::addServiceConfigInfo
     const std::string& configId,
     const std::string& service,
     const std::string& desc,
-    core::runtime::ConfigurationElement::csptr config
+    const boost::property_tree::ptree& config
 )
 {
     core::mt::WriteLock lock(m_registryMutex);
@@ -118,12 +95,6 @@ void Config::addServiceConfigInfo
 
 //-----------------------------------------------------------------------------
 
-Config::Config()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void Config::clearRegistry()
 {
     core::mt::WriteLock lock(m_registryMutex);
@@ -132,7 +103,7 @@ void Config::clearRegistry()
 
 //-----------------------------------------------------------------------------
 
-core::runtime::ConfigurationElement::csptr Config::getServiceConfig(
+boost::property_tree::ptree Config::getServiceConfig(
     const std::string& configId,
     const std::string& _serviceImpl
 ) const
@@ -143,7 +114,7 @@ core::runtime::ConfigurationElement::csptr Config::getServiceConfig(
     const std::string serviceImpl = core::runtime::filterID(_serviceImpl);
 #endif
     core::mt::ReadLock lock(m_registryMutex);
-    Registry::const_iterator iter = m_reg.find(configId);
+    auto iter = m_reg.find(configId);
     SIGHT_ASSERT(
         "The id " << configId << " is not found in the application configuration registry",
         iter != m_reg.end()
@@ -160,7 +131,7 @@ core::runtime::ConfigurationElement::csptr Config::getServiceConfig(
 const std::string& Config::getConfigDesc(const std::string& configId) const
 {
     core::mt::ReadLock lock(m_registryMutex);
-    Registry::const_iterator iter = m_reg.find(configId);
+    auto iter = m_reg.find(configId);
     SIGHT_ASSERT(
         "The id " << configId << " is not found in the application configuration registry",
         iter != m_reg.end()
@@ -176,7 +147,7 @@ std::vector<std::string> Config::getAllConfigForService(std::string _serviceImpl
     core::mt::ReadLock lock(m_registryMutex);
     std::vector<std::string> configs;
 
-    for(Registry::value_type srvCfg : m_reg)
+    for(const Registry::value_type& srvCfg : m_reg)
     {
         ServiceConfigInfo::sptr info = srvCfg.second;
         if((info->service.empty() && !matchingOnly) || info->service == serviceImpl)
@@ -190,6 +161,4 @@ std::vector<std::string> Config::getAllConfigForService(std::string _serviceImpl
 
 //-----------------------------------------------------------------------------
 
-} // namespace extension
-
-} // namespace sight::service
+} // namespace sight::service::extension
