@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,15 +24,13 @@
 
 #include "service/config.hpp"
 
-#include <core/runtime/ConfigurationElement.hpp>
 #include <core/tools/Object.hpp>
 
+#include <boost/property_tree/ptree.hpp>
+
 #include <map>
 
-namespace sight::service
-{
-
-namespace extension
+namespace sight::service::extension
 {
 
 /**
@@ -45,17 +43,15 @@ public:
 
     /// Constructor, do nothing.
     ServiceConfigInfo()
-    {
-    }
+    = default;
 
     /// Destructor, do nothing.
-    virtual ~ServiceConfigInfo()
-    {
-    }
+    ~ServiceConfigInfo() override
+    = default;
 
     std::string service;
     std::string desc;
-    core::runtime::ConfigurationElement::csptr config;
+    boost::property_tree::ptree config;
 };
 
 /**
@@ -87,7 +83,7 @@ public:
     SERVICE_API static Config::sptr getDefault();
 
     /// Destructor
-    SERVICE_API virtual ~Config();
+    SERVICE_API ~Config() override = default;
 
     /**
      * @brief Parses module information to retrieve service declaration.
@@ -108,14 +104,14 @@ public:
         const std::string& configId,
         const std::string& service,
         const std::string& desc,
-        core::runtime::ConfigurationElement::csptr config
+        const boost::property_tree::ptree& config
     );
 
     /**
      * @brief Returns the configuration with the given id for the service with the given implementation
      * @note This method is thread safe
      */
-    SERVICE_API core::runtime::ConfigurationElement::csptr getServiceConfig(
+    SERVICE_API boost::property_tree::ptree getServiceConfig(
         const std::string& configId,
         const std::string& serviceImpl =
         ""
@@ -151,7 +147,7 @@ protected:
     Registry m_reg;
 
     /// Constructor
-    SERVICE_API Config();
+    SERVICE_API Config() = default;
 
     const static std::string CONFIG_EXT_POINT;
 
@@ -162,6 +158,4 @@ protected:
     static Config::sptr s_currentServiceConfig;
 };
 
-} // namespace extension
-
-} // namespace sight::service
+} // namespace sight::service::extension
