@@ -25,20 +25,15 @@
 #include "service/IService.hpp"
 
 #include <core/LazyInstantiator.hpp>
-#include <core/runtime/ConfigurationElement.hpp>
 #include <core/runtime/helper.hpp>
-#include <core/runtime/profile/Profile.hpp>
-#include <core/runtime/Runtime.hpp>
+#include <core/runtime/runtime.hpp>
 
 #include <data/Exception.hpp>
 
 #include <functional>
 #include <vector>
 
-namespace sight::service
-{
-
-namespace extension
+namespace sight::service::extension
 {
 
 //-----------------------------------------------------------------------------
@@ -54,42 +49,42 @@ void Factory::parseBundleInformation()
 {
     SrvRegContainer moduleInfoMap;
 
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
-    typedef std::shared_ptr<core::runtime::Extension> ExtensionType;
+    using ExtensionType = std::shared_ptr<core::runtime::Extension>;
 
     std::vector<ExtensionType> extElements;
     extElements = core::runtime::getAllExtensionsForPoint("sight::service::extension::Factory");
-    for(ExtensionType extElt : extElements)
+    for(const ExtensionType& extElt : extElements)
     {
-        std::vector<ConfigurationType> cfgEltVec = extElt->getElements();
+        const core::runtime::config_t& cfgEltVec = extElt->getConfig();
         std::string type;
         std::string service;
         std::vector<std::string> objects;
         std::string desc;
         std::string tags;
 
-        for(ConfigurationType cfgElt : cfgEltVec)
+        for(const auto& cfgElt : cfgEltVec)
         {
-            std::string elt = cfgElt->getName();
+            const std::string elt = cfgElt.first;
+            const auto value      = cfgElt.second.get_value<std::string>();
             if(elt == "type")
             {
-                type = core::runtime::filterID(cfgElt->getValue());
+                type = core::runtime::filterID(value);
             }
             else if(elt == "service")
             {
-                service = core::runtime::filterID(cfgElt->getValue());
+                service = core::runtime::filterID(value);
             }
             else if(elt == "object")
             {
-                objects.push_back(core::runtime::filterID(cfgElt->getValue()));
+                objects.push_back(core::runtime::filterID(value));
             }
             else if(elt == "desc")
             {
-                desc = cfgElt->getValue();
+                desc = value;
             }
             else if(elt == "tags")
             {
-                tags = cfgElt->getValue();
+                tags = value;
             }
             else
             {
@@ -106,19 +101,19 @@ void Factory::parseBundleInformation()
         info.objectImpl           = std::move(objects);
         info.desc                 = desc;
         info.tags                 = tags;
-        info.module               = cfgEltVec[0]->getModule();
+        info.module               = extElt->getModule();
         SIGHT_ASSERT("Module not found.", info.module);
 
         moduleInfoMap.emplace(std::make_pair(service, info));
     }
 
-    this->printInfoMap(moduleInfoMap);
+    sight::service::extension::Factory::printInfoMap(moduleInfoMap);
 
     core::mt::ReadToWriteLock lock(m_srvImplToSrvInfoMutex);
     // Merge data info
-    for(SrvRegContainer::value_type module : moduleInfoMap)
+    for(const SrvRegContainer::value_type& module : moduleInfoMap)
     {
-        SrvRegContainer::iterator iter = m_srvImplToSrvInfo.find(module.first);
+        auto iter = m_srvImplToSrvInfo.find(module.first);
 
         if(iter != m_srvImplToSrvInfo.end())
         {
@@ -127,8 +122,8 @@ void Factory::parseBundleInformation()
                 << " )."
             );
 
-            ServiceInfo& info       = iter->second;
-            ServiceInfo& infoModule = module.second;
+            ServiceInfo& info             = iter->second;
+            const ServiceInfo& infoModule = module.second;
 
             SIGHT_ASSERT("Try to add a module, but this module already exists.", !info.module);
             SIGHT_ASSERT(
@@ -152,7 +147,7 @@ void Factory::parseBundleInformation()
         }
     }
 
-    this->printInfoMap(m_srvImplToSrvInfo);
+    sight::service::extension::Factory::printInfoMap(m_srvImplToSrvInfo);
     this->checkServicesNotDeclaredInPluginXml();
 }
 
@@ -164,7 +159,7 @@ IService::sptr Factory::create(const std::string& _srvImpl) const
     IService::sptr service;
 
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
 
     SIGHT_ASSERT(
         "The service called '" << srvImpl << "' does not exist in the Factory ",
@@ -198,8 +193,6 @@ IService::sptr Factory::create(const std::string& _srvImpl) const
         info.module->start();
         lock.lock();
 
-        core::runtime::getCurrentProfile()->setup();
-
         SIGHT_THROW_EXCEPTION_IF(
             data::Exception(
                 "After loading the module " + info.module->getIdentifier() + " , factory " + srvImpl
@@ -231,10 +224,10 @@ void Factory::addServiceFactory(
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     const std::string srvType = core::runtime::filterID(_srvType);
 
-    SIGHT_DEBUG("New service registering : srvImpl =" + srvImpl + " srvType=" + srvType);
+    SIGHT_DEBUG(std::string("New service registering : srvImpl =") + srvImpl + " srvType=" + srvType);
 
     core::mt::ReadToWriteLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
 
     if(iter != m_srvImplToSrvInfo.end())
     {
@@ -272,11 +265,11 @@ void Factory::addObjectFactory(const std::string& _srvImpl, const std::string& _
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     const std::string oImpl   = core::runtime::filterID(_oimpl);
 
-    SIGHT_DEBUG("New object oImpl=" + oImpl + "registering to service: srvImpl =" + srvImpl);
+    SIGHT_DEBUG(std::string("New object oImpl=") + oImpl + "registering to service: srvImpl =" + srvImpl);
     SIGHT_ASSERT("Empty oImpl", !oImpl.empty());
 
     core::mt::ReadToWriteLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
 
     SIGHT_ASSERT(
         "Try to associate an object to a service factory, but this srv is not yet registered.",
@@ -309,12 +302,12 @@ void Factory::addObjectFactory(const std::string& _srvImpl, const std::string& _
 
 //-----------------------------------------------------------------------------
 
-void Factory::printInfoMap(const SrvRegContainer& src) const
+void Factory::printInfoMap(const SrvRegContainer& src)
 {
     // not thread-safe
 
     //Print information
-    for(SrvRegContainer::value_type srvReg : src)
+    for(const SrvRegContainer::value_type& srvReg : src)
     {
         SIGHT_DEBUG(" Service name = " << srvReg.first);
         SIGHT_DEBUG("  - type   = " << srvReg.second.serviceType);
@@ -345,7 +338,7 @@ void Factory::checkServicesNotDeclaredInPluginXml() const
 {
     // not thread-safe
     //Print information
-    for(SrvRegContainer::value_type srvReg : m_srvImplToSrvInfo)
+    for(const SrvRegContainer::value_type& srvReg : m_srvImplToSrvInfo)
     {
         if(!srvReg.second.module)
         {
@@ -375,7 +368,7 @@ std::vector<std::string> Factory::getImplementationIdFromObjectAndType(
     std::vector<std::string> serviceImpl;
 
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    for(SrvRegContainer::value_type srv : m_srvImplToSrvInfo)
+    for(const SrvRegContainer::value_type& srv : m_srvImplToSrvInfo)
     {
         const ServiceInfo& srvInfo = srv.second;
         for(const auto& oimpl : srvInfo.objectImpl)
@@ -403,14 +396,14 @@ std::string Factory::getDefaultImplementationIdFromObjectAndType(
     const std::string type   = core::runtime::filterID(_type);
     SIGHT_ASSERT("This case is not managed ", object != "sight::data::Object");
 
-    std::string serviceImpl = "";
+    std::string serviceImpl;
 #ifdef _DEBUG
     bool genericImplIsFound = false;
 #endif
     bool specificImplIsFound = false;
 
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    for(SrvRegContainer::value_type srv : m_srvImplToSrvInfo)
+    for(const SrvRegContainer::value_type& srv : m_srvImplToSrvInfo)
     {
         const ServiceInfo& srvInfo = srv.second;
         if(srvInfo.serviceType == type)
@@ -430,7 +423,8 @@ std::string Factory::getDefaultImplementationIdFromObjectAndType(
                     serviceImpl         = srv.first;
                     break;
                 }
-                else if(oimpl == "sight::data::Object")
+
+                if(oimpl == "sight::data::Object")
                 {
                     SIGHT_ASSERT(
                         "Method has already found a generic service for the object ("
@@ -462,7 +456,7 @@ const std::vector<std::string>& Factory::getServiceObjects(const std::string& _s
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     std::string objImpl;
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
     SIGHT_ASSERT("The service " << srvImpl << " is not found.", iter != m_srvImplToSrvInfo.end());
     return iter->second.objectImpl;
 }
@@ -473,7 +467,7 @@ std::string Factory::getServiceDescription(const std::string& _srvImpl) const
 {
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
     SIGHT_ASSERT("The service " << srvImpl << " is not found.", iter != m_srvImplToSrvInfo.end());
     return iter->second.desc;
 }
@@ -484,7 +478,7 @@ std::string Factory::getServiceTags(const std::string& _srvImpl) const
 {
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
     SIGHT_ASSERT("The service " << srvImpl << " is not found.", iter != m_srvImplToSrvInfo.end());
     return iter->second.tags;
 }
@@ -497,7 +491,7 @@ bool Factory::checkServiceValidity(const std::string& _object, const std::string
     const std::string srvImpl = core::runtime::filterID(_srvImpl);
     bool isValid              = true;
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
     isValid &= (iter != m_srvImplToSrvInfo.end());
     if(isValid)
     {
@@ -527,7 +521,7 @@ bool Factory::support(const std::string& _object, const std::string& _srvType, c
 
     bool isSupported = true;
     core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-    SrvRegContainer::const_iterator iter = m_srvImplToSrvInfo.find(srvImpl);
+    auto iter = m_srvImplToSrvInfo.find(srvImpl);
     isSupported &= (iter != m_srvImplToSrvInfo.end());
     if(isSupported)
     {
@@ -568,7 +562,7 @@ bool Factory::support(const std::string& _object, const std::string& _srvType)
     else
     {
         core::mt::ReadLock lock(m_srvImplToSrvInfoMutex);
-        for(SrvRegContainer::value_type srv : m_srvImplToSrvInfo)
+        for(const SrvRegContainer::value_type& srv : m_srvImplToSrvInfo)
         {
             const ServiceInfo& srvInfo = srv.second;
 
@@ -602,13 +596,10 @@ Factory::KeyVectorType Factory::getFactoryKeys() const
         m_srvImplToSrvInfo.begin(),
         m_srvImplToSrvInfo.end(),
         std::back_inserter(vectKeys),
-        std::bind(&SrvRegContainer::value_type::first, std::placeholders::_1)
-    );
+        [](const auto& e){return e.first;});
     return vectKeys;
 }
 
 //-----------------------------------------------------------------------------
 
-} // namespace extension
-
-} // namespace sight::service
+} // namespace sight::service::extension
