@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,8 +25,6 @@
 #include "service/IService.hpp"
 #include "service/ServiceFactoryRegistry.hpp"
 
-#include <core/concept_checks.hpp>
-
 #include <boost/preprocessor/cat.hpp>
 #include <boost/preprocessor/facilities/empty.hpp>
 #include <boost/preprocessor/facilities/overload.hpp>
@@ -39,25 +37,10 @@ namespace sight::service
  */
 
 #define __FWSERVICE_REGISTER_MACRO(ServiceType, ServiceImpl) \
-    class BOOST_PP_CAT (ServiceTypeConceptCheck, __LINE__) \
-        { \
-        public : \
-            BOOST_CONCEPT_ASSERT((sight::core::concepts::SharedPtrTypedef<ServiceType>)); \
-}; \
-    class BOOST_PP_CAT (ServiceImplConceptCheck, __LINE__) \
-        { \
-        public : \
-            BOOST_CONCEPT_ASSERT((sight::core::concepts::SharedPtrTypedef<ServiceImpl>)); \
-}; \
     static sight::service::ServiceFactoryRegistry<ServiceImpl> \
     BOOST_PP_CAT(serviceRegistry, __LINE__)( #ServiceImpl, #ServiceType);
 
 #define __FWSERVICE_REGISTER_OBJECT_MACRO(ServiceImpl, ServiceObject) \
-    class BOOST_PP_CAT (ServiceObjectConceptCheck, __LINE__) \
-        { \
-        public : \
-            BOOST_CONCEPT_ASSERT((sight::core::concepts::SharedPtrTypedef<ServiceObject>)); \
-}; \
     static sight::service::ServiceObjectFactoryRegistry \
     BOOST_PP_CAT(serviceObjectRegistry, __LINE__)( #ServiceImpl, #ServiceObject);
 
@@ -86,4 +69,4 @@ namespace sight::service
 
 //@}
 
-}
+} // namespace sight::service
