@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,53 +20,15 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE
+
 #include "service/parser/Object.hpp"
 
-#include "service/macros.hpp"
+#include <ranges>
 
-#include <boost/foreach.hpp>
-
-namespace sight::service
+namespace sight::service::parser
 {
 
-namespace parser
-{
-
-//------------------------------------------------------------------------------
-
-Object::Object()
-{
-}
-
-//------------------------------------------------------------------------------
-
-Object::~Object()
-{
-}
-
-//------------------------------------------------------------------------------
-
-bool Object::refObjectValidator(core::runtime::ConfigurationElement::csptr _cfgElement)
-{
-    bool isOk = true;
-
-    for(core::runtime::ConfigurationElement::csptr elem : _cfgElement->getElements())
-    {
-        std::string subElementName = elem->getName();
-        if(subElementName != "service"
-           && subElementName != "serviceList")
-        {
-            SIGHT_ERROR(
-                "xml subelement \"" << subElementName
-                << "\" for element object is not supported for the moment when you use a reference on item composite."
-            );
-            isOk = false;
-        }
-    }
-
-    return isOk;
-}
-
 //------------------------------------------------------------------------------
 
 void Object::updating()
@@ -86,35 +48,21 @@ void Object::createConfig(core::tools::Object::sptr _obj)
     data::Object::sptr associatedObject = data::Object::dynamicCast(_obj);
     SIGHT_ASSERT("associatedObject not instanced", associatedObject);
 
-    for(core::runtime::ConfigurationElement::csptr elem : m_cfg->getElements())
+    for(const auto& elem : m_cfg)
     {
-        if(elem->getName() == "item")
+        if(elem.first == "item")
         {
-            // Test build mode
-            std::string buildMode = BUILD_OBJECT;
-
-            if(elem->hasAttribute(OBJECT_BUILD_MODE))
-            {
-                buildMode = elem->getExistingAttributeValue(OBJECT_BUILD_MODE);
-                SIGHT_ASSERT(
-                    "The buildMode \"" << buildMode << "\" is not supported, it should either be BUILD_OBJECT "
-                                                       "or GET_OBJECT.",
-                    buildMode == BUILD_OBJECT || buildMode == GET_OBJECT
-                );
-            }
-
+            const auto buildMode = elem.second.get<std::string>(OBJECT_BUILD_MODE, BUILD_OBJECT);
             SIGHT_ASSERT(
-                "The xml element \"item\" must have an attribute named \"key\" .",
-                elem->hasAttribute("key")
-            );
-            std::string key = elem->getExistingAttributeValue("key");
-            SIGHT_ASSERT(
-                "The xml element \"item\" must have an attribute named \"key\" which is not empty.",
-                !key.empty()
+                "The buildMode \"" << buildMode << "\" is not supported, it should be either BUILD_OBJECT"
+                                                   "or GET_OBJECT.",
+                buildMode == BUILD_OBJECT || buildMode == GET_OBJECT
             );
+
+            const auto key = elem.second.get<std::string>("<xmlattr>.key");
             SIGHT_ASSERT(
                 "The xml element \"item\" must have one (and only one) xml sub-element \"object\".",
-                elem->size() == 1 && (*(elem->getElements().begin()))->getName() == "object"
+                elem.second.count("object") == 1
             );
 
             if(buildMode == BUILD_OBJECT)
@@ -128,8 +76,8 @@ void Object::createConfig(core::tools::Object::sptr _obj)
                 );
 
                 // Create and manage object config
-                service::IAppConfigManager::sptr ctm = service::IAppConfigManager::New();
-                ctm->service::IAppConfigManager::setConfig(elem);
+                auto ctm = service::IAppConfigManager::New();
+                ctm->service::IAppConfigManager::setConfig(elem.second);
 
                 m_ctmContainer.push_back(ctm);
                 ctm->create();
@@ -151,7 +99,7 @@ void Object::createConfig(core::tools::Object::sptr _obj)
 
 void Object::startConfig()
 {
-    for(service::IAppConfigManager::sptr ctm : m_ctmContainer)
+    for(const service::IAppConfigManager::sptr& ctm : m_ctmContainer)
     {
         ctm->start();
     }
@@ -161,7 +109,7 @@ void Object::startConfig()
 
 void Object::updateConfig()
 {
-    for(service::IAppConfigManager::sptr ctm : m_ctmContainer)
+    for(const service::IAppConfigManager::sptr& ctm : m_ctmContainer)
     {
         ctm->update();
     }
@@ -171,7 +119,7 @@ void Object::updateConfig()
 
 void Object::stopConfig()
 {
-    BOOST_REVERSE_FOREACH(service::IAppConfigManager::sptr ctm, m_ctmContainer)
+    for(auto& ctm : std::views::reverse(m_ctmContainer))
     {
         ctm->stop();
     }
@@ -181,15 +129,14 @@ void Object::stopConfig()
 
 void Object::destroyConfig()
 {
-    BOOST_REVERSE_FOREACH(service::IAppConfigManager::sptr ctm, m_ctmContainer)
+    for(auto& ctm : std::views::reverse(m_ctmContainer))
     {
         ctm->destroy();
     }
+
     m_ctmContainer.clear();
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace parser
-
-} //namespace sight::service
+} // namespace sight::service::parser
