@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,8 @@
 
 #include "AppConfigParametersTest.hpp"
 
-#include <core/runtime/Module.hpp>
-#include <core/runtime/operations.hpp>
-#include <core/runtime/Runtime.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
 #include <service/extension/AppConfig.hpp>
 #include <service/extension/AppConfigParameters.hpp>
@@ -34,10 +33,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::AppConfigParametersTest);
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 //------------------------------------------------------------------------------
@@ -50,9 +46,7 @@ void AppConfigParametersTest::setUp()
     std::filesystem::path location = core::runtime::getResourceFilePath("tu_exec_service");
     CPPUNIT_ASSERT(std::filesystem::exists(location));
 
-    auto& runtime = core::runtime::Runtime::get();
-    runtime.addModules(location);
-
+    core::runtime::addModules(location);
     core::runtime::loadModule("sight::module::service");
     core::runtime::loadModule("AppConfigParametersTest");
 
@@ -88,11 +82,10 @@ void AppConfigParametersTest::appConfigParametersTest()
 
 void AppConfigParametersTest::concurentAccessToAppConfigParametersTest()
 {
-    const auto fn = std::bind(&AppConfigParametersTest::appConfigParametersTest, this);
     std::vector<std::future<void> > futures;
     for(unsigned int i = 0 ; i < 20 ; ++i)
     {
-        futures.push_back(std::async(std::launch::async, fn));
+        futures.push_back(std::async(std::launch::async, appConfigParametersTest));
     }
 
     for(auto& future : futures)
@@ -105,6 +98,4 @@ void AppConfigParametersTest::concurentAccessToAppConfigParametersTest()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
