@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,24 +24,35 @@
 
 #include "TestServices.hpp"
 
-#include <core/runtime/Convert.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
 #include <data/Image.hpp>
 #include <data/Mesh.hpp>
+#include <data/TransferFunction.hpp>
 
-#include <service/AppConfigManager.hpp>
 #include <service/base.hpp>
+#include <service/IAppConfigManager.hpp>
 #include <service/parser/Image.hpp>
+#include <service/parser/TransferFunction.hpp>
+
+#include <boost/property_tree/xml_parser.hpp>
+
+#include <glm/common.hpp>
+#include <glm/gtc/epsilon.hpp>
+
+static const double s_EPSILON = 1e-5;
+
+// There might be some uncertainty when sampling, so we need to include an epsilon when testing equality
+#define ASSERT_COLOR_EQUALS(c1, c2) \
+    CPPUNIT_ASSERT(glm::all(glm::epsilonEqual(c1, c2, s_EPSILON)));
 
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::ConfigParserTest);
 
 //------------------------------------------------------------------------------
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 //------------------------------------------------------------------------------
@@ -54,9 +65,7 @@ void ConfigParserTest::setUp()
     std::filesystem::path location = core::runtime::getResourceFilePath("tu_exec_service");
     CPPUNIT_ASSERT(std::filesystem::exists(location));
 
-    auto& runtime = core::runtime::Runtime::get();
-    runtime.addModules(location);
-
+    core::runtime::addModules(location);
     core::runtime::loadModule("sight::module::service");
 }
 
@@ -76,10 +85,10 @@ void ConfigParserTest::testObjectCreationWithConfig()
     const std::string serviceUUID2 = "myTestService2";
 
     // Create object configuration
-    core::runtime::ConfigurationElement::sptr config = buildObjectConfig();
+    const auto config = buildObjectConfig();
 
     // Create the object and its services from the configuration
-    service::AppConfigManager::sptr configManager = service::AppConfigManager::New();
+    auto configManager = service::IAppConfigManager::New();
     configManager->service::IAppConfigManager::setConfig(config);
     configManager->create();
     auto image = data::Image::dynamicCast(configManager->getConfigRoot());
@@ -95,7 +104,7 @@ void ConfigParserTest::testObjectCreationWithConfig()
     CPPUNIT_ASSERT(srv2->isStarted());
 
     // Test if object's service is created
-    CPPUNIT_ASSERT(image == srv1->getObject("data", data::Access::in));
+    CPPUNIT_ASSERT(image == srv1->data::IHasData::getObject("data", data::Access::in));
 
     // Test update services
     configManager->update();
@@ -124,22 +133,16 @@ void ConfigParserTest::testImageParser()
     objCfg.add("color", "#FF459812");
     config.add_child("object", objCfg);
 
-    service::IService::ConfigType serviceCfg;
-    serviceCfg.add_child("config", config);
-
-    // Create object configuration
-    const auto cfg = core::runtime::Convert::fromPropertyTree(serviceCfg);
-
     // Create the object and its services from the configuration
-    service::AppConfigManager::sptr configManager = service::AppConfigManager::New();
-    configManager->service::IAppConfigManager::setConfig(cfg);
+    auto configManager = service::IAppConfigManager::New();
+    configManager->service::IAppConfigManager::setConfig(config);
     configManager->create();
     auto image = std::dynamic_pointer_cast<data::Image>(core::tools::fwID::getObject(objectUUID));
 
     // Test object uid
     CPPUNIT_ASSERT_EQUAL(objectUUID, image->getID());
     CPPUNIT_ASSERT_EQUAL(sight::data::Image::RGBA, image->getPixelFormat());
-    CPPUNIT_ASSERT_EQUAL(sight::core::tools::Type::s_UINT8, image->getType());
+    CPPUNIT_ASSERT_EQUAL(sight::core::Type::UINT8, image->getType());
 
     // We only test the image content, we do not really care about the image size and other attributes for now
     const auto dumpLock = image->dump_lock();
@@ -159,7 +162,61 @@ void ConfigParserTest::testImageParser()
 
 //------------------------------------------------------------------------------
 
-core::runtime::ConfigurationElement::sptr ConfigParserTest::buildObjectConfig()
+void ConfigParserTest::testTransferFunctionParser()
+{
+    service::IService::ConfigType config;
+
+    std::stringstream config_string;
+    config_string << "<colors>"
+                     "<step color=\"#ffff00ff\" value=\"-200\" />"
+                     "<step color=\"#000000ff\" value=\"0\" />"
+                     "<step color=\"#0000ffff\" value=\"1\" />"
+                     "<step color=\"#0000ffff\" value=\"500\" />"
+                     "<step color=\"#00ff00ff\" value=\"1000\" />"
+                     "<step color=\"#ff0000ff\" value=\"1500\" />"
+                     "<step color=\"#000000ff\" value=\"5000\" />"
+                     "</colors>";
+    boost::property_tree::read_xml(config_string, config);
+
+    auto parser = sight::service::add<sight::service::parser::TransferFunction>(
+        "sight::service::parser::TransferFunction"
+    );
+    parser->setObjectConfig(config);
+
+    auto tf = sight::data::TransferFunction::New();
+    parser->createConfig(tf);
+
+    const auto piece = tf->pieces().front();
+    CPPUNIT_ASSERT_EQUAL(std::size_t(7), piece->size());
+
+    CPPUNIT_ASSERT_EQUAL(-200., piece->minMax().first);
+    CPPUNIT_ASSERT_EQUAL(5000., piece->minMax().second);
+    CPPUNIT_ASSERT_EQUAL(5200., piece->window());
+    CPPUNIT_ASSERT_EQUAL(2400., piece->level());
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(1., 1., 0., 1.), piece->sampleLinear(-200));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 0., 1.), piece->sampleLinear(0));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 1., 1.), piece->sampleLinear(250));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 1., 1.), piece->sampleLinear(500));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 1., 0., 1.), piece->sampleLinear(1000));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(1., 0., 0., 1.), piece->sampleLinear(1500));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 0., 1.), piece->sampleLinear(5000));
+
+    CPPUNIT_ASSERT_EQUAL(-200., tf->minMax().first);
+    CPPUNIT_ASSERT_EQUAL(5000., tf->minMax().second);
+    CPPUNIT_ASSERT_EQUAL(5200., tf->window());
+    CPPUNIT_ASSERT_EQUAL(2400., tf->level());
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(1., 1., 0., 1.), tf->sampleLinear(-200));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 0., 1.), tf->sampleLinear(0));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 1., 1.), tf->sampleLinear(250));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 1., 1.), tf->sampleLinear(500));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 1., 0., 1.), tf->sampleLinear(1000));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(1., 0., 0., 1.), tf->sampleLinear(1500));
+    ASSERT_COLOR_EQUALS(data::TransferFunction::color_t(0., 0., 0., 1.), tf->sampleLinear(5000));
+}
+
+//------------------------------------------------------------------------------
+
+service::IService::config_t ConfigParserTest::buildObjectConfig()
 {
     service::IService::ConfigType config;
 
@@ -199,14 +256,9 @@ core::runtime::ConfigurationElement::sptr ConfigParserTest::buildObjectConfig()
     update1.add("<xmlattr>.uid", "myTestService1");
     config.add_child("update", update1);
 
-    service::IService::ConfigType serviceCfg;
-    serviceCfg.add_child("config", config);
-
-    return core::runtime::Convert::fromPropertyTree(serviceCfg);
+    return config;
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
