@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -47,10 +47,7 @@ CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::LockTest);
 
 //------------------------------------------------------------------------------
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 class LockedService : public service::IService
@@ -63,9 +60,8 @@ public:
 
     SIGHT_DECLARE_SERVICE(LockedService, service::IService);
 
-    LockedService() noexcept
-    {
-    }
+    LockedService() noexcept =
+        default;
 
     std::atomic_bool m_started {false};
     std::atomic_bool m_stopped {false};
@@ -73,7 +69,7 @@ public:
 
     //------------------------------------------------------------------------------
 
-    virtual void starting() final
+    void starting() final
     {
         // Reading should not be blocked by other reader
         auto input = m_input.lock();
@@ -87,7 +83,7 @@ public:
 
     //------------------------------------------------------------------------------
 
-    virtual void stopping() final
+    void stopping() final
     {
         // Reading should not be blocked by other reader
         auto sharedOutput = m_output.lock();
@@ -103,19 +99,13 @@ public:
 
     //------------------------------------------------------------------------------
 
-    virtual void configuring() final
+    void configuring() final
     {
     }
 
     //------------------------------------------------------------------------------
 
-    virtual void reconfiguring() final
-    {
-    }
-
-    //------------------------------------------------------------------------------
-
-    virtual void updating() final
+    void updating() final
     {
     }
 
@@ -144,15 +134,15 @@ void LockTest::tearDown()
     // Clean up after the test run.
     // unregister the services that have not been unregistered because a test failed.
 
-    const auto& services = service::OSR::getServices<service::IService>();
-    for(auto service : services)
+    const auto& services = service::getServices<service::IService>();
+    for(const auto& service : services)
     {
         if(service->isStarted())
         {
             service->stop();
         }
 
-        service::OSR::unregisterService(service);
+        service::unregisterService(service);
     }
 }
 
@@ -169,11 +159,13 @@ void LockTest::testScopedLock()
     data::Integer::sptr inout  = data::Integer::New(0);
     data::Integer::sptr output = data::Integer::New(0);
 
+    CPPUNIT_ASSERT_EQUAL(std::uint64_t(0), inout->lastModified());
+    CPPUNIT_ASSERT_EQUAL(std::uint64_t(0), output->lastModified());
+
     // Register the data
     lockedService->setInput(input, service::ut::LockedService::s_INPUT);
     lockedService->setInOut(inout, service::ut::LockedService::s_INOUT);
     lockedService->setOutput(service::ut::LockedService::s_OUTPUT, output);
-    CPPUNIT_ASSERT_EQUAL(true, lockedService->hasAllRequiredObjects());
 
     // Test basic scoped lock
     data::mt::weak_ptr<const data::Integer> weakInput(input);
@@ -186,12 +178,14 @@ void LockTest::testScopedLock()
     {
         auto sharedInOut = weakInOut.lock();
         CPPUNIT_ASSERT_EQUAL(inout, sharedInOut.get_shared());
+        CPPUNIT_ASSERT_EQUAL(std::uint64_t(1), sharedInOut->lastModified());
     }
 
     data::mt::weak_ptr<data::Integer> weakOutput(output);
     {
         auto sharedOutput = weakOutput.lock();
         CPPUNIT_ASSERT_EQUAL(output, sharedOutput.get_shared());
+        CPPUNIT_ASSERT_EQUAL(std::uint64_t(1), sharedOutput->lastModified());
     }
 
     // Test basic scoped lock from service getters
@@ -205,12 +199,14 @@ void LockTest::testScopedLock()
     {
         auto sharedInOut = weakInOut.lock();
         CPPUNIT_ASSERT_EQUAL(inout, sharedInOut.get_shared());
+        CPPUNIT_ASSERT_EQUAL(std::uint64_t(2), sharedInOut->lastModified());
     }
 
     weakOutput = lockedService->getOutput<data::Integer>(service::ut::LockedService::s_OUTPUT);
     {
         auto sharedOutput = weakOutput.lock();
         CPPUNIT_ASSERT_EQUAL(output, sharedOutput.get_shared());
+        CPPUNIT_ASSERT_EQUAL(std::uint64_t(2), sharedOutput->lastModified());
     }
 
     // Test basic scoped lock from service direct locker
@@ -232,7 +228,7 @@ void LockTest::testScopedLock()
     }
 
     // cleanup
-    service::OSR::unregisterService(lockedService);
+    service::unregisterService(lockedService);
 }
 
 //------------------------------------------------------------------------------
@@ -241,7 +237,7 @@ void LockTest::testDumpLock()
 {
     data::Image::sptr image = data::Image::New();
 
-    utestData::generator::Image::generateRandomImage(image, core::tools::Type::s_UINT8);
+    utestData::generator::Image::generateRandomImage(image, core::Type::UINT8);
 
     // Add the service
     service::IService::sptr lockedService = service::add("sight::service::ut::LockedService");
@@ -286,11 +282,11 @@ void LockTest::testDumpLock()
 
         mesh->reserve(3, 1, data::Mesh::CellType::TRIANGLE, data::Mesh::Attributes::POINT_COLORS);
 
-        data::Mesh::position_t A[3] = {0., 0., 0.};
-        data::Mesh::position_t B[3] = {1., 0., 0.};
-        data::Mesh::position_t C[3] = {1., 1., 0.};
+        const std::array<data::Mesh::position_t, 3> A = {0., 0., 0.};
+        const std::array<data::Mesh::position_t, 3> B = {1., 0., 0.};
+        const std::array<data::Mesh::position_t, 3> C = {1., 1., 0.};
 
-        data::Mesh::point_t ids[3];
+        std::array<data::Mesh::point_t, 3> ids {};
 
         ids[0] = mesh->pushPoint(A);
         ids[1] = mesh->pushPoint(B);
@@ -302,7 +298,7 @@ void LockTest::testDumpLock()
         CPPUNIT_ASSERT_NO_THROW(mesh->pushPoint(B));
         CPPUNIT_ASSERT_NO_THROW(mesh->pushPoint(C));
 
-        CPPUNIT_ASSERT_NO_THROW(mesh->pushCell(ids, 3));
+        CPPUNIT_ASSERT_NO_THROW(mesh->pushCell(std::vector(ids.begin(), ids.end())));
 
         const std::array<data::Mesh::color_t, 4> color = {255, 0, 0, 255};
 
@@ -318,7 +314,7 @@ void LockTest::testDumpLock()
     {
         try
         {
-            mesh->pushPoint(0.f, 0.f, 0.f);
+            mesh->pushPoint(0.F, 0.F, 0.F);
         }
         catch(data::Exception&)
         {
@@ -351,7 +347,6 @@ void LockTest::testThreadedLock()
     lockedService->setInput(input, service::ut::LockedService::s_INPUT);
     lockedService->setInOut(inout, service::ut::LockedService::s_INOUT);
     lockedService->setOutput(service::ut::LockedService::s_OUTPUT, output);
-    CPPUNIT_ASSERT_EQUAL(true, lockedService->hasAllRequiredObjects());
 
     // Test that inputLock doesn't block other reader
     {
@@ -402,9 +397,7 @@ void LockTest::testThreadedLock()
     }
 
     // cleanup
-    service::OSR::unregisterService(lockedService);
+    service::unregisterService(lockedService);
 }
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
