@@ -34,10 +34,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::ServiceConfigTest);
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 //------------------------------------------------------------------------------
@@ -64,15 +61,14 @@ void ServiceConfigTest::serviceConfigTest()
     const std::string configId(service::extension::AppConfig::getUniqueIdentifier());
     const std::string service("sight::service::ut::TestService");
     const std::string desc("Description of config");
-    core::runtime::ConfigurationElement::csptr config = this->buildConfig();
+    service::IService::ConfigType config = buildConfig();
 
     currentServiceConfig->addServiceConfigInfo(configId, service, desc, config);
 
-    core::runtime::ConfigurationElement::csptr serviceConfig =
-        currentServiceConfig->getServiceConfig(configId, service);
-    CPPUNIT_ASSERT(serviceConfig);
-    CPPUNIT_ASSERT(serviceConfig->hasAttribute("uid"));
-    CPPUNIT_ASSERT_EQUAL(std::string("serviceUUID"), serviceConfig->getAttributeValue("uid"));
+    const auto serviceConfig = currentServiceConfig->getServiceConfig(configId, service);
+    CPPUNIT_ASSERT(!serviceConfig.empty());
+    CPPUNIT_ASSERT(serviceConfig.get_optional<std::string>("service.<xmlattr>.uid").has_value());
+    CPPUNIT_ASSERT_EQUAL(std::string("serviceUUID"), serviceConfig.get<std::string>("service.<xmlattr>.uid"));
 
     std::vector<std::string> configs = currentServiceConfig->getAllConfigForService(service);
     CPPUNIT_ASSERT(!configs.empty());
@@ -83,11 +79,10 @@ void ServiceConfigTest::serviceConfigTest()
 
 void ServiceConfigTest::concurentAccessToServiceConfigTest()
 {
-    const auto fn = std::bind(&ServiceConfigTest::serviceConfigTest, this);
     std::vector<std::future<void> > futures;
     for(unsigned int i = 0 ; i < 20 ; ++i)
     {
-        futures.push_back(std::async(std::launch::async, fn));
+        futures.push_back(std::async(std::launch::async, serviceConfigTest));
     }
 
     std::for_each(futures.begin(), futures.end(), std::mem_fn(&std::shared_future<void>::wait));
@@ -127,7 +122,7 @@ void ServiceConfigTest::getAllConfigsTest()
             configId,
             serviceName0,
             "Much test, oh wow",
-            nullptr
+            boost::property_tree::ptree()
         );
     }
 
@@ -141,7 +136,7 @@ void ServiceConfigTest::getAllConfigsTest()
             configId,
             serviceName1,
             "No, bad test ! Bad !",
-            nullptr
+            boost::property_tree::ptree()
         );
     }
 
@@ -156,21 +151,21 @@ void ServiceConfigTest::getAllConfigsTest()
             configId,
             "", // Empty type.
             "Such empty, much space, wow.",
-            nullptr
+            boost::property_tree::ptree()
         );
     }
 
     const std::vector<std::string> test0 = currentServiceConfig->getAllConfigForService(serviceName0);
     CPPUNIT_ASSERT_EQUAL(std::size_t(9), test0.size());
 
-    for(std::size_t i = 0 ; i < test0.size() ; ++i)
+    for(const auto& i : test0)
     {
         CPPUNIT_ASSERT_EQUAL(
             true,
             std::find(
                 vectConfigTest0.begin(),
                 vectConfigTest0.end(),
-                test0[i]
+                i
             ) != vectConfigTest0.end()
         );
     }
@@ -178,14 +173,14 @@ void ServiceConfigTest::getAllConfigsTest()
     const std::vector<std::string> test1 = currentServiceConfig->getAllConfigForService(serviceName1);
     CPPUNIT_ASSERT_EQUAL(std::size_t(7), test1.size());
 
-    for(std::size_t i = 0 ; i < test1.size() ; ++i)
+    for(const auto& i : test1)
     {
         CPPUNIT_ASSERT_EQUAL(
             true,
             std::find(
                 vectConfigTest1.begin(),
                 vectConfigTest1.end(),
-                test1[i]
+                i
             ) != vectConfigTest1.end()
         );
     }
@@ -229,22 +224,19 @@ void ServiceConfigTest::getAllConfigsTest()
 
 //------------------------------------------------------------------------------
 
-core::runtime::ConfigurationElement::sptr ServiceConfigTest::buildConfig()
+service::IService::ConfigType ServiceConfigTest::buildConfig()
 {
-    std::shared_ptr<core::runtime::EConfigurationElement> serviceCfg(new core::runtime::EConfigurationElement(
-                                                                         "config"
-    ));
-    serviceCfg->setAttributeValue("uid", "serviceUUID");
-    serviceCfg->setAttributeValue("type", "serviceType");
+    service::IService::ConfigType config;
 
-    core::runtime::EConfigurationElement::sptr cfg = serviceCfg->addConfigurationElement("param");
-    cfg->setValue("Parameter");
+    service::IService::ConfigType serviceCfg;
+    serviceCfg.add("<xmlattr>.uid", "serviceUUID");
+    serviceCfg.add("<xmlattr>.type", "serviceType");
+    serviceCfg.add("param", "Parameter");
 
-    return serviceCfg;
+    config.add_child("service", serviceCfg);
+    return config;
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
