@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2022 IRCAD France
  * Copyright (C) 2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,10 +23,7 @@
 #pragma once
 
 #include <cppunit/extensions/HelperMacros.h>
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 /**
@@ -41,14 +38,12 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void factoryTest();
+    static void factoryTest();
 
 private:
 };
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
