@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,7 +24,6 @@
 
 #include <core/com/helper/SigSlotConnection.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/EConfigurationElement.hpp>
 #include <core/runtime/helper.hpp>
 #include <core/thread/Worker.hpp>
 #include <core/TimeStamp.hpp>
@@ -45,10 +44,7 @@ CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::ServiceTest);
 
 //------------------------------------------------------------------------------
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 //------------------------------------------------------------------------------
@@ -65,15 +61,15 @@ void ServiceTest::tearDown()
     // Clean up after the test run.
     // unregister the services that have not been unregistered because a test failed.
 
-    auto services = service::OSR::getServices<service::IService>();
-    for(auto srv : services)
+    auto services = service::getServices<service::IService>();
+    for(const auto& srv : services)
     {
         if(srv->isStarted())
         {
             srv->stop();
         }
 
-        service::OSR::unregisterService(srv);
+        service::unregisterService(srv);
     }
 }
 
@@ -117,8 +113,8 @@ void ServiceTest::testServiceConfiguration()
     CPPUNIT_ASSERT_EQUAL(OPTION2, srv2->getOption());
 
     // Test erasing service
-    service::OSR::unregisterService(srv);
-    service::OSR::unregisterService(srv2);
+    service::unregisterService(srv);
+    service::unregisterService(srv2);
 }
 
 //------------------------------------------------------------------------------
@@ -143,40 +139,40 @@ void ServiceTest::testServiceCreationWithMultipleData()
     // Test adding service
     service::IService::sptr srv = service::add("sight::service::ut::STest2Inouts1Input");
     srv->setInOut(obj1, dataKey1);
-    CPPUNIT_ASSERT(obj1 == srv->getObject(dataKey1, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey2, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey3, data::Access::in));
+    CPPUNIT_ASSERT(obj1 == srv->data::IHasData::getObject(dataKey1, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey2, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey3, data::Access::in));
 
     // Test getting the service object
     CPPUNIT_ASSERT(srv->getInOut<data::Integer>(dataKey1).lock() == obj1);
 
-    srv->setObject(obj2, dataKey2, std::nullopt, data::Access::inout, false, false);
-    CPPUNIT_ASSERT(obj2 == srv->getObject(dataKey2, data::Access::inout));
+    srv->setInOut(obj2, dataKey2, false, false);
+    CPPUNIT_ASSERT(obj2 == srv->data::IHasData::getObject(dataKey2, data::Access::inout));
 
     // Test getting the service object
     CPPUNIT_ASSERT(srv->getInOut<data::Integer>(dataKey2).lock() == obj2);
 
     srv->setInput(obj3, dataKey3);
-    CPPUNIT_ASSERT(obj3 == srv->getObject(dataKey3, data::Access::in));
+    CPPUNIT_ASSERT(obj3 == srv->data::IHasData::getObject(dataKey3, data::Access::in));
 
     // Test getting the service object
     CPPUNIT_ASSERT(srv->getInput<data::Integer>(dataKey3).lock() == obj3);
 
     // Test unregistering the objects
     srv->setInOut(nullptr, dataKey1);
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey1, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr != srv->getObject(dataKey2, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr != srv->getObject(dataKey3, data::Access::in));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey1, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr != srv->data::IHasData::getObject(dataKey2, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr != srv->data::IHasData::getObject(dataKey3, data::Access::in));
 
     srv->setInOut(nullptr, dataKey2);
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey1, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey2, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr != srv->getObject(dataKey3, data::Access::in));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey1, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey2, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr != srv->data::IHasData::getObject(dataKey3, data::Access::in));
 
     srv->setInput(nullptr, dataKey3);
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey1, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey2, data::Access::inout));
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey3, data::Access::in));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey1, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey2, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey3, data::Access::in));
 
     // Test erasing service
     service::remove(srv);
@@ -200,14 +196,14 @@ void ServiceTest::testServiceCreationWithTemplateMethods()
     // Test adding service
     auto srv = service::add<service::ut::TestService>("sight::service::ut::STest1Inout");
     srv->setInOut(obj, dataKey);
-    CPPUNIT_ASSERT(srv->getObject(dataKey, data::Access::inout));
-    CPPUNIT_ASSERT(obj == srv->getObject(dataKey, data::Access::inout));
+    CPPUNIT_ASSERT(srv->data::IHasData::getObject(dataKey, data::Access::inout));
+    CPPUNIT_ASSERT(obj == srv->data::IHasData::getObject(dataKey, data::Access::inout));
 
     // Test getting the service its object
     CPPUNIT_ASSERT(srv->getInOut<data::Integer>(dataKey).lock() == obj);
 
     srv->setInOut(nullptr, dataKey);
-    CPPUNIT_ASSERT(nullptr == srv->getObject(dataKey, data::Access::inout));
+    CPPUNIT_ASSERT(nullptr == srv->data::IHasData::getObject(dataKey, data::Access::inout));
 
     // Test erasing service
     service::remove(srv);
@@ -254,12 +250,12 @@ void ServiceTest::testServiceCreationWithUUID()
     CPPUNIT_ASSERT(service2bis->getInOut<data::Integer>(dataKey).lock() == obj);
     CPPUNIT_ASSERT_EQUAL(myUUID2, service2bis->getID());
     CPPUNIT_ASSERT(!core::tools::fwID::exist(myUUID3));
-    CPPUNIT_ASSERT_EQUAL(nbServices, service::OSR::getServices("sight::service::ut::TestService").size());
+    CPPUNIT_ASSERT_EQUAL(nbServices, service::getServices("sight::service::ut::TestService").size());
 
     // Test erasing service
     service::remove(service);
     nbServices--;
-    CPPUNIT_ASSERT_EQUAL(nbServices, service::OSR::getServices("sight::service::ut::TestService").size());
+    CPPUNIT_ASSERT_EQUAL(nbServices, service::getServices("sight::service::ut::TestService").size());
     service::remove(service2);
 }
 
@@ -301,7 +297,7 @@ void ServiceTest::testStartStopUpdate()
     CPPUNIT_ASSERT(!service->isStarted());
 
     // Erase Service
-    service::OSR::unregisterService(service);
+    service::unregisterService(service);
 }
 
 //------------------------------------------------------------------------------
@@ -327,12 +323,9 @@ void ServiceTest::testStartStopUpdateExceptions()
 
 struct TestServiceSignals : public core::com::HasSlots
 {
-    typedef std::shared_ptr<TestServiceSignals> sptr;
+    using sptr = std::shared_ptr<TestServiceSignals>;
 
-    TestServiceSignals() :
-        m_started(false),
-        m_updated(false),
-        m_stopped(false)
+    TestServiceSignals()
     {
         newSlot("start", &TestServiceSignals::start, this);
         newSlot("update", &TestServiceSignals::update, this);
@@ -342,7 +335,7 @@ struct TestServiceSignals : public core::com::HasSlots
         m_slots.setWorker(m_worker);
     }
 
-    virtual ~TestServiceSignals();
+    ~TestServiceSignals() override;
 
     //------------------------------------------------------------------------------
 
@@ -366,9 +359,9 @@ struct TestServiceSignals : public core::com::HasSlots
     }
 
     core::thread::Worker::sptr m_worker;
-    bool m_started;
-    bool m_updated;
-    bool m_stopped;
+    bool m_started {false};
+    bool m_updated {false};
+    bool m_stopped {false};
 };
 
 //------------------------------------------------------------------------------
@@ -406,17 +399,17 @@ void ServiceTest::testCommunication()
     TestServiceSignals::sptr receiver2 = std::make_shared<TestServiceSignals>();
 
     core::com::helper::SigSlotConnection comHelper;
-    comHelper.connect(service1, service::IService::s_STARTED_SIG, receiver1, "start");
-    comHelper.connect(service1, service::IService::s_UPDATED_SIG, receiver1, "update");
-    comHelper.connect(service1, service::IService::s_STOPPED_SIG, receiver1, "stop");
+    comHelper.connect(service1, service::IService::signals::s_STARTED, receiver1, "start");
+    comHelper.connect(service1, service::IService::signals::s_UPDATED, receiver1, "update");
+    comHelper.connect(service1, service::IService::signals::s_STOPPED, receiver1, "stop");
 
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_started);
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_updated);
     CPPUNIT_ASSERT_EQUAL(false, receiver1->m_stopped);
 
-    comHelper.connect(service2, service::IService::s_STARTED_SIG, receiver2, "start");
-    comHelper.connect(service2, service::IService::s_UPDATED_SIG, receiver2, "update");
-    comHelper.connect(service2, service::IService::s_STOPPED_SIG, receiver2, "stop");
+    comHelper.connect(service2, service::IService::signals::s_STARTED, receiver2, "start");
+    comHelper.connect(service2, service::IService::signals::s_UPDATED, receiver2, "update");
+    comHelper.connect(service2, service::IService::signals::s_STOPPED, receiver2, "stop");
 
     CPPUNIT_ASSERT_EQUAL(false, receiver2->m_started);
     CPPUNIT_ASSERT_EQUAL(false, receiver2->m_updated);
@@ -439,17 +432,18 @@ void ServiceTest::testCommunication()
     // Register communication channel
     comHelper.connect(
         service1,
-        service::ut::ISTest::s_MSG_SENT_SIG,
+        service::ut::ISTest::signals::s_MSG_SENT,
         service2,
-        service::ut::ISTest::s_UPDATE2_SLOT
+        service::ut::ISTest::slots::s_UPDATE2
     );
 
     CPPUNIT_ASSERT(!service2->getIsUpdated2());
 
     // Service1 send notification
     {
-        auto sig  = service1->signal<service::ut::ISTest::MsgSentSignalType>(service::ut::ISTest::s_MSG_SENT_SIG);
-        auto slot = service1->slot(service::IService::s_UPDATE_SLOT);
+        auto sig =
+            service1->signal<service::ut::ISTest::signals::msg_sent_t>(service::ut::ISTest::signals::s_MSG_SENT);
+        auto slot = service1->slot(service::IService::slots::s_UPDATE);
         core::com::Connection::Blocker block(sig->getConnection(slot));
         sig->asyncEmit(EVENT);
     }
@@ -480,8 +474,8 @@ void ServiceTest::testCommunication()
 
     comHelper.disconnect();
 
-    service::OSR::unregisterService(service1);
-    service::OSR::unregisterService(service2);
+    service::unregisterService(service1);
+    service::unregisterService(service2);
 }
 
 //------------------------------------------------------------------------------
@@ -577,7 +571,7 @@ void ServiceTest::startStopUpdateExceptions(TestService::sptr _service)
     CPPUNIT_ASSERT(_service->isStopped());
 
     // Erase Service
-    service::OSR::unregisterService(_service);
+    service::unregisterService(_service);
 }
 
 //------------------------------------------------------------------------------
@@ -592,30 +586,37 @@ void ServiceTest::testWithInAndOut()
     );
 
     CPPUNIT_ASSERT(service);
-    CPPUNIT_ASSERT_EQUAL(false, service->hasAllRequiredObjects());
     service->setInput(obj[0], service::ut::TestServiceWithData::s_INPUT);
-    CPPUNIT_ASSERT_EQUAL(false, service->hasAllRequiredObjects());
     service->setInOut(obj[0], service::ut::TestServiceWithData::s_INOUT_GROUP, true, false, 0);
-    CPPUNIT_ASSERT_EQUAL(true, service->hasAllRequiredObjects());
     service->setInOut(obj[1], service::ut::TestServiceWithData::s_INOUT_GROUP, true, false, 1);
-    CPPUNIT_ASSERT_EQUAL(true, service->hasAllRequiredObjects());
 
     service->start().wait();
     CPPUNIT_ASSERT(service->isStarted());
-    CPPUNIT_ASSERT(nullptr != service->getObject(service::ut::TestServiceWithData::s_INPUT, data::Access::in));
+    CPPUNIT_ASSERT(
+        nullptr
+        != service->data::IHasData::getObject(service::ut::TestServiceWithData::s_INPUT, data::Access::in)
+    );
     service->update().wait();
-    CPPUNIT_ASSERT(nullptr != service->getObject(service::ut::TestServiceWithData::s_OUTPUT, data::Access::out));
-    data::Object::csptr output = service->getObject(service::ut::TestServiceWithData::s_OUTPUT, data::Access::out);
+    CPPUNIT_ASSERT(
+        nullptr
+        != service->data::IHasData::getObject(service::ut::TestServiceWithData::s_OUTPUT, data::Access::out)
+    );
+    data::Object::csptr output = service->data::IHasData::getObject(
+        service::ut::TestServiceWithData::s_OUTPUT,
+        data::Access::out
+    );
     CPPUNIT_ASSERT(output);
     data::Integer::csptr outInteger = data::Integer::dynamicCast(output);
     CPPUNIT_ASSERT(outInteger);
 
     CPPUNIT_ASSERT_EQUAL(obj[0]->value(), outInteger->value());
 
-    auto outInteger2 = service->getOutput<data::Integer>(service::ut::TestServiceWithData::s_OUTPUT).lock();
-    CPPUNIT_ASSERT(outInteger2);
+    {
+        auto outInteger2 = service->getOutput<data::Integer>(service::ut::TestServiceWithData::s_OUTPUT).lock();
+        CPPUNIT_ASSERT(outInteger2);
 
-    CPPUNIT_ASSERT_EQUAL(obj[0]->value(), outInteger2->value());
+        CPPUNIT_ASSERT_EQUAL(obj[0]->value(), outInteger2->value());
+    }
 
     // Test index access
     CPPUNIT_ASSERT_EQUAL(std::size_t(2), service->m_inoutGroup.size());
@@ -627,7 +628,7 @@ void ServiceTest::testWithInAndOut()
     for(const auto& data : service->m_inoutGroup)
     {
         auto i = (*itObj)->value();
-        CPPUNIT_ASSERT_EQUAL(i, data.second.lock()->value());
+        CPPUNIT_ASSERT_EQUAL(i, data.second->lock()->value());
         ++itObj;
     }
 
@@ -636,14 +637,18 @@ void ServiceTest::testWithInAndOut()
     auto nullInteger = service->getOutput<data::Integer>(service::ut::TestServiceWithData::s_OUTPUT);
     CPPUNIT_ASSERT(nullInteger.expired());
 
-    CPPUNIT_ASSERT(nullptr == service->getObject(service::ut::TestServiceWithData::s_OUTPUT, data::Access::out));
-    CPPUNIT_ASSERT(nullptr != service->getObject(service::ut::TestServiceWithData::s_INPUT, data::Access::in));
+    CPPUNIT_ASSERT(
+        nullptr
+        == service->data::IHasData::getObject(service::ut::TestServiceWithData::s_OUTPUT, data::Access::out)
+    );
+    CPPUNIT_ASSERT(
+        nullptr
+        != service->data::IHasData::getObject(service::ut::TestServiceWithData::s_INPUT, data::Access::in)
+    );
 
-    service::OSR::unregisterService(service);
+    service::unregisterService(service);
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
