@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,17 +27,14 @@
 #include <core/com/helper/SigSlotConnection.hpp>
 
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <utest/Exception.hpp>
 
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::service::ut::SigSlotConnectionTest);
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 //------------------------------------------------------------------------------
@@ -61,7 +58,7 @@ void SigSlotConnectionTest::basicTest()
     Buffer::sptr buffer = Buffer::New();
 
     SShowTest::sptr showTestSrv = service::factory::New<SShowTest>();
-    service::OSR::registerService(showTestSrv);
+    service::registerService(showTestSrv);
     showTestSrv->setInOut(buffer, IBasicTest::s_BUFFER_INOUT, true);
     showTestSrv->setWorker(core::thread::getDefaultWorker());
 
@@ -78,11 +75,9 @@ void SigSlotConnectionTest::basicTest()
     sig->asyncEmit();
     CPPUNIT_ASSERT_EQUAL(1, showTestSrv->m_receiveCount);
 
-    service::OSR::unregisterService(showTestSrv);
+    service::unregisterService(showTestSrv);
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
