@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,7 @@
 
 #include <thread>
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 SIGHT_REGISTER_DATA(Buffer);
@@ -53,11 +50,8 @@ SIGHT_REGISTER_SERVICE_OBJECT(sight::service::ut::SShow2Test, service::ut::Buffe
 //------------------------------------------------------------------------------
 //------------------------------------------------------------------------------
 
-SBasicTest::SBasicTest() :
-    m_updateFinished(false),
-    m_swapFinished(false)
-{
-}
+SBasicTest::SBasicTest()
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -75,7 +69,7 @@ void SBasicTest::stopping()
 
 //------------------------------------------------------------------------------
 
-void SBasicTest::swapping(std::string_view)
+void SBasicTest::swapping(std::string_view /*unused*/)
 {
     std::this_thread::sleep_for(m_swapRetarder);
     m_swapFinished = true;
@@ -101,7 +95,7 @@ void SReaderTest::updating()
     sig = buff->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
 
     {
-        core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+        core::com::Connection::Blocker block(sig->getConnection(this->slot(service::IService::signals::s_UPDATED)));
         sig->asyncEmit();
     }
 }
@@ -113,9 +107,7 @@ const core::com::Slots::SlotKeyType SShowTest::s_CHANGE_SLOT = "change";
 
 //------------------------------------------------------------------------------
 
-SShowTest::SShowTest() :
-    m_receiveCount(0),
-    m_changeCount(0)
+SShowTest::SShowTest()
 {
     m_slotChange = core::com::newSlot(&SShowTest::change, this);
     core::com::HasSlots::m_slots(s_CHANGE_SLOT, m_slotChange);
@@ -142,9 +134,7 @@ void SShowTest::change()
 
 service::IService::KeyConnectionsMap SShowTest::getAutoConnections() const
 {
-    KeyConnectionsMap connections;
-    connections.push(s_BUFFER_INOUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_BUFFER_INOUT, data::Object::s_MODIFIED_SIG, slots::s_UPDATE}};
 }
 
 //------------------------------------------------------------------------------
@@ -154,9 +144,9 @@ const core::com::Signals::SignalKeyType SReader2Test::s_CHANGED_SIG = "changed";
 
 //------------------------------------------------------------------------------
 
-SReader2Test::SReader2Test()
+SReader2Test::SReader2Test() :
+    m_sigChanged(ChangedSignalType::New())
 {
-    m_sigChanged = ChangedSignalType::New();
     // Register
     core::com::HasSignals::m_signals(s_CHANGED_SIG, m_sigChanged);
 }
@@ -178,8 +168,7 @@ const core::com::Slots::SlotKeyType SShow2Test::s_UPDATE_BUFFER_SLOT = "updateBu
 
 //------------------------------------------------------------------------------
 
-SShow2Test::SShow2Test() :
-    m_receiveCount(0)
+SShow2Test::SShow2Test()
 {
     newSlot(s_UPDATE_BUFFER_SLOT, &SShow2Test::updateBuffer, this);
 }
@@ -214,6 +203,4 @@ void SShow2Test::updateBuffer()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
