@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -46,18 +46,9 @@ SIGHT_REGISTER_SERVICE(sight::service::ut::ISTest, sight::service::ut::STest1Inp
 SIGHT_REGISTER_SERVICE(sight::service::ut::ISTest, sight::service::ut::STestOut);
 SIGHT_REGISTER_SERVICE(sight::service::IService, sight::service::ut::TestServiceWithData);
 
-namespace sight::service
+namespace sight::service::ut
 {
 
-namespace ut
-{
-
-const core::com::Signals::SignalKeyType ISTest::s_MSG_SENT_SIG = "msgSent";
-const core::com::Slots::SlotKeyType ISTest::s_UPDATE2_SLOT     = "update2";
-
-const core::com::Signals::SignalKeyType ISTest::s_SIG_1 = "signal1";
-const core::com::Slots::SlotKeyType ISTest::s_SLOT_1    = "slot1";
-
 unsigned int TestService::s_START_COUNTER  = 0;
 unsigned int TestService::s_UPDATE_COUNTER = 0;
 
@@ -123,6 +114,4 @@ void TestServiceWithData::stopping()
 
 //------------------------------------------------------------------------------
 
-} // namespace ut
-
-} // namespace sight::service
+} // namespace sight::service::ut
