@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,10 +32,7 @@
 
 #include <service/IService.hpp>
 
-namespace sight::service
-{
-
-namespace ut
+namespace sight::service::ut
 {
 
 /**
@@ -52,19 +49,17 @@ public:
     static const std::string s_NOT_DEFINED;
 
     SIGHT_DECLARE_SERVICE(TestService, service::IService);
-    TestService() noexcept
-    {
-    }
+    TestService() noexcept =
+        default;
 
-    virtual ~TestService() noexcept
-    {
-    }
+    ~TestService() noexcept override =
+        default;
 
     //------------------------------------------------------------------------------
 
-    virtual void configuring() final
+    void configuring() final
     {
-        const ConfigType cfg = this->getConfigTree();
+        const ConfigType cfg = this->getConfiguration();
 
         m_option = cfg.get(s_OPTION_KEY, s_NOT_DEFINED);
     }
@@ -72,7 +67,7 @@ public:
     void starting() override;
     //------------------------------------------------------------------------------
 
-    virtual void stopping() final;
+    void stopping() final;
     void updating() override;
     //------------------------------------------------------------------------------
 
@@ -159,37 +154,36 @@ public:
 
     SIGHT_DECLARE_CLASS(ISTest, TestService);
 
-    /// Keys to register Signal
-    static const core::com::Signals::SignalKeyType s_MSG_SENT_SIG;
-    /// Keys to register Slot
-    static const core::com::Slots::SlotKeyType s_UPDATE2_SLOT;
+    struct signals
+    {
+        static inline const core::com::Signals::SignalKeyType s_SIG_1    = "signal1";
+        static inline const core::com::Signals::SignalKeyType s_MSG_SENT = "msgSent";
 
-    /// Type of signal
-    typedef core::com::Signal<void (const std::string&)> MsgSentSignalType;
-
-    /// Keys to register Signal
-    static const core::com::Signals::SignalKeyType s_SIG_1;
-    /// Keys to register Slot
-    static const core::com::Slots::SlotKeyType s_SLOT_1;
+        using int_sent_t = core::com::Signal<void (int)>;
+        using msg_sent_t = core::com::Signal<void (const std::string&)>;
+    };
+    struct slots
+    {
+        static inline const core::com::Slots::SlotKeyType s_UPDATE2 = "update2";
+        static inline const core::com::Slots::SlotKeyType s_SLOT_1  = "slot1";
+    };
 
     /// Type of signal
     typedef core::com::Signal<void (int)> IntSentSignalType;
 
     //-------------------------------------------------------------------------
 
-    ISTest() noexcept :
-        m_received(false)
+    ISTest() noexcept
     {
-        newSignal<IntSentSignalType>(s_SIG_1);
-        newSignal<MsgSentSignalType>(s_MSG_SENT_SIG);
-        newSlot(s_SLOT_1, &ISTest::receiveSlot, this);
-        newSlot(s_UPDATE2_SLOT, &ISTest::update2, this);
+        newSignal<signals::int_sent_t>(signals::s_SIG_1);
+        newSignal<signals::msg_sent_t>(signals::s_MSG_SENT);
+        newSlot(slots::s_SLOT_1, &ISTest::receiveSlot, this);
+        newSlot(slots::s_UPDATE2, &ISTest::update2, this);
     }
 
     //-------------------------------------------------------------------------
-    ~ISTest() noexcept override
-    {
-    }
+    ~ISTest() noexcept override =
+        default;
 
     //-------------------------------------------------------------------------
     void starting() final
@@ -235,7 +229,7 @@ public:
     void swapping(std::string_view key) final
     {
         m_swappedObjectKey = key;
-        m_swappedObject    = this->getInput<data::Object>(key).lock().get_shared();
+        m_swappedObject    = this->getInput(key).lock().get_shared();
     }
 
     //-------------------------------------------------------------------------
@@ -256,25 +250,24 @@ public:
 
     IService::KeyConnectionsMap getAutoConnections() const override
     {
-        KeyConnectionsMap connections;
-        connections.push("data", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data1", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data2", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data3", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data4", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data5", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("dataGroup", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("dataGroup0", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("dataGroup1", data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-
-        return connections;
+        return {
+            {"data", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data1", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data2", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data3", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data4", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data5", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"dataGroup", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"dataGroup0", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"dataGroup1", data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE}
+        };
     }
 
 //-------------------------------------------------------------------------
 
 private:
 
-    int m_received;
+    bool m_received {false};
     std::string m_swappedObjectKey;
     data::Object::csptr m_swappedObject;
 };
@@ -337,10 +330,10 @@ public:
 
     IService::KeyConnectionsMap getAutoConnections() const override
     {
-        KeyConnectionsMap connections;
-        connections.push("data1", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data2", data::Object::s_MODIFIED_SIG, s_SLOT_1);
-        return connections;
+        return {
+            {"data1", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data2", data::Object::s_MODIFIED_SIG, slots::s_SLOT_1},
+        };
     }
 
 private:
@@ -397,11 +390,11 @@ public:
 
     IService::KeyConnectionsMap getAutoConnections() const override
     {
-        KeyConnectionsMap connections;
-        connections.push("data1", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data2", data::Object::s_MODIFIED_SIG, s_SLOT_1);
-        connections.push("data3", data::Object::s_MODIFIED_SIG, s_SLOT_1);
-        return connections;
+        return {
+            {"data1", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+            {"data2", data::Object::s_MODIFIED_SIG, slots::s_SLOT_1},
+            {"data3", data::Object::s_MODIFIED_SIG, slots::s_SLOT_1},
+        };
     }
 
 private:
@@ -435,9 +428,9 @@ public:
     IService::KeyConnectionsMap getAutoConnections() const override
     {
         KeyConnectionsMap connections;
-        connections.push("data1", data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-        connections.push("data2", data::Object::s_MODIFIED_SIG, s_SLOT_1);
-        connections.push("data3", data::Object::s_MODIFIED_SIG, s_SLOT_1);
+        connections.push("data1", data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+        connections.push("data2", data::Object::s_MODIFIED_SIG, slots::s_SLOT_1);
+        connections.push("data3", data::Object::s_MODIFIED_SIG, slots::s_SLOT_1);
         return connections;
     }
 
@@ -464,7 +457,7 @@ public:
 
     SIGHT_DECLARE_SERVICE(STest1Input1InputGroup, service::ut::ISTest);
 
-    data::ptr<data::Object, data::Access::in> m_input {this, "data1", true, 1};
+    data::ptr<data::Object, data::Access::in> m_input {this, "data1", true, true};
     data::ptr_vector<data::Object, data::Access::in> m_inputGroup {this, "dataGroup", true};
 };
 
@@ -530,6 +523,4 @@ public:
     data::ptr<data::Object, data::Access::out> m_output {this, "output", false, true};
 };
 
-} //namespace ut
-
-} //namespace sight::service
+} // namespace sight::service::ut
