@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,11 +26,6 @@ namespace sight::filter::dicom
 {
 
 Plugin::Plugin()
-{
-}
-
-Plugin::~Plugin()
-{
-}
+= default;
 
 } //namespace sight::filter::dicom
