@@ -34,12 +34,9 @@
 #include <dcmtk/dcmimgle/dcmimage.h>
 #include <dcmtk/dcmnet/diutil.h>
 
-fwDicomIOFilterRegisterMacro(sight::filter::dicom::sorter::ImagePositionPatientSorter);
+SIGHT_REGISTER_DICOM_FILTER(sight::filter::dicom::sorter::ImagePositionPatientSorter);
 
-namespace sight::filter::dicom
-{
-
-namespace sorter
+namespace sight::filter::dicom::sorter
 {
 
 const std::string ImagePositionPatientSorter::s_FILTER_NAME        = "Image position patient sorter";
@@ -49,16 +46,14 @@ const std::string ImagePositionPatientSorter::s_FILTER_DESCRIPTION =
 
 //-----------------------------------------------------------------------------
 
-ImagePositionPatientSorter::ImagePositionPatientSorter(filter::dicom::IFilter::Key) :
-    ISorter()
+ImagePositionPatientSorter::ImagePositionPatientSorter(filter::dicom::IFilter::Key /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
 ImagePositionPatientSorter::~ImagePositionPatientSorter()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -83,11 +78,10 @@ ImagePositionPatientSorter::DicomSeriesContainerType ImagePositionPatientSorter:
 {
     DicomSeriesContainerType result;
 
-    typedef std::map<double, core::memory::BufferObject::sptr> SortedDicomMapType;
+    using SortedDicomMapType = std::map<double, core::memory::BufferObject::sptr>;
     SortedDicomMapType sortedDicom;
 
     OFCondition status;
-    DcmDataset* dataset;
 
     for(const auto& item : series->getDicomContainer())
     {
@@ -113,7 +107,7 @@ ImagePositionPatientSorter::DicomSeriesContainerType ImagePositionPatientSorter:
         fileFormat.loadAllDataIntoMemory();
         fileFormat.transferEnd();
 
-        dataset = fileFormat.getDataset();
+        DcmDataset* dataset = fileFormat.getDataset();
 
         if(!dataset->tagExists(DCM_ImagePositionPatient) || !dataset->tagExists(DCM_ImageOrientationPatient))
         {
@@ -134,7 +128,7 @@ ImagePositionPatientSorter::DicomSeriesContainerType ImagePositionPatientSorter:
         for(unsigned int i = 0 ; i < 3 ; ++i)
         {
             dataset->findAndGetFloat64(DCM_ImageOrientationPatient, imageOrientationU[i], i);
-            dataset->findAndGetFloat64(DCM_ImageOrientationPatient, imageOrientationV[i], i + 3);
+            dataset->findAndGetFloat64(DCM_ImageOrientationPatient, imageOrientationV[i], i + std::size_t(3));
         }
 
         //Compute Z direction (cross product)
@@ -169,6 +163,4 @@ ImagePositionPatientSorter::DicomSeriesContainerType ImagePositionPatientSorter:
     return result;
 }
 
-} // namespace sorter
-
-} // namespace sight::filter::dicom
+} // namespace sight::filter::dicom::sorter
