@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,21 +22,16 @@
 
 #include "filter/dicom/splitter/ISplitter.hpp"
 
-namespace sight::filter::dicom
-{
-
-namespace splitter
+namespace sight::filter::dicom::splitter
 {
 
 ISplitter::ISplitter()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 ISplitter::~ISplitter()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -45,6 +40,4 @@ IFilter::FilterType ISplitter::getFilterType() const
     return ISplitter::SPLITTER;
 }
 
-} // namespace splitter
-
-} // namespace sight::filter::dicom
+} // namespace sight::filter::dicom::splitter
