@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,12 +33,9 @@
 #include <dcmtk/dcmimgle/dcmimage.h>
 #include <dcmtk/dcmnet/diutil.h>
 
-fwDicomIOFilterRegisterMacro(sight::filter::dicom::splitter::ImageDimensionsSplitter);
+SIGHT_REGISTER_DICOM_FILTER(sight::filter::dicom::splitter::ImageDimensionsSplitter);
 
-namespace sight::filter::dicom
-{
-
-namespace splitter
+namespace sight::filter::dicom::splitter
 {
 
 const std::string ImageDimensionsSplitter::s_FILTER_NAME        = "Image dimensions splitter";
@@ -47,16 +44,14 @@ const std::string ImageDimensionsSplitter::s_FILTER_DESCRIPTION =
 
 //-----------------------------------------------------------------------------
 
-ImageDimensionsSplitter::ImageDimensionsSplitter(filter::dicom::IFilter::Key) :
-    ISplitter()
+ImageDimensionsSplitter::ImageDimensionsSplitter(filter::dicom::IFilter::Key /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
 ImageDimensionsSplitter::~ImageDimensionsSplitter()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -95,6 +90,4 @@ ImageDimensionsSplitter::DicomSeriesContainerType ImageDimensionsSplitter::apply
     return result;
 }
 
-} // namespace splitter
-
-} // namespace sight::filter::dicom
+} // namespace sight::filter::dicom::splitter
