@@ -20,6 +20,10 @@
  *
  ***********************************************************************/
 
+#ifdef WIN32
+    #pragma warning(disable:4701)
+#endif
+
 #include "AutomaticRegistration.hpp"
 
 #include "filter/image/ItkImageCaster.hpp"
@@ -29,8 +33,10 @@
 
 #include <itkCommand.h>
 #include <itkCorrelationImageToImageMetricv4.h>
+#include <itkEuler3DTransform.h>
 #include <itkImage.h>
 #include <itkImageMomentsCalculator.h>
+#include <itkImageRegistrationMethodv4.h>
 #include <itkImageToImageMetricv4.h>
 #include <itkLinearInterpolateImageFunction.h>
 #include <itkMattesMutualInformationImageToImageMetricv4.h>
@@ -42,7 +48,89 @@
 namespace sight::filter::image
 {
 
-typedef typename itk::Image<float, 3> RegisteredImageType;
+using TransformType = itk::Euler3DTransform<AutomaticRegistration::RealType>;
+
+using RegistrationMethodType = itk::ImageRegistrationMethodv4<
+    AutomaticRegistration::RegisteredImageType,
+    AutomaticRegistration::RegisteredImageType,
+    TransformType
+>;
+
+class AutomaticRegistration::AutomaticRegistrationImpl final
+{
+public:
+
+    /// Delete default constructors and assignment operators
+    AutomaticRegistrationImpl()                                            = delete;
+    AutomaticRegistrationImpl(const AutomaticRegistrationImpl&)            = delete;
+    AutomaticRegistrationImpl(AutomaticRegistrationImpl&&)                 = delete;
+    AutomaticRegistrationImpl& operator=(const AutomaticRegistrationImpl&) = delete;
+    AutomaticRegistrationImpl& operator=(AutomaticRegistrationImpl&&)      = delete;
+
+    /// Constructor
+    inline explicit AutomaticRegistrationImpl(AutomaticRegistration* const automaticRegistration) :
+        m_automaticRegistration(automaticRegistration)
+    {
+    }
+
+    /// Default destructor
+    inline ~AutomaticRegistrationImpl() noexcept = default;
+
+    AutomaticRegistration* m_automaticRegistration {nullptr};
+
+    OptimizerType::Pointer m_optimizer {nullptr};
+
+    RegistrationMethodType::Pointer m_registrator {nullptr};
+
+    bool m_invert {false};
+
+    //------------------------------------------------------------------------------
+
+    inline void convertToF4sMatrix(const TransformType* _itkMat, const data::Matrix4::sptr& _f4sMat) const
+    {
+        itk::Matrix<RealType, 3, 3> rigidMat = _itkMat->GetMatrix();
+        itk::Vector<RealType, 3> offset      = _itkMat->GetOffset();
+
+        if(m_invert)
+        {
+            rigidMat = itk::Matrix<RealType, 3, 3>(_itkMat->GetMatrix().GetTranspose());
+            offset   = -(rigidMat * offset);
+        }
+
+        // Convert itk::RigidTransform to f4s matrix.
+        for(std::uint8_t i = 0 ; i < 3 ; ++i)
+        {
+            (*_f4sMat)(i, 3) = offset[i];
+            for(std::uint8_t j = 0 ; j < 3 ; ++j)
+            {
+                (*_f4sMat)(i, j) = rigidMat(i, j);
+            }
+        }
+    }
+
+    //------------------------------------------------------------------------------
+
+    inline static double computeVolume(const data::Image::csptr& _img)
+    {
+        const auto& spacing = _img->getSpacing();
+        const auto& size    = _img->getSize();
+
+        SIGHT_ASSERT(
+            "Degenerated image. Spacing and size should be of the same dimension.",
+            spacing.size() == size.size()
+        );
+
+        const double voxelVolume   = std::accumulate(spacing.begin(), spacing.end(), 1., std::multiplies<>());
+        const std::size_t nbVoxels = std::accumulate(
+            size.begin(),
+            size.end(),
+            std::size_t(1),
+            std::multiplies<>()
+        );
+
+        return voxelVolume * static_cast<double>(nbVoxels);
+    }
+};
 
 //------------------------------------------------------------------------------
 
@@ -50,9 +138,9 @@ class RegistrationObserver : public itk::Command
 {
 public:
 
-    typedef  RegistrationObserver Self;
-    typedef itk::Command Superclass;
-    typedef itk::SmartPointer<Self> Pointer;
+    using Self       = RegistrationObserver;
+    using Superclass = itk::Command;
+    using Pointer    = itk::SmartPointer<Self>;
     itkNewMacro(Self)
 
     /// Command to be executed. Updates the progress bar.
@@ -63,7 +151,7 @@ public:
     }
 
     /// Const overload of the above method.
-    void Execute(const itk::Object*, const itk::EventObject& event) override
+    void Execute(const itk::Object* /*caller*/, const itk::EventObject& event) override
     {
         {
             if(itk::IterationEvent().CheckEvent(&event))
@@ -83,13 +171,18 @@ public:
 private:
 
     /// Constructor, initializes progress dialog and sets the user cancel callback.
-    RegistrationObserver()
-    {
-    }
+    RegistrationObserver() = default;
 
     std::function<void()> m_iterationCallback;
 };
 
+AutomaticRegistration::AutomaticRegistration() noexcept :
+    m_pimpl(std::make_unique<AutomaticRegistration::AutomaticRegistrationImpl>(this))
+{
+}
+
+AutomaticRegistration::~AutomaticRegistration() noexcept = default;
+
 //------------------------------------------------------------------------------
 
 void AutomaticRegistration::registerImage(
@@ -100,7 +193,7 @@ void AutomaticRegistration::registerImage(
     const MultiResolutionParametersType& _multiResolutionParameters,
     RealType _samplingPercentage,
     double _minStep,
-    unsigned long _maxIterations,
+    std::uint64_t _maxIterations,
     IterationCallbackType _callback
 )
 {
@@ -110,11 +203,11 @@ void AutomaticRegistration::registerImage(
     data::Image::csptr ref = _reference;
     data::Image::csptr tgt = _target;
 
-    m_invert = computeVolume(tgt) < computeVolume(ref);
+    m_pimpl->m_invert = m_pimpl->computeVolume(tgt) < m_pimpl->computeVolume(ref);
 
     // Always register images with the largest one being fixed.
     // Otherwise, our metric may not find any matching points between them.
-    if(m_invert)
+    if(m_pimpl->m_invert)
     {
         std::swap(ref, tgt);
     }
@@ -162,14 +255,14 @@ void AutomaticRegistration::registerImage(
 
     for(std::uint8_t i = 0 ; i < 3 ; ++i)
     {
-        t[i] = _trf->getCoefficient(i, 3);
+        t[i] = (*_trf)(i, 3);
         for(std::uint8_t j = 0 ; j < 3 ; ++j)
         {
-            m(i, j) = _trf->getCoefficient(i, j);
+            m(i, j) = (*_trf)(i, j);
         }
     }
 
-    if(m_invert)
+    if(m_pimpl->m_invert)
     {
         // Our algorithm assumes m to be orthogonal. If it isn't, an exception will be thrown later on.
         m = itk::Matrix<RealType, 3, 3>(m.GetTranspose());
@@ -193,11 +286,11 @@ void AutomaticRegistration::registerImage(
     itkTransform->SetOffset(t);
 
     // Registration.
-    m_registrator = RegistrationMethodType::New();
-    m_optimizer   = OptimizerType::New();
+    m_pimpl->m_registrator = RegistrationMethodType::New();
+    m_pimpl->m_optimizer   = OptimizerType::New();
 
-    m_registrator->SetMetric(metric);
-    m_registrator->SetOptimizer(m_optimizer);
+    m_pimpl->m_registrator->SetMetric(metric);
+    m_pimpl->m_registrator->SetOptimizer(m_pimpl->m_optimizer);
 
     OptimizerType::ScalesType optimizerScales(static_cast<unsigned int>(itkTransform->GetNumberOfParameters()));
     const double translationScale = 1.0 / 1000.0;
@@ -208,13 +301,13 @@ void AutomaticRegistration::registerImage(
     optimizerScales[4] = translationScale;
     optimizerScales[5] = translationScale;
 
-    m_optimizer->SetScales(optimizerScales);
-    m_optimizer->SetDoEstimateLearningRateAtEachIteration(true);
-    m_optimizer->SetMinimumStepLength(_minStep);
+    m_pimpl->m_optimizer->SetScales(optimizerScales);
+    m_pimpl->m_optimizer->SetDoEstimateLearningRateAtEachIteration(true);
+    m_pimpl->m_optimizer->SetMinimumStepLength(_minStep);
 
     // The solution is the transform returned when optimization ends.
-    m_optimizer->SetReturnBestParametersAndValue(false);
-    m_optimizer->SetNumberOfIterations(_maxIterations);
+    m_pimpl->m_optimizer->SetReturnBestParametersAndValue(false);
+    m_pimpl->m_optimizer->SetNumberOfIterations(_maxIterations);
 
     // The fixed image isn't transformed, nearest neighbor interpolation is enough.
     auto fixedInterpolator  = itk::NearestNeighborInterpolateImageFunction<RegisteredImageType, RealType>::New();
@@ -225,7 +318,7 @@ void AutomaticRegistration::registerImage(
 
     // Number of registration stages
     SIGHT_ASSERT("255 is the maximum number of steps.", _multiResolutionParameters.size() < 256);
-    const std::uint8_t numberOfLevels = std::uint8_t(_multiResolutionParameters.size());
+    const auto numberOfLevels = std::uint8_t(_multiResolutionParameters.size());
 
     RegistrationMethodType::ShrinkFactorsArrayType shrinkFactorsPerLevel;
     shrinkFactorsPerLevel.SetSize(numberOfLevels);
@@ -240,33 +333,33 @@ void AutomaticRegistration::registerImage(
         smoothingSigmasPerLevel[i] = stageParameters.second;
     }
 
-    m_registrator->SetInitialTransform(itkTransform);
-    m_registrator->SetFixedImage(target);
-    m_registrator->SetMovingImage(reference);
+    m_pimpl->m_registrator->SetInitialTransform(itkTransform);
+    m_pimpl->m_registrator->SetFixedImage(target);
+    m_pimpl->m_registrator->SetMovingImage(reference);
 
-    m_registrator->SetMetricSamplingPercentage(_samplingPercentage);
+    m_pimpl->m_registrator->SetMetricSamplingPercentage(_samplingPercentage);
 
     const auto samplingStrategy = _samplingPercentage < 1.0
                                   ? RegistrationMethodType::REGULAR : RegistrationMethodType::NONE;
 
-    m_registrator->SetMetricSamplingStrategy(samplingStrategy);
-    m_registrator->SetNumberOfLevels(itk::SizeValueType(numberOfLevels));
-    m_registrator->SetSmoothingSigmasPerLevel(smoothingSigmasPerLevel);
-    m_registrator->SetShrinkFactorsPerLevel(shrinkFactorsPerLevel);
-    m_registrator->SetSmoothingSigmasAreSpecifiedInPhysicalUnits(true);
+    m_pimpl->m_registrator->SetMetricSamplingStrategy(samplingStrategy);
+    m_pimpl->m_registrator->SetNumberOfLevels(itk::SizeValueType(numberOfLevels));
+    m_pimpl->m_registrator->SetSmoothingSigmasPerLevel(smoothingSigmasPerLevel);
+    m_pimpl->m_registrator->SetShrinkFactorsPerLevel(shrinkFactorsPerLevel);
+    m_pimpl->m_registrator->SetSmoothingSigmasAreSpecifiedInPhysicalUnits(true);
 
     RegistrationObserver::Pointer observer = RegistrationObserver::New();
 
     if(_callback)
     {
         observer->setCallback(_callback);
-        m_optimizer->AddObserver(itk::IterationEvent(), observer);
+        m_pimpl->m_optimizer->AddObserver(itk::IterationEvent(), observer);
     }
 
     try
     {
         // Time for lift-off.
-        m_registrator->Update();
+        m_pimpl->m_registrator->Update();
         this->getCurrentMatrix(_trf);
     }
     catch(itk::ExceptionObject& err)
@@ -279,11 +372,11 @@ void AutomaticRegistration::registerImage(
 
 void AutomaticRegistration::stopRegistration()
 {
-    if(m_optimizer && m_registrator)
+    if((m_pimpl->m_optimizer != nullptr) && (m_pimpl->m_registrator != nullptr))
     {
         // Stop registration by removing all levels.
-        m_registrator->SetNumberOfLevels(0);
-        m_optimizer->StopOptimization();
+        m_pimpl->m_registrator->SetNumberOfLevels(0);
+        m_pimpl->m_optimizer->StopOptimization();
     }
 }
 
@@ -291,109 +384,67 @@ void AutomaticRegistration::stopRegistration()
 
 AutomaticRegistration::RealType AutomaticRegistration::getCurrentMetricValue() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetCurrentMetricValue();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetCurrentMetricValue();
 }
 
 //------------------------------------------------------------------------------
 
 const AutomaticRegistration::OptimizerType::ParametersType& AutomaticRegistration::getCurrentParameters() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetCurrentPosition();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetCurrentPosition();
 }
 
 //------------------------------------------------------------------------------
 
 AutomaticRegistration::RealType AutomaticRegistration::getRelaxationFactor() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetRelaxationFactor();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetRelaxationFactor();
 }
 
 //------------------------------------------------------------------------------
 
 AutomaticRegistration::RealType AutomaticRegistration::getLearningRate() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetLearningRate();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetLearningRate();
 }
 
 //------------------------------------------------------------------------------
 
 AutomaticRegistration::RealType AutomaticRegistration::getGradientMagnitudeTolerance() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetGradientMagnitudeTolerance();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetGradientMagnitudeTolerance();
 }
 
 //------------------------------------------------------------------------------
 
 itk::SizeValueType AutomaticRegistration::getCurrentIteration() const
 {
-    SIGHT_ASSERT("No optimization process running.", m_optimizer);
-    return m_optimizer->GetCurrentIteration();
+    SIGHT_ASSERT("No optimization process running.", m_pimpl->m_optimizer);
+    return m_pimpl->m_optimizer->GetCurrentIteration();
 }
 
 //------------------------------------------------------------------------------
 
 itk::SizeValueType filter::image::AutomaticRegistration::getCurrentLevel() const
 {
-    SIGHT_ASSERT("No registration process running.", m_registrator);
-    return m_registrator->GetCurrentLevel();
+    SIGHT_ASSERT("No registration process running.", m_pimpl->m_registrator);
+    return m_pimpl->m_registrator->GetCurrentLevel();
 }
 
 //------------------------------------------------------------------------------
 
 void AutomaticRegistration::getCurrentMatrix(const data::Matrix4::sptr& _trf) const
 {
-    SIGHT_ASSERT("No registration process running.", m_registrator);
-    auto itkMatrix = m_registrator->GetTransform();
-    this->convertToF4sMatrix(itkMatrix, _trf);
+    SIGHT_ASSERT("No registration process running.", m_pimpl->m_registrator);
+    const auto* itkMatrix = m_pimpl->m_registrator->GetTransform();
+    m_pimpl->convertToF4sMatrix(itkMatrix, _trf);
 }
 
 //------------------------------------------------------------------------------
 
-void AutomaticRegistration::convertToF4sMatrix(
-    const AutomaticRegistration::TransformType* _itkMat,
-    const data::Matrix4::sptr& _f4sMat
-) const
-{
-    itk::Matrix<RealType, 3, 3> rigidMat = _itkMat->GetMatrix();
-    itk::Vector<RealType, 3> offset      = _itkMat->GetOffset();
-
-    if(m_invert)
-    {
-        rigidMat = itk::Matrix<RealType, 3, 3>(_itkMat->GetMatrix().GetTranspose());
-        offset   = -(rigidMat * offset);
-    }
-
-    // Convert itk::RigidTransform to f4s matrix.
-    for(std::uint8_t i = 0 ; i < 3 ; ++i)
-    {
-        _f4sMat->setCoefficient(i, 3, offset[i]);
-        for(std::uint8_t j = 0 ; j < 3 ; ++j)
-        {
-            _f4sMat->setCoefficient(i, j, rigidMat(i, j));
-        }
-    }
-}
-
-//------------------------------------------------------------------------------
-
-double AutomaticRegistration::computeVolume(const data::Image::csptr& _img)
-{
-    const auto& spacing = _img->getSpacing();
-    const auto& size    = _img->getSize();
-
-    SIGHT_ASSERT("Degenerated image. Spacing and size should be of the same dimension.", spacing.size() == size.size());
-
-    const double voxelVolume   = std::accumulate(spacing.begin(), spacing.end(), 1., std::multiplies<double>());
-    const std::size_t nbVoxels = std::accumulate(size.begin(), size.end(), 1, std::multiplies<std::size_t>());
-
-    return voxelVolume * static_cast<double>(nbVoxels);
-}
-
-//------------------------------------------------------------------------------
-
-} // itkRegistrationOp
+} // namespace sight::filter::image
