@@ -28,8 +28,6 @@
 #include <data/Image.hpp>
 #include <data/Matrix4.hpp>
 
-#include <itkEuler3DTransform.h>
-#include <itkImageRegistrationMethodv4.h>
 #include <itkIntTypes.h>
 #include <itkRegularStepGradientDescentOptimizerv4.h>
 
@@ -46,16 +44,19 @@ class FILTER_IMAGE_CLASS_API AutomaticRegistration
 public:
 
     /// Numeric type used for internal computations.
-    typedef double RealType;
+    using RealType = double;
 
-    typedef typename itk::Image<float, 3> RegisteredImageType;
+    using RegisteredImageType = itk::Image<float, 3>;
 
-    typedef typename itk::RegularStepGradientDescentOptimizerv4<RealType> OptimizerType;
+    using OptimizerType = itk::RegularStepGradientDescentOptimizerv4<RealType>;
 
     /// Shrink factors per level and smoothing sigmas per level
-    typedef std::vector<std::pair<itk::SizeValueType, RealType> > MultiResolutionParametersType;
+    using MultiResolutionParametersType = std::vector<std::pair<itk::SizeValueType, RealType> >;
 
-    typedef std::function<void ()> IterationCallbackType;
+    using IterationCallbackType = std::function<void ()>;
+
+    FILTER_IMAGE_API AutomaticRegistration() noexcept;
+    FILTER_IMAGE_API virtual ~AutomaticRegistration() noexcept;
 
     /**
      * @brief find a rigid transform matching the reference image with the target image.
@@ -76,52 +77,41 @@ public:
         const MultiResolutionParametersType& _multiResolutionParameters,
         RealType _samplingPercentage    = 1.0,
         double _minStep                 = 0.0001,
-        unsigned long _maxIterations    = 200,
+        std::uint64_t _maxIterations    = 200,
         IterationCallbackType _callback = nullptr
     );
 
     FILTER_IMAGE_API void stopRegistration();
 
     /// Current metric evaluated by the optimizer.
-    FILTER_IMAGE_API RealType getCurrentMetricValue() const;
+    [[nodiscard]] FILTER_IMAGE_API RealType getCurrentMetricValue() const;
 
     /// Current set of parameters used to evaluate the metric in the optimizer.
-    FILTER_IMAGE_API const OptimizerType::ParametersType& getCurrentParameters() const;
+    [[nodiscard]] FILTER_IMAGE_API const OptimizerType::ParametersType& getCurrentParameters() const;
 
     /// Gradient descent relaxation factor.
-    FILTER_IMAGE_API RealType getRelaxationFactor() const;
+    [[nodiscard]] FILTER_IMAGE_API RealType getRelaxationFactor() const;
 
     /// Gradient descent learning rate.
-    FILTER_IMAGE_API RealType getLearningRate() const;
+    [[nodiscard]] FILTER_IMAGE_API RealType getLearningRate() const;
 
     /// Gradient magnitude tolerance.
-    FILTER_IMAGE_API RealType getGradientMagnitudeTolerance() const;
+    [[nodiscard]] FILTER_IMAGE_API RealType getGradientMagnitudeTolerance() const;
 
     /// Current optimizer iteration.
-    FILTER_IMAGE_API itk::SizeValueType getCurrentIteration() const;
+    [[nodiscard]] FILTER_IMAGE_API itk::SizeValueType getCurrentIteration() const;
 
     /// Current multi-resolution level.
-    FILTER_IMAGE_API itk::SizeValueType getCurrentLevel() const;
+    [[nodiscard]] FILTER_IMAGE_API itk::SizeValueType getCurrentLevel() const;
 
     /// Current registration result.
     FILTER_IMAGE_API void getCurrentMatrix(const data::Matrix4::sptr& _trf) const;
 
 private:
 
-    typedef typename itk::Euler3DTransform<RealType> TransformType;
-
-    typedef typename itk::ImageRegistrationMethodv4<RegisteredImageType, RegisteredImageType, TransformType>
-        RegistrationMethodType;
-
-    OptimizerType::Pointer m_optimizer {nullptr};
-
-    RegistrationMethodType::Pointer m_registrator {nullptr};
-
-    bool m_invert {false};
-
-    void convertToF4sMatrix(const TransformType* _itkMat, const data::Matrix4::sptr& _f4sMat) const;
-
-    static double computeVolume(const data::Image::csptr& _img);
+    /// PImpl
+    class AutomaticRegistrationImpl;
+    std::unique_ptr<AutomaticRegistrationImpl> m_pimpl;
 };
 
-} // itkRegistrationOp
+} // namespace sight::filter::image
