@@ -23,7 +23,6 @@
 #include "filter/image/Flipper.hpp"
 
 #include <core/tools/Dispatcher.hpp>
-#include <core/tools/TypeKeyTypeMapping.hpp>
 
 #include <data/helper/MedicalImage.hpp>
 
@@ -37,7 +36,7 @@ namespace sight::filter::image
 struct Parameters
 {
     data::Image::csptr i_image;
-    std::array<bool, 3> i_flipAxes;
+    std::array<bool, 3> i_flipAxes {};
     data::Image::sptr o_image;
 };
 
@@ -50,7 +49,7 @@ struct Flipping
 
     void operator()(Parameters& params)
     {
-        typedef typename itk::Image<PixelType, dimension> ImageType;
+        using ImageType = typename itk::Image<PixelType, dimension>;
         const typename ImageType::Pointer itkImage = io::itk::moveToItk<ImageType>(params.i_image);
 
         typename itk::FlipImageFilter<ImageType>::Pointer flipFilter =
@@ -124,7 +123,7 @@ void Flipper::flip(
         params.i_flipAxes = _inFlipAxes;
         params.o_image    = _outImage;
 
-        const core::tools::Type type = _inImage->getType();
+        const core::Type type = _inImage->getType();
         core::tools::Dispatcher<core::tools::SupportedDispatcherTypes, FlippingDimensionExtractor>::invoke(
             type,
             params
