@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,26 +23,38 @@
 #include "filter/image/ImageExtruder.hpp"
 
 #include <core/tools/Dispatcher.hpp>
-#include <core/tools/TypeKeyTypeMapping.hpp>
 
+#include <geometry/data/Matrix4.hpp>
+
+#include <glm/gtc/matrix_transform.hpp>
 #include <glm/gtx/intersect.hpp>
+#include <glm/matrix.hpp>
 #include <glm/vec2.hpp>
 
+#include <cmath>
+
 namespace sight::filter::image
 {
 
 //------------------------------------------------------------------------------
 
-void ImageExtruder::extrude(const data::Image::sptr& _image, const data::Mesh::csptr& _mesh)
+void ImageExtruder::extrude(
+    const data::Image::sptr& _image,
+    const data::Mesh::csptr& _mesh,
+    const data::Matrix4::csptr& _transform
+)
 {
     SIGHT_ASSERT("The image must be in 3 dimensions", _image->numDimensions() == 3);
+    SIGHT_ASSERT("Spacing should be set", _image->getSpacing() != data::Image::Spacing({0., 0., 0.}));
 
     Parameters param;
-    param.m_image = _image;
-    param.m_mesh  = _mesh;
+    param.m_image     = _image;
+    param.m_mesh      = _mesh;
+    param.m_mesh      = _mesh;
+    param.m_transform = _transform;
 
     // We use a dispatcher because we can't retrieve the image type without a DynamicType.
-    core::tools::Type type = _image->getType();
+    core::Type type = _image->getType();
     core::tools::Dispatcher<core::tools::SupportedDispatcherTypes, ImageExtruder>::invoke(type, param);
 }
 
@@ -51,6 +63,14 @@ void ImageExtruder::extrude(const data::Image::sptr& _image, const data::Mesh::c
 template<typename IMAGE_TYPE>
 void ImageExtruder::operator()(Parameters& _param)
 {
+    auto transform = glm::identity<glm::mat4>();
+    if(_param.m_transform)
+    {
+        // Apply the inverse matrix of the image to each point of the mesh
+        const glm::dmat4x4 mat = sight::geometry::data::getMatrixFromTF3D(*_param.m_transform);
+        transform = glm::inverse(mat);
+    }
+
     // Creates triangles and bounding box of the mesh.
     const float min = std::numeric_limits<float>::lowest();
     const float max = std::numeric_limits<float>::max();
@@ -62,7 +82,8 @@ void ImageExtruder::operator()(Parameters& _param)
     const auto addTriangle =
         [&](const data::iterator::point::xyz& _pa,
             const data::iterator::point::xyz& _pb,
-            const data::iterator::point::xyz& _pc)
+            const data::iterator::point::xyz& _pc,
+            const glm::mat4 _transform)
         {
             const float ax = _pa.x;
             const float ay = _pa.y;
@@ -76,19 +97,19 @@ void ImageExtruder::operator()(Parameters& _param)
             const float cy = _pc.y;
             const float cz = _pc.z;
 
-            const glm::vec3 triA(ax, ay, az);
-            const glm::vec3 triB(bx, by, bz);
-            const glm::vec3 triC(cx, cy, cz);
+            const glm::vec4 triA = _transform * glm::vec4(ax, ay, az, 1.0);
+            const glm::vec4 triB = _transform * glm::vec4(bx, by, bz, 1.0);
+            const glm::vec4 triC = _transform * glm::vec4(cx, cy, cz, 1.0);
 
             triangles.push_back(Triangle {triA, triB, triC});
 
-            minBound.x = std::min(std::min(std::min(minBound.x, ax), bx), cx);
-            minBound.y = std::min(std::min(std::min(minBound.y, ay), by), cy);
-            minBound.z = std::min(std::min(std::min(minBound.z, az), bz), cz);
+            minBound.x = std::min(std::min(std::min(minBound.x, triA.x), triB.x), triC.x);
+            minBound.y = std::min(std::min(std::min(minBound.y, triA.y), triB.y), triC.y);
+            minBound.z = std::min(std::min(std::min(minBound.z, triA.z), triB.z), triC.z);
 
-            maxBound.x = std::max(std::max(std::max(maxBound.x, ax), bx), cx);
-            maxBound.y = std::max(std::max(std::max(maxBound.y, ay), by), cy);
-            maxBound.z = std::max(std::max(std::max(maxBound.z, az), bz), cz);
+            maxBound.x = std::max(std::max(std::max(maxBound.x, triA.x), triB.x), triC.x);
+            maxBound.y = std::max(std::max(std::max(maxBound.y, triA.y), triB.y), triC.y);
+            maxBound.z = std::max(std::max(std::max(maxBound.z, triA.z), triB.z), triC.z);
         };
 
     auto itPoint = _param.m_mesh->cbegin<data::iterator::point::xyz>();
@@ -105,7 +126,7 @@ void ImageExtruder::operator()(Parameters& _param)
             const auto& pointA = itPoint + cell.pt[0];
             const auto& pointB = itPoint + cell.pt[1];
             const auto& pointC = itPoint + cell.pt[2];
-            addTriangle(*pointA, *pointB, *pointC);
+            addTriangle(*pointA, *pointB, *pointC, transform);
         }
     }
     else if(cellSize == 4)
@@ -117,8 +138,8 @@ void ImageExtruder::operator()(Parameters& _param)
             const auto& pointC = itPoint + cell.pt[2];
             const auto& pointD = itPoint + cell.pt[3];
 
-            addTriangle(*pointA, *pointB, *pointC);
-            addTriangle(*pointC, *pointD, *pointA);
+            addTriangle(*pointA, *pointB, *pointC, transform);
+            addTriangle(*pointC, *pointD, *pointA, transform);
         }
     }
     else
@@ -141,8 +162,8 @@ void ImageExtruder::operator()(Parameters& _param)
         indexXBeg = static_cast<std::int64_t>((minBound.x - origin[0]) / spacing[0]);
     }
 
-    std::int64_t indexXEnd = static_cast<std::int64_t>(size[0]);
-    if(origin[0] + indexXEnd * spacing[0] > maxBound.x)
+    auto indexXEnd = static_cast<std::int64_t>(size[0]);
+    if(origin[0] + double(indexXEnd) * spacing[0] > maxBound.x)
     {
         indexXEnd = static_cast<std::int64_t>((maxBound.x - origin[0]) / spacing[0]);
     }
@@ -153,8 +174,8 @@ void ImageExtruder::operator()(Parameters& _param)
         indexYBeg = static_cast<std::int64_t>((minBound.y - origin[1]) / spacing[1]);
     }
 
-    std::int64_t indexYEnd = size[1];
-    if(origin[1] + indexYEnd * spacing[1] > maxBound.y)
+    auto indexYEnd = std::int64_t(size[1]);
+    if(origin[1] + double(indexYEnd) * spacing[1] > maxBound.y)
     {
         indexYEnd = static_cast<std::int64_t>((maxBound.y - origin[1]) / spacing[1]);
     }
@@ -165,8 +186,8 @@ void ImageExtruder::operator()(Parameters& _param)
         indexZBeg = static_cast<std::int64_t>((minBound.z - origin[2]) / spacing[2]);
     }
 
-    std::int64_t indexZEnd = size[2];
-    if(origin[2] + indexZEnd * spacing[2] > maxBound.z)
+    auto indexZEnd = std::int64_t(size[2]);
+    if(origin[2] + double(indexZEnd) * spacing[2] > maxBound.z)
     {
         indexZEnd = static_cast<std::int64_t>((maxBound.z - origin[2]) / spacing[2]);
     }
@@ -180,7 +201,7 @@ void ImageExtruder::operator()(Parameters& _param)
             for(const Triangle& tri : triangles)
             {
                 glm::vec2 pos;
-                float distance;
+                float distance = NAN;
                 if(glm::intersectRayTriangle(
                        _rayOrig,
                        _rayDir,
@@ -191,7 +212,7 @@ void ImageExtruder::operator()(Parameters& _param)
                        distance
                 ))
                 {
-                    if(distance >= 0.f)
+                    if(distance >= 0.F)
                     {
                         const glm::vec3 cross = _rayOrig + _rayDir * distance;
                         // Sometime, the ray it the edge of a triangle, we need to take it into account only one time.
@@ -217,8 +238,10 @@ void ImageExtruder::operator()(Parameters& _param)
             return inside;
         };
 
-    // Check if each voxel are in the mesh and sets them to the lowest value.
-    const IMAGE_TYPE emptyValue = std::numeric_limits<IMAGE_TYPE>::lowest();
+    // Check if each voxel are in the mesh and sets the mask to zero.
+    const IMAGE_TYPE emptyValue = 0;
+
+    using IndexType = typename data::Image::IndexType;
 
     // We loop over two dimensions out of three, for each voxel, we launch a ray on the third dimension and get a
     // list of intersections. After that, we iterate over the voxel line on the third dimension and with the
@@ -233,9 +256,9 @@ void ImageExtruder::operator()(Parameters& _param)
                 for(std::int64_t y = indexYBeg ; y < indexYEnd ; ++y)
                 {
                     // For each voxel of the slice, launch a ray to the third axis.
-                    const glm::vec3 rayOrig(origin[0] + x * spacing[0] + spacing[0] / 2.f,
-                                            origin[1] + y * spacing[1] + spacing[1] / 2.f,
-                                            origin[2] + indexZBeg * spacing[2] + spacing[2] / 2.f);
+                    const glm::vec3 rayOrig(origin[0] + double(x) * spacing[0] + spacing[0] / 2.F,
+                                            origin[1] + double(y) * spacing[1] + spacing[1] / 2.F,
+                                            origin[2] + double(indexZBeg) * spacing[2] + spacing[2] / 2.F);
                     const glm::vec3 rayDirPos(rayOrig.x, rayOrig.y, rayOrig.z + 1);
                     const glm::vec3 rayDir = glm::normalize(rayDirPos - rayOrig);
 
@@ -244,7 +267,7 @@ void ImageExtruder::operator()(Parameters& _param)
                     bool inside = getIntersections(rayOrig, rayDir, intersections);
 
                     // If there is no intersection, the entire line is visible.
-                    if(intersections.size() > 0)
+                    if(!intersections.empty())
                     {
                         // Iterate over the "ray" and check intersections to know if the voxel is inside
                         // or outside of the mesh.
@@ -252,9 +275,9 @@ void ImageExtruder::operator()(Parameters& _param)
                         const auto intersectionEnd = intersections.end();
                         for(std::int64_t z = indexZBeg ; z < indexZEnd ; ++z)
                         {
-                            const glm::vec3 currentVoxelPos(origin[0] + x * spacing[0] + spacing[0] / 2.f,
-                                                            origin[1] + y * spacing[1] + spacing[1] / 2.f,
-                                                            origin[2] + z * spacing[2] + spacing[2] / 2.f);
+                            const glm::vec3 currentVoxelPos(origin[0] + double(x) * spacing[0] + spacing[0] / 2.F,
+                                                            origin[1] + double(y) * spacing[1] + spacing[1] / 2.F,
+                                                            origin[2] + double(z) * spacing[2] + spacing[2] / 2.F);
                             // While the current ray position is near to the next intersection, set the
                             // voxel to the value if
                             // it's needed.
@@ -262,7 +285,11 @@ void ImageExtruder::operator()(Parameters& _param)
                             {
                                 if(inside)
                                 {
-                                    _param.m_image->at<IMAGE_TYPE>(x, y, z) = emptyValue;
+                                    _param.m_image->at<IMAGE_TYPE>(
+                                        IndexType(x),
+                                        IndexType(y),
+                                        IndexType(z)
+                                    ) = emptyValue;
                                 }
                             }
                             // Once the intersection reach, get the next one.
@@ -277,7 +304,11 @@ void ImageExtruder::operator()(Parameters& _param)
                                     {
                                         for(std::int64_t zp = z ; zp < indexZEnd ; ++zp)
                                         {
-                                            _param.m_image->at<IMAGE_TYPE>(x, y, zp) = emptyValue;
+                                            _param.m_image->at<IMAGE_TYPE>(
+                                                IndexType(x),
+                                                IndexType(y),
+                                                IndexType(zp)
+                                            ) = emptyValue;
                                         }
                                     }
 
@@ -298,29 +329,33 @@ void ImageExtruder::operator()(Parameters& _param)
             {
                 for(std::int64_t z = indexZBeg ; z < indexZEnd ; ++z)
                 {
-                    const glm::vec3 rayOrig(origin[0] + x * spacing[0] + spacing[0] / 2.f,
-                                            origin[1] + indexYBeg * spacing[1] + spacing[1] / 2.f,
-                                            origin[2] + z * spacing[2] + spacing[2] / 2.f);
+                    const glm::vec3 rayOrig(origin[0] + double(x) * spacing[0] + spacing[0] / 2.F,
+                                            origin[1] + double(indexYBeg) * spacing[1] + spacing[1] / 2.F,
+                                            origin[2] + double(z) * spacing[2] + spacing[2] / 2.F);
                     const glm::vec3 rayDirPos(rayOrig.x, rayOrig.y + 1, rayOrig.z);
                     const glm::vec3 rayDir = glm::normalize(rayDirPos - rayOrig);
 
                     std::vector<glm::vec3> intersections;
                     bool inside = getIntersections(rayOrig, rayDir, intersections);
 
-                    if(intersections.size() > 0)
+                    if(!intersections.empty())
                     {
                         auto nextIntersection      = intersections.begin();
                         const auto intersectionEnd = intersections.end();
                         for(std::int64_t y = indexYBeg ; y < indexYEnd ; ++y)
                         {
-                            const glm::vec3 currentVoxelPos(origin[0] + x * spacing[0] + spacing[0] / 2.f,
-                                                            origin[1] + y * spacing[1] + spacing[1] / 2.f,
-                                                            origin[2] + z * spacing[2] + spacing[2] / 2.f);
+                            const glm::vec3 currentVoxelPos(origin[0] + double(x) * spacing[0] + spacing[0] / 2.F,
+                                                            origin[1] + double(y) * spacing[1] + spacing[1] / 2.F,
+                                                            origin[2] + double(z) * spacing[2] + spacing[2] / 2.F);
                             if(glm::distance(rayOrig, currentVoxelPos) < glm::distance(rayOrig, *nextIntersection))
                             {
                                 if(inside)
                                 {
-                                    _param.m_image->at<IMAGE_TYPE>(x, y, z) = emptyValue;
+                                    _param.m_image->at<IMAGE_TYPE>(
+                                        IndexType(x),
+                                        IndexType(y),
+                                        IndexType(z)
+                                    ) = emptyValue;
                                 }
                             }
                             else
@@ -333,7 +368,11 @@ void ImageExtruder::operator()(Parameters& _param)
                                     {
                                         for(std::int64_t yp = y ; yp < indexYEnd ; ++yp)
                                         {
-                                            _param.m_image->at<IMAGE_TYPE>(x, yp, z) = emptyValue;
+                                            _param.m_image->at<IMAGE_TYPE>(
+                                                IndexType(x),
+                                                IndexType(yp),
+                                                IndexType(z)
+                                            ) = emptyValue;
                                         }
                                     }
 
@@ -354,29 +393,33 @@ void ImageExtruder::operator()(Parameters& _param)
             {
                 for(std::int64_t z = indexZBeg ; z < indexZEnd ; ++z)
                 {
-                    const glm::vec3 rayOrig(origin[0] + indexXBeg * spacing[0] + spacing[0] / 2.f,
-                                            origin[1] + y * spacing[1] + spacing[1] / 2.f,
-                                            origin[2] + z * spacing[2] + spacing[2] / 2.f);
+                    const glm::vec3 rayOrig(origin[0] + double(indexXBeg) * spacing[0] + spacing[0] / 2.F,
+                                            origin[1] + double(y) * spacing[1] + spacing[1] / 2.F,
+                                            origin[2] + double(z) * spacing[2] + spacing[2] / 2.F);
                     const glm::vec3 rayDirPos(rayOrig.x + 1, rayOrig.y, rayOrig.z);
                     const glm::vec3 rayDir = glm::normalize(rayDirPos - rayOrig);
 
                     std::vector<glm::vec3> intersections;
                     bool inside = getIntersections(rayOrig, rayDir, intersections);
 
-                    if(intersections.size() > 0)
+                    if(!intersections.empty())
                     {
                         auto nextIntersection      = intersections.begin();
                         const auto intersectionEnd = intersections.end();
                         for(std::int64_t x = indexXBeg ; x < indexXEnd ; ++x)
                         {
-                            const glm::vec3 currentVoxelPos(origin[0] + x * spacing[0] + spacing[0] / 2.f,
-                                                            origin[1] + y * spacing[1] + spacing[1] / 2.f,
-                                                            origin[2] + z * spacing[2] + spacing[2] / 2.f);
+                            const glm::vec3 currentVoxelPos(origin[0] + double(x) * spacing[0] + spacing[0] / 2.F,
+                                                            origin[1] + double(y) * spacing[1] + spacing[1] / 2.F,
+                                                            origin[2] + double(z) * spacing[2] + spacing[2] / 2.F);
                             if(glm::distance(rayOrig, currentVoxelPos) < glm::distance(rayOrig, *nextIntersection))
                             {
                                 if(inside)
                                 {
-                                    _param.m_image->at<IMAGE_TYPE>(x, y, z) = emptyValue;
+                                    _param.m_image->at<IMAGE_TYPE>(
+                                        IndexType(x),
+                                        IndexType(y),
+                                        IndexType(z)
+                                    ) = emptyValue;
                                 }
                             }
                             else
@@ -389,7 +432,11 @@ void ImageExtruder::operator()(Parameters& _param)
                                     {
                                         for(std::int64_t xp = x ; xp < indexXEnd ; ++xp)
                                         {
-                                            _param.m_image->at<IMAGE_TYPE>(xp, y, z) = emptyValue;
+                                            _param.m_image->at<IMAGE_TYPE>(
+                                                IndexType(xp),
+                                                IndexType(y),
+                                                IndexType(z)
+                                            ) = emptyValue;
                                         }
                                     }
 
@@ -404,10 +451,10 @@ void ImageExtruder::operator()(Parameters& _param)
 
     // Get the smallest dimension in terms of voxel to loop over the minimum of voxel.
     std::uint8_t axis = 2;
-    std::size_t voxel = (indexXEnd - indexXBeg) * (indexYEnd - indexYBeg);
+    auto voxel        = std::size_t((indexXEnd - indexXBeg) * (indexYEnd - indexYBeg));
 
-    std::size_t voxelXZ = (indexXEnd - indexXBeg) * (indexZEnd - indexZBeg);
-    std::size_t voxelYZ = (indexYEnd - indexYBeg) * (indexZEnd - indexZBeg);
+    auto voxelXZ = std::size_t((indexXEnd - indexXBeg) * (indexZEnd - indexZBeg));
+    auto voxelYZ = std::size_t((indexYEnd - indexYBeg) * (indexZEnd - indexZBeg));
     if(voxelXZ < voxel)
     {
         axis  = 1;
@@ -434,7 +481,10 @@ void ImageExtruder::operator()(Parameters& _param)
         case 0:
             xLoop();
             break;
+
+        default:
+            SIGHT_ASSERT("Unreachable code", false);
     }
 }
 
-} // namespace sight::filter
+} // namespace sight::filter::image
