@@ -20,10 +20,11 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINT NOLINTNEXTLINE
+
 #include "filter/image/MinMaxPropagation.hpp"
 
 #include <core/tools/Dispatcher.hpp>
-#include <core/tools/TypeKeyTypeMapping.hpp>
 
 #include <data/helper/MedicalImage.hpp>
 #include <data/Image.hpp>
@@ -46,26 +47,24 @@ class MinMaxPropagCriterion : public itk::ImageFunction<TImage,
 {
 public:
 
-    typedef MinMaxPropagCriterion Self;
-    typedef itk::ImageFunction<TImage, bool> Superclass;
-    typedef itk::SmartPointer<Self> Pointer;
-    typedef itk::SmartPointer<Self const> ConstPointer;
+    using Self         = MinMaxPropagCriterion;
+    using Superclass   = itk::ImageFunction<TImage, bool>;
+    using Pointer      = itk::SmartPointer<Self>;
+    using ConstPointer = itk::SmartPointer<const Self>;
 
     itkNewMacro(Self);
     itkTypeMacro(MinMaxPropagCriterion, ImageFunction);
 
-    typedef typename Superclass::InputPixelType PixelType;
-    typedef typename TImage::IndexType IndexType;
-    typedef typename TImage::SpacingType SpacingType;
+    using PixelType   = typename Superclass::InputPixelType;
+    using IndexType   = typename TImage::IndexType;
+    using SpacingType = typename TImage::SpacingType;
 
     //-----------------------------------------------------------------------------
 
     MinMaxPropagCriterion() :
         m_min(itk::NumericTraits<PixelType>::max()),
         m_max(itk::NumericTraits<PixelType>::min()),
-        m_useRadius(false),
-        m_radius(std::numeric_limits<double>::infinity()),
-        m_overwrite(false)
+        m_radius(std::numeric_limits<double>::infinity())
     {
     }
 
@@ -116,7 +115,7 @@ public:
         double distance2 = 0;
         for(typename TImage::IndexValueType i = 0 ; i < IndexType::Dimension ; ++i)
         {
-            const double realDim = imgSize[i] * imgSpacing[i];
+            const double realDim = double(imgSize[std::uint32_t(i)]) * imgSpacing[i];
             distance2 += realDim * realDim;
         }
 
@@ -130,7 +129,7 @@ public:
 
     //-----------------------------------------------------------------------------
 
-    bool Evaluate(const typename Superclass::PointType& point) const override
+    bool Evaluate(const typename Superclass::PointType& point) const override // NOLINT(readability-identifier-naming)
     {
         IndexType index;
         this->ConvertPointToNearestIndex(point, index);
@@ -139,7 +138,7 @@ public:
 
     //-----------------------------------------------------------------------------
 
-    bool EvaluateAtIndex(const IndexType& index) const override
+    bool EvaluateAtIndex(const IndexType& index) const override // NOLINT(readability-identifier-naming)
     {
         const PixelType& currentValue = this->GetInputImage()->GetPixel(index);
 
@@ -162,16 +161,12 @@ public:
         }
 
         // Check if the max distance was reached
-        if(m_useRadius && !isInsideRadius(index))
-        {
-            return false;
-        }
-
-        return true;
+        return !(m_useRadius && !isInsideRadius(index));
     }
 
     //-----------------------------------------------------------------------------
 
+    // NOLINTNEXTLINE(readability-identifier-naming)
     bool EvaluateAtContinuousIndex(const typename Superclass::ContinuousIndexType& contIndex) const override
     {
         IndexType index;
@@ -193,7 +188,8 @@ public:
 
             for(typename TImage::IndexValueType i = 0 ; i < IndexType::Dimension ; ++i)
             {
-                const double distTmp = (index[i] - seed[i]) * imgSpacing[i];
+                const double distTmp = double(index[std::uint32_t(i)] - seed[std::uint32_t(i)])
+                                       * imgSpacing[std::uint32_t(i)];
                 distance2 += distTmp * distTmp;
             }
 
@@ -213,11 +209,15 @@ public:
         const auto dumpLock = m_roi->dump_lock();
         const auto size     = m_roi->getSize();
 
-        const data::Image::BufferType* roiVal =
+        const auto* roiVal =
             reinterpret_cast<const data::Image::BufferType*>(
-                m_roi->getPixel(index[0] + index[1] * size[0] + index[2] * size[0] * size[1]));
+                m_roi->getPixel(
+                    std::size_t(index[0]) + std::size_t(index[1]) * size[0] + std::size_t(index[2])
+                    * size[0] * size[1]
+                )
+            );
 
-        return !data::helper::MedicalImage::isBufNull(roiVal, m_roi->getType().sizeOf());
+        return !data::helper::MedicalImage::isBufNull(roiVal, std::uint32_t(m_roi->getType().size()));
     }
 
 private:
@@ -230,11 +230,11 @@ private:
 
     std::vector<IndexType> m_seeds;
 
-    bool m_useRadius;
+    bool m_useRadius {false};
 
     double m_radius;
 
-    bool m_overwrite;
+    bool m_overwrite {false};
 };
 
 //-----------------------------------------------------------------------------
@@ -247,11 +247,11 @@ struct MinMaxPropagator
         data::Image::sptr outputImage;
         data::Image::csptr roi;
         ImageDiff diff;
-        data::Image::BufferType* value;
+        data::Image::BufferType* value {};
         MinMaxPropagation::SeedsType seeds;
-        double radius;
-        bool overwrite;
-        MinMaxPropagation::Mode mode;
+        double radius {};
+        bool overwrite {};
+        MinMaxPropagation::Mode mode {MinMaxPropagation::Mode::MINMAX};
     };
 
     //------------------------------------------------------------------------------
@@ -259,8 +259,8 @@ struct MinMaxPropagator
     template<class PIXELTYPE>
     void operator()(Parameters& params)
     {
-        typedef typename itk::Image<PIXELTYPE, 3> ImageType;
-        typedef MinMaxPropagCriterion<ImageType> CriterionType;
+        using ImageType     = typename itk::Image<PIXELTYPE, 3>;
+        using CriterionType = MinMaxPropagCriterion<ImageType>;
 
         const typename ImageType::Pointer itkImage = io::itk::moveToItk<ImageType>(params.inputImage);
 
@@ -271,7 +271,7 @@ struct MinMaxPropagator
 
             for(typename ImageType::IndexValueType i = 0 ; i < ImageType::IndexType::Dimension ; ++i)
             {
-                index[i] = static_cast<typename ImageType::IndexValueType>(seed[i]);
+                index[std::uint32_t(i)] = typename ImageType::IndexValueType(seed[std::size_t(i)]);
             }
 
             itkSeeds.push_back(index);
@@ -286,14 +286,16 @@ struct MinMaxPropagator
 
         const auto dumpLock = params.outputImage->dump_lock();
 
-        const std::uint8_t outImgPixelSize = params.outputImage->getType().sizeOf()
-                                             * static_cast<std::uint8_t>(params.outputImage->numComponents());
+        const std::uint8_t outImgPixelSize = std::uint8_t(
+            params.outputImage->getType().size()
+            * params.outputImage->numComponents()
+        );
 
         for( ; !iter.IsAtEnd() ; ++iter)
         {
             const typename ImageType::IndexType currentIndex = iter.GetIndex();
 
-            const std::size_t bufferIndex = static_cast<std::size_t>(itkImage->ComputeOffset(currentIndex));
+            const auto bufferIndex = static_cast<std::size_t>(itkImage->ComputeOffset(currentIndex));
 
             const data::Image::BufferType* pixBuf =
                 reinterpret_cast<data::Image::BufferType*>(params.outputImage->getPixel(bufferIndex));
@@ -310,13 +312,13 @@ struct MinMaxPropagator
 //-----------------------------------------------------------------------------
 
 MinMaxPropagation::MinMaxPropagation(
-    const data::Image::csptr& inImage,
-    const data::Image::sptr& outImage,
-    const data::Image::csptr& roi
+    data::Image::csptr inImage,
+    data::Image::sptr outImage,
+    data::Image::csptr roi
 ) :
-    m_inImage(inImage),
-    m_roi(roi),
-    m_outImage(outImage)
+    m_inImage(std::move(inImage)),
+    m_roi(std::move(roi)),
+    m_outImage(std::move(outImage))
 {
 }
 
@@ -330,8 +332,8 @@ ImageDiff MinMaxPropagation::propagate(
     const Mode mode
 )
 {
-    const core::tools::Type type        = m_inImage->getType();
-    const std::size_t outImagePixelSize = m_outImage->getType().sizeOf() * m_outImage->numComponents();
+    const core::Type type               = m_inImage->getType();
+    const std::size_t outImagePixelSize = m_outImage->getType().size() * m_outImage->numComponents();
 
     MinMaxPropagator::Parameters params;
     params.inputImage  = m_inImage;
