@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,7 @@
 
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::filter::image::ut::FlipTest);
 
-namespace sight::filter::image
-{
-
-namespace ut
+namespace sight::filter::image::ut
 {
 
 //------------------------------------------------------------------------------
@@ -44,15 +41,14 @@ void FlipTest::flipAlongXAxisTest()
     const data::Image::Size size          = {{3, 3, 3}};
     const data::Image::Spacing spacing    = {{0.1, 0.4, 1.6}};
     const data::Image::Origin origin      = {{0., 0., 0.}};
-    const core::tools::Type type          = core::tools::Type::s_UINT8;
+    const core::Type type                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
     std::array<bool, 3> flipAxes {true, false, false};
 
     data::Image::sptr imageIn  = data::Image::New();
     data::Image::sptr imageOut = data::Image::New();
 
-    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-    utestData::generator::Image::randomizeImage(imageIn);
+    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
     const auto inDumpLock = imageIn->dump_lock();
     filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -81,15 +77,14 @@ void FlipTest::flipAlongYAxisTest()
     const data::Image::Size size          = {{3, 3, 3}};
     const data::Image::Spacing spacing    = {{0.5, 0.5, 0.5}};
     const data::Image::Origin origin      = {{8., 4., 2.}};
-    const core::tools::Type type          = core::tools::Type::s_UINT8;
+    const core::Type type                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
     std::array<bool, 3> flipAxes {false, true, false};
 
     data::Image::sptr imageIn  = data::Image::New();
     data::Image::sptr imageOut = data::Image::New();
 
-    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-    utestData::generator::Image::randomizeImage(imageIn);
+    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
     const auto inDumpLock = imageIn->dump_lock();
     filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -118,15 +113,14 @@ void FlipTest::flipAlongZAxisTest()
     const data::Image::Size size          = {{3, 3, 3}};
     const data::Image::Spacing spacing    = {{2.0, 2.0, 2.0}};
     const data::Image::Origin origin      = {{0., 0., 0.}};
-    const core::tools::Type type          = core::tools::Type::s_UINT8;
+    const core::Type type                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
     std::array<bool, 3> flipAxes {false, false, true};
 
     data::Image::sptr imageIn  = data::Image::New();
     data::Image::sptr imageOut = data::Image::New();
 
-    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-    utestData::generator::Image::randomizeImage(imageIn);
+    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
     const auto inDumpLock = imageIn->dump_lock();
     filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -156,15 +150,14 @@ void FlipTest::flipAlongMultipleAxesTest()
         const data::Image::Size size          = {{3, 3, 3}};
         const data::Image::Spacing spacing    = {{0.5, 0.5, 0.5}};
         const data::Image::Origin origin      = {{0., 0., 0.}};
-        const core::tools::Type type          = core::tools::Type::s_UINT8;
+        const core::Type type                 = core::Type::UINT8;
         const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
         std::array<bool, 3> flipAxes {true, true, false};
 
         data::Image::sptr imageIn  = data::Image::New();
         data::Image::sptr imageOut = data::Image::New();
 
-        utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-        utestData::generator::Image::randomizeImage(imageIn);
+        utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
         const auto inDumpLock = imageIn->dump_lock();
         filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -190,15 +183,14 @@ void FlipTest::flipAlongMultipleAxesTest()
         const data::Image::Size size          = {{3, 3, 3}};
         const data::Image::Spacing spacing    = {{0.5, 0.5, 0.5}};
         const data::Image::Origin origin      = {{0., 0., 0.}};
-        const core::tools::Type type          = core::tools::Type::s_UINT8;
+        const core::Type type                 = core::Type::UINT8;
         const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
         std::array<bool, 3> flipAxes {true, true, true};
 
         data::Image::sptr imageIn  = data::Image::New();
         data::Image::sptr imageOut = data::Image::New();
 
-        utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-        utestData::generator::Image::randomizeImage(imageIn);
+        utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
         const auto inDumpLock = imageIn->dump_lock();
         filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -232,15 +224,14 @@ void FlipTest::flipEmptyImageTest()
     const data::Image::Size size          = {0, 0, 0};
     const data::Image::Spacing spacing    = {0., 0., 0.};
     const data::Image::Origin origin      = {0., 0., 0.};
-    const core::tools::Type type          = core::tools::Type::s_UINT8;
+    const core::Type type                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
     std::array<bool, 3> flipAxes {false, true, false};
 
     data::Image::sptr imageIn  = data::Image::New();
     data::Image::sptr imageOut = data::Image::New();
 
-    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format);
-    utestData::generator::Image::randomizeImage(imageIn);
+    utestData::generator::Image::generateImage(imageIn, size, spacing, origin, type, format, 0);
 
     const auto inDumpLock = imageIn->dump_lock();
     filter::image::Flipper::flip(imageIn, imageOut, flipAxes);
@@ -256,6 +247,4 @@ void FlipTest::flipEmptyImageTest()
 
 //------------------------------------------------------------------------------
 
-} // ut
-
-} // imageFilterOp
+} // namespace sight::filter::image::ut
