@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::filter::image::ut::ImageExtruderTest);
 
-namespace sight::filter::image
-{
-
-namespace ut
+namespace sight::filter::image::ut
 {
 
 //------------------------------------------------------------------------------
@@ -110,39 +107,41 @@ void ImageExtruderTest::extrudeTriangleMesh()
         std::size_t pt = 0;
         for(std::size_t index = 0 ; index < 36 ; index += 3)
         {
-            it->pt[0] = indexes[pt++];
-            it->pt[1] = indexes[pt++];
-            it->pt[2] = indexes[pt++];
+            it->pt[0] = data::iterator::cell_t(indexes[pt++]);
+            it->pt[1] = data::iterator::cell_t(indexes[pt++]);
+            it->pt[2] = data::iterator::cell_t(indexes[pt++]);
 
             ++it;
         }
     }
 
     const data::Image::sptr image = data::Image::New();
-    image->deepCopy(m_image);
 
-    filter::image::ImageExtruder::extrude(image, mesh);
+    image->resize(m_image->getSize(), core::Type::UINT8, data::Image::PixelFormat::GRAY_SCALE);
+    image->setSpacing(m_image->getSpacing());
+
+    const auto dumpLock = image->dump_lock();
+    std::fill(image->begin(), image->end(), std::uint8_t(255));
+
+    filter::image::ImageExtruder::extrude(image, mesh, nullptr);
 
-    const auto dumpLock       = image->dump_lock();
     const auto dumpOriginLock = m_image->dump_lock();
+
     for(std::size_t z = 0 ; z < m_size[2] ; ++z)
     {
         for(std::size_t y = 0 ; y < m_size[1] ; ++y)
         {
             for(std::size_t x = 0 ; x < m_size[0] ; ++x)
             {
-                if(x >= static_cast<float>(m_origin[0] + 1) && x < static_cast<float>(m_size[0] - 1)
-                   && y >= static_cast<float>(m_origin[1] + 1) && y < static_cast<float>(m_size[1] - 1)
-                   && z >= static_cast<float>(m_origin[2] + 1) && z < static_cast<float>(m_size[2] - 1))
+                if(double(x) >= m_origin[0] + 1 && x < m_size[0] - 1
+                   && double(y) >= m_origin[1] + 1 && y < m_size[1] - 1
+                   && double(z) >= m_origin[2] + 1 && z < m_size[2] - 1)
                 {
-                    CPPUNIT_ASSERT_EQUAL(
-                        std::numeric_limits<std::int8_t>::lowest(),
-                        image->at<std::int8_t>(x, y, z)
-                    );
+                    CPPUNIT_ASSERT_EQUAL(std::uint8_t(0), image->at<std::uint8_t>(x, y, z));
                 }
                 else
                 {
-                    CPPUNIT_ASSERT_EQUAL(m_image->at<std::int8_t>(x, y, z), image->at<std::int8_t>(x, y, z));
+                    CPPUNIT_ASSERT_EQUAL(std::uint8_t(255), image->at<std::uint8_t>(x, y, z));
                 }
             }
         }
@@ -202,40 +201,41 @@ void ImageExtruderTest::extrudeQuadMesh()
         std::size_t pt = 0;
         for(std::size_t index = 0 ; index < 24 ; index += 4)
         {
-            it->pt[0] = indexes[pt++];
-            it->pt[1] = indexes[pt++];
-            it->pt[2] = indexes[pt++];
-            it->pt[3] = indexes[pt++];
+            it->pt[0] = data::iterator::cell_t(indexes[pt++]);
+            it->pt[1] = data::iterator::cell_t(indexes[pt++]);
+            it->pt[2] = data::iterator::cell_t(indexes[pt++]);
+            it->pt[3] = data::iterator::cell_t(indexes[pt++]);
 
             ++it;
         }
     }
 
     const data::Image::sptr image = data::Image::New();
-    image->deepCopy(m_image);
+    image->resize(m_image->getSize(), core::Type::UINT8, data::Image::PixelFormat::GRAY_SCALE);
+    image->setSpacing(m_image->getSpacing());
 
-    filter::image::ImageExtruder::extrude(image, mesh);
+    const auto dumpLock = image->dump_lock();
+    std::fill(image->begin(), image->end(), std::uint8_t(255));
+
+    filter::image::ImageExtruder::extrude(image, mesh, nullptr);
 
-    const auto dumpLock       = image->dump_lock();
     const auto dumpOriginLock = m_image->dump_lock();
+
     for(std::size_t z = 0 ; z < m_size[2] ; ++z)
     {
         for(std::size_t y = 0 ; y < m_size[1] ; ++y)
         {
             for(std::size_t x = 0 ; x < m_size[0] ; ++x)
             {
-                if(x >= static_cast<float>(m_origin[0] + 1) && x < static_cast<float>(m_size[0] - 1)
-                   && y >= static_cast<float>(m_origin[1] + 1) && y < static_cast<float>(m_size[1] - 1)
-                   && z >= static_cast<float>(m_origin[2] + 1) && z < static_cast<float>(m_size[2] - 1))
+                if(double(x) >= m_origin[0] + 1 && x < m_size[0] - 1
+                   && double(y) >= m_origin[1] + 1 && y < m_size[1] - 1
+                   && double(z) >= m_origin[2] + 1 && z < m_size[2] - 1)
                 {
-                    CPPUNIT_ASSERT_EQUAL(
-                        std::numeric_limits<std::int8_t>::lowest(),
-                        image->at<std::int8_t>(x, y, z)
-                    );
+                    CPPUNIT_ASSERT_EQUAL(std::uint8_t(0), image->at<std::uint8_t>(x, y, z));
                 }
                 else
                 {
-                    CPPUNIT_ASSERT_EQUAL(m_image->at<std::int8_t>(x, y, z), image->at<std::int8_t>(x, y, z));
+                    CPPUNIT_ASSERT_EQUAL(std::uint8_t(255), image->at<std::uint8_t>(x, y, z));
                 }
             }
         }
@@ -244,6 +244,4 @@ void ImageExtruderTest::extrudeQuadMesh()
 
 //------------------------------------------------------------------------------
 
-} // namespace ut.
-
-} // namespace sight::filter::image.
+} // namespace sight::filter::image::ut
