@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,7 @@
 
 #include <filesystem>
 
-namespace sight::io::base
-{
-
-namespace reader
+namespace sight::io::base::reader
 {
 
 /**
@@ -54,7 +51,7 @@ public:
     IO_BASE_API ArrayReader(io::base::reader::IObjectReader::Key key);
 
     /// Destructor. Does nothing.
-    IO_BASE_API virtual ~ArrayReader();
+    IO_BASE_API ~ArrayReader() override;
 
     /// Reads the file with zlib API.
     IO_BASE_API void read() override;
@@ -63,6 +60,4 @@ public:
     IO_BASE_API std::string extension() const override;
 };
 
-} // namespace reader
-
-} // namespace sight::io::base
+} // namespace sight::io::base::reader
