@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,13 +24,7 @@
 
 #include "io/base/reader/IObjectReader.hpp"
 
-namespace sight::io::base
-{
-
-namespace reader
-{
-
-namespace factory
+namespace sight::io::base::reader::factory
 {
 
 //------------------------------------------------------------------------------
@@ -40,8 +34,4 @@ io::base::reader::IObjectReader::sptr New(const io::base::reader::registry::KeyT
     return io::base::reader::registry::get()->create(classname);
 }
 
-} // namespace factory
-
-} // namespace reader
-
-} // namespace sight::io::base
+} // namespace sight::io::base::reader::factory
