@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,6 +36,11 @@ const core::com::Signals::SignalKeyType IGrabber::s_CAMERA_STOPPED_SIG = "camera
 
 const core::com::Signals::SignalKeyType IGrabber::s_FRAME_PRESENTED_SIG = "framePresented";
 
+const core::com::Signals::SignalKeyType IGrabber::s_PARAMETER_CHANGED_SIG = "parameterChanged";
+
+const core::com::Signals::SignalKeyType IGrabber::s_JOB_CREATED_SIG = "jobCreated";
+const core::com::Signals::SignalKeyType IGrabber::s_FPS_CHANGED_SIG = "fpsChanged";
+
 const core::com::Slots::SlotKeyType IGrabber::s_START_CAMERA_SLOT       = "startCamera";
 const core::com::Slots::SlotKeyType IGrabber::s_STOP_CAMERA_SLOT        = "stopCamera";
 const core::com::Slots::SlotKeyType IGrabber::s_PAUSE_CAMERA_SLOT       = "pauseCamera";
@@ -46,9 +51,19 @@ const core::com::Slots::SlotKeyType IGrabber::s_PREVIOUS_IMAGE_SLOT     = "previ
 const core::com::Slots::SlotKeyType IGrabber::s_NEXT_IMAGE_SLOT         = "nextImage";
 const core::com::Slots::SlotKeyType IGrabber::s_SET_STEP_SLOT           = "setStep";
 
+const core::com::Slots::SlotKeyType IGrabber::s_SET_PARAMETER_SLOT = "setParameter";
+
+const core::com::Slots::SlotKeyType IGrabber::s_REQUEST_SETTINGS_SLOT    = "requestSettings";
+const core::com::Slots::SlotKeyType IGrabber::s_OPTIMIZE_SLOT            = "optimize";
+const core::com::Slots::SlotKeyType IGrabber::s_FORWARD_FPS_CHANGED_SLOT = "forwardFPSChanged";
+
+const std::string IGrabber::s_ADD_ROI_CENTER_SLOT    = "addROICenter";
+const std::string IGrabber::s_REMOVE_ROI_CENTER_SLOT = "removeROICenter";
+
 // ----------------------------------------------------------------------------
 
-IGrabber::IGrabber() noexcept
+IGrabber::IGrabber() noexcept :
+    INotifier(m_signals)
 {
     //Declare all signals
     newSignal<PositionModifiedSignalType>(s_POSITION_MODIFIED_SIG);
@@ -57,6 +72,10 @@ IGrabber::IGrabber() noexcept
     newSignal<CameraStoppedSignalType>(s_CAMERA_STOPPED_SIG);
     newSignal<FramePresentedSignalType>(s_FRAME_PRESENTED_SIG);
 
+    newSignal<ParameterChangedSignalType>(s_PARAMETER_CHANGED_SIG);
+    newSignal<JobCreatedSignalType>(s_JOB_CREATED_SIG);
+    newSignal<FPSChangedSignalType>(s_FPS_CHANGED_SIG);
+
     newSlot(s_START_CAMERA_SLOT, &IGrabber::startCamera, this);
     newSlot(s_STOP_CAMERA_SLOT, &IGrabber::stopCamera, this);
     newSlot(s_PAUSE_CAMERA_SLOT, &IGrabber::pauseCamera, this);
@@ -66,12 +85,16 @@ IGrabber::IGrabber() noexcept
     newSlot(s_PREVIOUS_IMAGE_SLOT, &IGrabber::previousImage, this);
     newSlot(s_NEXT_IMAGE_SLOT, &IGrabber::nextImage, this);
     newSlot(s_SET_STEP_SLOT, &IGrabber::setStep, this);
-}
 
-// ----------------------------------------------------------------------------
+    newSlot(s_SET_PARAMETER_SLOT, &IGrabber::setParameter, this);
 
-IGrabber::~IGrabber() noexcept
-{
+    newSlot(s_REQUEST_SETTINGS_SLOT, &IGrabber::requestSettings, this);
+    newSlot(s_OPTIMIZE_SLOT, &IGrabber::optimize, this);
+
+    newSlot(s_ADD_ROI_CENTER_SLOT, &IGrabber::addROICenter, this);
+    newSlot(s_REMOVE_ROI_CENTER_SLOT, &IGrabber::removeROICenter, this);
+
+    newSlot(s_FORWARD_FPS_CHANGED_SLOT, &IGrabber::forwardFPSChanged, this);
 }
 
 // ----------------------------------------------------------------------------
@@ -108,8 +131,38 @@ void IGrabber::setStep(int /*step*/, std::string /*key*/)
     SIGHT_WARN("Frame by frame mode not implemented for this grabber type.");
 }
 
+//-----------------------------------------------------------------------------
+
+void IGrabber::setParameter(ui::base::parameter_t /*unused*/, std::string /*unused*/)
+{
+}
+
 // ----------------------------------------------------------------------------
 
+void IGrabber::requestSettings()
+{
+}
+
+// ----------------------------------------------------------------------------
+
+void IGrabber::optimize()
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IGrabber::addROICenter(sight::data::Point::sptr /*unused*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IGrabber::removeROICenter(sight::data::Point::sptr /*unused*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
 void IGrabber::clearTimeline(data::FrameTL& _tl)
 {
     if(_tl.isAllocated())
@@ -118,9 +171,9 @@ void IGrabber::clearTimeline(data::FrameTL& _tl)
         const core::HiResClock::HiResClockType timestamp = _tl.getNewerTimestamp() + 1;
 
         SPTR(data::FrameTL::BufferType) buffer = _tl.createBuffer(timestamp);
-        auto destBuffer = reinterpret_cast<std::uint8_t*>(buffer->addElement(0));
+        auto* destBuffer = reinterpret_cast<std::uint8_t*>(buffer->addElement(0));
 
-        std::fill(destBuffer, destBuffer + _tl.getWidth() * _tl.getHeight() * _tl.numComponents(), 0);
+        std::memset(destBuffer, 0, _tl.getWidth() * _tl.getHeight() * _tl.numComponents());
 
         // push buffer and notify
         _tl.clearTimeline();
@@ -140,6 +193,12 @@ void IGrabber::setStartState(bool state)
     m_isStarted = state;
 }
 
+//------------------------------------------------------------------------------
+
+void IGrabber::forwardFPSChanged(double /* fps */)
+{
+}
+
 // ----------------------------------------------------------------------------
 
 } // namespace sight::io::base::service
