@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,6 +25,8 @@
 #include "io/base/config.hpp"
 #include "io/base/service/ioTypes.hpp"
 
+#include <core/tools/Failed.hpp>
+
 #include <service/IService.hpp>
 
 #include <filesystem>
@@ -56,11 +58,10 @@ public:
     /// Enum to define a password policy
     enum class DialogPolicy : uint8_t
     {
-        NEVER   = 0,     /// Never use show the dialog
-        ONCE    = 1,     /// Show only once, store the location as long as the service is started
-        ALWAYS  = 2,     /// Always show the location dialog
-        DEFAULT = NEVER, /// Default behavior if nothing is set
-        INVALID = 255    /// Used for error management
+        NEVER   = 0,  /// Never show the dialog
+        ONCE    = 1,  /// Show only once, store the location as long as the service is started
+        ALWAYS  = 2,  /// Always show the location dialog
+        INVALID = 255 /// Used for error management
     };
 
     /**
@@ -173,9 +174,6 @@ public:
     {
         switch(policy)
         {
-            case DialogPolicy::NEVER:
-                return "never";
-
             case DialogPolicy::ONCE:
                 return "once";
 
@@ -183,41 +181,38 @@ public:
                 return "always";
 
             default:
-                return "default";
+                return "never";
         }
     }
 
     /// Convenience function to convert from string to DialogPolicy enum value
     constexpr static DialogPolicy stringToDialogPolicy(std::string_view policy) noexcept
     {
-        if(constexpr auto NEVER = dialogPolicyToString(DialogPolicy::NEVER); policy == NEVER)
+        if(constexpr auto NEVER = dialogPolicyToString(DialogPolicy::NEVER);
+           policy == NEVER || policy.empty() || policy == "default")
         {
             return DialogPolicy::NEVER;
         }
-        else if(constexpr auto ONCE = dialogPolicyToString(DialogPolicy::ONCE); policy == ONCE)
+
+        if(constexpr auto ONCE = dialogPolicyToString(DialogPolicy::ONCE); policy == ONCE)
         {
             return DialogPolicy::ONCE;
         }
-        else if(constexpr auto ALWAYS = dialogPolicyToString(DialogPolicy::ALWAYS); policy == ALWAYS)
+
+        if(constexpr auto ALWAYS = dialogPolicyToString(DialogPolicy::ALWAYS); policy == ALWAYS)
         {
             return DialogPolicy::ALWAYS;
         }
-        else if(policy.empty() || policy == "default")
-        {
-            return DialogPolicy::DEFAULT;
-        }
-        else
-        {
-            // Error case
-            return DialogPolicy::INVALID;
-        }
+
+        // Error case
+        return DialogPolicy::INVALID;
     }
 
 protected:
 
     IO_BASE_API IReader() noexcept;
 
-    IO_BASE_API virtual ~IReader() noexcept;
+    IO_BASE_API ~IReader() noexcept override;
 
     /**
      * @brief This method proposes to parse xml configuration to retrieve
@@ -288,9 +283,9 @@ protected:
 private:
 
     /// Slot to read folder
-    void readFolder(std::filesystem::path path);
+    void readFolder(std::filesystem::path folder);
     /// Slot to read file
-    void readFile(std::filesystem::path path);
+    void readFile(std::filesystem::path file);
     /// Slot to read files
     void readFiles(io::base::service::LocationsType files);
 
