@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,6 +25,9 @@
 #include "io/base/config.hpp"
 #include "io/base/service/ioTypes.hpp"
 
+#include <core/com/Signal.hpp>
+#include <core/tools/Failed.hpp>
+
 #include <service/IService.hpp>
 
 #include <filesystem>
@@ -35,11 +38,26 @@ namespace sight::io::base::service
 /**
  * @brief Writer service API. It manages extension points definition and extension configuration
  *
+ * @section Signals Signals
+ * - \b prefixSet(): Emitted when the prefix has been correctly updated,
+ * - \b baseFolderSet(): Emitted When the base folder has been correctly updated.
+ *
  * @section Slots Slots
- * - \b setFileFolder(const std::filesystem::path&): Sets the folder when a path is configured in FILE or
- * FILES mode
- * - \b setTimestampPrefix(core::HiResClock::HiResClockType): When connected to a timestamp-emitting signal,
- * this slot will concatenate the current timestamp as a prefix of the output file (file-mode only).
+ * - \b setPrefix(std::string): When connected to a string-emitting signal (or function),
+ *   this slot will concatenate the string as a prefix of the output file/folder.
+ * - \b setBaseFolder(std::string): When connected to a string-emitting signal (or function),
+ *   this slot will set the base folder used by writers.
+ *
+ * @subsection Configuration Configuration
+ * - \b file: default file path.
+ * - \b folder: default folder path.
+ * - \b baseFolder: path or preference key specifying the root output path.
+ *      If set, it will override user setting the path via GUI input,
+ *      leading to a service that automatically saves data without user queries.
+ *      If the output is a file, then the output will be built as follows:
+ *        <base_folder>(/<prefix>)^{0,1}/<file>, where file is the value in the file tag.
+ *      If the output is a folder, then the output will be built as follows:
+ *        <base_folder>(/<prefix>)^{0,1}/<folder>, where folder is the value in the folder tag.
  *
  * This class represents the base interface for writer services.
  * Use the base service methods :
@@ -57,19 +75,27 @@ public:
     /// Enum to define a dialog policy
     enum class DialogPolicy : uint8_t
     {
-        NEVER   = 0,     /// Never use show the dialog
-        ONCE    = 1,     /// Show only once, store the location as long as the service is started
-        ALWAYS  = 2,     /// Always show the location dialog
-        DEFAULT = NEVER, /// Default behavior if nothing is set
-        INVALID = 255    /// Used for error management
+        NEVER   = 0,  /// Never use show the dialog
+        ONCE    = 1,  /// Show only once, store the location as long as the service is started
+        ALWAYS  = 2,  /// Always show the location dialog
+        INVALID = 255 /// Used for error management
     };
 
+    /**
+     * @name Signals API
+     * @{
+     */
+
+    IO_BASE_API static const core::com::Signals::SignalKeyType s_PREFIX_SET_SIG;
+    IO_BASE_API static const core::com::Signals::SignalKeyType s_BASE_FOLDER_SET_SIG;
+    typedef core::com::Signal<void ()> VoidSignalType;
+
     /**
      * @name Slots API
      * @{
      */
-    IO_BASE_API static const core::com::Slots::SlotKeyType s_SET_FILE_FOLDER;
-    IO_BASE_API static const core::com::Slots::SlotKeyType s_SET_TIMESTAMP_PREFIX;
+    IO_BASE_API static const core::com::Slots::SlotKeyType s_SET_PREFIX;
+    IO_BASE_API static const core::com::Slots::SlotKeyType s_SET_BASE_FOLDER;
     /// @}
 
     /**
@@ -95,7 +121,7 @@ public:
      * @pre exception if a file path is not defined  ( m_locations.empty() )
      * @pre exception if service does not support FILE mode
      */
-    IO_BASE_API const std::filesystem::path& getFile() const;
+    IO_BASE_API std::filesystem::path getFile() const;
 
     /**
      * @brief Sets file path
@@ -121,7 +147,7 @@ public:
      * @pre exception if a folder path is not defined ( m_locations.empty() )
      * @pre exception if service does not support FOLDER mode
      */
-    IO_BASE_API const std::filesystem::path& getFolder() const;
+    IO_BASE_API std::filesystem::path getFolder() const;
 
     /**
      * @brief Clear any location set by the setFile/setFiles/setFolder setter
@@ -141,20 +167,16 @@ public:
     IO_BASE_API void setFolder(const std::filesystem::path& folder);
 
     /**
-     * @brief Slot: Sets the folder when a path is configured in FILE or FILES mode
-     * This is ignored if a path is not configured
+     * @brief Slot: Inserts a path prefix generated via a signal sent to the service.
      *
-     * @pre exception if service does not support FILE or FILES mode
      */
-    IO_BASE_API void setFileFolder(std::filesystem::path folder);
+    IO_BASE_API void setPrefix(std::string prefix);
 
     /**
-     * @brief Slot: Sets a timestamp prefix on the output file name
-     * When this slot is first triggered, it will enable the addition of a timestamp prefix to the filename.
-     * At each update, the filename name will get the newest timestamp as prefix.
+     * @brief Slot: Sets the output base folder.
      *
      */
-    IO_BASE_API void setTimestampPrefix(core::HiResClock::HiResClockType timestamp);
+    IO_BASE_API void setBaseFolder(std::string path);
 
     /// Returns if a location has been defined ( by the configuration process or directly by user )
     IO_BASE_API bool hasLocationDefined() const;
@@ -167,9 +189,6 @@ public:
     {
         switch(policy)
         {
-            case DialogPolicy::NEVER:
-                return "never";
-
             case DialogPolicy::ONCE:
                 return "once";
 
@@ -177,41 +196,38 @@ public:
                 return "always";
 
             default:
-                return "default";
+                return "never";
         }
     }
 
     /// Convenience function to convert from string to DialogPolicy enum value
     constexpr static DialogPolicy stringToDialogPolicy(std::string_view policy) noexcept
     {
-        if(constexpr auto NEVER = dialogPolicyToString(DialogPolicy::NEVER); policy == NEVER)
+        if(constexpr auto NEVER = dialogPolicyToString(DialogPolicy::NEVER);
+           policy == NEVER || policy.empty() || policy == "default")
         {
             return DialogPolicy::NEVER;
         }
-        else if(constexpr auto ONCE = dialogPolicyToString(DialogPolicy::ONCE); policy == ONCE)
+
+        if(constexpr auto ONCE = dialogPolicyToString(DialogPolicy::ONCE); policy == ONCE)
         {
             return DialogPolicy::ONCE;
         }
-        else if(constexpr auto ALWAYS = dialogPolicyToString(DialogPolicy::ALWAYS); policy == ALWAYS)
+
+        if(constexpr auto ALWAYS = dialogPolicyToString(DialogPolicy::ALWAYS); policy == ALWAYS)
         {
             return DialogPolicy::ALWAYS;
         }
-        else if(policy.empty() || policy == "default")
-        {
-            return DialogPolicy::DEFAULT;
-        }
-        else
-        {
-            // Error case
-            return DialogPolicy::INVALID;
-        }
+
+        // Error case
+        return DialogPolicy::INVALID;
     }
 
 protected:
 
     IO_BASE_API IWriter() noexcept;
 
-    IO_BASE_API virtual ~IWriter() noexcept;
+    IO_BASE_API ~IWriter() noexcept override;
 
     /**
      * @brief This method proposes to parse xml configuration to retrieve
@@ -263,15 +279,19 @@ protected:
 
 private:
 
+    /// Triggers an update of the base folder, and outputs it via a reference.
+    // We need to check for potential updates, notably in the case
+    // where the user updates an associated preference during runtime.
+    void updateBaseFolder(std::string& /*outBaseFolder*/) const;
+
     /// Value to store file or folder paths
     io::base::service::LocationsType m_locations;
 
-    /// Value indicating whether we should append timestamps or not
-    bool m_useTimestampPrefix;
-    core::HiResClock::HiResClockType m_currentTimestamp;
+    /// Prefix to be inserted
+    std::string m_currentPrefix;
 
-    /// Value acting as a temporary location for timestamped path
-    mutable std::filesystem::path m_currentLocation;
+    /// Base folder
+    std::string m_baseFolder;
 };
 
 } //namespace sight::io::base::service
