@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,7 @@
 
 #include <filesystem>
 
-namespace sight::io::base
-{
-
-namespace writer
+namespace sight::io::base::writer
 {
 
 /**
@@ -59,7 +56,7 @@ public:
     IO_BASE_API GzBufferImageWriter(io::base::writer::IObjectWriter::Key key);
 
     /// Destructor. Does nothing.
-    IO_BASE_API virtual ~GzBufferImageWriter();
+    IO_BASE_API ~GzBufferImageWriter() override;
 
     /// Reads the file using the zlib API.
     IO_BASE_API void write() override;
@@ -68,6 +65,4 @@ public:
     IO_BASE_API std::string extension() const override;
 };
 
-} // namespace writer
-
-} // namespace sight::io::base
+} // namespace sight::io::base::writer
