@@ -28,13 +28,7 @@
 
 #include <gdcmDataSet.h>
 
-namespace sight::io::dicom
-{
-
-namespace container
-{
-
-namespace sr
+namespace sight::io::dicom::container::sr
 {
 
 /**
@@ -48,17 +42,13 @@ public:
     IO_DICOM_API DicomSRContainerNode(const DicomCodedAttribute& codedAttribute, const std::string& relationship = "");
 
     /// Destructor
-    IO_DICOM_API virtual ~DicomSRContainerNode();
+    IO_DICOM_API ~DicomSRContainerNode() override;
 
     /**
      * @brief Write the SR node in the dataset
      * @param[in] dataset Destination dataset
      */
-    IO_DICOM_API virtual void write(gdcm::DataSet& dataset) const;
+    IO_DICOM_API void write(gdcm::DataSet& dataset) const override;
 };
 
-} //namespace sr
-
-} //namespace container
-
-} //namespace sight::io::dicom
+} // namespace sight::io::dicom::container::sr
