@@ -28,13 +28,7 @@
 
 #include <gdcmDataSet.h>
 
-namespace sight::io::dicom
-{
-
-namespace container
-{
-
-namespace sr
+namespace sight::io::dicom::container::sr
 {
 
 /**
@@ -48,20 +42,20 @@ public:
     IO_DICOM_API DicomSRTextNode(
         const DicomCodedAttribute& codedAttribute,
         const std::string& relationship,
-        const std::string textValue
+        std::string textValue
     );
 
     /// Destructor
-    IO_DICOM_API virtual ~DicomSRTextNode();
+    IO_DICOM_API ~DicomSRTextNode() override;
 
     /**
      * @brief Write the SR node in the dataset
      * @param[in] dataset Destination dataset
      */
-    IO_DICOM_API virtual void write(gdcm::DataSet& dataset) const;
+    IO_DICOM_API void write(gdcm::DataSet& dataset) const override;
 
     /// Get Text value
-    const std::string& getTextValue() const
+    [[nodiscard]] const std::string& getTextValue() const
     {
         return m_textValue;
     }
@@ -75,14 +69,10 @@ public:
 protected:
 
     /// Dump function
-    virtual void print(std::ostream& os) const;
+    void print(std::ostream& os) const override;
 
     /// Text Value (0040, a160)
     std::string m_textValue;
 };
 
-} //namespace sr
-
-} //namespace container
-
-} //namespace sight::io::dicom
+} // namespace sight::io::dicom::container::sr
