@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,8 +30,8 @@
 #include <core/base.hpp>
 #include <core/jobs/IJob.hpp>
 #include <core/jobs/Observer.hpp>
-#include <core/runtime/operations.hpp>
-#include <core/tools/System.hpp>
+#include <core/os/TempPath.hpp>
+#include <core/runtime/path.hpp>
 
 #include <boost/algorithm/string/join.hpp>
 #include <boost/date_time/gregorian/gregorian.hpp>
@@ -42,16 +42,13 @@
 #include <gdcmReader.h>
 #include <gdcmUIDGenerator.h>
 #include <gdcmWriter.h>
-#include <time.h>
 
 #include <cstdint>
+#include <ctime>
 #include <filesystem>
 #include <iomanip>
 
-namespace sight::io::dicom
-{
-
-namespace helper
+namespace sight::io::dicom::helper
 {
 
 const std::string c_MIN_DATE_STRING = "19000101";
@@ -61,8 +58,6 @@ gdcm::UIDGenerator GENERATOR;
 DicomAnonymizer::DicomAnonymizer() :
     m_publicDictionary(gdcm::Global::GetInstance().GetDicts().GetPublicDict()),
     m_observer(core::jobs::Observer::New("Anonymization process")),
-    m_archiving(false),
-    m_fileIndex(0),
     m_referenceDate(boost::gregorian::from_undelimited_string(c_MIN_DATE_STRING))
 {
     const std::filesystem::path tagsPath = core::runtime::getLibraryResourceFilePath(
@@ -127,8 +122,7 @@ DicomAnonymizer::DicomAnonymizer() :
 //------------------------------------------------------------------------------
 
 DicomAnonymizer::~DicomAnonymizer()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -249,8 +243,7 @@ const DicomAnonymizer::TagContainerType& DicomAnonymizer::getActionCodeUTags()
 void DicomAnonymizer::anonymizationProcess(const std::filesystem::path& dirPath)
 {
     // Create temporary directory
-    std::filesystem::path tmpPath = core::tools::System::getTemporaryFolder("DicomAnonymizer");
-    tmpPath /= "tmp";
+    core::os::TempDir tmpPath;
 
     // Doesn't use std::filesystem::rename because of potential issues when moving folders across volumes
     moveDirectory(dirPath, tmpPath);
@@ -289,8 +282,8 @@ void DicomAnonymizer::anonymizationProcess(const std::filesystem::path& dirPath)
 
         this->anonymize(inStream, outStream);
 
-        std::uint64_t progress = static_cast<std::uint64_t>(
-            ((m_archiving) ? 50 : 100) * static_cast<float>(fileIndex) / static_cast<float>(dicomFiles.size()));
+        auto progress = static_cast<std::uint64_t>(
+            ((m_archiving) ? 50.F : 100.F) * static_cast<float>(fileIndex) / static_cast<float>(dicomFiles.size()));
         m_observer->doneWork(progress);
     }
 }
@@ -322,7 +315,6 @@ void DicomAnonymizer::anonymize(std::istream& inputStream, std::ostream& outputS
     m_stringFilter.SetFile(reader.GetFile());
 
     // Objects used to scan groups of elements
-    gdcm::Tag tag;
     gdcm::DataElement dataElement;
     const gdcm::File& datasetFile = reader.GetFile();
     gdcm::DataSet dataset         = datasetFile.GetDataSet();
@@ -341,7 +333,7 @@ void DicomAnonymizer::anonymize(std::istream& inputStream, std::ostream& outputS
     m_anonymizer.RemoveGroupLength();
     m_anonymizer.RemoveRetired();
 
-    for(ExceptionTagMapType::value_type exception : m_exceptionTagMap)
+    for(const ExceptionTagMapType::value_type& exception : m_exceptionTagMap)
     {
         m_anonymizer.Replace(exception.first, exception.second.c_str());
     }
@@ -374,7 +366,7 @@ void DicomAnonymizer::anonymize(std::istream& inputStream, std::ostream& outputS
 
     for(const auto& tag : m_actionCodeCTags)
     {
-        this->applyActionCodeC(tag);
+        sight::io::dicom::helper::DicomAnonymizer::applyActionCodeC(tag);
     }
 
     for(const auto& tag : m_actionCodeUTags)
@@ -391,6 +383,7 @@ void DicomAnonymizer::anonymize(std::istream& inputStream, std::ostream& outputS
                                          };
 
     const auto dataElementSet = dataset.GetDES();
+    gdcm::Tag tag;
 
     // Curve Data (0x50xx,0xxxxx)
     auto element = dataElementSet.lower_bound(gdcm::Tag(0x5000, 0x0));
@@ -499,7 +492,7 @@ void DicomAnonymizer::applyActionCodeK(const gdcm::Tag& tag)
 
 //------------------------------------------------------------------------------
 
-void DicomAnonymizer::applyActionCodeC(const gdcm::Tag& tag)
+void DicomAnonymizer::applyActionCodeC(const gdcm::Tag& /*tag*/)
 {
     SIGHT_FATAL(
         "Basic profile \"C\" is not supported yet: "
@@ -606,21 +599,12 @@ void DicomAnonymizer::generateDummyValue(const gdcm::Tag& tag)
             break;
 
         case gdcm::VR::FD:
-            m_anonymizer.Replace(tag, "0");
-            break;
-
         case gdcm::VR::FL:
-            m_anonymizer.Replace(tag, "0");
-            break;
-
         case gdcm::VR::IS:
             m_anonymizer.Replace(tag, "0");
             break;
 
         case gdcm::VR::LO:
-            m_anonymizer.Replace(tag, "ANONYMIZED");
-            break;
-
         case gdcm::VR::LT:
             m_anonymizer.Replace(tag, "ANONYMIZED");
             break;
@@ -630,9 +614,6 @@ void DicomAnonymizer::generateDummyValue(const gdcm::Tag& tag)
             break;
 
         case gdcm::VR::OF:
-            m_anonymizer.Replace(tag, "0");
-            break;
-
         case gdcm::VR::OW:
             m_anonymizer.Replace(tag, "0");
             break;
@@ -751,6 +732,4 @@ SPTR(core::jobs::IJob) DicomAnonymizer::getJob() const
 
 //------------------------------------------------------------------------------
 
-} // namespace helper
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::helper
