@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,26 +36,23 @@ namespace sight::core::jobs
 class Observer;
 class IJob;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::data
 {
 
 class DicomSeries;
 
-}
+} // namespace sight::data
 
 namespace sight::io::zip
 {
 
 class IWriteArchive;
 
-}
+} // namespace sight::io::zip
 
-namespace sight::io::dicom
-{
-
-namespace helper
+namespace sight::io::dicom::helper
 {
 
 class DicomAnonymizer;
@@ -69,8 +66,8 @@ class DicomAnonymizer;
  * If the DicomSeries contains the binaries of the DICOM files, the files are extracted (or zipped).
  * If the DicomSeries contains the paths of the DICOM files, a simple copy (or zip) is performed.
  */
-class DicomSeriesWriter : public io::base::writer::GenericObjectWriter<data::DicomSeries>,
-                          public core::location::SingleFolder
+class IO_DICOM_CLASS_API DicomSeriesWriter : public io::base::writer::GenericObjectWriter<data::DicomSeries>,
+                                             public core::location::SingleFolder
 {
 public:
 
@@ -123,7 +120,7 @@ protected:
     void processWrite();
 
     /// Write count
-    int m_writeCount;
+    int m_writeCount {0};
 
     /// Job observer
     SPTR(core::jobs::Observer) m_job;
@@ -138,6 +135,4 @@ protected:
     std::string m_subPath;
 };
 
-} // namespace helper
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::helper
