@@ -29,10 +29,7 @@
 #include <boost/algorithm/string/split.hpp>
 #include <boost/locale/encoding.hpp>
 
-namespace sight::io::dicom
-{
-
-namespace helper
+namespace sight::io::dicom::helper
 {
 
 const Encoding::DefinedTermToCharsetMapType Encoding::s_DEFINED_TERM_TO_CHARSET = {
@@ -107,20 +104,20 @@ const Encoding::DefinedTermToCharsetMapType Encoding::s_DEFINED_TERM_TO_CHARSET
 };
 
 const Encoding::EscapeSequenceToCharsetMapType Encoding::s_ESCAPE_SEQUENCE_TO_CHARSET = {
-    {{0x28, 0x42}, {"ISO 2022 IR 6", ""}},             // ASCII
-    {{0x2d, 0x41}, {"ISO 2022 IR 100", "ISO-8859-1"}}, // Latin alphabet No. 1
-    {{0x2d, 0x42}, {"ISO 2022 IR 101", "ISO-8859-2"}}, // Latin alphabet No. 2
-    {{0x2d, 0x43}, {"ISO 2022 IR 109", "ISO-8859-3"}}, // Latin alphabet No. 3
-    {{0x2d, 0x44}, {"ISO 2022 IR 110", "ISO-8859-4"}}, // Latin alphabet No. 4
-    {{0x2d, 0x4c}, {"ISO 2022 IR 144", "ISO-8859-5"}}, // Cyrillic
-    {{0x2d, 0x47}, {"ISO 2022 IR 127", "ISO-8859-6"}}, // Arabic
-    {{0x2d, 0x46}, {"ISO 2022 IR 126", "ISO-8859-7"}}, // Greek
-    {{0x2d, 0x48}, {"ISO 2022 IR 138", "ISO-8859-8"}}, // Hebrew
-    {{0x2d, 0x4d}, {"ISO 2022 IR 148", "ISO-8859-9"}}, // Latin alphabet No. 5
-    {{0x29, 0x49}, {"ISO 2022 IR 13", "JIS_X0201"}},   // Japanese { may require "ISO-IR-13"}
-    {{0x28, 0x4a}, {"ISO 2022 IR 13", "ISO-IR-14"}},   // Japanese
-    {{0x2d, 0x54}, {"ISO 2022 IR 166", "ISO-IR-166"}}, // Thai
-    {{0x24, 0x42}, {"ISO 2022 IR 87", "ISO-IR-87"}} // Japanese { multi-byte}
+    {{char(0x28), char(0x42)}, {"ISO 2022 IR 6", ""}},             // ASCII
+    {{char(0x2d), char(0x41)}, {"ISO 2022 IR 100", "ISO-8859-1"}}, // Latin alphabet No. 1
+    {{char(0x2d), char(0x42)}, {"ISO 2022 IR 101", "ISO-8859-2"}}, // Latin alphabet No. 2
+    {{char(0x2d), char(0x43)}, {"ISO 2022 IR 109", "ISO-8859-3"}}, // Latin alphabet No. 3
+    {{char(0x2d), char(0x44)}, {"ISO 2022 IR 110", "ISO-8859-4"}}, // Latin alphabet No. 4
+    {{char(0x2d), char(0x4c)}, {"ISO 2022 IR 144", "ISO-8859-5"}}, // Cyrillic
+    {{char(0x2d), char(0x47)}, {"ISO 2022 IR 127", "ISO-8859-6"}}, // Arabic
+    {{char(0x2d), char(0x46)}, {"ISO 2022 IR 126", "ISO-8859-7"}}, // Greek
+    {{char(0x2d), char(0x48)}, {"ISO 2022 IR 138", "ISO-8859-8"}}, // Hebrew
+    {{char(0x2d), char(0x4d)}, {"ISO 2022 IR 148", "ISO-8859-9"}}, // Latin alphabet No. 5
+    {{char(0x29), char(0x49)}, {"ISO 2022 IR 13", "JIS_X0201"}},   // Japanese { may require "ISO-IR-13"}
+    {{char(0x28), char(0x4a)}, {"ISO 2022 IR 13", "ISO-IR-14"}},   // Japanese
+    {{char(0x2d), char(0x54)}, {"ISO 2022 IR 166", "ISO-IR-166"}}, // Thai
+    {{char(0x24), char(0x42)}, {"ISO 2022 IR 87", "ISO-IR-87"}} // Japanese { multi-byte}
 };
 
 //------------------------------------------------------------------------------
@@ -145,41 +142,40 @@ std::string Encoding::convertString(
     {
         return convertStringWithoutCodeExtensions(source, definedCharsetTerm, logger);
     }
+
     // Several charsets with code extension techniques are used
+
+    // If the attribute Specific Character Set (0008,0005) has more than one value
+    // and value 1 is empty, it is assumed that value 1 is ISO 2022 IR 6.
+    if(definedTermList[0].empty())
+    {
+        definedTermList[0] = "ISO 2022 IR 6";
+    }
+
+    // Check for characters ESC delimiter
+    std::vector<std::string> sequenceList;
+    boost::split(sequenceList, source, boost::is_any_of("\033"));
+
+    std::string result;
+
+    // Add the first part
+    if(source[0] != '\033')
+    {
+        result += convertStringWithoutCodeExtensions(sequenceList[0], definedTermList[0], logger);
+    }
     else
     {
-        // If the attribute Specific Character Set (0008,0005) has more than one value
-        // and value 1 is empty, it is assumed that value 1 is ISO 2022 IR 6.
-        if(definedTermList[0].empty())
-        {
-            definedTermList[0] = "ISO 2022 IR 6";
-        }
-
-        // Check for characters ESC delimiter
-        std::vector<std::string> sequenceList;
-        boost::split(sequenceList, source, boost::is_any_of("\033"));
-
-        std::string result;
-
-        // Add the first part
-        if(source[0] != '\033')
-        {
-            result += convertStringWithoutCodeExtensions(sequenceList[0], definedTermList[0], logger);
-        }
-        else
-        {
-            result += Encoding::convertSequenceWithCodeExtensions(sequenceList[0], definedTermList, logger);
-        }
-
-        // Convert remaining sequences according to specific charsets
-        std::vector<std::string>::iterator it = ++sequenceList.begin();
-        for( ; it != sequenceList.end() ; ++it)
-        {
-            result += convertSequenceWithCodeExtensions(*it, definedTermList, logger);
-        }
-
-        return result;
+        result += Encoding::convertSequenceWithCodeExtensions(sequenceList[0], definedTermList, logger);
     }
+
+    // Convert remaining sequences according to specific charsets
+    auto it = ++sequenceList.begin();
+    for( ; it != sequenceList.end() ; ++it)
+    {
+        result += convertSequenceWithCodeExtensions(*it, definedTermList, logger);
+    }
+
+    return result;
 }
 
 //------------------------------------------------------------------------------
@@ -228,10 +224,8 @@ std::string Encoding::convertStringWithoutCodeExtensions(
     {
         return source;
     }
-    else
-    {
-        return boost::locale::conv::to_utf<char>(source, charset);
-    }
+
+    return boost::locale::conv::to_utf<char>(source, charset);
 }
 
 //------------------------------------------------------------------------------
@@ -269,7 +263,7 @@ std::string Encoding::convertSequenceWithCodeExtensions(
     const char c1 = sequence[0];
     const char c2 = sequence[1];
 
-    unsigned short escapeSize = 2;
+    std::uint16_t escapeSize = 2;
 
     EscapeSequenceType escapeSequence                   = std::make_pair(c1, c2);
     DefinedTermAndCharsetPairType definedTermAndCharset = std::make_pair("", "");
@@ -320,14 +314,10 @@ std::string Encoding::convertSequenceWithCodeExtensions(
     {
         return sequence.substr(escapeSize);
     }
-    else
-    {
-        return boost::locale::conv::to_utf<char>(sequence.substr(escapeSize), definedTermAndCharset.second);
-    }
+
+    return boost::locale::conv::to_utf<char>(sequence.substr(escapeSize), definedTermAndCharset.second);
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace helper
-
-} //namespace sight::io::dicom
+} // namespace sight::io::dicom::helper
