@@ -32,33 +32,24 @@
 #include <data/Image.hpp>
 #include <data/ImageSeries.hpp>
 #include <data/ModelSeries.hpp>
-#include <data/SeriesDB.hpp>
-#include <data/Study.hpp>
-
-#include <boost/algorithm/string/classification.hpp>
-#include <boost/algorithm/string/split.hpp>
 
 #include <gdcmImageReader.h>
 #include <gdcmScanner.h>
 
-namespace sight::io::dicom
-{
+#include <memory>
 
-namespace reader
+namespace sight::io::dicom::reader
 {
 
 //------------------------------------------------------------------------------
 
-Series::Series() :
-    m_enableBufferRotation(true)
-{
-}
+Series::Series()
+= default;
 
 //------------------------------------------------------------------------------
 
 Series::~Series()
-{
-}
+= default;
 
 // ----------------------------------------------------------------------------
 
@@ -87,8 +78,6 @@ data::Series::sptr Series::read(const data::DicomSeries::csptr& dicomSeries)
             // Read the image
             data::ImageSeries::sptr imageSeries = data::dicom::Series::convertToImageSeries(dicomSeries);
             imageSeries->setDicomReference(dicomSeries);
-            data::Image::sptr image = data::Image::New();
-            imageSeries->setImage(image);
 
             // Create IOD Reader
             io::dicom::reader::iod::CTMRImageIOD iod(dicomSeries, instance, m_logger,
@@ -164,7 +153,7 @@ data::Series::sptr Series::read(const data::DicomSeries::csptr& dicomSeries)
             else
             {
                 m_logger->critical(
-                    "The spatial fiducials series \"" + dicomSeries->getInstanceUID()
+                    "The spatial fiducials series \"" + dicomSeries->getSeriesInstanceUID()
                     + "\" could not be read as it refers to an unknown series UID."
                 );
             }
@@ -208,7 +197,7 @@ data::Series::sptr Series::read(const data::DicomSeries::csptr& dicomSeries)
             else
             {
                 m_logger->critical(
-                    "The structured report series \"" + dicomSeries->getInstanceUID()
+                    "The structured report series \"" + dicomSeries->getSeriesInstanceUID()
                     + "\" could not be read as it refers to an unknown series UID."
                 );
             }
@@ -241,14 +230,14 @@ SPTR(io::dicom::container::DicomInstance) Series::getSpatialFiducialsReferencedS
 
     // Create Reader
     std::shared_ptr<gdcm::Reader> reader =
-        std::shared_ptr<gdcm::Reader>(new gdcm::Reader);
+        std::make_shared<gdcm::Reader>();
     const core::memory::BufferObject::sptr bufferObj         = dicomContainer.begin()->second;
     const core::memory::BufferManager::StreamInfo streamInfo = bufferObj->getStreamInfo();
     SPTR(std::istream) is = streamInfo.stream;
     reader->SetStream(*is);
 
     // Series Instance UID of the referenced Series
-    std::string seriesInstanceUID = "";
+    std::string seriesInstanceUID;
 
     if(reader->Read())
     {
@@ -275,7 +264,7 @@ SPTR(io::dicom::container::DicomInstance) Series::getSpatialFiducialsReferencedS
 
     if(!seriesInstanceUID.empty())
     {
-        for(SeriesContainerMapType::value_type v : m_seriesContainerMap)
+        for(const SeriesContainerMapType::value_type& v : m_seriesContainerMap)
         {
             if(v.first->getSeriesInstanceUID() == seriesInstanceUID)
             {
@@ -301,14 +290,14 @@ SPTR(io::dicom::container::DicomInstance) Series::getStructuredReportReferencedS
 
     // Create Reader
     std::shared_ptr<gdcm::Reader> reader =
-        std::shared_ptr<gdcm::Reader>(new gdcm::Reader);
+        std::make_shared<gdcm::Reader>();
     const core::memory::BufferObject::sptr bufferObj         = dicomContainer.begin()->second;
     const core::memory::BufferManager::StreamInfo streamInfo = bufferObj->getStreamInfo();
     SPTR(std::istream) is = streamInfo.stream;
     reader->SetStream(*is);
 
     // Series Instance UID of the referenced Series
-    std::string seriesInstanceUID = "";
+    std::string seriesInstanceUID;
 
     if(reader->Read())
     {
@@ -348,7 +337,7 @@ SPTR(io::dicom::container::DicomInstance) Series::getStructuredReportReferencedS
 
     if(!seriesInstanceUID.empty())
     {
-        for(SeriesContainerMapType::value_type v : m_seriesContainerMap)
+        for(const SeriesContainerMapType::value_type& v : m_seriesContainerMap)
         {
             if(v.first->getSeriesInstanceUID() == seriesInstanceUID)
             {
@@ -362,6 +351,4 @@ SPTR(io::dicom::container::DicomInstance) Series::getStructuredReportReferencedS
 }
 //------------------------------------------------------------------------------
 
-} // namespace reader
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::reader
