@@ -25,15 +25,8 @@
 #include "io/dicom/helper/DicomDataReader.hxx"
 
 #include <data/DicomSeries.hpp>
-#include <data/Patient.hpp>
 
-namespace sight::io::dicom
-{
-
-namespace reader
-{
-
-namespace ie
+namespace sight::io::dicom::reader::ie
 {
 
 //------------------------------------------------------------------------------
@@ -42,21 +35,20 @@ Patient::Patient(
     const data::DicomSeries::csptr& dicomSeries,
     const SPTR(gdcm::Reader)& reader,
     const io::dicom::container::DicomInstance::sptr& instance,
-    const data::Patient::sptr& patient,
+    const data::Series::sptr& series,
     const core::log::Logger::sptr& logger,
     ProgressCallback progress,
     CancelRequestedCallback cancel
 ) :
-    io::dicom::reader::ie::InformationEntity<data::Patient>(dicomSeries, reader, instance, patient, logger,
-                                                            progress, cancel)
+    io::dicom::reader::ie::InformationEntity<data::Series>(dicomSeries, reader, instance, series, logger,
+                                                           progress, cancel)
 {
 }
 
 //------------------------------------------------------------------------------
 
 Patient::~Patient()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -68,26 +60,22 @@ void Patient::readPatientModule()
     // Patient's name - Type 2
     const std::string& patientName =
         io::dicom::helper::DicomDataReader::getTagValue<0x0010, 0x0010>(dataset);
-    m_object->setName(patientName);
+    m_object->setPatientName(patientName);
 
     // Patient's ID - Type 2
     const std::string& patientId =
         io::dicom::helper::DicomDataReader::getTagValue<0x0010, 0x0020>(dataset);
-    m_object->setPatientId(patientId);
+    m_object->setPatientID(patientId);
 
     // Patient's birth date - Type 2
-    const std::string& birthDate =
+    const std::string& patientBirthDate =
         io::dicom::helper::DicomDataReader::getTagValue<0x0010, 0x0030>(dataset);
-    m_object->setBirthdate(birthDate);
+    m_object->setPatientBirthDate(patientBirthDate);
 
     // Patient's sex - Type 2
-    const std::string& sex =
+    const std::string& patientSex =
         io::dicom::helper::DicomDataReader::getTagValue<0x0010, 0x0040>(dataset);
-    m_object->setSex(sex);
+    m_object->setPatientSex(patientSex);
 }
 
-} // namespace ie
-
-} // namespace reader
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::reader::ie
