@@ -24,21 +24,15 @@
 
 #include "io/dicom/reader/ie/InformationEntity.hpp"
 
-#include <data/Patient.hpp>
+#include <data/Series.hpp>
 
-namespace sight::io::dicom
-{
-
-namespace reader
-{
-
-namespace ie
+namespace sight::io::dicom::reader::ie
 {
 
 /**
  * @brief Patient Information Entity class
  */
-class IO_DICOM_CLASS_API Patient : public io::dicom::reader::ie::InformationEntity<data::Patient>
+class IO_DICOM_CLASS_API Patient : public io::dicom::reader::ie::InformationEntity<data::Series>
 {
 public:
 
@@ -47,7 +41,7 @@ public:
      * @param[in] dicomSeries DicomSeries used to access computed tag values.
      * @param[in] reader GDCM reader that must be used to read patient.
      * @param[in] instance DICOM instance used to share informations between modules
-     * @param[in] patient Patient data
+     * @param[in] Series Patient data
      * @param[in] logger Logger
      * @param[in] progress Progress callback
      * @param[in] cancel Cancel requested callback
@@ -56,14 +50,14 @@ public:
         const CSPTR(data::DicomSeries)& dicomSeries,
         const SPTR(gdcm::Reader)& reader,
         const SPTR(io::dicom::container::DicomInstance)& instance,
-        const data::Patient::sptr& patient,
+        const data::Series::sptr& series,
         const core::log::Logger::sptr& logger = nullptr,
         ProgressCallback progress             = nullptr,
         CancelRequestedCallback cancel        = nullptr
     );
 
     /// Destructor
-    IO_DICOM_API virtual ~Patient();
+    IO_DICOM_API ~Patient() override;
 
     /**
      * @brief Read Patient Module tags
@@ -72,8 +66,4 @@ public:
     IO_DICOM_API virtual void readPatientModule();
 };
 
-} // namespace ie
-
-} // namespace reader
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::reader::ie
