@@ -42,13 +42,7 @@
 
 #include <sstream>
 
-namespace sight::io::dicom
-{
-
-namespace reader
-{
-
-namespace ie
+namespace sight::io::dicom::reader::ie
 {
 
 //------------------------------------------------------------------------------
@@ -70,8 +64,7 @@ Surface::Surface(
 //------------------------------------------------------------------------------
 
 Surface::~Surface()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -251,10 +244,9 @@ void Surface::readSurfaceSegmentationModule(
 
     // Computed Mask Volume (0x5649, 0x1001)
     const gdcm::Tag computedMaskVolumeTag(0x5649, 0x1001);
-    privateCreator = gdcm::LOComp::Trim(segmentDataset.GetPrivateCreator(computedMaskVolumeTag).c_str());
     if(segmentDataset.FindDataElement(computedMaskVolumeTag))
     {
-        gdcm::Attribute<0x5649, 0x1001, gdcm::VR::OD, gdcm::VM::VM1> attribute;
+        gdcm::Attribute<0x5649, 0x1001, gdcm::VR::OD, gdcm::VM::VM1> attribute {};
         attribute.SetFromDataSet(segmentDataset);
         const double volume = attribute.GetValue();
         reconstruction->setComputedMaskVolume(volume);
@@ -276,8 +268,8 @@ void Surface::readSurfaceMeshModule(
     data::Material::sptr material = data::Material::New();
 
     // Convert CIE Lab to RGBA
-    const unsigned short* lab = surface->GetRecommendedDisplayCIELabValue();
-    gdcm::SurfaceHelper::ColorArray CIELab(lab, lab + sizeof(lab) / sizeof(unsigned short));
+    const std::uint16_t* lab = surface->GetRecommendedDisplayCIELabValue();
+    gdcm::SurfaceHelper::ColorArray CIELab(lab, lab + 3);
     std::vector<float> colorVector = gdcm::SurfaceHelper::RecommendedDisplayCIELabToRGB(CIELab, 1);
 
     // Recommended Presentation Opacity
@@ -285,7 +277,7 @@ void Surface::readSurfaceMeshModule(
 
     // Adapt color to material
     data::Color::ColorArray rgba;
-    boost::algorithm::clamp_range(colorVector.begin(), colorVector.end(), rgba.begin(), 0.f, 1.f);
+    boost::algorithm::clamp_range(colorVector.begin(), colorVector.end(), rgba.begin(), 0.F, 1.F);
 
     // Set reconstruction's visibility
     const double epsilon = 1e-3;
@@ -316,7 +308,7 @@ void Surface::readSurfaceMeshModule(
 
     // Point Coordinates Data
     const gdcm::ByteValue* pointCoordinates = surface->GetPointCoordinatesData().GetByteValue();
-    if(!pointCoordinates || !pointCoordinates->GetPointer())
+    if((pointCoordinates == nullptr) || (pointCoordinates->GetPointer() == nullptr))
     {
         throw io::dicom::exception::Failed("No point coordinates data found.");
     }
@@ -330,19 +322,16 @@ void Surface::readSurfaceMeshModule(
 
     // Surface Points Normals
     const gdcm::ByteValue* normalCoordinates = surface->GetVectorCoordinateData().GetByteValue();
-    const char* normalCoordinatesPointer     = nullptr;
     if(!surface->GetVectorCoordinateData().IsEmpty())
     {
         // Check that the surface contains normals
-        if(!normalCoordinates || !normalCoordinates->GetPointer())
+        if((normalCoordinates == nullptr) || (normalCoordinates->GetPointer() == nullptr))
         {
             throw io::dicom::exception::Failed("No normal coordinates data found.");
         }
 
-        normalCoordinatesPointer = normalCoordinates->GetPointer();
-
         // Compute number of normal coordinates
-        const unsigned long normalCoordinateSize = normalCoordinates->GetLength() / sizeof(float);
+        const std::uint64_t normalCoordinateSize = normalCoordinates->GetLength() / sizeof(float);
         if((normalCoordinateSize / 3) != surface->GetNumberOfVectors() || normalCoordinateSize != pointCoordinatesSize)
         {
             throw io::dicom::exception::Failed("Normal coordinates data are corrupted.");
@@ -351,20 +340,22 @@ void Surface::readSurfaceMeshModule(
 
     // Triangle Point Index List
     const gdcm::ByteValue* pointIndices = meshPrimitive->GetPrimitiveData().GetByteValue();
-    if(!pointIndices || !pointIndices->GetPointer())
+    if((pointIndices == nullptr) || (pointIndices->GetPointer() == nullptr))
     {
         throw io::dicom::exception::Failed("No triangle point index list found.");
     }
 
     // Get number of primitives
-    const unsigned long indexSize = pointIndices->GetLength() / sizeof(uint32_t);
+    const std::uint64_t indexSize = pointIndices->GetLength() / sizeof(uint32_t);
 
     // Create a new Mesh
     io::dicom::container::DicomSurface surfaceContainer(reinterpret_cast<const float*>(pointCoordinates->GetPointer()),
-                                                        pointCoordinatesSize,
+                                                        data::Mesh::size_t(pointCoordinatesSize),
                                                         reinterpret_cast<const uint32_t*>(pointIndices->GetPointer()),
-                                                        indexSize,
-                                                        reinterpret_cast<const float*>(normalCoordinatesPointer));
+                                                        data::Mesh::size_t(indexSize),
+                                                        surface->GetVectorCoordinateData().IsEmpty() ? nullptr
+                                                                                                     : reinterpret_cast<
+                                                            const float*>(normalCoordinates->GetPointer()));
 
     // Set the reconstruction
     reconstruction->setMaterial(material);
@@ -373,8 +364,4 @@ void Surface::readSurfaceMeshModule(
 
 //------------------------------------------------------------------------------
 
-} // namespace ie
-
-} // namespace reader
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::reader::ie
