@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,14 +33,10 @@
 #include <utestData/Data.hpp>
 
 #include <boost/algorithm/string/replace.hpp>
-#include <boost/foreach.hpp>
 
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::io::dicom::ut::DicomDirTest);
 
-namespace sight::io::dicom
-{
-
-namespace ut
+namespace sight::io::dicom::ut
 {
 
 //------------------------------------------------------------------------------
@@ -83,21 +79,18 @@ void DicomDirTest::readDicomDir()
         std::filesystem::exists(path)
     );
 
-    std::vector<data::DicomSeries::sptr> seriesDB;
+    std::vector<data::DicomSeries::sptr> seriesContainer;
 
     core::log::Logger::sptr logger = core::log::Logger::New();
 
     // Read DICOMDIR file
-    io::dicom::helper::DicomDir::retrieveDicomSeries(path / "DICOMDIR", seriesDB, logger);
-    CPPUNIT_ASSERT_EQUAL(std::size_t(1), seriesDB.size());
+    io::dicom::helper::DicomDir::retrieveDicomSeries(path / "DICOMDIR", seriesContainer, logger);
+    CPPUNIT_ASSERT_EQUAL(std::size_t(1), seriesContainer.size());
     CPPUNIT_ASSERT(logger->empty());
 
-    auto series = *seriesDB.begin();
-    CPPUNIT_ASSERT_EQUAL(std::size_t(84), series->getDicomContainer().size());
+    CPPUNIT_ASSERT_EQUAL(std::size_t(84), seriesContainer.front()->getDicomContainer().size());
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace ut
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::ut
