@@ -24,15 +24,10 @@
 
 #include "io/dicom/helper/DicomDataWriter.hxx"
 
-#include <data/Study.hpp>
+#include <array>
+#include <utility>
 
-namespace sight::io::dicom
-{
-
-namespace writer
-{
-
-namespace ie
+namespace sight::io::dicom::writer::ie
 {
 
 //------------------------------------------------------------------------------
@@ -40,21 +35,20 @@ namespace ie
 Study::Study(
     const SPTR(gdcm::Writer)& writer,
     const SPTR(io::dicom::container::DicomInstance)& instance,
-    const data::Study::csptr& study,
+    const data::Series::csptr& series,
     const core::log::Logger::sptr& logger,
     ProgressCallback progress,
     CancelRequestedCallback cancel
 ) :
-    io::dicom::writer::ie::InformationEntity<data::Study>(writer, instance, study,
-                                                          logger, progress, cancel)
+    io::dicom::writer::ie::InformationEntity<data::Series>(writer, instance, series,
+                                                           logger, progress, cancel)
 {
 }
 
 //------------------------------------------------------------------------------
 
 Study::~Study()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -63,22 +57,12 @@ void Study::writeGeneralStudyModule()
     // Retrieve dataset
     gdcm::DataSet& dataset = m_writer->GetFile().GetDataSet();
 
-    io::dicom::helper::DicomDataWriter::setTagValue<0x0020, 0x000d>(m_object->getInstanceUID(), dataset);
+    io::dicom::helper::DicomDataWriter::setTagValue<0x0020, 0x000d>(m_object->getStudyInstanceUID(), dataset);
     io::dicom::helper::DicomDataWriter::setTagValue<0x0020, 0x0010>(m_object->getStudyID(), dataset);
-    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0020>(m_object->getDate(), dataset);
-    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0030>(m_object->getTime(), dataset);
+    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0020>(m_object->getStudyDate(), dataset);
+    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0030>(m_object->getStudyTime(), dataset);
     io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0090>(m_object->getReferringPhysicianName(), dataset);
-
-    //TODO: >getConsultingPhysicianName() contains only 1 value, gdcm wants a list (VM : 1-N).
-    gdcm::String<> consultingPhysicianName[] = {m_object->getConsultingPhysicianName()};
-
-    io::dicom::helper::DicomDataWriter::setTagValues<gdcm::String<>, 0x0008, 0x009C>(
-        consultingPhysicianName,
-        1,
-        dataset
-    );
-    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x1030>(m_object->getDescription(), dataset);
-
+    io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x1030>(m_object->getStudyDescription(), dataset);
     // Study 's accession number - Type 2
     io::dicom::helper::DicomDataWriter::setTagValue<0x0008, 0x0050>("", dataset);
 }
@@ -91,26 +75,18 @@ void Study::writePatientStudyModule()
     gdcm::DataSet& dataset = m_writer->GetFile().GetDataSet();
 
     io::dicom::helper::DicomDataWriter::setTagValue<0x0010, 0x1010>(m_object->getPatientAge(), dataset);
-    // Following tags are represented as Decimal String, in GDCM DS = Double.
-    // To avoid exception of stod, we need to test first if string is empty.
-    io::dicom::helper::DicomDataWriter::setTagValue<double, 0x0010, 0x1020>(
-        m_object->getPatientSize().empty() ? 0. : std::stod(m_object->getPatientSize()),
-        dataset
-    );
-    io::dicom::helper::DicomDataWriter::setTagValue<double, 0x0010, 0x1030>(
-        m_object->getPatientWeight().empty() ? 0. : std::stod(m_object->getPatientWeight()),
-        dataset
-    );
-    io::dicom::helper::DicomDataWriter::setTagValue<double, 0x0010, 0x1022>(
-        m_object->getPatientBodyMassIndex().empty() ? 0. : std::stod(m_object->getPatientBodyMassIndex()),
-        dataset
-    );
+
+    if(const auto& patientSize = m_object->getPatientSize(); patientSize)
+    {
+        io::dicom::helper::DicomDataWriter::setTagValue<double, 0x0010, 0x1020>(*patientSize, dataset);
+    }
+
+    if(const auto& patientWeight = m_object->getPatientWeight(); patientWeight)
+    {
+        io::dicom::helper::DicomDataWriter::setTagValue<double, 0x0010, 0x1030>(*patientWeight, dataset);
+    }
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace ie
-
-} // namespace writer
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::writer::ie
