@@ -32,8 +32,6 @@
 #include "io/dicom/container/sr/DicomSRUIDRefNode.hpp"
 #include "io/dicom/helper/DicomDataTools.hpp"
 
-#include <core/tools/Stringizer.hpp>
-
 #include <data/helper/MedicalImage.hpp>
 #include <data/PointList.hpp>
 #include <data/Series.hpp>
@@ -45,13 +43,7 @@
 
 #include <sstream>
 
-namespace sight::io::dicom
-{
-
-namespace writer
-{
-
-namespace tid
+namespace sight::io::dicom::writer::tid
 {
 
 //------------------------------------------------------------------------------
@@ -68,8 +60,7 @@ Measurement::Measurement(
 //------------------------------------------------------------------------------
 
 Measurement::~Measurement()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -82,7 +73,7 @@ void Measurement::createNodes(
     if(distanceVector)
     {
         unsigned int id = 1;
-        for(data::Object::sptr object : distanceVector->getContainer())
+        for(const data::Object::sptr& object : *distanceVector)
         {
             data::PointList::sptr pointList = data::PointList::dynamicCast(object);
             if(pointList)
@@ -98,20 +89,21 @@ void Measurement::createNodes(
 void Measurement::createMeasurement(
     const SPTR(io::dicom::container::sr::DicomSRNode)& parent,
     const data::PointList::csptr& pointList,
-    unsigned int id,
+    unsigned int /*id*/,
     bool useSCoord3D
 )
 {
     const data::Point::sptr point1 = pointList->getPoints()[0];
     const data::Point::sptr point2 = pointList->getPoints()[1];
 
-    double coordinates[6];
-    coordinates[0] = point1->getCoord()[0];
-    coordinates[1] = point1->getCoord()[1];
-    coordinates[2] = point1->getCoord()[2];
-    coordinates[3] = point2->getCoord()[0];
-    coordinates[4] = point2->getCoord()[1];
-    coordinates[5] = point2->getCoord()[2];
+    std::array coordinates {
+        point1->getCoord()[0],
+        point1->getCoord()[1],
+        point1->getCoord()[2],
+        point2->getCoord()[0],
+        point2->getCoord()[1],
+        point2->getCoord()[2]
+    };
 
     const double distance = sqrt(
         (coordinates[0] - coordinates[3]) * (coordinates[0] - coordinates[3])
@@ -136,7 +128,7 @@ void Measurement::createMeasurement(
     if(useSCoord3D)
     {
         // Create SCoord Node
-        const float scoord[] = {
+        std::vector<float> scoordVector {
             static_cast<float>(point1->getCoord()[0]),
             static_cast<float>(point1->getCoord()[1]),
             static_cast<float>(point1->getCoord()[2]),
@@ -144,7 +136,6 @@ void Measurement::createMeasurement(
             static_cast<float>(point2->getCoord()[1]),
             static_cast<float>(point2->getCoord()[2])
         };
-        std::vector<float> scoordVector(scoord, scoord + 6);
         SPTR(io::dicom::container::sr::DicomSRSCoord3DNode) scoordNode =
             std::make_shared<io::dicom::container::sr::DicomSRSCoord3DNode>(
                 io::dicom::container::DicomCodedAttribute("121230", "DCM", "Path"),
@@ -163,13 +154,12 @@ void Measurement::createMeasurement(
         );
 
         // Create SCoord Node
-        const float scoord[] = {
+        std::vector<float> scoordVector {
             static_cast<float>(point1->getCoord()[0]),
             static_cast<float>(point1->getCoord()[1]),
             static_cast<float>(point2->getCoord()[0]),
             static_cast<float>(point2->getCoord()[1])
         };
-        std::vector<float> scoordVector(scoord, scoord + 4);
         SPTR(io::dicom::container::sr::DicomSRSCoordNode) scoordNode =
             std::make_shared<io::dicom::container::sr::DicomSRSCoordNode>(
                 io::dicom::container::DicomCodedAttribute("121230", "DCM", "Path"),
@@ -186,7 +176,7 @@ void Measurement::createMeasurement(
                 "SELECTED FROM",
                 m_instance->getSOPClassUID(),
                 m_instance->getSOPInstanceUIDContainer()[frameNumber1 - 1],
-                frameNumber1
+                int(frameNumber1)
             );
         scoordNode->addSubNode(imageNode);
     }
@@ -194,8 +184,4 @@ void Measurement::createMeasurement(
 
 //------------------------------------------------------------------------------
 
-} // namespace tid
-
-} // namespace writer
-
-} // namespace sight::io::dicom
+} // namespace sight::io::dicom::writer::tid
