@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,9 +24,9 @@
 
 #include "io/dimse/exceptions/RequestFailure.hpp"
 
-#include <core/runtime/operations.hpp>
+#include <core/os/TempPath.hpp>
+#include <core/runtime/path.hpp>
 #include <core/thread/Worker.hpp>
-#include <core/tools/System.hpp>
 
 #include <dcmtk/config/osconfig.h>
 #include <dcmtk/dcmnet/diutil.h>
@@ -41,22 +41,20 @@ const core::com::Slots::SlotKeyType SeriesRetriever::s_PROGRESS_CALLBACK_SLOT =
 // ----------------------------------------------------------------------------
 
 SeriesRetriever::SeriesRetriever() :
-    m_path(""),
-    m_progressCallback(ProgressCallbackSlotType::sptr())
+    m_path("")
 {
 }
 
 // ----------------------------------------------------------------------------
 
 SeriesRetriever::~SeriesRetriever()
-{
-}
+= default;
 
 // ----------------------------------------------------------------------------
 
 void SeriesRetriever::initialize(
     const std::string& applicationTitle,
-    unsigned short applicationport,
+    std::uint16_t applicationport,
     int timeout,
     ProgressCallbackSlotType::sptr progressCallback
 )
@@ -65,7 +63,7 @@ void SeriesRetriever::initialize(
     m_progressCallback = progressCallback;
 
     //Creating folder
-    m_path = core::tools::System::getTemporaryFolder() / "dicom/";
+    m_path = core::os::TempDir::sharedDirectory() / "dicom/";
     if(!std::filesystem::exists(m_path))
     {
         std::filesystem::create_directories(m_path);
@@ -82,7 +80,7 @@ void SeriesRetriever::initialize(
     this->setAndCheckAssociationProfile("Default");
 
     // Set non blocking states & timeout so we don't end up in an infinite loop
-    this->setConnectionTimeout(timeout);
+    this->setConnectionTimeout(Uint32(timeout));
     this->setConnectionBlockingMode(DUL_NOBLOCK);
 }
 
@@ -133,10 +131,10 @@ OFCondition SeriesRetriever::handleSTORERequest(
     OFString tempStr;
 
     // Get Dataset
-    DcmDataset* dataset = new DcmDataset();
+    auto* dataset = new DcmDataset();
     if(this->receiveDIMSEDataset(&presID, &dataset).good())
     {
-        if(dataset != NULL)
+        if(dataset != nullptr)
         {
             //Find the series UID
             OFString seriesID;
@@ -162,7 +160,7 @@ OFCondition SeriesRetriever::handleSTORERequest(
             dataset->saveFile(filePath.c_str());
 
             // Send a store response
-            T_DIMSE_C_StoreRSP rsp;
+            T_DIMSE_C_StoreRSP rsp {};
             rsp.DimseStatus = STATUS_Success;
             cond            = this->sendSTOREResponse(presID, incomingMsg->msg.CStoreRQ, rsp.DimseStatus);
 
@@ -173,9 +171,6 @@ OFCondition SeriesRetriever::handleSTORERequest(
                 const std::string msg = "Cannot send C-STORE Response to the server.";
                 throw io::dimse::exceptions::RequestFailure(msg);
             }
-            else
-            {
-            }
 
             // Notify callback
             if(m_progressCallback)
