@@ -20,6 +20,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINT
+
 #pragma once
 
 #include "io/igtl/detail/converter/IConverter.hpp"
@@ -30,14 +32,11 @@
 #include <data/Float.hpp>
 #include <data/Integer.hpp>
 
-#include <boost/lexical_cast.hpp>
-#include <boost/static_assert.hpp>
 #include <boost/type_traits/is_base_of.hpp>
 
-namespace sight::io::igtl::detail
-{
+#include <utility>
 
-namespace converter
+namespace sight::io::igtl::detail::converter
 {
 
 /**
@@ -52,26 +51,25 @@ public:
     /// Constructor
     ScalarConverter()
     {
-        BOOST_STATIC_ASSERT(boost::is_base_of<data::Object, FwDataObjectType>::value);
+        static_assert(std::is_base_of<data::Object, FwDataObjectType>::value);
     }
 
-    ScalarConverter(const std::string& a) :
-        m_igtlType(a)
+    ScalarConverter(std::string a) :
+        m_igtlType(std::move(a))
     {
-        BOOST_STATIC_ASSERT(boost::is_base_of<data::Object, FwDataObjectType>::value);
+        static_assert(std::is_base_of<data::Object, FwDataObjectType>::value);
     }
 
     /// Destructor
-    virtual ~ScalarConverter()
-    {
-    }
+    ~ScalarConverter() override
+    = default;
 
     /**
      * @brief convert a igtl::RawMessage(which contain scalar) to a FwDataObjectType
      *
      * @return an data::Integer converted from an igtl::RawMessage
      */
-    data::Object::sptr fromIgtlMessage(const ::igtl::MessageBase::Pointer src) const
+    [[nodiscard]] data::Object::sptr fromIgtlMessage(const ::igtl::MessageBase::Pointer src) const override
     {
         typename FwDataObjectType::sptr obj = FwDataObjectType::New();
 
@@ -87,15 +85,15 @@ public:
      *
      * @return an  igtl::RawMessage converted from an data::Integer
      */
-    ::igtl::MessageBase::Pointer fromFwDataObject(data::Object::csptr src) const
+    [[nodiscard]] ::igtl::MessageBase::Pointer fromFwDataObject(data::Object::csptr src) const override
     {
         RawMessage::Pointer msg;
         typename FwDataObjectType::csptr obj = FwDataObjectType::dynamicConstCast(src);
 
         msg = RawMessage::New(m_igtlType);
-        RawMessage::RawDataType content = helper::ScalarToBytes<ScalarType>::toBytes(obj->getValue());
+        RawMessage::RawDataType content = helper::ScalarToBytes<ScalarType>::toBytes(ScalarType(obj->getValue()));
         msg->append(content);
-        return ::igtl::MessageBase::Pointer(msg);
+        return ::igtl::MessageBase::Pointer(msg); // NOLINT(modernize-return-braced-init-list)
     }
 
     /**
@@ -113,7 +111,7 @@ public:
      *
      * @return the igtlType supported for conversion
      */
-    const std::string& getIgtlType() const
+    [[nodiscard]] const std::string& getIgtlType() const override
     {
         return m_igtlType;
     }
@@ -123,7 +121,7 @@ public:
      *
      * @return the fwData Object type supported for conversion
      */
-    const std::string& getFwDataObjectType() const
+    [[nodiscard]] const std::string& getFwDataObjectType() const override
     {
         return FwDataObjectType::classname();
     }
@@ -147,9 +145,8 @@ public:
     }
 
     /// Destructor
-    virtual ~IntConverter()
-    {
-    }
+    ~IntConverter() override
+    = default;
 
     /**
      * @brief create a new IntConverter smart pointer
@@ -175,9 +172,8 @@ public:
     }
 
     /// Destructor
-    virtual ~FloatConverter()
-    {
-    }
+    ~FloatConverter() override
+    = default;
 
     /**
      * @brief create a new FloatConverter smart pointer
@@ -190,6 +186,4 @@ public:
     }
 };
 
-} // namespace converter
-
-} // namespace sight::io::igtl::detail
+} // namespace sight::io::igtl::detail::converter
