@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,13 +24,7 @@
 
 #include <data/Image.hpp>
 
-namespace sight::io::itk
-{
-
-namespace ut
-{
-
-namespace helper
+namespace sight::io::itk::ut::helper
 {
 
 //------------------------------------------------------------------------------
@@ -51,8 +45,4 @@ void roundSpacing(data::Image::sptr image)
 
 //------------------------------------------------------------------------------
 
-} //namespace helper
-
-} //namespace ut
-
-} //namespace sight::io::itk
+} // namespace sight::io::itk::ut::helper
