@@ -32,10 +32,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::io::opencv::ut::MatrixTest);
 
-namespace sight::io::opencv
-{
-
-namespace ut
+namespace sight::io::opencv::ut
 {
 
 //-----------------------------------------------------------------------------
@@ -64,35 +61,32 @@ void MatrixTest::copyFromCvFloat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
 
     // 1 to 16 values
     cvMat = cv::Matx44f(
-        1.f,
-        2.f,
-        3.f,
-        4.f,
-        5.f,
-        6.f,
-        7.f,
-        8.f,
-        9.f,
-        10.f,
-        11.f,
-        12.f,
-        13.f,
-        14.f,
-        15.f,
-        16.f
+        1.F,
+        2.F,
+        3.F,
+        4.F,
+        5.F,
+        6.F,
+        7.F,
+        8.F,
+        9.F,
+        10.F,
+        11.F,
+        12.F,
+        13.F,
+        14.F,
+        15.F,
+        16.F
     );
 
     //values test
@@ -102,12 +96,10 @@ void MatrixTest::copyFromCvFloat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]",
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
@@ -128,23 +120,21 @@ void MatrixTest::copyToCvFloat()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
                 static_cast<double>(cvMat(i, j)),
                 1e-8
             );
         }
     }
 
-    data::Matrix4::TMCoefArray array = {{0.16, 0.15, 0.14, 0.1378942,
+    data::Matrix4::container_type array = {{0.16, 0.15, 0.14, 0.1378942,
         12.0, 11.0, 10.0, 9.0,
         0.08, 0.07, 0.0645687, 0.05,
         40.0, 30.0, 20.0, 10.0
     }
     };
-    fwMat->setCoefficients(array);
+    (*fwMat) = array;
 
     io::opencv::Matrix::copyToCv(fwMat, cvMat);
 
@@ -153,10 +143,9 @@ void MatrixTest::copyToCvFloat()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]",
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
+                (*fwMat)(i, j),
                 1e-8
             );
         }
@@ -177,13 +166,10 @@ void MatrixTest::copyFromCvDouble()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
@@ -215,12 +201,10 @@ void MatrixTest::copyFromCvDouble()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]",
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
@@ -240,24 +224,21 @@ void MatrixTest::copyToCvDouble()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
-                static_cast<double>(cvMat(i, j)),
-                1e-8
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
+                static_cast<double>(cvMat(i, j))
             );
         }
     }
 
-    data::Matrix4::TMCoefArray array = {{0.16, 0.15, 0.14, 0.1378942,
+    data::Matrix4::container_type array = {{0.16, 0.15, 0.14, 0.1378942,
         12.0, 11.0, 10.0, 9.0,
         0.08, 0.07, 0.0645687, 0.05,
         40.0, 30.0, 20.0, 10.0
     }
     };
-    fwMat->setCoefficients(array);
+    (*fwMat) = array;
 
     //values test
     io::opencv::Matrix::copyToCv(fwMat, cvMat);
@@ -266,12 +247,10 @@ void MatrixTest::copyToCvDouble()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]",
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 static_cast<double>(cvMat(i, j)),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
@@ -291,13 +270,10 @@ void MatrixTest::copyFromCvMat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
-                cvMat.at<double>(i, j),
-                1e-8
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
+                cvMat.at<double>(i, j)
             );
         }
     }
@@ -316,13 +292,10 @@ void MatrixTest::copyFromCvMat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
-                cvMat.at<double>(i, j),
-                1e-8
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
+                cvMat.at<double>(i, j)
             );
         }
     }
@@ -342,24 +315,21 @@ void MatrixTest::copyToCvMat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
-                cvMat.at<double>(i, j),
-                1e-8
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
+                cvMat.at<double>(i, j)
             );
         }
     }
 
-    data::Matrix4::TMCoefArray array = {{0.16, 0.15, 0.14, 0.1378942,
+    data::Matrix4::container_type array = {
+        0.16, 0.15, 0.14, 0.1378942,
         12.0, 11.0, 10.0, 9.0,
         0.08, 0.07, 0.0645687, 0.05,
         40.0, 30.0, 20.0, 10.0
-    }
     };
-    fwMat->setCoefficients(array);
+    (*fwMat) = array;
 
     //values test
     io::opencv::Matrix::copyToCv(fwMat, cvMat);
@@ -368,12 +338,10 @@ void MatrixTest::copyToCvMat()
     {
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
-            CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]",
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
                 cvMat.at<double>(i, j),
-                fwMat->getCoefficient(i, j),
-                1e-8
+                (*fwMat)(i, j)
             );
         }
     }
@@ -398,10 +366,8 @@ void MatrixTest::copyFromRvecTvec()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
                 cvMat.at<double>(i, j),
                 1e-8
             );
@@ -425,10 +391,8 @@ void MatrixTest::copyFromRvecTvec()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
                 cvMat.at<double>(i, j),
                 1e-8
             );
@@ -447,10 +411,8 @@ void MatrixTest::copyFromRvecTvec()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
                 cvMat.at<double>(i, j),
                 1e-8
             );
@@ -463,9 +425,10 @@ void MatrixTest::copyFromRvecTvec()
 void MatrixTest::copyToRvecTvec()
 {
     data::Matrix4::sptr fwMat = data::Matrix4::New();
-    cv::Mat expectedRvec = (cv::Mat_<double>(3, 1) << 0., 0., 0.);
-    cv::Mat expectedTvec = (cv::Mat_<double>(3, 1) << 0., 0., 0.);
-    cv::Mat rvec, tvec;
+    cv::Mat expectedRvec      = (cv::Mat_<double>(3, 1) << 0., 0., 0.);
+    cv::Mat expectedTvec      = (cv::Mat_<double>(3, 1) << 0., 0., 0.);
+    cv::Mat rvec;
+    cv::Mat tvec;
 
     //identity test
     CPPUNIT_ASSERT_NO_THROW(io::opencv::Matrix::copyToCv(fwMat, rvec, tvec));
@@ -487,13 +450,13 @@ void MatrixTest::copyToRvecTvec()
         );
     }
 
-    data::Matrix4::TMCoefArray array = {{1., 0., 0., 4.,
+    data::Matrix4::container_type array = {
+        1., 0., 0., 4.,
         0., 0.86601905, -0.50001100, 8.,
         0., 0.50001100, 0.86601905, 12.,
         0., 0., 0., 1.
-    }
     };
-    fwMat->setCoefficients(array);
+    (*fwMat) = array;
 
     //values test
     io::opencv::Matrix::copyToCv(fwMat, rvec, tvec);
@@ -527,10 +490,8 @@ void MatrixTest::copyToRvecTvec()
         for(std::uint8_t j = 0 ; j < 4 ; ++j)
         {
             CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE(
-                "values are not equals at [" + std::to_string(i)
-                + " ; " + std::to_string(j) + "]"
-                ,
-                fwMat->getCoefficient(i, j),
+                "values are not equals at [" + std::to_string(i) + " ; " + std::to_string(j) + "]",
+                (*fwMat)(i, j),
                 mat4x4.at<double>(i, j),
                 1e-8
             );
@@ -540,6 +501,4 @@ void MatrixTest::copyToRvecTvec()
 
 //-----------------------------------------------------------------------------
 
-} // namespace ut
-
-} // namespace sight::io::opencv
+} // namespace sight::io::opencv::ut
