@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -21,7 +21,7 @@
 
 #include "SessionReader.hpp"
 
-#include "detail/SessionDeserializer.hpp"
+#include "io/session/detail/core/SessionDeserializer.hpp"
 
 #include <core/crypto/PasswordKeeper.hpp>
 
@@ -48,10 +48,10 @@ public:
     SessionReaderImpl& operator=(SessionReaderImpl&&)      = delete;
 
     /// Constructor
-    inline SessionReaderImpl(SessionReader* const sessionReader) :
+    inline explicit SessionReaderImpl(SessionReader* const sessionReader) :
         m_sessionReader(sessionReader),
         m_password(std::make_unique<PasswordKeeper>()),
-        m_encryptionPolicy(PasswordKeeper::EncryptionPolicy::DEFAULT),
+        m_encryptionPolicy(PasswordKeeper::EncryptionPolicy::PASSWORD),
         m_archiveFormat(Archive::ArchiveFormat::DEFAULT)
     {
     }
@@ -90,7 +90,7 @@ public:
     Archive::ArchiveFormat m_archiveFormat;
 };
 
-SessionReader::SessionReader(base::reader::IObjectReader::Key) :
+SessionReader::SessionReader(base::reader::IObjectReader::Key /*unused*/) :
     m_pimpl(std::make_unique<SessionReaderImpl>(this))
 {
 }
@@ -117,7 +117,7 @@ std::string SessionReader::extension() const
 
 //------------------------------------------------------------------------------
 
-void SessionReader::set_password(const secure_string& password)
+void SessionReader::setPassword(const secure_string& password)
 {
     m_pimpl->m_password->set_password(password);
 }
@@ -138,16 +138,23 @@ void SessionReader::setArchiveFormat(const Archive::ArchiveFormat archiveFormat)
 
 //------------------------------------------------------------------------------
 
-void SessionReader::setDeserializer(const std::string& className, deserializer_t deserializer)
+void SessionReader::setCustomDeserializer(const std::string& className, deserializer_t deserializer)
 {
-    m_pimpl->m_sessionDeserializer.setDeserializer(className, deserializer);
+    m_pimpl->m_sessionDeserializer.setCustomDeserializer(className, deserializer);
 }
 
 //------------------------------------------------------------------------------
 
-void SessionReader::setDefaultDeserializer(const std::string& className, deserializer_t deserializer)
+void SessionReader::setDeserializer(const std::string& className, deserializer_t deserializer)
 {
-    detail::SessionDeserializer::setDefaultDeserializer(className, deserializer);
+    detail::SessionDeserializer::setDeserializer(className, deserializer);
+}
+
+//------------------------------------------------------------------------------
+
+deserializer_t SessionReader::deserializer(const std::string& className)
+{
+    return detail::SessionDeserializer::deserializer(className);
 }
 
 } // namespace sight::io::session
