@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -87,29 +87,34 @@ public:
 
     /// Sets the password
     /// @param password the new password
-    IO_SESSION_API void set_password(const core::crypto::secure_string& password);
+    IO_SESSION_API void setPassword(const core::crypto::secure_string& password);
 
     /// Sets the encryption policy
     /// @param policy the encryption policy: @see sight::io::session::PasswordKeeper::EncryptionPolicy
-    IO_SESSION_API void setEncryptionPolicy(const core::crypto::PasswordKeeper::EncryptionPolicy policy);
+    IO_SESSION_API void setEncryptionPolicy(core::crypto::PasswordKeeper::EncryptionPolicy policy);
 
     /// Set archive format
     /// @param archiveFormat how files are stored in the archive: @see sight::io::zip::Archive::ArchiveFormat
-    IO_SESSION_API void setArchiveFormat(const zip::Archive::ArchiveFormat archiveFormat);
+    IO_SESSION_API void setArchiveFormat(zip::Archive::ArchiveFormat archiveFormat);
 
     /// Set a deserialization function for an object
     /// @param className the name of the object to serialize
     /// @param deserializer the function pointer to the deserialization function
-    IO_SESSION_API void setDeserializer(const std::string& className, deserializer_t deserializer = nullptr);
+    IO_SESSION_API void setCustomDeserializer(const std::string& className, deserializer_t deserializer = nullptr);
 
     /// Set a default deserialization function for an object
     /// @param className the name of the object to serialize
     /// @param deserializer the function pointer to the deserialization function
-    IO_SESSION_API static void setDefaultDeserializer(
+    IO_SESSION_API static void setDeserializer(
         const std::string& className,
         deserializer_t deserializer = nullptr
     );
 
+    /// Return the registered deserialization function for an object
+    /// @param className the name of the object to deserialize
+    /// @return the function pointer to the deserialization function
+    IO_SESSION_API static deserializer_t deserializer(const std::string& className);
+
 private:
 
     /// PImpl
