@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -21,7 +21,7 @@
 
 #include "SessionWriter.hpp"
 
-#include "detail/SessionSerializer.hpp"
+#include "io/session/detail/core/SessionSerializer.hpp"
 
 #include <core/crypto/PasswordKeeper.hpp>
 
@@ -47,10 +47,10 @@ public:
     SessionWriterImpl& operator=(SessionWriterImpl&&)      = delete;
 
     /// Constructor
-    inline SessionWriterImpl(SessionWriter* const sessionWriter) :
+    inline explicit SessionWriterImpl(SessionWriter* const sessionWriter) :
         m_sessionWriter(sessionWriter),
         m_password(std::make_unique<PasswordKeeper>()),
-        m_encryptionPolicy(PasswordKeeper::EncryptionPolicy::DEFAULT),
+        m_encryptionPolicy(PasswordKeeper::EncryptionPolicy::PASSWORD),
         m_archiveFormat(Archive::ArchiveFormat::DEFAULT)
     {
     }
@@ -91,7 +91,7 @@ public:
     Archive::ArchiveFormat m_archiveFormat;
 };
 
-SessionWriter::SessionWriter(base::writer::IObjectWriter::Key) :
+SessionWriter::SessionWriter(base::writer::IObjectWriter::Key /*unused*/) :
     m_pimpl(std::make_unique<SessionWriterImpl>(this))
 {
 }
@@ -115,7 +115,7 @@ std::string SessionWriter::extension() const
 
 //------------------------------------------------------------------------------
 
-void SessionWriter::set_password(const secure_string& password)
+void SessionWriter::setPassword(const secure_string& password)
 {
     m_pimpl->m_password->set_password(password);
 }
@@ -136,16 +136,23 @@ void SessionWriter::setArchiveFormat(const Archive::ArchiveFormat archiveFormat)
 
 //------------------------------------------------------------------------------
 
-void SessionWriter::setSerializer(const std::string& className, serializer_t serializer)
+void SessionWriter::setCustomSerializer(const std::string& className, serializer_t serializer)
 {
-    m_pimpl->m_sessionSerializer.setSerializer(className, serializer);
+    m_pimpl->m_sessionSerializer.setCustomSerializer(className, serializer);
 }
 
 //------------------------------------------------------------------------------
 
-void SessionWriter::setDefaultSerializer(const std::string& className, serializer_t serializer)
+void SessionWriter::setSerializer(const std::string& className, serializer_t serializer)
 {
-    detail::SessionSerializer::setDefaultSerializer(className, serializer);
+    detail::SessionSerializer::setSerializer(className, serializer);
+}
+
+//------------------------------------------------------------------------------
+
+serializer_t SessionWriter::serializer(const std::string& className)
+{
+    return detail::SessionSerializer::serializer(className);
 }
 
 } //namespace sight::io::session
