@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -31,10 +31,7 @@
 
 #include <filesystem>
 
-namespace sight::io::session
-{
-
-namespace detail
+namespace sight::io::session::detail
 {
 
 /// Interface to define a location that holds what is needed to de/serialize a session.
@@ -47,12 +44,13 @@ public:
     constexpr static auto s_uuid {"uuid"};
     constexpr static auto s_children {"children"};
     constexpr static auto s_fields {"fields"};
+    constexpr static auto s_description {"description"};
 
     /// String serialization function
-    inline std::string toString() const override;
+    [[nodiscard]] inline std::string toString() const override;
 
     /// Return the default index file path inside the session archive
-    inline std::filesystem::path getIndexFilePath() const;
+    static inline std::filesystem::path getIndexFilePath();
 
     /// Salt the password, depending of the encryption level
     /// "PASSWORD" means encrypt if a password is provided, using the same key.
@@ -67,7 +65,7 @@ public:
     static inline core::crypto::secure_string pickle(
         const core::crypto::secure_string& password,
         const core::crypto::secure_string& salt,
-        const core::crypto::PasswordKeeper::EncryptionPolicy policy = core::crypto::PasswordKeeper::EncryptionPolicy::DEFAULT
+        core::crypto::PasswordKeeper::EncryptionPolicy policy = core::crypto::PasswordKeeper::EncryptionPolicy::PASSWORD
     );
 
 protected:
@@ -76,7 +74,7 @@ protected:
     IO_SESSION_API ISession() = default;
 
     /// Destructor
-    IO_SESSION_API virtual ~ISession() = default;
+    IO_SESSION_API ~ISession() override = default;
 };
 
 //------------------------------------------------------------------------------
@@ -88,7 +86,7 @@ inline std::string ISession::toString() const
 
 //------------------------------------------------------------------------------
 
-inline std::filesystem::path ISession::getIndexFilePath() const
+inline std::filesystem::path ISession::getIndexFilePath()
 {
     return "index.json";
 }
@@ -126,6 +124,4 @@ inline core::crypto::secure_string ISession::pickle(
     }
 }
 
-} // namespace detail
-
-} // namespace sight::io::session
+} // namespace sight::io::session::detail
