@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -37,7 +37,7 @@ namespace sight::core::jobs
 
 class Observer;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::io::vtk
 {
@@ -47,8 +47,8 @@ namespace sight::io::vtk
  *
  * Read a VTK Image using the VTK lib
  */
-class ImageReader : public base::reader::GenericObjectReader<data::Image>,
-                    public core::location::SingleFile
+class IO_VTK_CLASS_API ImageReader : public base::reader::GenericObjectReader<data::Image>,
+                                     public core::location::SingleFile
 {
 public:
 
@@ -63,7 +63,7 @@ public:
     IO_VTK_API ImageReader(io::base::reader::IObjectReader::Key key);
 
     //! @brief Destructor.
-    IO_VTK_API ~ImageReader();
+    IO_VTK_API ~ImageReader() override;
 
     //! @brief Reading operator.
     IO_VTK_API void read() override;
