@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -41,7 +41,7 @@ namespace sight::io::vtk
 
 //------------------------------------------------------------------------------
 
-ImageWriter::ImageWriter(io::base::writer::IObjectWriter::Key) :
+ImageWriter::ImageWriter(io::base::writer::IObjectWriter::Key /*unused*/) :
     m_job(core::jobs::Observer::New("VTK Image Writer"))
 {
 }
@@ -49,14 +49,13 @@ ImageWriter::ImageWriter(io::base::writer::IObjectWriter::Key) :
 //------------------------------------------------------------------------------
 
 ImageWriter::~ImageWriter()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void ImageWriter::write()
 {
-    using namespace sight::io::vtk::helper;
+    using helper::vtkLambdaCommand;
 
     assert(!m_object.expired());
     assert(m_object.lock());
@@ -73,9 +72,9 @@ void ImageWriter::write()
     vtkSmartPointer<vtkLambdaCommand> progressCallback;
     progressCallback = vtkSmartPointer<vtkLambdaCommand>::New();
     progressCallback->SetCallback(
-        [this](vtkObject* caller, long unsigned int, void*)
+        [this](vtkObject* caller, std::uint64_t, void*)
         {
-            auto filter = static_cast<vtkGenericDataObjectWriter*>(caller);
+            auto* filter = static_cast<vtkGenericDataObjectWriter*>(caller);
             m_job->doneWork(static_cast<std::uint64_t>(filter->GetProgress() * 100.));
         });
 
