@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -39,7 +39,7 @@ namespace sight::core::jobs
 
 class Observer;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::io::vtk
 {
@@ -49,8 +49,8 @@ namespace sight::io::vtk
  *
  * Write a VTK Image using the VTK lib
  */
-class ImageWriter : public base::writer::GenericObjectWriter<data::Image>,
-                    public core::location::SingleFile
+class IO_VTK_CLASS_API ImageWriter : public base::writer::GenericObjectWriter<data::Image>,
+                                     public core::location::SingleFile
 {
 public:
 
@@ -65,7 +65,7 @@ public:
     IO_VTK_API ImageWriter(io::base::writer::IObjectWriter::Key key);
 
     //! @brief Destructor.
-    IO_VTK_API ~ImageWriter();
+    IO_VTK_API ~ImageWriter() override;
 
     //! @brief Writing operator.
     IO_VTK_API void write() override;
