@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -42,7 +42,7 @@ namespace sight::io::vtk
 
 //------------------------------------------------------------------------------
 
-MetaImageReader::MetaImageReader(io::base::reader::IObjectReader::Key) :
+MetaImageReader::MetaImageReader(io::base::reader::IObjectReader::Key /*unused*/) :
     m_job(core::jobs::Observer::New("Meta image reader"))
 {
 }
@@ -50,14 +50,13 @@ MetaImageReader::MetaImageReader(io::base::reader::IObjectReader::Key) :
 //------------------------------------------------------------------------------
 
 MetaImageReader::~MetaImageReader()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void MetaImageReader::read()
 {
-    using namespace sight::io::vtk::helper;
+    using helper::vtkLambdaCommand;
     assert(!m_object.expired());
     assert(m_object.lock());
 
@@ -70,9 +69,9 @@ void MetaImageReader::read()
 
     progressCallback = vtkSmartPointer<vtkLambdaCommand>::New();
     progressCallback->SetCallback(
-        [&](vtkObject* caller, long unsigned int, void*)
+        [&](vtkObject* caller, std::uint64_t, void*)
         {
-            auto filter = static_cast<vtkMetaImageReader*>(caller);
+            auto* filter = static_cast<vtkMetaImageReader*>(caller);
             m_job->doneWork(static_cast<std::uint64_t>(filter->GetProgress() * 100.));
         });
     reader->AddObserver(vtkCommand::ProgressEvent, progressCallback);
