@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -42,7 +42,7 @@ namespace sight::io::vtk
 
 //------------------------------------------------------------------------------
 
-MetaImageWriter::MetaImageWriter(io::base::writer::IObjectWriter::Key) :
+MetaImageWriter::MetaImageWriter(io::base::writer::IObjectWriter::Key /*unused*/) :
     m_job(core::jobs::Observer::New("MetaImage writer"))
 {
 }
@@ -50,14 +50,13 @@ MetaImageWriter::MetaImageWriter(io::base::writer::IObjectWriter::Key) :
 //------------------------------------------------------------------------------
 
 MetaImageWriter::~MetaImageWriter()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void MetaImageWriter::write()
 {
-    using namespace sight::io::vtk::helper;
+    using helper::vtkLambdaCommand;
 
     assert(!m_object.expired());
     assert(m_object.lock());
@@ -74,9 +73,9 @@ void MetaImageWriter::write()
     vtkSmartPointer<vtkLambdaCommand> progressCallback;
     progressCallback = vtkSmartPointer<vtkLambdaCommand>::New();
     progressCallback->SetCallback(
-        [this](vtkObject* caller, long unsigned int, void*)
+        [this](vtkObject* caller, std::uint64_t, void*)
         {
-            auto filter = static_cast<vtkMetaImageWriter*>(caller);
+            auto* filter = static_cast<vtkMetaImageWriter*>(caller);
             m_job->doneWork(static_cast<std::uint64_t>(filter->GetProgress() * 100.));
         });
 
