@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2021 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,7 +35,7 @@ namespace sight::data
 
 class Mesh;
 
-}
+} // namespace sight::data
 
 namespace sight::core::jobs
 {
@@ -43,7 +43,7 @@ namespace sight::core::jobs
 class Observer;
 class IJob;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::io::vtk
 {
@@ -52,8 +52,8 @@ namespace sight::io::vtk
  * @brief Writes a Mesh in .obj format using VTK library.
  */
 
-class ObjMeshWriter : public base::writer::GenericObjectWriter<data::Mesh>,
-                      public core::location::SingleFile
+class IO_VTK_CLASS_API ObjMeshWriter : public base::writer::GenericObjectWriter<data::Mesh>,
+                                       public core::location::SingleFile
 {
 public:
 
@@ -68,7 +68,7 @@ public:
     IO_VTK_API ObjMeshWriter(io::base::writer::IObjectWriter::Key key);
 
     /// @brief Destructor.
-    IO_VTK_API ~ObjMeshWriter();
+    IO_VTK_API ~ObjMeshWriter() override;
 
     /// @brief Reading operator.
     IO_VTK_API void write() override;
