@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2021 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -38,7 +38,7 @@ namespace sight::core::jobs
 class Observer;
 class IJob;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::io::vtk
 {
@@ -48,8 +48,8 @@ namespace sight::io::vtk
  *
  */
 
-class StlMeshReader : public base::reader::GenericObjectReader<data::Mesh>,
-                      public core::location::SingleFile
+class IO_VTK_CLASS_API StlMeshReader : public base::reader::GenericObjectReader<data::Mesh>,
+                                       public core::location::SingleFile
 {
 public:
 
@@ -64,7 +64,7 @@ public:
     IO_VTK_API StlMeshReader(io::base::reader::IObjectReader::Key key);
 
     /// @brief Destructor.
-    IO_VTK_API ~StlMeshReader();
+    IO_VTK_API ~StlMeshReader() override;
 
     /// @brief Reading operator.
     IO_VTK_API void read() override;
