@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -43,7 +43,7 @@ namespace sight::io::vtk
 
 //------------------------------------------------------------------------------
 
-VtiImageReader::VtiImageReader(io::base::reader::IObjectReader::Key) :
+VtiImageReader::VtiImageReader(io::base::reader::IObjectReader::Key /*unused*/) :
     m_job(core::jobs::Observer::New("Vti image reader"))
 {
 }
@@ -51,8 +51,7 @@ VtiImageReader::VtiImageReader(io::base::reader::IObjectReader::Key) :
 //------------------------------------------------------------------------------
 
 VtiImageReader::~VtiImageReader()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -66,14 +65,14 @@ void VtiImageReader::read()
     vtkSmartPointer<vtkXMLImageDataReader> reader = vtkSmartPointer<vtkXMLImageDataReader>::New();
     reader->SetFileName(this->getFile().string().c_str());
 
-    using namespace sight::io::vtk::helper;
+    using helper::vtkLambdaCommand;
     vtkSmartPointer<vtkLambdaCommand> progressCallback;
 
     progressCallback = vtkSmartPointer<vtkLambdaCommand>::New();
     progressCallback->SetCallback(
-        [&](vtkObject* caller, long unsigned int, void*)
+        [&](vtkObject* caller, std::uint64_t, void*)
         {
-            auto filter = static_cast<vtkGenericDataObjectReader*>(caller);
+            auto* filter = static_cast<vtkGenericDataObjectReader*>(caller);
             m_job->doneWork(static_cast<std::uint64_t>(filter->GetProgress() * 100.));
         });
     reader->AddObserver(vtkCommand::ProgressEvent, progressCallback);
