@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -38,7 +38,7 @@ namespace sight::core::jobs
 class Observer;
 class IJob;
 
-}
+} // namespace sight::core::jobs
 
 namespace sight::io::vtk
 {
@@ -48,8 +48,8 @@ namespace sight::io::vtk
  *
  * Read a VTK Image using the VTK lib
  */
-class VtiImageReader : public base::reader::GenericObjectReader<data::Image>,
-                       public core::location::SingleFile
+class IO_VTK_CLASS_API VtiImageReader : public base::reader::GenericObjectReader<data::Image>,
+                                        public core::location::SingleFile
 {
 public:
 
@@ -65,7 +65,7 @@ public:
     IO_VTK_API VtiImageReader(io::base::reader::IObjectReader::Key key);
 
     //! @brief Destructor.
-    IO_VTK_API ~VtiImageReader();
+    IO_VTK_API ~VtiImageReader() override;
 
     //! @brief Reading operator.
     IO_VTK_API void read() override;
