@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -43,7 +43,7 @@ namespace sight::io::vtk
 
 //------------------------------------------------------------------------------
 
-VtiImageWriter::VtiImageWriter(io::base::writer::IObjectWriter::Key) :
+VtiImageWriter::VtiImageWriter(io::base::writer::IObjectWriter::Key /*unused*/) :
     m_job(core::jobs::Observer::New("VTK Image Writer"))
 {
 }
@@ -51,14 +51,13 @@ VtiImageWriter::VtiImageWriter(io::base::writer::IObjectWriter::Key) :
 //------------------------------------------------------------------------------
 
 VtiImageWriter::~VtiImageWriter()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void VtiImageWriter::write()
 {
-    using namespace sight::io::vtk::helper;
+    using helper::vtkLambdaCommand;
 
     assert(!m_object.expired());
     assert(m_object.lock());
@@ -80,9 +79,9 @@ void VtiImageWriter::write()
     vtkSmartPointer<vtkLambdaCommand> progressCallback;
     progressCallback = vtkSmartPointer<vtkLambdaCommand>::New();
     progressCallback->SetCallback(
-        [this](vtkObject* caller, long unsigned int, void*)
+        [this](vtkObject* caller, std::uint64_t, void*)
         {
-            auto filter = static_cast<vtkXMLImageDataWriter*>(caller);
+            auto* filter = static_cast<vtkXMLImageDataWriter*>(caller);
             m_job->doneWork(static_cast<std::uint64_t>(filter->GetProgress() * 100.));
         });
 
