@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,10 +30,7 @@
 #include <vtkSmartPointer.h>
 #include <vtkUnstructuredGrid.h>
 
-namespace sight::io::vtk
-{
-
-namespace helper
+namespace sight::io::vtk::helper
 {
 
 /**
@@ -83,6 +80,4 @@ public:
     IO_VTK_API static double computeVolume(const data::Mesh::csptr& mesh);
 };
 
-} // namespace helper
-
-} // namespace sight::io::vtk
+} // namespace sight::io::vtk::helper
