@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,10 @@
 
 #include "MeshTest.hpp"
 
-#include <core/tools/NumericRoundCast.hxx>
+#include <core/os/TempPath.hpp>
 #include <core/tools/random/Generator.hpp>
-#include <core/tools/System.hpp>
+
+#include <data/iterator.hpp>
 
 #include <geometry/data/Mesh.hpp>
 
@@ -43,6 +44,8 @@
 #include <utestData/Data.hpp>
 #include <utestData/generator/Mesh.hpp>
 
+#include <vtkCellData.h>
+#include <vtkFloatArray.h>
 #include <vtkPolyData.h>
 #include <vtkPolyDataMapper.h>
 #include <vtkSmartPointer.h>
@@ -54,10 +57,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::io::vtk::ut::MeshTest);
 
-namespace sight::io::vtk
-{
-
-namespace ut
+namespace sight::io::vtk::ut
 {
 
 using core::tools::random::safeRand;
@@ -221,8 +221,8 @@ void MeshTest::testExportImportSyntheticMesh()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "testExportImportSyntheticMesh.vtk";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "testExportImportSyntheticMesh.vtk";
 
     const io::vtk::MeshWriter::sptr writer = io::vtk::MeshWriter::New();
     writer->setObject(mesh1);
@@ -237,16 +237,13 @@ void MeshTest::testExportImportSyntheticMesh()
     reader->read();
 
     CPPUNIT_ASSERT(*mesh1 == *mesh2);
-
-    const bool removed = std::filesystem::remove(testFile);
-    CPPUNIT_ASSERT(removed);
 }
 
 //------------------------------------------------------------------------------
 
 void MeshTest::testPointCloud()
 {
-    const data::Mesh::size_t NB_POINTS = static_cast<data::Mesh::size_t>(100 + safeRand() % 1000);
+    const auto NB_POINTS = static_cast<data::Mesh::size_t>(100 + safeRand() % 1000);
 
     const data::Mesh::sptr mesh1 = data::Mesh::New();
 
@@ -256,10 +253,10 @@ void MeshTest::testPointCloud()
 
     for(data::Mesh::size_t i = 0 ; i < NB_POINTS ; ++i)
     {
-        data::Mesh::position_t point[3];
-        point[0] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
-        point[1] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
-        point[2] = (static_cast<float>(safeRand() % 1000) - 500.f) / 3.f;
+        std::array<data::Mesh::position_t, 3> point {};
+        point[0] = (static_cast<float>(safeRand() % 1000) - 500.F) / 3.F;
+        point[1] = (static_cast<float>(safeRand() % 1000) - 500.F) / 3.F;
+        point[2] = (static_cast<float>(safeRand() % 1000) - 500.F) / 3.F;
         mesh1->pushPoint(point);
         mesh1->pushCell(i);
     }
@@ -405,10 +402,10 @@ void MeshTest::testWriteVtkFile()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "vtkTestMesh.vtk";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "vtkTestMesh.vtk";
 
-    const io::vtk::MeshWriter::sptr writer = io::vtk::MeshWriter::New();
+    const auto writer = io::vtk::MeshWriter::New();
     writer->setObject(mesh1);
     writer->setFile(testFile);
     CPPUNIT_ASSERT_NO_THROW(writer->write());
@@ -429,10 +426,10 @@ void MeshTest::testWriteVtpFile()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "vtpTestMesh.vtp";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "vtpTestMesh.vtp";
 
-    const io::vtk::VtpMeshWriter::sptr writer = io::vtk::VtpMeshWriter::New();
+    const auto writer = io::vtk::VtpMeshWriter::New();
     writer->setObject(mesh1);
     writer->setFile(testFile);
     CPPUNIT_ASSERT_NO_THROW(writer->write());
@@ -453,10 +450,10 @@ void MeshTest::testWriteObjFile()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "objTestMesh.obj";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "objTestMesh.obj";
 
-    const io::vtk::ObjMeshWriter::sptr writer = io::vtk::ObjMeshWriter::New();
+    const auto writer = io::vtk::ObjMeshWriter::New();
     writer->setObject(mesh1);
     writer->setFile(testFile);
     CPPUNIT_ASSERT_NO_THROW(writer->write());
@@ -477,10 +474,10 @@ void MeshTest::testWritePlyFile()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "plyTestMesh.ply";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "plyTestMesh.ply";
 
-    const io::vtk::PlyMeshWriter::sptr writer = io::vtk::PlyMeshWriter::New();
+    const auto writer = io::vtk::PlyMeshWriter::New();
     writer->setObject(mesh1);
     writer->setFile(testFile);
     CPPUNIT_ASSERT_NO_THROW(writer->write());
@@ -501,10 +498,10 @@ void MeshTest::testWriteStlFile()
 
     mesh1->shrinkToFit();
 
-    const std::filesystem::path testFile = core::tools::System::getTemporaryFolder()
-                                           / "stlTestMesh.stl";
+    core::os::TempDir tmpDir;
+    const auto testFile = tmpDir / "stlTestMesh.stl";
 
-    const io::vtk::StlMeshWriter::sptr writer = io::vtk::StlMeshWriter::New();
+    const auto writer = io::vtk::StlMeshWriter::New();
     writer->setObject(mesh1);
     writer->setFile(testFile);
     CPPUNIT_ASSERT_NO_THROW(writer->write());
@@ -513,6 +510,337 @@ void MeshTest::testWriteStlFile()
 
 //------------------------------------------------------------------------------
 
-} // namespace ut
+void MeshTest::toVtkMeshWithLinesTest()
+{
+    auto mesh     = data::Mesh::New();
+    auto meshLock = mesh->dump_lock();
+    mesh->reserve(4, 3, data::Mesh::CellType::LINE);
+    mesh->pushPoint(0, 1, 2);
+    mesh->pushPoint(3, 4, 5);
+    mesh->pushPoint(6, 7, 8);
+    mesh->pushPoint(9, 10, 11);
+    mesh->pushCell(0U, 1U);
+    mesh->pushCell(1U, 2U);
+    mesh->pushCell(2U, 3U);
 
-} // namespace sight::io::vtk
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    io::vtk::helper::Mesh::toVTKMesh(mesh, vtkMesh);
+
+    for(std::uint8_t i = 0 ; i < 4 ; i++)
+    {
+        for(std::uint8_t j = 0 ; j < 3 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "component " + std::to_string(j) + " of point " + std::to_string(i),
+                i * 3. + j,
+                vtkMesh->GetPoints()->GetPoint(i)[j]
+            );
+        }
+    }
+
+    auto* pointIdList = vtkIdList::New();
+    for(std::uint8_t i = 0 ; i < 3 ; i++)
+    {
+        vtkMesh->GetCellPoints(i, pointIdList);
+        for(std::uint8_t j = 0 ; j < 2 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "point " + std::to_string(j) + " of cell " + std::to_string(i),
+                vtkIdType(i) + j,
+                pointIdList->GetId(j)
+            );
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::toVtkMeshWithTetrasTest()
+{
+    auto mesh     = data::Mesh::New();
+    auto meshLock = mesh->dump_lock();
+    mesh->reserve(5, 3, data::Mesh::CellType::TETRA);
+    mesh->pushPoint(0, 1, 2);
+    mesh->pushPoint(3, 4, 5);
+    mesh->pushPoint(6, 7, 8);
+    mesh->pushPoint(9, 10, 11);
+    mesh->pushPoint(12, 13, 14);
+    mesh->pushCell(0U, 1U, 2U, 3U);
+    mesh->pushCell(1U, 2U, 3U, 4U);
+    mesh->pushCell(2U, 3U, 4U, 0U);
+
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    io::vtk::helper::Mesh::toVTKMesh(mesh, vtkMesh);
+
+    for(std::uint8_t i = 0 ; i < 5 ; i++)
+    {
+        for(std::uint8_t j = 0 ; j < 3 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "component " + std::to_string(j) + " of point " + std::to_string(i),
+                i * 3. + j,
+                vtkMesh->GetPoints()->GetPoint(i)[j]
+            );
+        }
+    }
+
+    auto* pointIdList = vtkIdList::New();
+    for(std::uint8_t i = 0 ; i < 3 ; i++)
+    {
+        vtkMesh->GetCellPoints(i, pointIdList);
+        for(std::uint8_t j = 0 ; j < 4 ; j++)
+        {
+            // TODO: fix crash. With CellType = TETRA, the pointIdList is always empty.
+            // CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(j) + " of cell " + std::to_string(i),
+            // (vtkIdType(i) + j)%4, pointIdList->GetId(j));
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::toVtkMeshWithCellTexCoordsTest()
+{
+    auto mesh     = data::Mesh::New();
+    auto meshLock = mesh->dump_lock();
+    mesh->reserve(3, 3, data::Mesh::CellType::POINT, data::Mesh::Attributes::CELL_TEX_COORDS);
+    mesh->pushPoint(0, 1, 2);
+    mesh->pushPoint(3, 4, 5);
+    mesh->pushPoint(6, 7, 8);
+    mesh->pushCell(0U);
+    mesh->pushCell(1U);
+    mesh->pushCell(2U);
+    mesh->setCellTexCoord(0, 0, 1);
+    mesh->setCellTexCoord(1, 1, 2);
+    mesh->setCellTexCoord(2, 2, 3);
+
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    io::vtk::helper::Mesh::toVTKMesh(mesh, vtkMesh);
+
+    for(std::uint8_t i = 0 ; i < 3 ; i++)
+    {
+        for(std::uint8_t j = 0 ; j < 3 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "component " + std::to_string(j) + " of point " + std::to_string(i),
+                i * 3. + j,
+                vtkMesh->GetPoints()->GetPoint(i)[j]
+            );
+        }
+    }
+
+    auto* pointIdList = vtkIdList::New();
+    for(std::uint8_t i = 0 ; i < 3 ; i++)
+    {
+        vtkMesh->GetCellPoints(i, pointIdList);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), vtkIdType(i), pointIdList->GetId(0));
+    }
+
+    for(std::uint8_t i = 0 ; i < 3 ; i++)
+    {
+        for(std::uint8_t j = 0 ; j < 2 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "cell " + std::to_string(i),
+                double(i) + j,
+                vtkMesh->GetCellData()->GetTCoords()->GetTuple(i)[j]
+            );
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::fromVtkMeshWithLinesTest()
+{
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    auto points  = vtkSmartPointer<vtkPoints>::New();
+    points->InsertNextPoint(0, 1, 2);
+    points->InsertNextPoint(3, 4, 5);
+    points->InsertNextPoint(6, 7, 8);
+    points->InsertNextPoint(9, 10, 11);
+    vtkMesh->SetPoints(points);
+    auto cells = vtkSmartPointer<vtkCellArray>::New();
+    cells->InsertNextCell({0, 1});
+    cells->InsertNextCell({1, 2});
+    cells->InsertNextCell({2, 3});
+    vtkMesh->SetLines(cells);
+
+    auto mesh = data::Mesh::New();
+    io::vtk::helper::Mesh::fromVTKMesh(vtkMesh, mesh);
+
+    auto meshLock  = mesh->dump_lock();
+    std::uint8_t i = 0;
+    for(auto p : mesh->crange<data::iterator::point::xyz>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i, p.x);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 1, p.y);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 2, p.z);
+        i++;
+    }
+
+    auto* pointIdList = vtkIdList::New();
+    i = 0;
+    for(auto c : mesh->crange<data::iterator::cell::line>())
+    {
+        vtkMesh->GetCellPoints(i, pointIdList);
+        for(std::uint8_t j = 0 ; j < 2 ; j++)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "point " + std::to_string(j) + " of cell " + std::to_string(i),
+                data::iterator::cell_t(i) + j,
+                c.pt[j]
+            );
+        }
+
+        i++;
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::fromVtkMeshWithQuadsTest()
+{
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    auto points  = vtkSmartPointer<vtkPoints>::New();
+    points->InsertNextPoint(0, 1, 2);
+    points->InsertNextPoint(3, 4, 5);
+    points->InsertNextPoint(6, 7, 8);
+    points->InsertNextPoint(9, 10, 11);
+    points->InsertNextPoint(12, 13, 14);
+    vtkMesh->SetPoints(points);
+    auto cells = vtkSmartPointer<vtkCellArray>::New();
+    cells->InsertNextCell({0, 1, 2, 3});
+    cells->InsertNextCell({1, 2, 3, 4});
+    cells->InsertNextCell({2, 3, 4, 0});
+    vtkMesh->SetPolys(cells);
+
+    auto mesh = data::Mesh::New();
+    io::vtk::helper::Mesh::fromVTKMesh(vtkMesh, mesh);
+
+    auto meshLock  = mesh->dump_lock();
+    std::uint8_t i = 0;
+    for(auto p : mesh->crange<data::iterator::point::xyz>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i, p.x);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 1, p.y);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 2, p.z);
+        i++;
+    }
+
+    i = 0;
+    for(auto c : mesh->crange<data::iterator::cell::quad>())
+    {
+        std::uint8_t j = 0;
+        for(auto pt : c.pt)
+        {
+            CPPUNIT_ASSERT_EQUAL_MESSAGE(
+                "point " + std::to_string(j) + " of cell " + std::to_string(i),
+                (i + j) % 5U,
+                pt
+            );
+            j++;
+        }
+
+        i++;
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::fromVtkMeshWithCellTexCoordsTest()
+{
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    auto points  = vtkSmartPointer<vtkPoints>::New();
+    points->InsertNextPoint(0, 1, 2);
+    points->InsertNextPoint(3, 4, 5);
+    points->InsertNextPoint(6, 7, 8);
+    vtkMesh->SetPoints(points);
+    auto cells                    = vtkSmartPointer<vtkCellArray>::New();
+    std::vector<vtkIdType> idList = {0};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    idList = {1};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    idList = {2};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    vtkMesh->SetVerts(cells);
+    auto* texCoordsArray = new float [6] {0, 1, 1, 2, 2, 3};
+    auto texCoords       = vtkSmartPointer<vtkFloatArray>::New();
+    texCoords->SetNumberOfComponents(2);
+    texCoords->SetArray(texCoordsArray, 3, 0, vtkFloatArray::VTK_DATA_ARRAY_DELETE);
+    vtkMesh->GetCellData()->SetTCoords(texCoords);
+
+    auto mesh = data::Mesh::New();
+    io::vtk::helper::Mesh::fromVTKMesh(vtkMesh, mesh);
+
+    auto meshLock  = mesh->dump_lock();
+    std::uint8_t i = 0;
+    for(auto p : mesh->crange<data::iterator::point::xyz>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i, p.x);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 1, p.y);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 2, p.z);
+        i++;
+    }
+
+    i = 0;
+    for(auto [c, uv] : mesh->czip_range<data::iterator::cell::point, data::iterator::cell::uv>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), unsigned(i), c.pt);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), float(i), uv.u);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), float(i) + 1, uv.v);
+        i++;
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void MeshTest::fromVtkMeshWith3ComponentsCellColorsTest()
+{
+    auto vtkMesh = vtkSmartPointer<vtkPolyData>::New();
+    auto points  = vtkSmartPointer<vtkPoints>::New();
+    points->InsertNextPoint(0, 1, 2);
+    points->InsertNextPoint(3, 4, 5);
+    points->InsertNextPoint(6, 7, 8);
+    vtkMesh->SetPoints(points);
+    auto cells                    = vtkSmartPointer<vtkCellArray>::New();
+    std::vector<vtkIdType> idList = {0};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    idList = {1};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    idList = {2};
+    cells->InsertNextCell(static_cast<vtkIdType>(idList.size()), idList.data());
+    vtkMesh->SetVerts(cells);
+    auto* colorsArray = new std::uint8_t[9] {0, 1, 2, 3, 4, 5, 6, 7, 8};
+    auto colors       = vtkSmartPointer<vtkUnsignedCharArray>::New();
+    colors->SetNumberOfComponents(3);
+    colors->SetName("Colors");
+    colors->SetArray(colorsArray, 3, 0, vtkFloatArray::VTK_DATA_ARRAY_DELETE);
+    vtkMesh->GetCellData()->SetScalars(colors);
+
+    auto mesh = data::Mesh::New();
+    io::vtk::helper::Mesh::fromVTKMesh(vtkMesh, mesh);
+
+    auto meshLock  = mesh->dump_lock();
+    std::uint8_t i = 0;
+    for(auto p : mesh->crange<data::iterator::point::xyz>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i, p.x);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 1, p.y);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("point " + std::to_string(i), 3.F * i + 2, p.z);
+        i++;
+    }
+
+    i = 0;
+    for(auto [c, rgba] : mesh->czip_range<data::iterator::cell::point, data::iterator::cell::rgba>())
+    {
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), unsigned(i), c.pt);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), std::uint8_t(3 * i), rgba.r);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), std::uint8_t(3 * i + 1), rgba.g);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), std::uint8_t(3 * i + 2), rgba.b);
+        CPPUNIT_ASSERT_EQUAL_MESSAGE("cell " + std::to_string(i), std::uint8_t(255), rgba.a);
+        i++;
+    }
+}
+
+} // namespace sight::io::vtk::ut
