@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -84,25 +84,29 @@ public:
         {
             return ArchiveFormat::FILESYSTEM;
         }
-        else if(archiveFormat == archiveFormatToString(ArchiveFormat::COMPATIBLE))
+
+        if(archiveFormat == archiveFormatToString(ArchiveFormat::COMPATIBLE))
         {
             return ArchiveFormat::COMPATIBLE;
         }
-        else if(archiveFormat == archiveFormatToString(ArchiveFormat::OPTIMIZED))
+
+        if(archiveFormat == archiveFormatToString(ArchiveFormat::OPTIMIZED))
         {
             return ArchiveFormat::OPTIMIZED;
         }
-        else if(archiveFormat.empty() || archiveFormat == "default")
+
+        if(archiveFormat.empty() || archiveFormat == "default")
         {
             return ArchiveFormat::DEFAULT;
         }
-        else
-        {
-            // Error case
-            return ArchiveFormat::INVALID;
-        }
+
+        // Error case
+        return ArchiveFormat::INVALID;
     }
 
+    /// Returns the path of the archive
+    inline const std::filesystem::path& getArchivePath() const;
+
 protected:
 
     /// Constructor
@@ -113,4 +117,11 @@ private:
     const std::filesystem::path m_archive_path;
 };
 
-} // namespace sight::io::session
+//------------------------------------------------------------------------------
+
+inline const std::filesystem::path& Archive::getArchivePath() const
+{
+    return m_archive_path;
+}
+
+} // namespace sight::io::zip
