@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,6 +23,7 @@
 #pragma once
 
 #include "io/zip/Archive.hpp"
+#include "io/zip/config.hpp"
 
 #include <core/crypto/secure_string.hpp>
 
@@ -56,7 +57,7 @@ public:
     /// @param format the format of the archive. @see sight::io::zip::Archive::ArchiveFormat
     IO_ZIP_API static ArchiveReader::uptr get(
         const std::filesystem::path& archive_path,
-        const ArchiveFormat format = ArchiveFormat::DEFAULT
+        ArchiveFormat format = ArchiveFormat::DEFAULT
     );
 
     /// Returns an std::istream to read an archived file
@@ -67,8 +68,16 @@ public:
         const core::crypto::secure_string& password = ""
     )                                               = 0;
 
+    /// Extracts all the content of the archive in the specified folder
+    /// @param outputPath the output folder
+    /// @param password the password needed to decrypt the file.
+    IO_ZIP_API virtual void extractAllTo(
+        const std::filesystem::path& outputPath,
+        const core::crypto::secure_string& password = ""
+    )                                               = 0;
+
     /// Returns true for raw archive
-    IO_ZIP_API virtual bool isRaw() const = 0;
+    [[nodiscard]] IO_ZIP_API virtual bool isRaw() const = 0;
 
 protected:
 
