@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -34,6 +34,7 @@
 
 #include <boost/iostreams/stream.hpp>
 
+#include <cstdlib>
 #include <cstring>
 #include <fstream>
 #include <iostream>
@@ -49,8 +50,17 @@ namespace sight::io::zip
 namespace
 {
 
+// Force deflate if env variable is set
+const bool s_legacy_compression =
+    []
+    {
+        const char* const env_legacy_compression = std::getenv("SIGHT_LEGACY_COMPRESSION");
+
+        return env_legacy_compression != nullptr && std::strncmp(env_legacy_compression, "1", 1) == 0;
+    }();
+
 /// Convert argument to minizip dialect
-static inline std::tuple<std::uint16_t, std::int16_t> to_minizip_parameter(Method method, Level level)
+inline std::tuple<std::uint16_t, std::int16_t> toMinizipParameter(Method method, Level level)
 {
     std::uint16_t minizipMethod = MZ_COMPRESS_METHOD_ZSTD;
     std::int16_t minizipLevel   = MZ_COMPRESS_LEVEL_DEFAULT;
@@ -109,7 +119,12 @@ static inline std::tuple<std::uint16_t, std::int16_t> to_minizip_parameter(Metho
             break;
 
         default:
-            return to_minizip_parameter(Method::ZSTD, level);
+            return toMinizipParameter(Method::ZSTD, level);
+    }
+
+    if(s_legacy_compression && minizipMethod != MZ_COMPRESS_METHOD_DEFLATE)
+    {
+        return toMinizipParameter(Method::DEFLATE, level);
     }
 
     return {minizipMethod, minizipLevel};
@@ -128,7 +143,7 @@ public:
     RawArchiveWriter& operator=(const RawArchiveWriter&) = delete;
     RawArchiveWriter& operator=(RawArchiveWriter&&)      = delete;
 
-    RawArchiveWriter(const std::filesystem::path& root) :
+    explicit RawArchiveWriter(const std::filesystem::path& root) :
         ArchiveWriter(root),
         m_root(root)
     {
@@ -160,7 +175,7 @@ public:
 
     //------------------------------------------------------------------------------
 
-    bool isRaw() const override
+    [[nodiscard]] bool isRaw() const override
     {
         return true;
     }
@@ -184,7 +199,8 @@ public:
 
     inline ZipHandle(const std::filesystem::path& archive_path, const Archive::ArchiveFormat format) :
         m_archive_path(archive_path.string()),
-        m_format(format)
+        m_format(format),
+        m_zip_writer(mz_zip_writer_create())
     {
         // Create the sub directories if needed
         if(archive_path.has_parent_path())
@@ -192,9 +208,6 @@ public:
             std::filesystem::create_directories(archive_path.parent_path());
         }
 
-        // Create zip writer instance
-        mz_zip_writer_create(&m_zip_writer);
-
         SIGHT_THROW_EXCEPTION_IF(
             exception::Write(
                 "Cannot create zip writer instance",
@@ -210,11 +223,14 @@ public:
                                       : Method::DEFAULT;
 
         // Set default options
-        auto [minizipMethod, minizipLevel] = to_minizip_parameter(default_method, Level::DEFAULT);
+        auto [minizipMethod, minizipLevel] = toMinizipParameter(default_method, Level::DEFAULT);
 
         mz_zip_writer_set_compress_method(m_zip_writer, minizipMethod);
         mz_zip_writer_set_compress_level(m_zip_writer, minizipLevel);
-        mz_zip_writer_set_zip_cd(m_zip_writer, m_format == Archive::ArchiveFormat::COMPATIBLE ? 0 : 1);
+        mz_zip_writer_set_zip_cd(
+            m_zip_writer,
+            s_legacy_compression || m_format == Archive::ArchiveFormat::COMPATIBLE ? 0 : 1
+        );
 
         // Open the zip file
         auto result = mz_zip_writer_open_file(m_zip_writer, m_archive_path.c_str(), 0, 0);
@@ -272,34 +288,34 @@ public:
     inline ZipFileHandle(
         std::shared_ptr<ZipHandle> zip_handle,
         const std::filesystem::path& file_path,
-        const core::crypto::secure_string& password = "",
-        const Method method                         = Method::DEFAULT,
-        const Level level                           = Level::DEFAULT
+        core::crypto::secure_string password = "",
+        const Method method                  = Method::DEFAULT,
+        const Level level                    = Level::DEFAULT
     ) :
-        m_file_name(file_path.string()),
-        m_password(password),
-        m_zip_handle(zip_handle)
+        m_fileName(file_path.string()),
+        m_password(std::move(password)),
+        m_zipHandle(std::move(zip_handle))
     {
         // Translate to minizip dialect
-        auto [minizipMethod, minizipLevel] = to_minizip_parameter(
+        auto [minizipMethod, minizipLevel] = toMinizipParameter(
             method != Method::DEFAULT
             ? method
-            : m_zip_handle->m_format == Archive::ArchiveFormat::COMPATIBLE
+            : m_zipHandle->m_format == Archive::ArchiveFormat::COMPATIBLE
             ? Method::DEFLATE
-            : m_zip_handle->m_format == Archive::ArchiveFormat::OPTIMIZED
+            : m_zipHandle->m_format == Archive::ArchiveFormat::OPTIMIZED
             ? Method::ZSTD
             : Method::DEFAULT,
             level
         );
 
         // Set compression method and level
-        mz_zip_writer_set_compress_method(m_zip_handle->m_zip_writer, minizipMethod);
-        mz_zip_writer_set_compress_level(m_zip_handle->m_zip_writer, minizipLevel);
+        mz_zip_writer_set_compress_method(m_zipHandle->m_zip_writer, minizipMethod);
+        mz_zip_writer_set_compress_level(m_zipHandle->m_zip_writer, minizipLevel);
 
         // Set encryption
         const bool use_encryption = !m_password.empty();
-        mz_zip_writer_set_aes(m_zip_handle->m_zip_writer, use_encryption ? 1 : 0);
-        mz_zip_writer_set_password(m_zip_handle->m_zip_writer, use_encryption ? m_password.c_str() : nullptr);
+        mz_zip_writer_set_aes(m_zipHandle->m_zip_writer, use_encryption ? 1 : 0);
+        mz_zip_writer_set_password(m_zipHandle->m_zip_writer, use_encryption ? m_password.c_str() : nullptr);
 
         const auto now = time(nullptr);
 
@@ -312,22 +328,22 @@ public:
         zip_file.modified_date      = now;
         zip_file.accessed_date      = now;
         zip_file.creation_date      = now;
-        zip_file.filename           = m_file_name.c_str();
+        zip_file.filename           = m_fileName.c_str();
 
         if(use_encryption)
         {
-            zip_file.aes_version         = MZ_AES_VERSION;
-            zip_file.aes_encryption_mode = MZ_AES_ENCRYPTION_MODE_256;
+            zip_file.aes_version  = MZ_AES_VERSION;
+            zip_file.aes_strength = MZ_AES_STRENGTH_256;
         }
 
-        const auto result = mz_zip_writer_entry_open(m_zip_handle->m_zip_writer, &zip_file);
+        const auto result = mz_zip_writer_entry_open(m_zipHandle->m_zip_writer, &zip_file);
 
         SIGHT_THROW_EXCEPTION_IF(
             exception::Write(
                 "Cannot write file '"
-                + m_file_name
+                + m_fileName
                 + "' in archive '"
-                + m_zip_handle->m_archive_path
+                + m_zipHandle->m_archive_path
                 + "'. Error code: "
                 + std::to_string(result),
                 result
@@ -338,20 +354,20 @@ public:
 
     inline ~ZipFileHandle()
     {
-        const auto result = mz_zip_writer_entry_close(m_zip_handle->m_zip_writer);
+        const auto result = mz_zip_writer_entry_close(m_zipHandle->m_zip_writer);
 
         // Restore defaults
-        mz_zip_writer_set_compress_method(m_zip_handle->m_zip_writer, MZ_COMPRESS_METHOD_ZSTD);
-        mz_zip_writer_set_compress_level(m_zip_handle->m_zip_writer, MZ_COMPRESS_LEVEL_DEFAULT);
-        mz_zip_writer_set_aes(m_zip_handle->m_zip_writer, 0);
-        mz_zip_writer_set_password(m_zip_handle->m_zip_writer, nullptr);
+        mz_zip_writer_set_compress_method(m_zipHandle->m_zip_writer, MZ_COMPRESS_METHOD_ZSTD);
+        mz_zip_writer_set_compress_level(m_zipHandle->m_zip_writer, MZ_COMPRESS_LEVEL_DEFAULT);
+        mz_zip_writer_set_aes(m_zipHandle->m_zip_writer, 0);
+        mz_zip_writer_set_password(m_zipHandle->m_zip_writer, nullptr);
 
         SIGHT_THROW_EXCEPTION_IF(
             exception::Write(
                 "Cannot close file '"
-                + m_file_name
+                + m_fileName
                 + "' in archive '"
-                + m_zip_handle->m_archive_path
+                + m_zipHandle->m_archive_path
                 + "'. Error code: "
                 + std::to_string(result),
                 result
@@ -365,13 +381,13 @@ private:
     friend class ZipSink;
 
     // Path to the file converted to string because on Windows std::filesystem::path.c_str() returns a wchar*
-    const std::string m_file_name;
+    const std::string m_fileName;
 
     // The password must be kept alive since minizip doesn't copy it
     const core::crypto::secure_string m_password;
 
     // Zip handles pack which contains the zip writer
-    const std::shared_ptr<ZipHandle> m_zip_handle;
+    const std::shared_ptr<ZipHandle> m_zipHandle;
 };
 
 class ZipSink final
@@ -383,8 +399,8 @@ public:
     using category  = boost::iostreams::sink_tag;
 
     // BEWARE: Boost make shallow copies of the ZipSink...
-    ZipSink(const std::shared_ptr<ZipFileHandle> zip_file_handle) :
-        m_zip_file_handle(zip_file_handle)
+    explicit ZipSink(std::shared_ptr<ZipFileHandle> zip_file_handle) :
+        m_zipFileHandle(std::move(zip_file_handle))
     {
     }
 
@@ -392,7 +408,7 @@ public:
     std::streamsize write(const char* buffer, std::streamsize size)
     {
         const auto written = mz_zip_writer_entry_write(
-            m_zip_file_handle->m_zip_handle->m_zip_writer,
+            m_zipFileHandle->m_zipHandle->m_zip_writer,
             buffer,
             std::int32_t(size)
         );
@@ -400,9 +416,9 @@ public:
         SIGHT_THROW_EXCEPTION_IF(
             exception::Write(
                 "Cannot write in file '"
-                + m_zip_file_handle->m_file_name
+                + m_zipFileHandle->m_fileName
                 + "' in archive '"
-                + m_zip_file_handle->m_zip_handle->m_archive_path
+                + m_zipFileHandle->m_zipHandle->m_archive_path
                 + "'. Error code: "
                 + std::to_string(written),
                 written
@@ -415,7 +431,7 @@ public:
 
 private:
 
-    const std::shared_ptr<ZipFileHandle> m_zip_file_handle;
+    const std::shared_ptr<ZipFileHandle> m_zipFileHandle;
 };
 
 class ZipArchiveWriter final : public ArchiveWriter
@@ -433,7 +449,7 @@ public:
 
     inline ZipArchiveWriter(const std::filesystem::path& archive_path, const ArchiveFormat format) :
         ArchiveWriter(archive_path),
-        m_zip_handle(std::make_shared<ZipHandle>(archive_path, format))
+        m_zipHandle(std::make_shared<ZipHandle>(archive_path, format))
     {
     }
 
@@ -449,7 +465,7 @@ public:
     ) override
     {
         const auto zip_file_handle = std::make_shared<ZipFileHandle>(
-            m_zip_handle,
+            m_zipHandle,
             file_path,
             password,
             method,
@@ -461,17 +477,17 @@ public:
 
     //------------------------------------------------------------------------------
 
-    inline bool isRaw() const override
+    [[nodiscard]] inline bool isRaw() const override
     {
         return false;
     }
 
 private:
 
-    std::shared_ptr<ZipHandle> m_zip_handle;
+    std::shared_ptr<ZipHandle> m_zipHandle;
 };
 
-} // namespace anonymous
+} // namespace
 
 ArchiveWriter::ArchiveWriter(const std::filesystem::path& archive_path) :
     Archive(archive_path)
@@ -489,10 +505,8 @@ ArchiveWriter::uptr ArchiveWriter::get(
     {
         return std::make_unique<RawArchiveWriter>(archivePath);
     }
-    else
-    {
-        return std::make_unique<ZipArchiveWriter>(archivePath, format);
-    }
+
+    return std::make_unique<ZipArchiveWriter>(archivePath, format);
 }
 
 } // namespace sight::io::zip
