@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <core/Exception.hpp>
 
-namespace sight::io::zip
-{
-
-namespace exception
+namespace sight::io::zip::exception
 {
 
 /// Read exception.
@@ -52,6 +49,4 @@ struct BadPassword : Read
     }
 };
 
-} // namespace exception
-
-} // namespace sight::io::zip
+} // namespace sight::io::zip::exception
