@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,22 +22,21 @@
 
 #include "ArchiveTest.hpp"
 
-#include <core/tools/System.hpp>
+#include <core/os/TempPath.hpp>
 
 #include <io/zip/ArchiveReader.hpp>
 #include <io/zip/ArchiveWriter.hpp>
 #include <io/zip/exception/Read.hpp>
 
+#include <boost/algorithm/string.hpp>
+
 #include <iostream>
 #include <string>
 
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::io::zip::ut::ArchiveTest);
 
-namespace sight::io::zip
-{
-
-namespace ut
+namespace sight::io::zip::ut
 {
 
 //------------------------------------------------------------------------------
@@ -61,16 +60,27 @@ void ArchiveTest::newTest()
     // Nominal test
     {
         // Create a temporary file
-        const std::filesystem::path folderPath = core::tools::System::getTemporaryFolder();
-        std::filesystem::create_directories(folderPath);
-        const std::filesystem::path archivePath = folderPath / "newTest.zip";
+        core::os::TempDir tmpDir;
+        const std::filesystem::path archivePath = tmpDir / "newTest.zip";
 
         {
             auto archiveWriter = ArchiveWriter::get(archivePath);
+
+            // check the archive path getter
+            CPPUNIT_ASSERT_EQUAL(
+                archivePath,
+                archiveWriter->getArchivePath()
+            );
         }
 
         {
-            auto archive_reader = ArchiveReader::get(archivePath);
+            auto archiveReader = ArchiveReader::get(archivePath);
+
+            // check the archive path getter
+            CPPUNIT_ASSERT_EQUAL(
+                archivePath,
+                archiveReader->getArchivePath()
+            );
         }
     }
 
@@ -89,9 +99,8 @@ void ArchiveTest::newTest()
 void ArchiveTest::singletonTest()
 {
     // Create a temporary file
-    const std::filesystem::path folderPath = core::tools::System::getTemporaryFolder();
-    std::filesystem::create_directories(folderPath);
-    const std::filesystem::path archivePath = folderPath / "singletonTest.zip";
+    core::os::TempDir tmpDir;
+    const std::filesystem::path archivePath = tmpDir / "singletonTest.zip";
 
     // Error test
     {
@@ -110,9 +119,8 @@ void ArchiveTest::singletonTest()
 void ArchiveTest::openTest()
 {
     // Create a temporary file
-    const std::filesystem::path folderPath = core::tools::System::getTemporaryFolder();
-    std::filesystem::create_directories(folderPath);
-    const std::filesystem::path archivePath = folderPath / "openTest.zip";
+    core::os::TempDir tmpDir;
+    const std::filesystem::path archivePath = tmpDir / "openTest.zip";
 
     // Test default parameters
     const std::string unencrypted_zstd_default("unencrypted_zstd_default");
@@ -201,10 +209,10 @@ void ArchiveTest::openTest()
 void ArchiveTest::rawTest()
 {
     // Create a temporary file
-    std::filesystem::path folderPath = core::tools::System::getTemporaryFolder();
+    core::os::TempDir tmpDir;
 
     // use a complex uncreated path
-    folderPath = folderPath / std::filesystem::path("a/b/c/d");
+    auto folderPath = tmpDir / std::filesystem::path("a/b/c/d");
 
     // Test default parameters
     const std::string raw_text("raw_text");
@@ -232,6 +240,36 @@ void ArchiveTest::rawTest()
     std::filesystem::remove_all(folderPath);
 }
 
-} // namespace ut
+//------------------------------------------------------------------------------
 
-} // namespace sight::io::zip
+void ArchiveTest::archiveFormatToStringTest()
+{
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(name) \
+    CPPUNIT_ASSERT_EQUAL( \
+        boost::to_lower_copy(std::string(#name)), \
+        std::string(Archive::archiveFormatToString(Archive::ArchiveFormat::name)) \
+    )
+    TEST(FILESYSTEM);
+    TEST(COMPATIBLE);
+    TEST(OPTIMIZED);
+    #undef TEST
+}
+
+//------------------------------------------------------------------------------
+
+void ArchiveTest::stringToArchiveFormat()
+{
+    // NOLINTNEXTLINE(cppcoreguidelines-macro-usage)
+    #define TEST(name) \
+    CPPUNIT_ASSERT_EQUAL( \
+        Archive::ArchiveFormat::name, \
+        Archive::stringToArchiveFormat(boost::to_lower_copy(std::string(#name))) \
+    )
+    TEST(FILESYSTEM);
+    TEST(COMPATIBLE);
+    TEST(OPTIMIZED);
+    #undef TEST
+}
+
+} // namespace sight::io::zip::ut
