@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::io::zip
-{
-
-namespace ut
+namespace sight::io::zip::ut
 {
 
 class ArchiveTest : public CPPUNIT_NS::TestFixture
@@ -37,20 +34,22 @@ CPPUNIT_TEST(newTest);
 CPPUNIT_TEST(singletonTest);
 CPPUNIT_TEST(openTest);
 CPPUNIT_TEST(rawTest);
+CPPUNIT_TEST(archiveFormatToStringTest);
+CPPUNIT_TEST(stringToArchiveFormat);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void newTest();
-    void singletonTest();
-    void openTest();
-    void rawTest();
+    static void newTest();
+    static void singletonTest();
+    static void openTest();
+    static void rawTest();
+    static void archiveFormatToStringTest();
+    static void stringToArchiveFormat();
 };
 
-} // namespace ut
-
-} // namespace sight::io::zip
+} // namespace sight::io::zip::ut
