@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::io::zip
-{
-
-namespace ut
+namespace sight::io::zip::ut
 {
 
 class DirTest : public CPPUNIT_NS::TestFixture
@@ -41,14 +38,12 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void writeReadFileTest();
-    void writeDirTest();
-    void putFileTest();
+    static void writeReadFileTest();
+    static void writeDirTest();
+    static void putFileTest();
 };
 
-} // namespace ut
-
-} // namespace sight::io::zip
+} // namespace sight::io::zip::ut
