@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,9 +28,13 @@
 
 #include <core/base.hpp>
 
+#include <boost/property_tree/ptree.hpp>
+
 namespace sight::ui::base
 {
 
+using config_t = boost::property_tree::ptree;
+
 /**
  * @brief Base class for all fwGui's classes
  */
@@ -61,19 +65,8 @@ public:
 
 protected:
 
-    /**
-     * @name Constructor/Destructor
-     * @{ */
-
-    GuiBaseObject()
-    {
-    }
-
-    virtual ~GuiBaseObject()
-    {
-    }
-
-    /**  @} */
+    GuiBaseObject()           = default;
+    ~GuiBaseObject() override = default;
 };
 
 } // namespace sight::ui::base
