@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -41,14 +41,12 @@ GuiRegistry::MenuMapType GuiRegistry::m_globalSIDToFwMenu;
 GuiRegistry::ActionToParentMapType GuiRegistry::m_actionSIDToParentSID;
 
 GuiRegistry::GuiRegistry()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 GuiRegistry::~GuiRegistry()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -297,7 +295,7 @@ void GuiRegistry::registerActionSIDToParentSID(std::string actionSid, std::strin
     {
         // Action already exist in map
         SIGHT_ASSERT(
-            "The action '" + actionSid + "' already exists for the parent '" + parentSid + "'",
+            std::string("The action '") + actionSid + "' already exists for the parent '" + parentSid + "'",
             std::find(
                 m_actionSIDToParentSID[actionSid].begin(),
                 m_actionSIDToParentSID[actionSid].end(),
@@ -337,10 +335,10 @@ void GuiRegistry::unregisterActionSIDToParentSID(std::string actionSid, std::str
     else
     {
         // Action has several parents
-        ParentSidsType::iterator iter =
+        auto iter =
             std::find(m_actionSIDToParentSID[actionSid].begin(), m_actionSIDToParentSID[actionSid].end(), parentSid);
         SIGHT_ASSERT(
-            "The action with the sid '" + actionSid + "' has no parent named '" + parentSid + "'",
+            std::string("The action with the sid '") + actionSid + "' has no parent named '" + parentSid + "'",
             iter != m_actionSIDToParentSID[actionSid].end()
         );
         m_actionSIDToParentSID[actionSid].erase(iter);
@@ -355,11 +353,12 @@ void GuiRegistry::actionServiceStopping(std::string actionSid)
     {
         ParentSidsType parentSids = m_actionSIDToParentSID[actionSid];
 
-        for(std::string parentSid : parentSids)
+        for(const std::string& parentSid : parentSids)
         {
             bool service_exists = core::tools::fwID::exist(parentSid);
             SIGHT_INFO_IF(
-                "The service '" + parentSid + "' managing the action '" + actionSid + "' does not exist.",
+                std::string("The service '") + parentSid + "' managing the action '" + actionSid
+                + "' does not exist.",
                 !service_exists
             );
             if(service_exists)
@@ -378,8 +377,8 @@ void GuiRegistry::actionServiceStopping(std::string actionSid)
                 else
                 {
                     SIGHT_FATAL(
-                        "The service '" + parentSid + "' managing the action '" + actionSid
-                        + "' must be managed by a menu or a toolBar"
+                        std::string("The service '") + parentSid + "' managing the action '"
+                        + actionSid + "' must be managed by a menu or a toolBar"
                     );
                 }
             }
@@ -395,11 +394,12 @@ void GuiRegistry::actionServiceStarting(std::string actionSid)
     {
         ParentSidsType parentSids = m_actionSIDToParentSID[actionSid];
 
-        for(std::string parentSid : parentSids)
+        for(const std::string& parentSid : parentSids)
         {
             bool service_exists = core::tools::fwID::exist(parentSid);
             SIGHT_INFO_IF(
-                "The service '" + parentSid + "' managing the action '" + actionSid + "' does not exist.",
+                std::string("The service '") + parentSid + "' managing the action '" + actionSid
+                + "' does not exist.",
                 !service_exists
             );
             if(service_exists)
@@ -418,8 +418,8 @@ void GuiRegistry::actionServiceStarting(std::string actionSid)
                 else
                 {
                     SIGHT_FATAL(
-                        "The service '" + parentSid + "' managing the action '" + actionSid
-                        + "' must be managed by a menu or a toolBar"
+                        std::string("The service '") + parentSid + "' managing the action '"
+                        + actionSid + "' must be managed by a menu or a toolBar"
                     );
                 }
             }
@@ -429,17 +429,18 @@ void GuiRegistry::actionServiceStarting(std::string actionSid)
 
 //-----------------------------------------------------------------------------
 
-void GuiRegistry::actionServiceSetActive(std::string actionSid, bool isActive)
+void GuiRegistry::actionServiceSetChecked(std::string actionSid, bool isChecked)
 {
     if(m_actionSIDToParentSID.find(actionSid) != m_actionSIDToParentSID.end())
     {
         ParentSidsType parentSids = m_actionSIDToParentSID[actionSid];
 
-        for(std::string parentSid : parentSids)
+        for(const std::string& parentSid : parentSids)
         {
             bool service_exists = core::tools::fwID::exist(parentSid);
             SIGHT_INFO_IF(
-                "The service '" + parentSid + "' managing the action '" + actionSid + "' does not exist.",
+                std::string("The service '") + parentSid + "' managing the action '" + actionSid
+                + "' does not exist.",
                 !service_exists
             );
             if(service_exists)
@@ -449,17 +450,17 @@ void GuiRegistry::actionServiceSetActive(std::string actionSid, bool isActive)
                 ui::base::IToolBar::sptr toolbarSrv = ui::base::IToolBar::dynamicCast(service);
                 if(menuSrv)
                 {
-                    menuSrv->actionServiceSetActive(actionSid, isActive);
+                    menuSrv->actionServiceSetChecked(actionSid, isChecked);
                 }
                 else if(toolbarSrv)
                 {
-                    toolbarSrv->actionServiceSetActive(actionSid, isActive);
+                    toolbarSrv->actionServiceSetChecked(actionSid, isChecked);
                 }
                 else
                 {
                     SIGHT_FATAL(
-                        "The service '" + parentSid + "' managing the action '" + actionSid
-                        + "' must be managed by a menu or a toolBar"
+                        std::string("The service '") + parentSid + "' managing the action '"
+                        + actionSid + "' must be managed by a menu or a toolBar"
                     );
                 }
             }
@@ -469,17 +470,18 @@ void GuiRegistry::actionServiceSetActive(std::string actionSid, bool isActive)
 
 //-----------------------------------------------------------------------------
 
-void GuiRegistry::actionServiceSetExecutable(std::string actionSid, bool isExecutable)
+void GuiRegistry::actionServiceSetEnabled(std::string actionSid, bool isEnabled)
 {
     if(m_actionSIDToParentSID.find(actionSid) != m_actionSIDToParentSID.end())
     {
         ParentSidsType parentSids = m_actionSIDToParentSID[actionSid];
 
-        for(std::string parentSid : parentSids)
+        for(const std::string& parentSid : parentSids)
         {
             bool service_exists = core::tools::fwID::exist(parentSid);
             SIGHT_INFO_IF(
-                "The service '" + parentSid + "' managing the action '" + actionSid + "' does not exist.",
+                std::string("The service '") + parentSid + "' managing the action '" + actionSid
+                + "' does not exist.",
                 !service_exists
             );
             if(service_exists)
@@ -489,17 +491,17 @@ void GuiRegistry::actionServiceSetExecutable(std::string actionSid, bool isExecu
                 ui::base::IToolBar::sptr toolbarSrv = ui::base::IToolBar::dynamicCast(service);
                 if(menuSrv)
                 {
-                    menuSrv->actionServiceSetExecutable(actionSid, isExecutable);
+                    menuSrv->actionServiceSetEnabled(actionSid, isEnabled);
                 }
                 else if(toolbarSrv)
                 {
-                    toolbarSrv->actionServiceSetExecutable(actionSid, isExecutable);
+                    toolbarSrv->actionServiceSetEnabled(actionSid, isEnabled);
                 }
                 else
                 {
                     SIGHT_FATAL(
-                        "The service '" + parentSid + "' managing the action '" + actionSid
-                        + "' must be managed by a menu or a toolBar"
+                        std::string("The service '") + parentSid + "' managing the action '"
+                        + actionSid + "' must be managed by a menu or a toolBar"
                     );
                 }
             }
@@ -515,11 +517,12 @@ void GuiRegistry::actionServiceSetVisible(std::string actionSid, bool isVisible)
     {
         ParentSidsType parentSids = m_actionSIDToParentSID[actionSid];
 
-        for(std::string parentSid : parentSids)
+        for(const std::string& parentSid : parentSids)
         {
             bool service_exists = core::tools::fwID::exist(parentSid);
             SIGHT_INFO_IF(
-                "The service '" + parentSid + "' managing the action '" + actionSid + "' does not exist.",
+                std::string("The service '") + parentSid + "' managing the action '" + actionSid
+                + "' does not exist.",
                 !service_exists
             );
             if(service_exists)
@@ -538,8 +541,8 @@ void GuiRegistry::actionServiceSetVisible(std::string actionSid, bool isVisible)
                 else
                 {
                     SIGHT_FATAL(
-                        "The service '" + parentSid + "' managing the action '" + actionSid
-                        + "' must be managed by a menu or a toolBar"
+                        std::string("The service '") + parentSid + "' managing the action '"
+                        + actionSid + "' must be managed by a menu or a toolBar"
                     );
                 }
             }
@@ -549,4 +552,4 @@ void GuiRegistry::actionServiceSetVisible(std::string actionSid, bool isVisible)
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::ui
+} // namespace sight::ui::base
