@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,16 +29,13 @@ const IApplication::FactoryRegistryKeyType IApplication::REGISTRY_KEY = "::ui::b
 
 //-----------------------------------------------------------------------------
 
-IApplication::IApplication() :
-    m_confirm(false)
-{
-}
+IApplication::IApplication()
+= default;
 
 //-----------------------------------------------------------------------------
 
 IApplication::~IApplication()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
