@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -43,13 +43,11 @@ public:
 
 protected:
 
-    IDialogEditor() noexcept
-    {
-    }
+    IDialogEditor() noexcept =
+        default;
 
-    virtual ~IDialogEditor() noexcept
-    {
-    }
+    ~IDialogEditor() noexcept override =
+        default;
 };
 
 } // namespace sight::ui::base
