@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,7 +34,6 @@
 
 #include <service/macros.hpp>
 
-#include <boost/foreach.hpp>
 #include <boost/lambda/lambda.hpp>
 
 namespace sight::ui::base
@@ -50,12 +49,12 @@ const core::com::Slots::SlotKeyType IFrame::s_HIDE_SLOT        = "hide";
 
 const core::com::Signals::SignalKeyType IFrame::s_CLOSED_SIG = "closed";
 
-ui::base::container::fwContainer::wptr IFrame::m_progressWidget =
-    std::weak_ptr<ui::base::container::fwContainer>();
+ui::base::container::fwContainer::wptr IFrame::m_progressWidget = std::weak_ptr<ui::base::container::fwContainer>();
+
+//-----------------------------------------------------------------------------
 
 IFrame::IFrame() :
-    m_hasMenuBar(false),
-    m_hasToolBar(false),
+
     m_closePolicy("exit")
 {
     m_sigClosed = newSignal<ClosedSignalType>(s_CLOSED_SIG);
@@ -67,56 +66,41 @@ IFrame::IFrame() :
 
 //-----------------------------------------------------------------------------
 
-IFrame::~IFrame()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void IFrame::initialize()
 {
-    // find gui configuration
-    std::vector<ConfigurationType> vectGui    = m_configuration->find("gui");
-    std::vector<ConfigurationType> vectWindow = m_configuration->find("window");
+    m_viewRegistry = ui::base::registry::View::New(this->getID());
 
-    if(!vectGui.empty())
+    const auto config = this->getConfiguration();
+    const auto gui    = config.get_child_optional("gui");
+
+    if(gui.has_value())
     {
-        // find LayoutManager configuration
-        std::vector<ConfigurationType> vectLayoutMng = vectGui.at(0)->find("frame");
-        SIGHT_ASSERT("[" + this->getID() + "' ] <frame> element must exist", !vectLayoutMng.empty());
-        m_frameConfig = vectLayoutMng.at(0);
-        this->initializeLayoutManager(m_frameConfig);
+        this->initializeLayoutManager(gui->get_child("frame"));
 
-        // find menuBarBuilder configuration
-        std::vector<ConfigurationType> vectMBBuilder = vectGui.at(0)->find("menuBar");
-        if(!vectMBBuilder.empty())
+        if(const auto menuBar = gui->get_child_optional("menuBar"); menuBar.has_value())
         {
-            m_menuBarConfig = vectMBBuilder.at(0);
-            this->initializeMenuBarBuilder(m_menuBarConfig);
+            this->initializeMenuBarBuilder(menuBar.value());
 
             m_hasMenuBar = true;
         }
 
-        // find toolBarBuilder configuration
-        std::vector<ConfigurationType> vectTBBuilder = vectGui.at(0)->find("toolBar");
-        if(!vectTBBuilder.empty())
+        if(const auto toolBar = gui->get_child_optional("toolBar"); toolBar.has_value())
         {
-            m_toolBarConfig = vectTBBuilder.at(0);
-            this->initializeToolBarBuilder(m_toolBarConfig);
+            this->initializeToolBarBuilder(toolBar.value());
 
             m_hasToolBar = true;
         }
+
+        // find ViewRegistryManager configuration
+        if(const auto registry = config.get_child_optional("registry"); registry.has_value())
+        {
+            m_viewRegistry->initialize(registry.value());
+        }
     }
 
-    if(!vectWindow.empty())
+    if(const auto onclose = config.get<std::string>("window.<xmlattr>.onclose", ""); !onclose.empty())
     {
-        ConfigurationType window = vectWindow.at(0);
-        std::string onclose      = window->getAttributeValue("onclose");
-        if(!onclose.empty())
-        {
-            m_closePolicy = onclose;
-        }
-
+        m_closePolicy = onclose;
         SIGHT_ASSERT(
             "[" + this->getID() + "' ] Invalid onclose value, actual: '" << m_closePolicy << "', accepted: '"
             + CLOSE_POLICY_NOTIFY + "', '" + CLOSE_POLICY_EXIT + "' or '" + CLOSE_POLICY_MESSAGE + "'",
@@ -124,15 +108,6 @@ void IFrame::initialize()
             || m_closePolicy == CLOSE_POLICY_MESSAGE
         );
     }
-
-    m_viewRegistry = ui::base::registry::View::New(this->getID());
-    // find ViewRegistryManager configuration
-    std::vector<ConfigurationType> vectRegistry = m_configuration->find("registry");
-    if(!vectRegistry.empty())
-    {
-        m_registryConfig = vectRegistry.at(0);
-        m_viewRegistry->initialize(m_registryConfig);
-    }
 }
 
 //-----------------------------------------------------------------------------
@@ -168,15 +143,15 @@ void IFrame::create()
 
     if(m_closePolicy == CLOSE_POLICY_EXIT)
     {
-        fct = std::bind(&ui::base::IFrame::onCloseExit, this);
+        fct = onCloseExit;
     }
     else if(m_closePolicy == CLOSE_POLICY_NOTIFY)
     {
-        fct = std::bind(&ui::base::IFrame::onCloseNotify, this);
+        fct = [this](auto&& ...){onCloseNotify();};
     }
     else if(m_closePolicy == CLOSE_POLICY_MESSAGE)
     {
-        fct = std::bind(&ui::base::IFrame::onCloseMessage, this);
+        fct = onCloseMessage;
         auto app = ui::base::Application::New();
         app->setConfirm(true);
     }
@@ -258,13 +233,8 @@ void IFrame::destroy()
 
 //-----------------------------------------------------------------------------
 
-void IFrame::initializeLayoutManager(ConfigurationType frameConfig)
+void IFrame::initializeLayoutManager(const ui::base::config_t& layoutConfig)
 {
-    SIGHT_ASSERT(
-        "[" + this->getID() + "' ] Wrong configuration name, expected: 'frame', actual: '"
-        + frameConfig->getName() + "'",
-        frameConfig->getName() == "frame"
-    );
     ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(
         ui::base::layoutManager::IFrameLayoutManager::REGISTRY_KEY
     );
@@ -274,19 +244,13 @@ void IFrame::initializeLayoutManager(ConfigurationType frameConfig)
         m_frameLayoutManager
     );
 
-    m_frameLayoutManager->initialize(frameConfig);
+    m_frameLayoutManager->initialize(layoutConfig);
 }
 
 //-----------------------------------------------------------------------------
 
-void IFrame::initializeMenuBarBuilder(ConfigurationType menuBarConfig)
+void IFrame::initializeMenuBarBuilder(const ui::base::config_t& menuBarConfig)
 {
-    SIGHT_ASSERT(
-        "[" + this->getID() + "' ] Wrong configuration name, expected: 'menuBar', actual: '"
-        + menuBarConfig->getName() + "'",
-        menuBarConfig->getName() == "menuBar"
-    );
-
     ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(ui::base::builder::IMenuBarBuilder::REGISTRY_KEY);
     m_menuBarBuilder = ui::base::builder::IMenuBarBuilder::dynamicCast(guiObj);
     SIGHT_ASSERT(
@@ -299,14 +263,8 @@ void IFrame::initializeMenuBarBuilder(ConfigurationType menuBarConfig)
 
 //-----------------------------------------------------------------------------
 
-void IFrame::initializeToolBarBuilder(ConfigurationType toolBarConfig)
+void IFrame::initializeToolBarBuilder(const ui::base::config_t& toolBarConfig)
 {
-    SIGHT_ASSERT(
-        "[" + this->getID() + "' ] Wrong configuration name, expected: 'toolBar', actual: '"
-        + toolBarConfig->getName() + "'",
-        toolBarConfig->getName() == "toolBar"
-    );
-
     ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(ui::base::builder::IToolBarBuilder::REGISTRY_KEY);
     m_toolBarBuilder = ui::base::builder::IToolBarBuilder::dynamicCast(guiObj);
     SIGHT_ASSERT(
@@ -370,4 +328,4 @@ void IFrame::hide()
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::ui
+} // namespace sight::ui::base
