@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,9 +29,6 @@
 #include "ui/base/layoutManager/IFrameLayoutManager.hpp"
 #include "ui/base/registry/View.hpp"
 
-#include <core/com/Signal.hpp>
-#include <core/com/Signals.hpp>
-
 #include <service/IService.hpp>
 
 namespace sight::ui::base
@@ -79,6 +76,8 @@ namespace sight::ui::base
  *   - \b style : defines frame style (modal, always on top, etc.), not mandatory.
  *     Allowed values are MODAL, STAY_ON_TOP and DEFAULT (default value).
  *   - \b visibility : set the frame visibility when it is created. Possible values are true (default) or false.
+ *   - \b minSize : the minimum width and height the application window can have
+ *   - \b maxSize : the maximum width and height the application window can have
  * - The toolBar section isn't mandatory.
  * - The menuBar section isn't mandatory.
 
@@ -124,10 +123,8 @@ public:
 protected:
 
     UI_BASE_API IFrame();
+    UI_BASE_API ~IFrame() override = default;
 
-    UI_BASE_API virtual ~IFrame();
-
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
     /**
      * @brief Initialize frame managers.
      *
@@ -161,25 +158,20 @@ private:
     /// SLOT: hide the container
     void hide();
 
-    void onCloseExit();
+    static void onCloseExit();
     void onCloseNotify();
-    void onCloseMessage();
-    void initializeLayoutManager(core::runtime::ConfigurationElement::sptr layoutConfig);
-    void initializeMenuBarBuilder(core::runtime::ConfigurationElement::sptr menuBarConfig);
-    void initializeToolBarBuilder(core::runtime::ConfigurationElement::sptr toolBarConfig);
+    static void onCloseMessage();
+    void initializeLayoutManager(const ui::base::config_t& layoutConfig);
+    void initializeMenuBarBuilder(const ui::base::config_t& menuBarConfig);
+    void initializeToolBarBuilder(const ui::base::config_t& toolBarConfig);
 
     ui::base::layoutManager::IFrameLayoutManager::sptr m_frameLayoutManager;
     ui::base::registry::View::sptr m_viewRegistry;
     ui::base::builder::IMenuBarBuilder::sptr m_menuBarBuilder;
     ui::base::builder::IToolBarBuilder::sptr m_toolBarBuilder;
 
-    ConfigurationType m_registryConfig;
-    ConfigurationType m_frameConfig;
-    ConfigurationType m_menuBarConfig;
-    ConfigurationType m_toolBarConfig;
-
-    bool m_hasMenuBar;
-    bool m_hasToolBar;
+    bool m_hasMenuBar {false};
+    bool m_hasToolBar {false};
 
     std::string m_closePolicy;
 
