@@ -25,65 +25,41 @@
 #include "ui/base/IAction.hpp"
 #include "ui/base/IMenuItemCallback.hpp"
 
-#include <core/thread/Worker.hpp>
 #include <core/thread/Worker.hxx>
-#include <core/tools/fwID.hpp>
 
-#include <service/macros.hpp>
 #include <service/op/Get.hpp>
 
 namespace sight::ui::base
 {
 
-IMenu::IMenu() :
-    m_hideActions(false)
-{
-}
+IMenu::IMenu()
+= default;
 
 //-----------------------------------------------------------------------------
 
 IMenu::~IMenu()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void IMenu::initialize()
 {
     m_registry = ui::base::registry::Menu::New(this->getID());
-    // find ViewRegistryManager configuration
-    std::vector<ConfigurationType> vectRegistry = m_configuration->find("registry");
-    SIGHT_ASSERT("[" + this->getID() + "'] <registry> section is mandatory.", !vectRegistry.empty());
 
-    if(!vectRegistry.empty())
+    const auto& config = this->getConfiguration();
+
+    // find ViewRegistryManager configuration
+    if(const auto registryConfig = config.get_child_optional("registry"); registryConfig.has_value())
     {
-        m_registryConfig = vectRegistry.at(0);
-        m_registry->initialize(m_registryConfig);
+        m_registry->initialize(registryConfig.value());
     }
 
-    // find gui configuration
-    std::vector<ConfigurationType> vectGui = m_configuration->find("gui");
-    SIGHT_ASSERT("[" + this->getID() + "'] <gui> section is mandatory.", !vectGui.empty());
-    if(!vectGui.empty())
+    // find LayoutManager configuration
+    if(const auto layoutConfig = config.get_child_optional("gui.layout"); layoutConfig.has_value())
     {
-        // find LayoutManager configuration
-        std::vector<ConfigurationType> vectLayoutMng = vectGui.at(0)->find("layout");
-        SIGHT_ASSERT("[" + this->getID() + "'] <layout> section is mandatory.", !vectLayoutMng.empty());
-        if(!vectLayoutMng.empty())
-        {
-            m_layoutConfig = vectLayoutMng.at(0);
-            this->initializeLayoutManager(m_layoutConfig);
+        this->initializeLayoutManager(layoutConfig.value());
 
-            if(m_layoutConfig->hasAttribute("hideAction"))
-            {
-                std::string hideActions = m_layoutConfig->getAttributeValue("hideActions");
-                SIGHT_ASSERT(
-                    "[" + this->getID() + "'] 'hideActions' attribute value must be 'true' or 'false'",
-                    hideActions == "true" || hideActions == "false"
-                );
-                m_hideActions = (hideActions == "true");
-            }
-        }
+        m_hideActions = layoutConfig->get<bool>("hideActions", m_hideActions);
     }
 }
 
@@ -97,11 +73,13 @@ void IMenu::create()
     SIGHT_ASSERT("Parent menu is unknown.", menu);
     m_layoutManager->setCallbacks(callbacks);
 
+    const std::string serviceID = getID().substr(getID().find_last_of('_') + 1);
+
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
         {
-            m_layoutManager->createLayout(menu);
+            m_layoutManager->createLayout(menu, serviceID);
         })
     ).wait();
 
@@ -182,11 +160,11 @@ void IMenu::actionServiceStarting(std::string actionSrvSID)
             std::function<void()>(
                 [&]
             {
-                m_layoutManager->menuItemSetEnabled(menuItem, actionSrv->getIsExecutable());
-                const bool isInverted = actionSrv->isInverted();
-                const bool isActive   = actionSrv->getIsActive();
-                m_layoutManager->menuItemSetChecked(menuItem, isInverted ? !isActive : isActive);
-                m_layoutManager->menuItemSetVisible(menuItem, actionSrv->isVisible());
+                m_layoutManager->menuItemSetEnabled(menuItem, actionSrv->enabled());
+                const bool inverted  = actionSrv->inverted();
+                const bool isChecked = actionSrv->checked();
+                m_layoutManager->menuItemSetChecked(menuItem, inverted ? !isChecked : isChecked);
+                m_layoutManager->menuItemSetVisible(menuItem, actionSrv->visible());
             })
         ).wait();
     }
@@ -194,7 +172,7 @@ void IMenu::actionServiceStarting(std::string actionSrvSID)
 
 //-----------------------------------------------------------------------------
 
-void IMenu::actionServiceSetActive(std::string actionSrvSID, bool isActive)
+void IMenu::actionServiceSetChecked(std::string actionSrvSID, bool isChecked)
 {
     ui::base::container::fwMenuItem::sptr menuItem = m_registry->getFwMenuItem(
         actionSrvSID,
@@ -208,15 +186,15 @@ void IMenu::actionServiceSetActive(std::string actionSrvSID, bool isActive)
         std::function<void()>(
             [&]
         {
-            const bool isInverted = actionSrv->isInverted();
-            m_layoutManager->menuItemSetChecked(menuItem, isInverted ? !isActive : isActive);
+            const bool inverted = actionSrv->inverted();
+            m_layoutManager->menuItemSetChecked(menuItem, inverted ? !isChecked : isChecked);
         })
     ).wait();
 }
 
 //-----------------------------------------------------------------------------
 
-void IMenu::actionServiceSetExecutable(std::string actionSrvSID, bool isExecutable)
+void IMenu::actionServiceSetEnabled(std::string actionSrvSID, bool isEnabled)
 {
     ui::base::container::fwMenuItem::sptr menuItem = m_registry->getFwMenuItem(
         actionSrvSID,
@@ -227,7 +205,7 @@ void IMenu::actionServiceSetExecutable(std::string actionSrvSID, bool isExecutab
         std::function<void()>(
             [&]
         {
-            m_layoutManager->menuItemSetEnabled(menuItem, isExecutable);
+            m_layoutManager->menuItemSetEnabled(menuItem, isEnabled);
         })
     ).wait();
 }
@@ -252,13 +230,8 @@ void IMenu::actionServiceSetVisible(std::string actionSrvSID, bool isVisible)
 
 //-----------------------------------------------------------------------------
 
-void IMenu::initializeLayoutManager(ConfigurationType layoutConfig)
+void IMenu::initializeLayoutManager(const ui::base::config_t& layoutConfig)
 {
-    SIGHT_ASSERT(
-        "Bad configuration name " << layoutConfig->getName() << ", must be layout",
-        layoutConfig->getName() == "layout"
-    );
-
     ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(
         ui::base::layoutManager::IMenuLayoutManager::REGISTRY_KEY
     );
@@ -273,4 +246,4 @@ void IMenu::initializeLayoutManager(ConfigurationType layoutConfig)
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::ui
+} // namespace sight::ui::base
