@@ -47,10 +47,10 @@ public:
     UI_BASE_API void actionServiceStarting(std::string actionSrvSID);
 
     /// Method called when the action service is activated
-    UI_BASE_API void actionServiceSetActive(std::string actionSrvSID, bool isActive);
+    UI_BASE_API void actionServiceSetChecked(std::string actionSrvSID, bool isChecked);
 
     /// Method called when the action service is executable
-    UI_BASE_API void actionServiceSetExecutable(std::string actionSrvSID, bool isExecutable);
+    UI_BASE_API void actionServiceSetEnabled(std::string actionSrvSID, bool isEnabled);
 
     /// Method called when the action service is visible
     UI_BASE_API void actionServiceSetVisible(std::string actionSrvSID, bool isVisible);
@@ -59,9 +59,7 @@ protected:
 
     UI_BASE_API IMenu();
 
-    UI_BASE_API virtual ~IMenu();
-
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
+    UI_BASE_API ~IMenu() override;
 
     /**
      * @brief Initialize the layout and registry managers.
@@ -116,16 +114,13 @@ protected:
 
 private:
 
-    void initializeLayoutManager(core::runtime::ConfigurationElement::sptr layoutConfig);
+    void initializeLayoutManager(const ui::base::config_t& layoutConfig);
 
     ui::base::layoutManager::IMenuLayoutManager::sptr m_layoutManager;
     ui::base::registry::Menu::sptr m_registry;
 
-    ConfigurationType m_registryConfig;
-    ConfigurationType m_layoutConfig;
-
     /// Flag to hide or disable the actions if the service is stopped
-    bool m_hideActions;
+    bool m_hideActions {false};
 };
 
 } // namespace sight::ui::base
