@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -49,11 +49,8 @@ public:
 
 protected:
 
-    UI_BASE_API IMenuBar();
-
-    UI_BASE_API virtual ~IMenuBar();
-
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
+    UI_BASE_API IMenuBar()           = default;
+    UI_BASE_API ~IMenuBar() override = default;
 
     /**
      * @brief Initialize the layout and registry managers.
@@ -97,16 +94,13 @@ protected:
 
 private:
 
-    void initializeLayoutManager(core::runtime::ConfigurationElement::sptr layoutConfig);
+    void initializeLayoutManager(const ui::base::config_t& layoutConfig);
 
     ui::base::layoutManager::IMenuBarLayoutManager::sptr m_layoutManager;
     ui::base::registry::MenuBar::sptr m_registry;
 
-    ConfigurationType m_registryConfig;
-    ConfigurationType m_layoutConfig;
-
     /// Flag to hide or disable the menu if the service is stopped
-    bool m_hideMenus;
+    bool m_hideMenus {false};
 };
 
 } // namespace sight::ui::base
