@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,6 +25,8 @@
 #include "ui/base/IAction.hpp"
 #include "ui/base/IMenuItemCallback.hpp"
 
+#include <core/com/Slot.hxx>
+#include <core/com/Slots.hxx>
 #include <core/thread/Worker.hpp>
 #include <core/thread/Worker.hxx>
 #include <core/tools/fwID.hpp>
@@ -35,15 +37,14 @@
 namespace sight::ui::base
 {
 
-IToolBar::IToolBar() :
-    m_hideActions(false)
-{
-}
-
 //-----------------------------------------------------------------------------
 
-IToolBar::~IToolBar()
+IToolBar::IToolBar()
 {
+    newSlot(slots::s_SET_VISIBLE_SLOT, &IToolBar::setVisible, this);
+    newSlot(slots::s_SET_VISIBLE_BY_PARAM_SLOT, &IToolBar::setVisibleByParameter, this);
+    newSlot(slots::s_SHOW_SLOT, &IToolBar::show, this);
+    newSlot(slots::s_HIDE_SLOT, &IToolBar::hide, this);
 }
 
 //-----------------------------------------------------------------------------
@@ -51,41 +52,21 @@ IToolBar::~IToolBar()
 void IToolBar::initialize()
 {
     m_registry = ui::base::registry::ToolBar::New(this->getID());
-    // find ViewRegistryManager configuration
-    std::vector<ConfigurationType> vectRegistry = m_configuration->find("registry");
-    SIGHT_ASSERT("[" + this->getID() + "'] <registry> section is mandatory.", !vectRegistry.empty());
 
-    if(!vectRegistry.empty())
+    const auto& config = this->getConfiguration();
+
+    // find ViewRegistryManager configuration
+    if(const auto registryConfig = config.get_child_optional("registry"); registryConfig.has_value())
     {
-        m_registryConfig = vectRegistry.at(0);
-        m_registry->initialize(m_registryConfig);
+        m_registry->initialize(registryConfig.value());
     }
 
-    // find gui configuration
-    std::vector<ConfigurationType> vectGui = m_configuration->find("gui");
-    SIGHT_ASSERT("[" + this->getID() + "'] <gui> section is mandatory.", !vectGui.empty());
-
-    if(!vectGui.empty())
+    // find LayoutManager configuration
+    if(const auto layoutConfig = config.get_child_optional("gui.layout"); layoutConfig.has_value())
     {
-        // find LayoutManager configuration
-        std::vector<ConfigurationType> vectLayoutMng = vectGui.at(0)->find("layout");
-        SIGHT_ASSERT("[" + this->getID() + "'] <layout> section is mandatory.", !vectLayoutMng.empty());
+        this->initializeLayoutManager(layoutConfig.value());
 
-        if(!vectLayoutMng.empty())
-        {
-            m_layoutConfig = vectLayoutMng.at(0);
-            this->initializeLayoutManager(m_layoutConfig);
-
-            if(m_layoutConfig->hasAttribute("hideActions"))
-            {
-                std::string hideActions = m_layoutConfig->getAttributeValue("hideActions");
-                SIGHT_ASSERT(
-                    "[" + this->getID() + "'] 'hideActions' attribute value must be 'true' or 'false'",
-                    hideActions == "true" || hideActions == "false"
-                );
-                m_hideActions = (hideActions == "true");
-            }
-        }
+        m_hideActions = layoutConfig->get<bool>("hideActions", m_hideActions);
     }
 }
 
@@ -99,11 +80,13 @@ void IToolBar::create()
     SIGHT_ASSERT("Parent toolBar is unknown.", toolBar);
     m_layoutManager->setCallbacks(callbacks);
 
+    const std::string serviceID = getID().substr(getID().find_last_of('_') + 1);
+
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
         {
-            m_layoutManager->createLayout(toolBar);
+            m_layoutManager->createLayout(toolBar, serviceID);
         })
     ).wait();
 
@@ -174,18 +157,18 @@ void IToolBar::actionServiceStarting(std::string actionSrvSID)
         std::function<void()>(
             [&]
         {
-            m_layoutManager->menuItemSetEnabled(menuItem, actionSrv->getIsExecutable());
-            const bool isInverted = actionSrv->isInverted();
-            const bool isActive   = actionSrv->getIsActive();
-            m_layoutManager->menuItemSetChecked(menuItem, isInverted ? !isActive : isActive);
-            m_layoutManager->menuItemSetVisible(menuItem, actionSrv->isVisible());
+            m_layoutManager->menuItemSetEnabled(menuItem, actionSrv->enabled());
+            const bool inverted  = actionSrv->inverted();
+            const bool isChecked = actionSrv->checked();
+            m_layoutManager->menuItemSetChecked(menuItem, inverted ? !isChecked : isChecked);
+            m_layoutManager->menuItemSetVisible(menuItem, actionSrv->visible());
         })
     ).wait();
 }
 
 //-----------------------------------------------------------------------------
 
-void IToolBar::actionServiceSetActive(std::string actionSrvSID, bool isActive)
+void IToolBar::actionServiceSetChecked(std::string actionSrvSID, bool isChecked)
 {
     ui::base::container::fwMenuItem::sptr menuItem = m_registry->getFwMenuItem(
         actionSrvSID,
@@ -199,15 +182,15 @@ void IToolBar::actionServiceSetActive(std::string actionSrvSID, bool isActive)
         std::function<void()>(
             [&]
         {
-            const bool isInverted = actionSrv->isInverted();
-            m_layoutManager->menuItemSetChecked(menuItem, isInverted ? !isActive : isActive);
+            const bool inverted = actionSrv->inverted();
+            m_layoutManager->menuItemSetChecked(menuItem, inverted ? !isChecked : isChecked);
         })
     ).wait();
 }
 
 //-----------------------------------------------------------------------------
 
-void IToolBar::actionServiceSetExecutable(std::string actionSrvSID, bool isExecutable)
+void IToolBar::actionServiceSetEnabled(std::string actionSrvSID, bool isEnabled)
 {
     ui::base::container::fwMenuItem::sptr menuItem = m_registry->getFwMenuItem(
         actionSrvSID,
@@ -218,7 +201,7 @@ void IToolBar::actionServiceSetExecutable(std::string actionSrvSID, bool isExecu
         std::function<void()>(
             [&]
         {
-            m_layoutManager->menuItemSetEnabled(menuItem, isExecutable);
+            m_layoutManager->menuItemSetEnabled(menuItem, isEnabled);
         })
     ).wait();
 }
@@ -243,13 +226,8 @@ void IToolBar::actionServiceSetVisible(std::string actionSrvSID, bool isVisible)
 
 //-----------------------------------------------------------------------------
 
-void IToolBar::initializeLayoutManager(ConfigurationType layoutConfig)
+void IToolBar::initializeLayoutManager(const ui::base::config_t& layoutConfig)
 {
-    SIGHT_ASSERT(
-        "Bad configuration name " << layoutConfig->getName() << ", must be layout",
-        layoutConfig->getName() == "layout"
-    );
-
     ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(
         ui::base::layoutManager::IToolBarLayoutManager::REGISTRY_KEY
     );
@@ -264,4 +242,34 @@ void IToolBar::initializeLayoutManager(ConfigurationType layoutConfig)
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::ui
+void IToolBar::setVisible(bool isVisible)
+{
+    m_layoutManager->setVisible(isVisible);
+}
+
+//-----------------------------------------------------------------------------
+
+void IToolBar::setVisibleByParameter(ui::base::parameter_t isVisible)
+{
+    // Only consider boolean alternative, skip all other type of the variant.
+    if(std::holds_alternative<bool>(isVisible))
+    {
+        this->setVisible(std::get<bool>(isVisible));
+    }
+}
+
+//-----------------------------------------------------------------------------
+
+void IToolBar::show()
+{
+    this->setVisible(true);
+}
+
+//-----------------------------------------------------------------------------
+
+void IToolBar::hide()
+{
+    this->setVisible(false);
+}
+
+} // namespace sight::ui::base
