@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,6 +28,8 @@
 
 #include <service/IService.hpp>
 
+#include <ui/base/parameter.hpp>
+
 namespace sight::ui::base
 {
 
@@ -47,10 +49,10 @@ public:
     UI_BASE_API void actionServiceStarting(std::string actionSrvSID);
 
     /// Method called when the action service is activated
-    UI_BASE_API void actionServiceSetActive(std::string actionSrvSID, bool isActive);
+    UI_BASE_API void actionServiceSetChecked(std::string actionSrvSID, bool isChecked);
 
     /// Method called when the action service is executable
-    UI_BASE_API void actionServiceSetExecutable(std::string actionSrvSID, bool isExecutable);
+    UI_BASE_API void actionServiceSetEnabled(std::string actionSrvSID, bool isEnabled);
 
     /// Method called when the action service is visible
     UI_BASE_API void actionServiceSetVisible(std::string actionSrvSID, bool isVisible);
@@ -58,10 +60,7 @@ public:
 protected:
 
     UI_BASE_API IToolBar();
-
-    UI_BASE_API virtual ~IToolBar();
-
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
+    UI_BASE_API ~IToolBar() override = default;
 
     /**
      * @brief Initialize the layout and registry managers.
@@ -104,6 +103,13 @@ protected:
      *   - \<menu\> represents IMenu
      *   - \<editor\> represents container service (IEditor, IView, ...)
      *
+     *  * @section Slots Slots
+     * - \b setVisible(bool isVisible) : this slot shows the toolBar (if isVisible = true) or hides it.
+     * - \b setVisibleByParam(ui::base::parameter_t isVisible) : this slot shows the toolBar (if isEnabled holds boolean
+     * alternative) or hides it.
+     * - \b show() : this slot shows the toolBar.
+     * - \b hide() : this slot hides the toolBar.
+     *
      *   @warning
      *   - The number of item in the gui section must be EQUAL to the registry section.
      *   - The order of the item in each section (gui and registry) must be the same.\n
@@ -120,18 +126,37 @@ protected:
     /// Destroy the layout and stop the managed services.
     UI_BASE_API void destroy();
 
+    /// @brief slots: change the toolbar visibility
+    struct slots
+    {
+        using key_t = sight::core::com::Slots::SlotKeyType;
+        static inline const key_t s_SET_VISIBLE_SLOT          = "setVisible";
+        static inline const key_t s_SET_VISIBLE_BY_PARAM_SLOT = "setVisibleByParam";
+        static inline const key_t s_SHOW_SLOT                 = "show";
+        static inline const key_t s_HIDE_SLOT                 = "hide";
+    };
+
+    /// SLOT: show/hide the container
+    UI_BASE_API void setVisible(bool isVisible);
+
+    /// SLOT: show/hide the container using parameter_t (only testing bool alternative).
+    UI_BASE_API void setVisibleByParameter(ui::base::parameter_t);
+
+    /// SLOT: show the container
+    UI_BASE_API void show();
+
+    /// SLOT: hide the container
+    UI_BASE_API void hide();
+
 private:
 
-    void initializeLayoutManager(core::runtime::ConfigurationElement::sptr layoutConfig);
+    void initializeLayoutManager(const ui::base::config_t& layoutConfig);
 
     ui::base::layoutManager::IToolBarLayoutManager::sptr m_layoutManager;
     ui::base::registry::ToolBar::sptr m_registry;
 
-    ConfigurationType m_registryConfig;
-    ConfigurationType m_layoutConfig;
-
     /// Flag to hide or disable the actions if the service is stopped
-    bool m_hideActions;
+    bool m_hideActions {false};
 };
 
 } // namespace sight::ui::base
