@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,10 +29,7 @@
 
 #include <boost/lexical_cast.hpp>
 
-namespace sight::ui::base
-{
-
-namespace builder
+namespace sight::ui::base::builder
 {
 
 const IToolBarBuilder::RegistryKeyType IToolBarBuilder::REGISTRY_KEY = "::ui::base::ToolBarBuilder";
@@ -40,42 +37,30 @@ const IToolBarBuilder::RegistryKeyType IToolBarBuilder::REGISTRY_KEY = "::ui::ba
 //-----------------------------------------------------------------------------
 
 IToolBarBuilder::IToolBarBuilder() :
-    m_alignment(TOP)
-{
-    m_toolBitmapSize = std::make_pair(32, 32);
-}
-
-//-----------------------------------------------------------------------------
-
-IToolBarBuilder::~IToolBarBuilder()
+    m_toolBitmapSize(std::make_pair(-1, -1))
 {
 }
 
 //-----------------------------------------------------------------------------
 
-void IToolBarBuilder::initialize(core::runtime::ConfigurationElement::sptr configuration)
+void IToolBarBuilder::initialize(const ui::base::config_t& configuration)
 {
-    SIGHT_ASSERT(
-        "Bad configuration name " << configuration->getName() << ", must be toolBar",
-        configuration->getName() == "toolBar"
-    );
-
-    if(configuration->hasAttribute("align"))
+    const auto alignment = configuration.get_optional<std::string>("<xmlattr>.align");
+    if(alignment.has_value())
     {
-        std::string alignment = configuration->getExistingAttributeValue("align");
-        if(alignment == "top")
+        if(alignment.value() == "top")
         {
             m_alignment = TOP;
         }
-        else if(alignment == "bottom")
+        else if(alignment.value() == "bottom")
         {
             m_alignment = BOTTOM;
         }
-        else if(alignment == "right")
+        else if(alignment.value() == "right")
         {
             m_alignment = RIGHT;
         }
-        else if(alignment == "left")
+        else if(alignment.value() == "left")
         {
             m_alignment = LEFT;
         }
@@ -85,37 +70,19 @@ void IToolBarBuilder::initialize(core::runtime::ConfigurationElement::sptr confi
         }
     }
 
-    if(configuration->hasAttribute("backgroundColor"))
+    if(const auto hexaColor = configuration.get<std::string>("<xmlattr>.backgroundColor", ""); !hexaColor.empty())
     {
-        const std::string hexaColor = configuration->getExistingAttributeValue("backgroundColor");
-        if(!hexaColor.empty())
-        {
-            SIGHT_ASSERT(
-                "Color string should start with '#' and followed by 6 or 8 "
-                "hexadecimal digits. Given color: " << hexaColor,
-                hexaColor[0] == '#'
-                && (hexaColor.length() == 7 || hexaColor.length() == 9)
-            );
-            m_backgroundColor = hexaColor;
-        }
+        SIGHT_ASSERT(
+            "Color string should start with '#' and followed by 6 or 8 "
+            "hexadecimal digits. Given color: " << hexaColor,
+            hexaColor[0] == '#'
+            && (hexaColor.length() == 7 || hexaColor.length() == 9)
+        );
+        m_backgroundColor = hexaColor;
     }
 
-    core::runtime::ConfigurationElementContainer::Iterator iter;
-    for(iter = configuration->begin() ; iter != configuration->end() ; ++iter)
-    {
-        if((*iter)->getName() == "toolBitmapSize")
-        {
-            if((*iter)->hasAttribute("height"))
-            {
-                m_toolBitmapSize.second = boost::lexical_cast<int>((*iter)->getExistingAttributeValue("height"));
-            }
-
-            if((*iter)->hasAttribute("width"))
-            {
-                m_toolBitmapSize.first = boost::lexical_cast<int>((*iter)->getExistingAttributeValue("width"));
-            }
-        }
-    }
+    m_toolBitmapSize.first  = configuration.get<int>("toolBitmapSize.<xmlattr>.width", m_toolBitmapSize.first);
+    m_toolBitmapSize.second = configuration.get<int>("toolBitmapSize.<xmlattr>.height", m_toolBitmapSize.second);
 }
 
 //-----------------------------------------------------------------------------
@@ -127,6 +94,4 @@ ui::base::container::fwToolBar::sptr IToolBarBuilder::getToolBar()
 
 //-----------------------------------------------------------------------------
 
-} // namespace builder
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::builder
