@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,10 +25,7 @@
 #include "ui/base/config.hpp"
 #include "ui/base/GuiBaseObject.hpp"
 
-namespace sight::ui::base
-{
-
-namespace container
+namespace sight::ui::base::container
 {
 
 /**
@@ -44,6 +41,4 @@ public:
     UI_BASE_API virtual void destroyContainer() = 0;
 };
 
-} // namespace container
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::container
