@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -21,13 +21,3 @@
  ***********************************************************************/
 
 #include "ui/base/container/fwToolBar.hpp"
-
-namespace sight::ui::base
-{
-
-namespace container
-{
-
-}
-
-}
