@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,14 +28,13 @@
 #include <data/String.hpp>
 
 #include <service/IService.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/base/Preferences.hpp>
 
-namespace sight::ui::base
-{
+#include <boost/algorithm/string.hpp>
 
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 const ILocationDialog::FactoryRegistryKeyType ILocationDialog::REGISTRY_KEY = "::ui::base::dialog::LocationDialog";
@@ -46,36 +45,34 @@ const std::string ILocationDialog::DLG_DEFAULT_DIRECTORY = "DLG_DEFAULT_DIRECTOR
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_key(const std::string& title)
+inline static std::string getFrameKey(const std::string& title)
 {
-    return ILocationDialog::SOFTWARE_UI + "." + title;
+    return std::string(ILocationDialog::SOFTWARE_UI) + "." + title;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_file_key(const std::string& title)
+inline static std::string getFileKey(const std::string& title)
 {
-    return get_frame_key(title) + "." + ILocationDialog::DLG_DEFAULT_FILE;
+    return getFrameKey(title) + "." + ILocationDialog::DLG_DEFAULT_FILE;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_directory_key(const std::string& title)
+inline static std::string getDirectoryKey(const std::string& title)
 {
-    return get_frame_key(title) + "." + ILocationDialog::DLG_DEFAULT_DIRECTORY;
+    return getFrameKey(title) + "." + ILocationDialog::DLG_DEFAULT_DIRECTORY;
 }
 
 //-----------------------------------------------------------------------------
 
 ILocationDialog::ILocationDialog()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 ILocationDialog::~ILocationDialog()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -100,7 +97,7 @@ void ILocationDialog::setDefaultLocation(core::location::ILocation::sptr loc)
 
 //------------------------------------------------------------------------------
 
-const core::location::ILocation::sptr ILocationDialog::getDefaultLocation()
+core::location::ILocation::sptr ILocationDialog::getDefaultLocation()
 {
     core::location::ILocation::sptr location;
 
@@ -108,7 +105,7 @@ const core::location::ILocation::sptr ILocationDialog::getDefaultLocation()
     {
         ui::base::Preferences preferences;
 
-        if(const auto& default_file = preferences.get_optional<std::filesystem::path>(get_file_key(getTitle()));
+        if(const auto& default_file = preferences.get_optional<std::filesystem::path>(getFileKey(getTitle()));
            default_file)
         {
             auto single_file = std::make_shared<core::location::SingleFile>();
@@ -116,7 +113,7 @@ const core::location::ILocation::sptr ILocationDialog::getDefaultLocation()
             location = single_file;
         }
         else if(const auto& default_directory =
-                    preferences.get_optional<std::filesystem::path>(get_directory_key(getTitle())); default_directory)
+                    preferences.get_optional<std::filesystem::path>(getDirectoryKey(getTitle())); default_directory)
         {
             auto single_directory = std::make_shared<core::location::SingleFolder>();
             single_directory->setFolder(*default_directory);
@@ -148,11 +145,11 @@ void ILocationDialog::saveDefaultLocation(core::location::ILocation::sptr loc)
 
             if(auto singleFile = core::location::SingleFile::dynamicCast(loc))
             {
-                preferences.put(get_file_key(getTitle()), singleFile->getFile());
+                preferences.put(getFileKey(getTitle()), singleFile->getFile());
             }
             else if(auto singleDirectory = core::location::SingleFolder::dynamicCast(loc))
             {
-                preferences.put(get_directory_key(getTitle()), singleDirectory->getFolder());
+                preferences.put(getDirectoryKey(getTitle()), singleDirectory->getFolder());
             }
         }
         catch(const ui::base::PreferencesDisabled&)
@@ -162,8 +159,26 @@ void ILocationDialog::saveDefaultLocation(core::location::ILocation::sptr loc)
     }
 }
 
+//------------------------------------------------------------------------------
+
+std::vector<std::string> ILocationDialog::getSelectedExtensions() const
+{
+    // Get the current selection, remove all "*" characters
+    const std::string& selection = boost::replace_all_copy(getCurrentSelection(), "*", "");
+
+    // Split the selection into a vector of extensions
+    std::vector<std::string> extensions;
+
+    boost::split(
+        extensions,
+        selection,
+        boost::is_any_of(" "),
+        boost::token_compress_on
+    );
+
+    return extensions;
+}
+
 //-----------------------------------------------------------------------------
 
-} //namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
