@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,10 +22,7 @@
 
 #include "ui/base/dialog/ILoggerDialog.hpp"
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 const ILoggerDialog::FactoryRegistryKeyType ILoggerDialog::REGISTRY_KEY = "::ui::base::dialog::LoggerDialog";
@@ -33,17 +30,13 @@ const ILoggerDialog::FactoryRegistryKeyType ILoggerDialog::REGISTRY_KEY = "::ui:
 //-----------------------------------------------------------------------------
 
 ILoggerDialog::ILoggerDialog()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 ILoggerDialog::~ILoggerDialog()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
-} // namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
