@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,23 +22,16 @@
 
 #include "ui/base/dialog/IMultiSelectorDialog.hpp"
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 const IMultiSelectorDialog::FactoryRegistryKeyType IMultiSelectorDialog::REGISTRY_KEY =
     "::ui::base::dialog::MultiSelectorDialog";
 
 IMultiSelectorDialog::IMultiSelectorDialog()
-{
-}
+= default;
 
 IMultiSelectorDialog::~IMultiSelectorDialog()
-{
-}
+= default;
 
-} // namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
