@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,15 +24,12 @@
 
 #include <core/thread/Worker.hpp>
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 //-----------------------------------------------------------------------------
 
-std::string InputDialog::showInputDialog(
+std::pair<std::string, bool> InputDialog::showInputDialog(
     const std::string& title,
     const std::string& message,
     const std::string& text,
@@ -50,10 +47,10 @@ InputDialog::InputDialog()
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IInputDialog::REGISTRY_KEY);
-                m_implementation                     = ui::base::dialog::IInputDialog::dynamicCast(guiObj);
-            })
+        {
+            ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IInputDialog::REGISTRY_KEY);
+            m_implementation                     = ui::base::dialog::IInputDialog::dynamicCast(guiObj);
+        })
     );
 }
 
@@ -69,22 +66,21 @@ InputDialog::InputDialog(
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IInputDialog::REGISTRY_KEY);
-                m_implementation                     = ui::base::dialog::IInputDialog::dynamicCast(guiObj);
-                m_implementation->setTitle(title);
-                m_implementation->setMessage(message);
-                m_implementation->setInput(text);
-                m_implementation->setEchoMode(echoMode);
-            })
+        {
+            ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IInputDialog::REGISTRY_KEY);
+            m_implementation                     = ui::base::dialog::IInputDialog::dynamicCast(guiObj);
+            m_implementation->setTitle(title);
+            m_implementation->setMessage(message);
+            m_implementation->setInput(text);
+            m_implementation->setEchoMode(echoMode);
+        })
     );
 }
 
 //-----------------------------------------------------------------------------
 
 InputDialog::~InputDialog()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -93,9 +89,9 @@ void InputDialog::setTitle(const std::string& title)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                m_implementation->setTitle(title);
-            })
+        {
+            m_implementation->setTitle(title);
+        })
     ).wait();
 }
 
@@ -106,9 +102,9 @@ void InputDialog::setMessage(const std::string& msg)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                m_implementation->setMessage(msg);
-            })
+        {
+            m_implementation->setMessage(msg);
+        })
     ).wait();
 }
 
@@ -119,9 +115,9 @@ void InputDialog::setInput(const std::string& text)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                m_implementation->setInput(text);
-            })
+        {
+            m_implementation->setInput(text);
+        })
     ).wait();
 }
 
@@ -132,25 +128,23 @@ void InputDialog::setEchoMode(EchoMode echoMode)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                m_implementation->setEchoMode(echoMode);
-            })
+        {
+            m_implementation->setEchoMode(echoMode);
+        })
     ).wait();
 }
 
 //-----------------------------------------------------------------------------
 
-std::string InputDialog::getInput()
+std::pair<std::string, bool> InputDialog::getInput()
 {
-    std::function<std::string()> func = std::bind(&IInputDialog::getInput, m_implementation);
-    std::shared_future<std::string> f =
-        core::thread::getDefaultWorker()->postTask<std::string>(func);
+    std::function<std::pair<std::string, bool>()> func  = [this](auto&& ...){return m_implementation->getInput();};
+    std::shared_future<std::pair<std::string, bool> > f =
+        core::thread::getDefaultWorker()->postTask<std::pair<std::string, bool> >(func);
     f.wait();
     return f.get();
 }
 
 //-----------------------------------------------------------------------------
 
-} //namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
