@@ -26,10 +26,7 @@
 
 #include <functional>
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 //-----------------------------------------------------------------------------
@@ -47,26 +44,15 @@ IMessageDialog::Buttons MessageDialog::show(
 
 //-----------------------------------------------------------------------------
 
-IMessageDialog::Buttons MessageDialog::showMessageDialog(
-    const std::string& title,
-    const std::string& message,
-    ui::base::dialog::IMessageDialog::Icons icon
-)
-{
-    return show(title, message, icon);
-}
-
-//-----------------------------------------------------------------------------
-
 MessageDialog::MessageDialog()
 {
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMessageDialog::REGISTRY_KEY);
-                m_implementation                     = ui::base::dialog::IMessageDialog::dynamicCast(guiObj);
-            })
+        {
+            ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMessageDialog::REGISTRY_KEY);
+            m_implementation                     = ui::base::dialog::IMessageDialog::dynamicCast(guiObj);
+        })
     ).wait();
 }
 
@@ -81,25 +67,24 @@ MessageDialog::MessageDialog(
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
-            {
-                ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMessageDialog::REGISTRY_KEY);
-                m_implementation                     = ui::base::dialog::IMessageDialog::dynamicCast(guiObj);
+        {
+            ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMessageDialog::REGISTRY_KEY);
+            m_implementation                     = ui::base::dialog::IMessageDialog::dynamicCast(guiObj);
 
-                if(m_implementation)
-                {
-                    m_implementation->setTitle(title);
-                    m_implementation->setMessage(message);
-                    m_implementation->setIcon(icon);
-                }
-            })
+            if(m_implementation)
+            {
+                m_implementation->setTitle(title);
+                m_implementation->setMessage(message);
+                m_implementation->setIcon(icon);
+            }
+        })
     ).wait();
 }
 
 //-----------------------------------------------------------------------------
 
 MessageDialog::~MessageDialog()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -108,12 +93,12 @@ void MessageDialog::setTitle(const std::string& title)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->setTitle(title);
-                }
-            })
+                m_implementation->setTitle(title);
+            }
+        })
     ).wait();
 }
 
@@ -124,12 +109,12 @@ void MessageDialog::setMessage(const std::string& msg)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->setMessage(msg);
-                }
-            })
+                m_implementation->setMessage(msg);
+            }
+        })
     ).wait();
 }
 
@@ -140,12 +125,12 @@ void MessageDialog::setIcon(ui::base::dialog::IMessageDialog::Icons icon)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->setIcon(icon);
-                }
-            })
+                m_implementation->setIcon(icon);
+            }
+        })
     ).wait();
 }
 
@@ -156,12 +141,12 @@ void MessageDialog::addButton(ui::base::dialog::IMessageDialog::Buttons button)
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->addButton(button);
-                }
-            })
+                m_implementation->addButton(button);
+            }
+        })
     ).wait();
 }
 
@@ -172,12 +157,12 @@ void MessageDialog::setDefaultButton(ui::base::dialog::IMessageDialog::Buttons b
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->setDefaultButton(button);
-                }
-            })
+                m_implementation->setDefaultButton(button);
+            }
+        })
     ).wait();
 }
 
@@ -188,12 +173,12 @@ void MessageDialog::addCustomButton(const std::string& label, std::function<void
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [&]
+        {
+            if(m_implementation)
             {
-                if(m_implementation)
-                {
-                    m_implementation->addCustomButton(label, clickedFn);
-                }
-            })
+                m_implementation->addCustomButton(label, clickedFn);
+            }
+        })
     ).wait();
 }
 
@@ -203,22 +188,18 @@ ui::base::dialog::IMessageDialog::Buttons MessageDialog::show()
 {
     if(m_implementation)
     {
-        typedef ui::base::dialog::IMessageDialog::Buttons R;
+        using R = ui::base::dialog::IMessageDialog::Buttons;
 
-        std::function<R()> func = std::bind(&IMessageDialog::show, m_implementation);
+        std::function<R()> func = [this](auto&& ...){return m_implementation->show();};
         std::shared_future<R> f = core::thread::getDefaultWorker()->postTask<R>(func);
         f.wait();
 
         return f.get();
     }
-    else
-    {
-        return ui::base::dialog::IMessageDialog::NOBUTTON;
-    }
+
+    return ui::base::dialog::IMessageDialog::NOBUTTON;
 }
 
 //-----------------------------------------------------------------------------
 
-} //namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
