@@ -24,10 +24,7 @@
 
 #include <core/thread/Worker.hpp>
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 //-----------------------------------------------------------------------------
@@ -37,10 +34,10 @@ MultiSelectorDialog::MultiSelectorDialog()
     core::thread::getDefaultWorker()->postTask<void>(
         std::function<void()>(
             [this]
-            {
-                ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMultiSelectorDialog::REGISTRY_KEY);
-                m_implementation                     = ui::base::dialog::IMultiSelectorDialog::dynamicCast(guiObj);
-            })
+        {
+            ui::base::GuiBaseObject::sptr guiObj = ui::base::factory::New(IMultiSelectorDialog::REGISTRY_KEY);
+            m_implementation                     = ui::base::dialog::IMultiSelectorDialog::dynamicCast(guiObj);
+        })
     ).wait();
 }
 
@@ -50,17 +47,17 @@ void MultiSelectorDialog::setTitle(std::string title)
 {
     core::thread::getDefaultWorker()->postTask<void>(
         [&]
-            {
-                m_implementation->setTitle(title);
-            }).wait();
+        {
+            m_implementation->setTitle(title);
+        }).wait();
 }
 
 //-----------------------------------------------------------------------------
 
 IMultiSelectorDialog::Selections MultiSelectorDialog::show()
 {
-    typedef IMultiSelectorDialog::Selections R;
-    std::function<R()> func = std::bind(&IMultiSelectorDialog::show, m_implementation);
+    using R = IMultiSelectorDialog::Selections;
+    std::function<R()> func = [this](auto&& ...){return m_implementation->show();};
     std::shared_future<R> f = core::thread::getDefaultWorker()->postTask<R>(func);
 
     f.wait();
@@ -73,9 +70,9 @@ void MultiSelectorDialog::setSelections(Selections _selections)
 {
     core::thread::getDefaultWorker()->postTask<void>(
         [&]
-            {
-                m_implementation->setSelections(_selections);
-            }).wait();
+        {
+            m_implementation->setSelections(_selections);
+        }).wait();
 }
 
 //-----------------------------------------------------------------------------
@@ -84,13 +81,11 @@ void MultiSelectorDialog::setMessage(const std::string& msg)
 {
     core::thread::getDefaultWorker()->postTask<void>(
         [&]
-            {
-                m_implementation->setMessage(msg);
-            }).wait();
+        {
+            m_implementation->setMessage(msg);
+        }).wait();
 }
 
 //-----------------------------------------------------------------------------
 
-} //namespace dialog
-
-} //namespace sight::ui::base
+} // namespace sight::ui::base::dialog
