@@ -27,16 +27,13 @@
 
 #include <core/base.hpp>
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 /**
  * @brief   MultiSelectorDialog allows the choice of some element among several (_selections)
  *
- * Use the Delegate design pattern. The specific implementation selection is ensured by fwGuiRegisterMacro
+ * Use the Delegate design pattern. The specific implementation selection is ensured by SIGHT_REGISTER_GUI
  * The specific implementation are in fwGuiWX and fwGuiQT libraries
  *
  */
@@ -68,6 +65,4 @@ protected:
     ui::base::dialog::IMultiSelectorDialog::sptr m_implementation;
 };
 
-} //namespace dialog
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::dialog
