@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,10 +27,7 @@
 
 #include <core/base.hpp>
 
-namespace sight::ui::base
-{
-
-namespace dialog
+namespace sight::ui::base::dialog
 {
 
 /**
@@ -43,61 +40,47 @@ public:
 
     SIGHT_DECLARE_CLASS(NotificationDialog, ui::base::dialog::INotificationDialog, new NotificationDialog);
 
-    /**
-     * Opens a default message box with the specified title, text and icon.
-     *
-     * @param _message Message of the notification box
-     * @param _type type of the notification box (SUCCESS, FAILURE or INFO)
-     * @param _pos position where notification is displayed (TOP_LEFT, TOP_RIGHT, ...)
-     */
-    UI_BASE_API static void show(
-        const std::string& _message,
-        INotificationDialog::Type _type =
-        INotificationDialog::Type::DEFAULT,
-        INotificationDialog::Position _pos = INotificationDialog::Position::DEFAULT
-    );
-
-    /**
-     * Opens a default message box with the specified title, text and icon.
-     *
-     * @param _message Message of the notification box
-     * @param _type type of the notification box (SUCCESS, FAILURE or INFO)
-     * @param _pos position where notification is displayed (TOP_LEFT, TOP_RIGHT, ...)
-     * @deprecated use show() instead
-     */
-    [[deprecated("Sight 22.0, use show() instead.")]]
-    UI_BASE_API static void showNotificationDialog(
-        const std::string& _message,
-        INotificationDialog::Type _type =
-        INotificationDialog::Type::DEFAULT,
-        INotificationDialog::Position _pos = INotificationDialog::Position::DEFAULT
+    /// Opens a default message box with the specified title, text and icon.
+    /// @param _message Message of the notification box
+    /// @param _type type of the notification box (SUCCESS, FAILURE or INFO)
+    /// @param _pos position where notification is displayed (TOP_LEFT, TOP_RIGHT, ...)
+    /// @{
+    UI_BASE_API static void show(service::Notification notification);
+    inline static void show(
+        std::string _message,
+        service::Notification::Type _type    = service::Notification::Type::INFO,
+        service::Notification::Position _pos = service::Notification::Position::TOP_RIGHT
     );
+    /// @}
 
     /// Constructor. Create the implementation of the specific message box
     UI_BASE_API NotificationDialog();
 
-    /**
-     * Constructor
-     * Creates a notification box with the specified text and type.
-     *
-     * @param _message message of the notification box
-     * @param _type type of the notification box (SUCCESS, FAILURE or INFO)
-     * @param _pos position where notification is displayed (TOP_LEFT, TOP_RIGHT, ...)
-     */
-    UI_BASE_API NotificationDialog(
-        const std::string& _message,
-        INotificationDialog::Type _type    = INotificationDialog::Type::DEFAULT,
-        INotificationDialog::Position _pos = INotificationDialog::Position::DEFAULT
-    );
+    /// Constructor. Creates a notification box with the specified text and type.
+    /// @param _message message of the notification box
+    /// @param _type type of the notification box (SUCCESS, FAILURE or INFO)
+    /// @param _pos position where notification is displayed (TOP_LEFT, TOP_RIGHT, ...)
+    /// @{
+    UI_BASE_API NotificationDialog(service::Notification notification);
+    inline explicit NotificationDialog(
+        std::string _message,
+        service::Notification::Type _type    = service::Notification::Type::INFO,
+        service::Notification::Position _pos = service::Notification::Position::TOP_RIGHT
+    ) :
+        NotificationDialog({.type = _type, .position = _pos, .message = std::move(_message)})
+    {
+    }
+
+    /// @}
 
     /// Destructor. Does nothing
-    UI_BASE_API ~NotificationDialog() override;
+    UI_BASE_API ~NotificationDialog() override = default;
 
-    /// Shows the message box and return the clicked button.
+    /// Shows the notification.
     UI_BASE_API void show() override;
 
     /// Sets the message.
-    UI_BASE_API void setMessage(const std::string& _msg) override;
+    UI_BASE_API void setMessage(std::string _msg) override;
 
     /// Sets the notification type.
     UI_BASE_API void setType(Type _type) override;
@@ -106,13 +89,23 @@ public:
     UI_BASE_API void setPosition(Position _position) override;
 
     /// Sets the size
-    UI_BASE_API void setSize(unsigned int _width, unsigned int _height) override;
+    UI_BASE_API void setSize(std::array<int, 2> _size) override;
+    UI_BASE_API std::array<int, 2> getSize() const override;
 
     /// Sets the index
     UI_BASE_API void setIndex(unsigned int _index) override;
 
     /// Sets the duration in ms.
-    UI_BASE_API void setDuration(int _durationInMs) override;
+    UI_BASE_API void setDuration(std::optional<std::chrono::milliseconds> _durationInMs) override;
+    UI_BASE_API std::optional<std::chrono::milliseconds> getDuration() const override;
+
+    /// Sets the channel. Empty string for default global channel
+    UI_BASE_API void setChannel(std::string) override;
+    UI_BASE_API std::string getChannel() const override;
+
+    /// Sets the closable property. std::nullopt means finite duration is closable
+    UI_BASE_API void setClosable(std::optional<bool> _closable) override;
+    UI_BASE_API std::optional<bool> isClosable() const override;
 
     /**
      * @brief Gets the visibility
@@ -141,6 +134,15 @@ protected:
     ui::base::dialog::INotificationDialog::sptr m_implementation;
 };
 
-} //namespace dialog
+//------------------------------------------------------------------------------
 
-} // namespace sight::ui::base
+inline void NotificationDialog::show(
+    std::string _message,
+    service::Notification::Type _type,
+    service::Notification::Position _pos
+)
+{
+    show({.type = _type, .position = _pos, .message = std::move(_message)});
+}
+
+} // namespace sight::ui::base::dialog
