@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,13 +23,13 @@
 #include "ui/base/layoutManager/IFrameLayoutManager.hpp"
 
 #include <core/base.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <data/Integer.hpp>
 #include <data/String.hpp>
 
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/base/Preferences.hpp>
 
@@ -37,10 +37,7 @@
 
 #include <filesystem>
 
-namespace sight::ui::base
-{
-
-namespace layoutManager
+namespace sight::ui::base::layoutManager
 {
 
 //-----------------------------------------------------------------------------
@@ -56,133 +53,92 @@ const std::string IFrameLayoutManager::FRAME_POSITION_Y_UI = "FRAME_POSITION_Y_U
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_key(const std::string& name)
+inline static std::string getFrameKey(const std::string& name)
 {
-    return IFrameLayoutManager::SOFTWARE_UI + "." + name;
+    return std::string(IFrameLayoutManager::SOFTWARE_UI) + "." + name;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_state_key(const std::string& name)
+inline static std::string getFrameStateKey(const std::string& name)
 {
-    return get_frame_key(name) + "." + IFrameLayoutManager::FRAME_STATE_UI;
+    return getFrameKey(name) + "." + IFrameLayoutManager::FRAME_STATE_UI;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_w_key(const std::string& name)
+inline static std::string getFrameWKey(const std::string& name)
 {
-    return get_frame_key(name) + "." + IFrameLayoutManager::FRAME_SIZE_W_UI;
+    return getFrameKey(name) + "." + IFrameLayoutManager::FRAME_SIZE_W_UI;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_h_key(const std::string& name)
+inline static std::string getFrameHKey(const std::string& name)
 {
-    return get_frame_key(name) + "." + IFrameLayoutManager::FRAME_SIZE_H_UI;
+    return getFrameKey(name) + "." + IFrameLayoutManager::FRAME_SIZE_H_UI;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_x_key(const std::string& name)
+inline static std::string getFrameXKey(const std::string& name)
 {
-    return get_frame_key(name) + "." + IFrameLayoutManager::FRAME_POSITION_X_UI;
+    return getFrameKey(name) + "." + IFrameLayoutManager::FRAME_POSITION_X_UI;
 }
 
 //------------------------------------------------------------------------------
 
-inline static std::string get_frame_y_key(const std::string& name)
+inline static std::string getFrameYKey(const std::string& name)
 {
-    return get_frame_key(name) + "." + IFrameLayoutManager::FRAME_POSITION_Y_UI;
+    return getFrameKey(name) + "." + IFrameLayoutManager::FRAME_POSITION_Y_UI;
 }
 
 //-----------------------------------------------------------------------------
 
 IFrameLayoutManager::IFrameLayoutManager()
 {
-    CloseCallback fct = std::bind(&ui::base::layoutManager::IFrameLayoutManager::defaultCloseCallback, this);
-    this->setCloseCallback(fct);
+    this->IFrameLayoutManager::setCloseCallback(defaultCloseCallback);
 }
 
 //-----------------------------------------------------------------------------
 
-IFrameLayoutManager::~IFrameLayoutManager()
+void IFrameLayoutManager::initialize(const ui::base::config_t& configuration)
 {
-}
+    m_frameInfo.m_name       = configuration.get<std::string>("name", m_frameInfo.m_name);
+    m_frameInfo.m_version    = configuration.get<std::string>("version", "");
+    m_frameInfo.m_visibility = configuration.get<bool>("visibility", m_frameInfo.m_visibility);
 
-//-----------------------------------------------------------------------------
-
-void IFrameLayoutManager::initialize(ConfigurationType configuration)
-{
-    SIGHT_ASSERT(
-        "Bad configuration name " << configuration->getName() << ", must be frame",
-        configuration->getName() == "frame"
-    );
-
-    std::vector<ConfigurationType> name       = configuration->find("name");
-    std::vector<ConfigurationType> icon       = configuration->find("icon");
-    std::vector<ConfigurationType> minSize    = configuration->find("minSize");
-    std::vector<ConfigurationType> styles     = configuration->find("style");
-    std::vector<ConfigurationType> visibility = configuration->find("visibility");
-
-    if(!visibility.empty())
+    if(const auto icon = configuration.get_optional<std::string>("icon"); icon.has_value())
     {
-        m_frameInfo.m_visibility = (visibility.at(0)->getValue() == "true");
-    }
-
-    if(!name.empty())
-    {
-        m_frameInfo.m_name = name.at(0)->getValue();
-    }
-
-    if(!icon.empty())
-    {
-        m_frameInfo.m_iconPath = core::runtime::getModuleResourceFilePath(icon.at(0)->getValue());
+        m_frameInfo.m_iconPath = core::runtime::getModuleResourceFilePath(icon.value());
         SIGHT_ASSERT(
             "The icon " << m_frameInfo.m_iconPath << " doesn't exist, please ensure that the path is correct",
             std::filesystem::exists(m_frameInfo.m_iconPath)
         );
     }
 
-    if(!minSize.empty())
+    m_frameInfo.m_minSize.first  = configuration.get<int>("minSize.<xmlattr>.width", m_frameInfo.m_minSize.first);
+    m_frameInfo.m_minSize.second = configuration.get<int>("minSize.<xmlattr>.height", m_frameInfo.m_minSize.second);
+    m_frameInfo.m_maxSize.first  = configuration.get<int>("maxSize.<xmlattr>.width", m_frameInfo.m_maxSize.first);
+    m_frameInfo.m_maxSize.second = configuration.get<int>("maxSize.<xmlattr>.height", m_frameInfo.m_maxSize.second);
+
+    if(const auto mode = configuration.get_optional<std::string>("style.<xmlattr>.mode"); mode.has_value())
     {
-        if(minSize.at(0)->hasAttribute("width"))
-        {
-            m_frameInfo.m_minSize.first =
-                boost::lexical_cast<int>(minSize.at(0)->getExistingAttributeValue("width"));
-        }
-
-        if(minSize.at(0)->hasAttribute("height"))
-        {
-            m_frameInfo.m_minSize.second = boost::lexical_cast<int>(
-                minSize.at(0)->getExistingAttributeValue(
-                    "height"
-                )
-            );
-        }
-    }
-
-    if(!styles.empty())
-    {
-        core::runtime::ConfigurationElement::sptr stylesCfgElt = styles.at(0);
-        SIGHT_FATAL_IF("<style> node must contain mode attribute", !stylesCfgElt->hasAttribute("mode"));
-        const std::string style = stylesCfgElt->getExistingAttributeValue("mode");
-
-        if(style == "DEFAULT")
+        if(mode.value() == "DEFAULT")
         {
             m_frameInfo.m_style = DEFAULT;
         }
-        else if(style == "STAY_ON_TOP")
+        else if(mode.value() == "STAY_ON_TOP")
         {
             m_frameInfo.m_style = STAY_ON_TOP;
         }
-        else if(style == "MODAL")
+        else if(mode.value() == "MODAL")
         {
             m_frameInfo.m_style = MODAL;
         }
         else
         {
-            SIGHT_FATAL("The style " << style << " is unknown, it should be DEFAULT, STAY_ON_TOP or MODAL.");
+            SIGHT_FATAL("The style " << mode.value() << " is unknown, it should be DEFAULT, STAY_ON_TOP or MODAL.");
         }
     }
 
@@ -213,17 +169,17 @@ void IFrameLayoutManager::readConfig()
 
         m_frameInfo.m_state =
             static_cast<FrameState>(preferences.get(
-                                        get_frame_state_key(m_frameInfo.m_name),
+                                        getFrameStateKey(m_frameInfo.m_name),
                                         static_cast<std::uint8_t>(m_frameInfo.m_state)
             ));
-        m_frameInfo.m_size.first     = preferences.get(get_frame_w_key(m_frameInfo.m_name), m_frameInfo.m_size.first);
-        m_frameInfo.m_size.second    = preferences.get(get_frame_h_key(m_frameInfo.m_name), m_frameInfo.m_size.second);
+        m_frameInfo.m_size.first     = preferences.get(getFrameWKey(m_frameInfo.m_name), m_frameInfo.m_size.first);
+        m_frameInfo.m_size.second    = preferences.get(getFrameHKey(m_frameInfo.m_name), m_frameInfo.m_size.second);
         m_frameInfo.m_position.first = preferences.get(
-            get_frame_x_key(m_frameInfo.m_name),
+            getFrameXKey(m_frameInfo.m_name),
             m_frameInfo.m_position.first
         );
         m_frameInfo.m_position.second = preferences.get(
-            get_frame_y_key(m_frameInfo.m_name),
+            getFrameYKey(m_frameInfo.m_name),
             m_frameInfo.m_position.second
         );
     }
@@ -235,7 +191,7 @@ void IFrameLayoutManager::readConfig()
 
 //-----------------------------------------------------------------------------
 
-void IFrameLayoutManager::writeConfig()
+void IFrameLayoutManager::writeConfig() const
 {
     try
     {
@@ -243,13 +199,13 @@ void IFrameLayoutManager::writeConfig()
 
         if(m_frameInfo.m_state != FrameState::ICONIZED)
         {
-            preferences.put(get_frame_state_key(m_frameInfo.m_name), static_cast<std::uint8_t>(m_frameInfo.m_state));
+            preferences.put(getFrameStateKey(m_frameInfo.m_name), static_cast<std::uint8_t>(m_frameInfo.m_state));
         }
 
-        preferences.put(get_frame_w_key(m_frameInfo.m_name), m_frameInfo.m_size.first);
-        preferences.put(get_frame_h_key(m_frameInfo.m_name), m_frameInfo.m_size.second);
-        preferences.put(get_frame_x_key(m_frameInfo.m_name), m_frameInfo.m_position.first);
-        preferences.put(get_frame_y_key(m_frameInfo.m_name), m_frameInfo.m_position.second);
+        preferences.put(getFrameWKey(m_frameInfo.m_name), m_frameInfo.m_size.first);
+        preferences.put(getFrameHKey(m_frameInfo.m_name), m_frameInfo.m_size.second);
+        preferences.put(getFrameXKey(m_frameInfo.m_name), m_frameInfo.m_position.first);
+        preferences.put(getFrameYKey(m_frameInfo.m_name), m_frameInfo.m_position.second);
     }
     catch(const ui::base::PreferencesDisabled&)
     {
@@ -259,6 +215,4 @@ void IFrameLayoutManager::writeConfig()
 
 //-----------------------------------------------------------------------------
 
-} // namespace layoutManager
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::layoutManager
