@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,18 +26,11 @@
 #include "ui/base/container/fwContainer.hpp"
 #include "ui/base/GuiBaseObject.hpp"
 
-#include <core/runtime/ConfigurationElement.hpp>
-
-#include <data/Composite.hpp>
-
 #include <filesystem>
 #include <functional>
 #include <list>
 
-namespace sight::ui::base
-{
-
-namespace layoutManager
+namespace sight::ui::base::layoutManager
 {
 
 /**
@@ -49,8 +42,6 @@ public:
 
     SIGHT_DECLARE_CLASS(IFrameLayoutManager, ui::base::GuiBaseObject);
 
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
-
     /// Defines all possible style for a frame
     typedef enum
     {
@@ -81,44 +72,54 @@ public:
     public:
 
         FrameInfo() :
-            m_name(""),
+
             m_minSize(std::make_pair(-1, -1)),
-            m_style(DEFAULT),
             m_size(std::make_pair(-1, -1)),
-            m_position(std::make_pair(-1, -1)),
-            m_state(FrameState::UNKNOWN),
-            m_visibility(true)
+            m_position(std::make_pair(-1, -1))
         {
         }
 
         /// Frame name.
         std::string m_name;
+
+        /// Optional version number, displayed in the title if specified.
+        std::string m_version;
+
         /// Frame icon.
         std::filesystem::path m_iconPath;
+
         /// Frame minimum size (min width and min height)
         std::pair<int, int> m_minSize;
+
+        /// Frame maximum size (max width and max height)
+        std::pair<int, int> m_maxSize {-1, -1};
+
         /// Frame style
-        Style m_style;
+        Style m_style {DEFAULT};
+
         /// Frame size
         std::pair<int, int> m_size;
+
         /// Frame position
         std::pair<int, int> m_position;
+
         /// Frame state (maximize, minized, full screen)
-        FrameState m_state;
+        FrameState m_state {FrameState::UNKNOWN};
+
         /// Frame visibility
-        bool m_visibility;
+        bool m_visibility {true};
     };
 
     /// Constructor. Do nothing.
     UI_BASE_API IFrameLayoutManager();
 
     /// Destructor. Do nothing.
-    UI_BASE_API virtual ~IFrameLayoutManager();
+    UI_BASE_API ~IFrameLayoutManager() override = default;
 
     /**
      * @brief Configure the layout before creation.
      */
-    UI_BASE_API virtual void initialize(ConfigurationType configuration);
+    UI_BASE_API virtual void initialize(const ui::base::config_t& configuration);
 
     UI_BASE_API static const RegistryKeyType REGISTRY_KEY;
 
@@ -179,16 +180,14 @@ protected:
 
     UI_BASE_API void readConfig();
 
-    UI_BASE_API void writeConfig();
+    UI_BASE_API void writeConfig() const;
 
 private:
 
-    void defaultCloseCallback();
+    static void defaultCloseCallback();
 
     /// Save frame configuration definition
     FrameInfo m_frameInfo;
 };
 
-} // namespace layoutManager
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::layoutManager
