@@ -33,14 +33,9 @@
 #include "ui/base/GuiBaseObject.hpp"
 #include "ui/base/IMenuItemCallback.hpp"
 
-#include <core/runtime/ConfigurationElement.hpp>
-
 #include <filesystem>
 
-namespace sight::ui::base
-{
-
-namespace layoutManager
+namespace sight::ui::base::layoutManager
 {
 
 /**
@@ -52,7 +47,6 @@ public:
 
     SIGHT_DECLARE_CLASS(IMenuLayoutManager, ui::base::GuiBaseObject);
 
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
     typedef std::string RegistryKeyType;
     typedef std::vector<ui::base::IMenuItemCallback::sptr> CallbacksType;
 
@@ -71,34 +65,25 @@ public:
     public:
 
         ActionInfo() :
-            m_name(""),
-            m_shortcut(""),
-            m_icon(""),
-            m_isCheckable(false),
-            m_isRadio(false),
-            m_type(DEFAULT),
-            m_isSeparator(false),
-            m_isMenu(false)
+
+            m_icon("")
         {
         }
 
         std::string m_name;
         std::string m_shortcut;
         std::filesystem::path m_icon;
-        bool m_isCheckable;
-        bool m_isRadio;
-        ActionType m_type;
-        bool m_isSeparator;
-        bool m_isMenu;
+        bool m_isCheckable {false};
+        bool m_isRadio {false};
+        ActionType m_type {DEFAULT};
+        bool m_isSeparator {false};
+        bool m_isMenu {false};
     };
 
     UI_BASE_API const static RegistryKeyType REGISTRY_KEY;
 
-    /// Constructor. Do nothing.
-    UI_BASE_API IMenuLayoutManager();
-
     /// Destructor. Do nothing.
-    UI_BASE_API virtual ~IMenuLayoutManager();
+    UI_BASE_API ~IMenuLayoutManager() override = default;
 
     /**
      * @brief Returns the vector of fwMenuItem managed by this layout.
@@ -151,12 +136,12 @@ public:
      *  - \b name (mandatory) : give the name of the menu that will appear in the interface.
      * - \<separator/\> : allow to divide the menu by part (draw a line).
      */
-    UI_BASE_API virtual void initialize(ConfigurationType configuration);
+    UI_BASE_API virtual void initialize(const ui::base::config_t& configuration);
 
     /**
      * @brief Instantiate actions with parent menu.
      */
-    UI_BASE_API virtual void createLayout(ui::base::container::fwMenu::sptr parent) = 0;
+    UI_BASE_API virtual void createLayout(ui::base::container::fwMenu::sptr parent, const std::string& id) = 0;
 
     /**
      * @brief Destroy local actions.
@@ -207,6 +192,4 @@ protected:
     CallbacksType m_callbacks;
 };
 
-} // namespace layoutManager
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::layoutManager
