@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,12 +27,7 @@
 #include "ui/base/container/fwMenuBar.hpp"
 #include "ui/base/GuiBaseObject.hpp"
 
-#include <core/runtime/ConfigurationElement.hpp>
-
-namespace sight::ui::base
-{
-
-namespace registry
+namespace sight::ui::base::registry
 {
 
 /**
@@ -52,10 +47,10 @@ public:
     }
 
     /// Constructor.
-    UI_BASE_API MenuBar(const std::string& sid);
+    UI_BASE_API MenuBar(std::string sid);
 
     /// Destructor. Do nothing
-    UI_BASE_API virtual ~MenuBar();
+    UI_BASE_API ~MenuBar() override = default;
 
     /// Return the parent container
     UI_BASE_API virtual ui::base::container::fwMenuBar::sptr getParent();
@@ -97,7 +92,7 @@ public:
      * service.
      */
 
-    UI_BASE_API virtual void initialize(core::runtime::ConfigurationElement::sptr configuration);
+    UI_BASE_API virtual void initialize(const ui::base::config_t& configuration);
 
     /**
      * @brief Starting menu bar registry.
@@ -116,7 +111,6 @@ public:
 
 protected:
 
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
     typedef std::map<std::string, std::pair<unsigned int, bool> > SIDMenuMapType;
 
     /**
@@ -129,6 +123,4 @@ protected:
     std::string m_sid;
 };
 
-} // namespace registry
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::registry
