@@ -27,35 +27,26 @@
 #include "ui/base/container/fwToolBar.hpp"
 #include "ui/base/GuiRegistry.hpp"
 
-#include <core/runtime/Convert.hpp>
 #include <core/runtime/helper.hpp>
 
-#include <service/macros.hpp>
 #include <service/op/Get.hpp>
 
-#include <boost/property_tree/xml_parser.hpp>
-
 #include <utility>
 
-namespace sight::ui::base
-{
-
-namespace registry
+namespace sight::ui::base::registry
 {
 
 //-----------------------------------------------------------------------------
 
-View::View(const std::string& sid) :
-    m_parentWid(""),
-    m_sid(sid)
+View::View(std::string sid) :
+    m_sid(std::move(sid))
 {
 }
 
 //-----------------------------------------------------------------------------
 
 View::~View()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -92,30 +83,21 @@ void View::setParent(std::string wid)
         "The method 'setParent()' is available only if this service declares its parent container with a 'wid'.",
         !m_parentWid.empty()
     );
-    m_parentWid = wid;
+    m_parentWid = std::move(wid);
 }
 
 //-----------------------------------------------------------------------------
 
-void View::initialize(core::runtime::ConfigurationElement::sptr configuration)
+void View::initialize(const ui::base::config_t& configuration)
 {
-    const auto configTree = core::runtime::Convert::toPropertyTree(configuration);
-    const auto registryIt = configTree.find("registry");
-    SIGHT_THROW_IF(
-        "Wrong configuration name for '" + m_sid + "', expected 'registry'",
-        registryIt == configTree.not_found()
-    );
-
-    // find parent container, ignore if it does not exist
-    m_parentWid = configTree.get<std::string>("registry.parent.<xmlattr>.wid", "");
+    m_parentWid = configuration.get<std::string>("parent.<xmlattr>.wid", "");
 
     // index represents associated container with position in subViews vector
     unsigned int index = 0;
 
     // initialize m_sids and m_wids map with configuration
-    const auto registryCfg  = registryIt->second;
-    const auto viewsIt      = registryCfg.equal_range("view");
-    const auto slideViewsIt = registryCfg.equal_range("slideView");
+    const auto viewsIt      = configuration.equal_range("view");
+    const auto slideViewsIt = configuration.equal_range("slideView");
 
     // Extracts a ptree from an iterator
     auto itToTreeFn = [](auto& it)
@@ -152,23 +134,21 @@ void View::initialize(core::runtime::ConfigurationElement::sptr configuration)
     }
 
     // find menuBar
-    if(registryCfg.find("menuBar") != registryCfg.not_found())
     {
-        const std::string sid = registryCfg.get<std::string>("menuBar.<xmlattr>.sid", "");
+        const std::string sid = configuration.get<std::string>("menuBar.<xmlattr>.sid", "");
         if(!sid.empty())
         {
-            const bool start = core::runtime::get_ptree_value(registryCfg, "menuBar.<xmlattr>.start", false);
+            const bool start = core::runtime::get_ptree_value(configuration, "menuBar.<xmlattr>.start", false);
             m_menuBarSid = std::make_pair(sid, start);
         }
     }
 
     // find toolBar
-    if(registryCfg.find("toolBar") != registryCfg.not_found())
     {
-        const std::string sid = registryCfg.get<std::string>("toolBar.<xmlattr>.sid", "");
+        const std::string sid = configuration.get<std::string>("toolBar.<xmlattr>.sid", "");
         if(!sid.empty())
         {
-            const bool start = core::runtime::get_ptree_value(registryCfg, "toolBar.<xmlattr>.start", false);
+            const bool start = core::runtime::get_ptree_value(configuration, "toolBar.<xmlattr>.start", false);
             m_toolBarSid = std::make_pair(sid, start);
         }
     }
@@ -179,7 +159,7 @@ void View::initialize(core::runtime::ConfigurationElement::sptr configuration)
 void View::manage(std::vector<ui::base::container::fwContainer::sptr> subViews)
 {
     ui::base::container::fwContainer::sptr container;
-    for(SIDContainerMapType::value_type sid : m_sids)
+    for(const SIDContainerMapType::value_type& sid : m_sids)
     {
         SIGHT_ASSERT(
             "The view '" << m_sid << "' contains more sub-views in <registry> than in <layout>: "
@@ -208,7 +188,7 @@ void View::manage(std::vector<ui::base::container::fwContainer::sptr> subViews)
         }
     }
 
-    for(WIDContainerMapType::value_type wid : m_wids)
+    for(const WIDContainerMapType::value_type& wid : m_wids)
     {
         SIGHT_ASSERT(
             "The view '" << m_sid << "' contains more sub-views in <registry> than in <layout>: "
@@ -224,7 +204,7 @@ void View::manage(std::vector<ui::base::container::fwContainer::sptr> subViews)
 
 void View::manageMenuBar(ui::base::container::fwMenuBar::sptr menuBar)
 {
-    ui::base::GuiRegistry::registerSIDMenuBar(m_menuBarSid.first, menuBar);
+    ui::base::GuiRegistry::registerSIDMenuBar(m_menuBarSid.first, std::move(menuBar));
     if(m_menuBarSid.second) //service is auto started?
     {
         SIGHT_ASSERT(
@@ -240,7 +220,7 @@ void View::manageMenuBar(ui::base::container::fwMenuBar::sptr menuBar)
 
 void View::manageToolBar(ui::base::container::fwToolBar::sptr toolBar)
 {
-    ui::base::GuiRegistry::registerSIDToolBar(m_toolBarSid.first, toolBar);
+    ui::base::GuiRegistry::registerSIDToolBar(m_toolBarSid.first, std::move(toolBar));
     if(m_toolBarSid.second) //service is auto started?
     {
         SIGHT_ASSERT(
@@ -256,7 +236,7 @@ void View::manageToolBar(ui::base::container::fwToolBar::sptr toolBar)
 
 void View::unmanage()
 {
-    for(SIDContainerMapType::value_type sid : m_sids)
+    for(const SIDContainerMapType::value_type& sid : m_sids)
     {
         if(sid.second.second) //service is auto started?
         {
@@ -272,7 +252,7 @@ void View::unmanage()
         ui::base::GuiRegistry::unregisterSIDContainer(sid.first);
     }
 
-    for(WIDContainerMapType::value_type wid : m_wids)
+    for(const WIDContainerMapType::value_type& wid : m_wids)
     {
         ui::base::GuiRegistry::unregisterWIDContainer(wid.first);
     }
@@ -320,6 +300,4 @@ void View::unmanageMenuBar()
 
 //-----------------------------------------------------------------------------
 
-} // namespace registry
-
-} //namespace sight::ui::base
+} // namespace sight::ui::base::registry
