@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,8 @@
 
 #include "PreferencesTest.hpp"
 
-#include <core/runtime/operations.hpp>
 #include <core/runtime/Profile.hpp>
+#include <core/runtime/runtime.hpp>
 #include <core/tools/Os.hpp>
 #include <core/tools/UUID.hpp>
 
@@ -38,10 +38,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::ui::base::ut::PreferencesTest);
 
-namespace sight::ui::base
-{
-
-namespace ut
+namespace sight::ui::base::ut
 {
 
 //------------------------------------------------------------------------------
@@ -49,16 +46,18 @@ namespace ut
 void PreferencesTest::setUp()
 {
     ui::base::Preferences::set_enabled(true);
+    ui::base::Preferences::set_password_policy(core::crypto::PasswordKeeper::PasswordPolicy::NEVER);
 
     core::runtime::init();
+    core::runtime::loadModule("sight::module::ui::base");
 
     // Set the profile name
     const std::string& profileName = core::tools::UUID::generateUUID();
     core::runtime::getCurrentProfile()->setName(profileName);
 
     // Compute the expected preferences file path
-    m_preferencesPath = core::tools::os::getUserDataDir("sight", profileName) + "/preferences.json";
-    m_encryptedPath   = core::tools::os::getUserDataDir("sight", profileName) + "/preferences.sight";
+    m_preferencesPath = core::tools::os::getUserConfigDir(profileName) / "preferences.json";
+    m_encryptedPath   = core::tools::os::getUserConfigDir(profileName) / "preferences.sight";
 }
 
 //------------------------------------------------------------------------------
@@ -66,8 +65,7 @@ void PreferencesTest::setUp()
 void PreferencesTest::tearDown()
 {
     ui::base::Preferences::set_enabled(false);
-    std::filesystem::remove(m_preferencesPath);
-    std::filesystem::remove(m_encryptedPath);
+    std::filesystem::remove_all(m_preferencesPath.parent_path());
 }
 
 //------------------------------------------------------------------------------
@@ -100,8 +98,11 @@ void PreferencesTest::simpleTest()
         ui::base::Preferences preferences;
 
         // Check get value from an empty preferences file
-        CPPUNIT_ASSERT_THROW(preferences.get<std::string>(root_key), boost::property_tree::ptree_error);
-        CPPUNIT_ASSERT_NO_THROW(preferences.get(root_key, string_value));
+        CPPUNIT_ASSERT_THROW(
+            auto p = preferences.get<std::string>(root_key),
+            boost::property_tree::ptree_error
+        );
+        CPPUNIT_ASSERT_NO_THROW(std::string p = preferences.get(root_key, string_value));
 
         const auto& same_value = preferences.get(root_key, string_value);
         CPPUNIT_ASSERT_EQUAL(string_value, same_value);
@@ -110,7 +111,7 @@ void PreferencesTest::simpleTest()
         CPPUNIT_ASSERT_NO_THROW(
             preferences.put(string_key, string_value);
         );
-        CPPUNIT_ASSERT_NO_THROW(preferences.get<std::string>(string_key));
+        CPPUNIT_ASSERT_NO_THROW(auto p = preferences.get<std::string>(string_key));
         const auto& set_value = preferences.get<std::string>(string_key);
         CPPUNIT_ASSERT_EQUAL(string_value, set_value);
     }
@@ -159,6 +160,39 @@ void PreferencesTest::delimeterTest()
 
 //------------------------------------------------------------------------------
 
+void PreferencesTest::parsedGetTest()
+{
+    const std::string& root_key      = "ROOT";
+    const std::string& str_key       = root_key + ".STR";
+    const std::string& delimited_key = "%" + str_key + "%";
+    const std::string str_value      = "1664";
+
+    ui::base::Preferences preferences;
+
+    CPPUNIT_ASSERT_NO_THROW(
+        preferences.put(str_key, str_value);
+    );
+
+    // Now test the getter
+    {
+        // Test without delimiter, will fail as the key won't be found
+        // The key will however be returned as the val
+        auto [key, val] = preferences.parsed_get<std::string>(str_key);
+        CPPUNIT_ASSERT_EQUAL(key, std::string(""));
+        CPPUNIT_ASSERT_EQUAL(val, str_key);
+    }
+
+    {
+        // Test with a delimiter, both values should be returned
+        // As the preferneces is valid this time
+        auto [key, val] = preferences.parsed_get<std::string>(delimited_key);
+        CPPUNIT_ASSERT_EQUAL(key, str_key);
+        CPPUNIT_ASSERT_EQUAL(val, str_value);
+    }
+}
+
+//------------------------------------------------------------------------------
+
 void PreferencesTest::encryptedTest()
 {
     // Setting a password will enable encryption
@@ -172,8 +206,11 @@ void PreferencesTest::encryptedTest()
         ui::base::Preferences preferences;
 
         // Check get value from an empty preferences file
-        CPPUNIT_ASSERT_THROW(preferences.get<std::string>(root_key), boost::property_tree::ptree_error);
-        CPPUNIT_ASSERT_NO_THROW(preferences.get(root_key, string_value));
+        CPPUNIT_ASSERT_THROW(
+            auto p = preferences.get<std::string>(root_key),
+            boost::property_tree::ptree_error
+        );
+        CPPUNIT_ASSERT_NO_THROW(std::string p = preferences.get(root_key, string_value));
 
         const auto& same_value = preferences.get(root_key, string_value);
         CPPUNIT_ASSERT_EQUAL(string_value, same_value);
@@ -182,41 +219,45 @@ void PreferencesTest::encryptedTest()
         CPPUNIT_ASSERT_NO_THROW(
             preferences.put(string_key, string_value);
         );
-        CPPUNIT_ASSERT_NO_THROW(preferences.get<std::string>(string_key));
+        CPPUNIT_ASSERT_NO_THROW(auto p = preferences.get<std::string>(string_key));
         const auto& set_value = preferences.get<std::string>(string_key);
         CPPUNIT_ASSERT_EQUAL(string_value, set_value);
     }
 
-    // The preferences file should have been saved but as a .sight file
-    CPPUNIT_ASSERT(std::filesystem::exists(m_encryptedPath) && std::filesystem::is_regular_file(m_encryptedPath));
+    {
+        // The preferences file should have been saved but as a .sight file
+        CPPUNIT_ASSERT(std::filesystem::exists(m_encryptedPath) && std::filesystem::is_regular_file(m_encryptedPath));
 
-    // Open the archive that holds the property tree
-    const auto& archive = io::zip::ArchiveReader::get(m_encryptedPath);
+        // Open the archive that holds the property tree
+        const auto& archive = io::zip::ArchiveReader::get(m_encryptedPath);
 
-    // Create the input stream, with a password, allowing decoding an encrypted file
-    const auto& istream = archive->openFile(
-        "preferences.json",
-        "password"
-    );
+        // Create the input stream, with a password, allowing decoding an encrypted file
+        const auto& istream = archive->openFile(
+            "preferences.json",
+            "password"
+        );
 
-    // Read the property tree from the archive
-    boost::property_tree::ptree from_disk;
-    boost::property_tree::read_json(*istream, from_disk);
+        // Read the property tree from the archive
+        boost::property_tree::ptree from_disk;
+        boost::property_tree::read_json(*istream, from_disk);
 
-    // Test the saved string
-    const auto& saved_value = from_disk.get<std::string>(string_key);
-    CPPUNIT_ASSERT_EQUAL(string_value, saved_value);
+        // Test the saved string
+        const auto& saved_value = from_disk.get<std::string>(string_key);
+        CPPUNIT_ASSERT_EQUAL(string_value, saved_value);
+    }
 
-    // This will reset preferences
-    ui::base::Preferences::set_enabled(false);
-    ui::base::Preferences::set_enabled(true);
+    {
+        // This will reset preferences
+        ui::base::Preferences::set_enabled(false);
+        ui::base::Preferences::set_enabled(true);
 
-    // Set a bad password and see what happens
-    ui::base::Preferences::set_password("Test_password!");
-    CPPUNIT_ASSERT_THROW(ui::base::Preferences(), ui::base::PreferencesDisabled);
+        // Set a bad password and see what happens
+        ui::base::Preferences::set_password("bad_password!");
+        CPPUNIT_ASSERT_THROW(ui::base::Preferences(), ui::base::BadPassword);
 
-    // Setting an empty password will reset to clear json save
-    ui::base::Preferences::set_password("");
+        // Setting an empty password will reset to clear json save
+        ui::base::Preferences::set_password("");
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -240,7 +281,7 @@ void PreferencesTest::forcedEncryptionTest()
         );
 
         // check the value
-        CPPUNIT_ASSERT_NO_THROW(preferences.get<std::string>(string_key));
+        CPPUNIT_ASSERT_NO_THROW(auto p = preferences.get<std::string>(string_key));
         const auto& set_value = preferences.get<std::string>(string_key);
         CPPUNIT_ASSERT_EQUAL(string_value, set_value);
     }
@@ -258,12 +299,10 @@ void PreferencesTest::forcedEncryptionTest()
         ui::base::Preferences preferences;
 
         // check the value
-        CPPUNIT_ASSERT_NO_THROW(preferences.get<std::string>(string_key));
+        CPPUNIT_ASSERT_NO_THROW(auto p = preferences.get<std::string>(string_key));
         const auto& set_value = preferences.get<std::string>(string_key);
         CPPUNIT_ASSERT_EQUAL(string_value, set_value);
     }
 }
 
-} //namespace ut
-
-} //namespace sight::ui::base
+} // namespace sight::ui::base::ut
