@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,7 +30,6 @@
 #include <core/com/Slot.hpp>
 #include <core/com/Slot.hxx>
 #include <core/com/Slots.hxx>
-#include <core/runtime/operations.hpp>
 #include <core/tools/dateAndTime.hpp>
 #include <core/tools/UUID.hpp>
 
@@ -39,27 +38,16 @@
 
 #include <service/macros.hpp>
 
-namespace sight::ui::base
+namespace sight::ui::base::view
 {
 
-namespace view
-{
-
-const core::com::Slots::SlotKeyType IActivityView::s_LAUNCH_ACTIVITY_SLOT        = "launchActivity";
-const core::com::Slots::SlotKeyType IActivityView::s_LAUNCH_ACTIVITY_SERIES_SLOT = "launchActivitySeries";
+const core::com::Slots::SlotKeyType IActivityView::s_LAUNCH_ACTIVITY_SLOT = "launchActivity";
 
 //-----------------------------------------------------------------------------
 
 IActivityView::IActivityView()
 {
     newSlot(s_LAUNCH_ACTIVITY_SLOT, &IActivityView::launchActivity, this);
-    newSlot(s_LAUNCH_ACTIVITY_SERIES_SLOT, &IActivityView::launchActivitySeries, this);
-}
-
-//-----------------------------------------------------------------------------
-
-IActivityView::~IActivityView()
-{
 }
 
 //------------------------------------------------------------------------------
@@ -68,30 +56,31 @@ void IActivityView::configuring()
 {
     this->ui::base::IGuiContainer::initialize();
 
-    const ConfigType config = this->getConfigTree();
+    const ConfigType config = this->getConfiguration();
 
-    this->parseConfiguration(config, this->getInOuts());
+    sight::activity::IActivityLauncher::InOutMapType inoutMap;
+    std::for_each(
+        m_data.begin(),
+        m_data.end(),
+        [&inoutMap](const auto& p)
+        {
+            const auto obj = p.second->lock();
+            if(obj != nullptr)
+            {
+                inoutMap.push_back(obj->getID());
+            }
+        });
+    this->parseConfiguration(config, inoutMap);
 }
 
 //------------------------------------------------------------------------------
 
-void IActivityView::launchActivitySeries(data::Series::sptr series)
+bool IActivityView::validateActivity(data::Activity::sptr activity) const
 {
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::dynamicCast(series);
-    if(activitySeries)
-    {
-        this->launchActivity(activitySeries);
-    }
-}
-
-//------------------------------------------------------------------------------
-
-bool IActivityView::validateActivity(data::ActivitySeries::sptr activitySeries) const
-{
-    bool isValid;
+    bool isValid = false;
     std::string message;
 
-    std::tie(isValid, message) = this->activity::IActivityLauncher::validateActivity(activitySeries);
+    std::tie(isValid, message) = activity::IActivityLauncher::validateActivity(activity);
 
     if(!isValid)
     {
@@ -107,11 +96,11 @@ bool IActivityView::validateActivity(data::ActivitySeries::sptr activitySeries)
 
 //------------------------------------------------------------------------------
 
-data::ActivitySeries::sptr IActivityView::createMainActivity() const
+data::Activity::sptr IActivityView::createMainActivity() const
 {
-    data::ActivitySeries::sptr actSeries = this->activity::IActivityLauncher::createMainActivity();
+    auto activity = this->activity::IActivityLauncher::createMainActivity();
 
-    if(nullptr == actSeries)
+    if(!activity)
     {
         ui::base::dialog::MessageDialog::show(
             "Main activity",
@@ -121,9 +110,7 @@ data::ActivitySeries::sptr IActivityView::createMainActivity() const
         );
     }
 
-    return actSeries;
+    return activity;
 }
 
-} // namespace view
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::view
