@@ -29,10 +29,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::ui::history::ut::ImageDiffCommandTest);
 
-namespace sight::ui::history
-{
-
-namespace ut
+namespace sight::ui::history::ut
 {
 
 //------------------------------------------------------------------------------
@@ -54,7 +51,7 @@ void ImageDiffCommandTest::undoredoTest()
     const data::Image::Size SIZE          = {{32, 32, 32}};
     const data::Image::Spacing SPACING    = {{1., 1., 1.}};
     const data::Image::Origin ORIGIN      = {{0., 0., 0.}};
-    const core::tools::Type TYPE          = core::tools::Type::s_UINT8;
+    const core::Type TYPE                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
 
     data::Image::sptr image = data::Image::New();
@@ -63,11 +60,11 @@ void ImageDiffCommandTest::undoredoTest()
 
     const auto dumpLock = image->dump_lock();
 
-    filter::image::ImageDiff diff(image->getType().sizeOf());
+    filter::image::ImageDiff diff(image->getType().size());
 
     std::uint8_t NEWVALUE = 1;
 
-    data::Image::BufferType* newBufferValue = reinterpret_cast<data::Image::BufferType*>(&NEWVALUE);
+    auto* newBufferValue = reinterpret_cast<data::Image::BufferType*>(&NEWVALUE);
 
     const std::vector<data::Image::IndexType> indices = {{51, 10, 8, 123, 1098, 23456, 6, 9999}};
 
@@ -123,7 +120,7 @@ void ImageDiffCommandTest::getSizeTest()
     const data::Image::Size SIZE          = {{32, 32, 32}};
     const data::Image::Spacing SPACING    = {{1., 1., 1.}};
     const data::Image::Origin ORIGIN      = {{0., 0., 0.}};
-    const core::tools::Type TYPE          = core::tools::Type::s_UINT8;
+    const core::Type TYPE                 = core::Type::UINT8;
     const data::Image::PixelFormat format = data::Image::GRAY_SCALE;
 
     data::Image::sptr image = data::Image::New();
@@ -132,11 +129,11 @@ void ImageDiffCommandTest::getSizeTest()
 
     const auto dumpLock = image->dump_lock();
 
-    filter::image::ImageDiff diff(image->getType().sizeOf() * 64);
+    filter::image::ImageDiff diff(image->getType().size() * 64);
 
     std::uint8_t NEWVALUE = 1;
 
-    data::Image::BufferType* newBufferValue = reinterpret_cast<data::Image::BufferType*>(&NEWVALUE);
+    auto* newBufferValue = reinterpret_cast<data::Image::BufferType*>(&NEWVALUE);
 
     const std::vector<data::Image::IndexType> indices = {{51, 10, 8, 123, 1098, 23456, 6, 9999}};
 
@@ -167,6 +164,4 @@ void ImageDiffCommandTest::getSizeTest()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace registrationOp
+} // namespace sight::ui::history::ut
