@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2021 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -40,10 +40,12 @@ public:
 
     UI_QML_API App(int& argc, char** argv);
 
+    UI_QML_API bool notify(QObject* receiver, QEvent* e) override;
+
 public Q_SLOTS:
 
     void aboutToQuit();
-    void onExit();
+    static void onExit();
 };
 
 } // namespace sight::ui::qml
