@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2022 IRCAD France
  * Copyright (C) 2018-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,7 +23,6 @@
 #include "QmlEngine.hpp"
 
 #include <core/LazyInstantiator.hpp>
-#include <core/runtime/Runtime.hpp>
 #include <core/spyLog.hpp>
 #include <core/tools/Os.hpp>
 
@@ -41,10 +40,9 @@ namespace sight::ui::qml
 
 //-----------------------------------------------------------------------------
 
-QmlEngine::QmlEngine()
+QmlEngine::QmlEngine() :
+    m_engine(new QQmlApplicationEngine())
 {
-    m_engine = new QQmlApplicationEngine();
-
 #ifdef WIN32
     // To get Qml initialized properly, we need to find its plugins
     // This is difficult to do, especially because the location of the deps is different whether
@@ -70,8 +68,7 @@ QmlEngine::QmlEngine()
 //-----------------------------------------------------------------------------
 
 QmlEngine::~QmlEngine()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -146,4 +143,4 @@ QQmlContext* QmlEngine::getRootContext()
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::ui
+} // namespace sight::ui::qml
