@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,10 +32,7 @@
 
 #include <string>
 
-namespace sight::ui::qml
-{
-
-namespace dialog
+namespace sight::ui::qml::dialog
 {
 
 /**
@@ -66,7 +63,7 @@ public:
 
     UI_QML_API InputDialog(ui::base::GuiBaseObject::Key key);
 
-    UI_QML_API virtual ~InputDialog();
+    UI_QML_API ~InputDialog() override;
 
     /// Set the title of the message box
     UI_QML_API void setTitle(const std::string& title) override;
@@ -81,7 +78,7 @@ public:
     UI_QML_API void setInput(const std::string& text) override;
 
     /// Get the input text in the input field
-    UI_QML_API std::string getInput() override;
+    UI_QML_API std::pair<std::string, bool> getInput() override;
 
 Q_SIGNALS:
 
@@ -111,6 +108,4 @@ private:
     EchoMode m_echoMode {EchoMode::DEFAULT};
 };
 
-} // namespace dialog
-
-} // namespace sight::ui::qml
+} // namespace sight::ui::qml::dialog
