@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,26 +26,25 @@
 
 #include <QApplication>
 
-fwGuiRegisterMacro(sight::ui::qt::Cursor, sight::ui::base::ICursor::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::Cursor, sight::ui::base::ICursor::REGISTRY_KEY);
 
 namespace sight::ui::qt
 {
 
 //-----------------------------------------------------------------------------
 
-Cursor::Cursor(ui::base::GuiBaseObject::Key)
+Cursor::Cursor(ui::base::GuiBaseObject::Key /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
 Cursor::~Cursor()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
-void Cursor::setCursor(ui::base::ICursor::CursorType cursor)
+void Cursor::setCursor(ui::base::ICursor::CursorType cursor, bool setOverridenAsDefault)
 {
     QCursor qtCursor(Qt::ArrowCursor);
     switch(cursor)
@@ -62,12 +61,27 @@ void Cursor::setCursor(ui::base::ICursor::CursorType cursor)
             qtCursor.setShape(Qt::CrossCursor);
             break;
 
+        case ICursor::OPEN_HAND:
+            qtCursor.setShape(Qt::OpenHandCursor);
+            break;
+
+        case ICursor::CLOSED_HAND:
+            qtCursor.setShape(Qt::ClosedHandCursor);
+            break;
+
         case ICursor::DEFAULT:
             qtCursor.setShape(Qt::BusyCursor);
             break;
     }
 
-    qApp->setOverrideCursor(qtCursor);
+    if(setOverridenAsDefault)
+    {
+        qApp->setOverrideCursor(qtCursor);
+    }
+    else
+    {
+        qApp->changeOverrideCursor(qtCursor);
+    }
 }
 
 //-----------------------------------------------------------------------------
