@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,28 +33,24 @@
 #include <QMainWindow>
 #include <QMenuBar>
 
-fwGuiRegisterMacro(
+SIGHT_REGISTER_GUI(
     sight::ui::base::builder::MenuBarBuilder,
     sight::ui::base::builder::IMenuBarBuilder::REGISTRY_KEY
 );
 
-namespace sight::ui::base
-{
-
-namespace builder
+namespace sight::ui::base::builder
 {
 
 //-----------------------------------------------------------------------------
 
-MenuBarBuilder::MenuBarBuilder(ui::base::GuiBaseObject::Key)
+MenuBarBuilder::MenuBarBuilder(ui::base::GuiBaseObject::Key /*unused*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
 MenuBarBuilder::~MenuBarBuilder()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -62,31 +58,31 @@ void MenuBarBuilder::createMenuBar(ui::base::container::fwContainer::sptr parent
 {
     m_parent = ui::qt::container::QtContainer::dynamicCast(parent);
     SIGHT_ASSERT("The parent container is not a QtContainer", m_parent);
-    QMainWindow* window = qobject_cast<QMainWindow*>(m_parent->getQtContainer());
-    if(!window)
+    auto* window = qobject_cast<QMainWindow*>(m_parent->getQtContainer());
+    if(window == nullptr)
     {
         window = qobject_cast<QMainWindow*>(m_parent->getQtContainer()->parent());
     }
 
     SIGHT_ASSERT("The parent container must be a QMainWindow", window);
-    if(window)
+    if(window != nullptr)
     {
         ui::qt::container::QtMenuBarContainer::sptr menuBarContainer =
             ui::qt::container::QtMenuBarContainer::New();
-        QMenuBar* menuBar = new QMenuBar(0);
+        auto* menuBar = new QMenuBar(nullptr);
         menuBarContainer->setQtMenuBar(menuBar);
         window->setMenuBar(menuBar);
         m_menuBar = menuBarContainer;
 
         if(!m_backgroundColor.empty())
         {
-            std::uint8_t rgba[4];
+            std::array<std::uint8_t, 4> rgba {};
             data::tools::Color::hexaStringToRGBA(m_backgroundColor, rgba);
             std::stringstream ss;
-            ss << "QMenuBar, QMenu { background-color: rgba(" << static_cast<short>(rgba[0]) << ','
-            << static_cast<short>(rgba[1]) << ','
-            << static_cast<short>(rgba[2]) << ','
-            << (static_cast<float>(rgba[3]) / 255.f) * 100 << "%); } ";
+            ss << "QMenuBar, QMenu { background-color: rgba(" << static_cast<std::int16_t>(rgba[0]) << ','
+            << static_cast<std::int16_t>(rgba[1]) << ','
+            << static_cast<std::int16_t>(rgba[2]) << ','
+            << (static_cast<float>(rgba[3]) / 255.F) * 100 << "%); } ";
             const QString style = QString::fromStdString(ss.str());
             menuBar->setStyleSheet(qApp->styleSheet() + style);
         }
@@ -99,16 +95,16 @@ void MenuBarBuilder::destroyMenuBar()
 {
     SIGHT_ASSERT("The menu is not initialized", m_menuBar);
     SIGHT_ASSERT("The parent container is not a QtContainer", m_parent);
-    QMainWindow* window = qobject_cast<QMainWindow*>(m_parent->getQtContainer());
-    if(!window)
+    auto* window = qobject_cast<QMainWindow*>(m_parent->getQtContainer());
+    if(window == nullptr)
     {
         window = qobject_cast<QMainWindow*>(m_parent->getQtContainer()->parent());
     }
 
     SIGHT_ASSERT("The parent container must be a QMainWindow", window);
-    if(window)
+    if(window != nullptr)
     {
-        window->setMenuBar(NULL);
+        window->setMenuBar(nullptr);
     }
 
     m_menuBar->destroyContainer();
@@ -116,6 +112,4 @@ void MenuBarBuilder::destroyMenuBar()
 
 //-----------------------------------------------------------------------------
 
-} // namespace builder
-
-} // namespace sight::ui::base
+} // namespace sight::ui::base::builder
