@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,10 +30,7 @@
 
 #include <string>
 
-namespace sight::ui::qt
-{
-
-namespace dialog
+namespace sight::ui::qt::dialog
 {
 
 /**
@@ -56,7 +53,7 @@ public:
 
     UI_QT_API InputDialog(ui::base::GuiBaseObject::Key key);
 
-    UI_QT_API virtual ~InputDialog();
+    UI_QT_API ~InputDialog() override;
 
     /// Set the title of the message box
     UI_QT_API void setTitle(const std::string& title) override;
@@ -71,7 +68,7 @@ public:
     UI_QT_API void setInput(const std::string& text) override;
 
     /// Get the input text in the input field
-    UI_QT_API std::string getInput() override;
+    UI_QT_API std::pair<std::string, bool> getInput() override;
 
 protected:
 
@@ -88,6 +85,4 @@ protected:
     base::dialog::IInputDialog::EchoMode m_echoMode {base::dialog::IInputDialog::EchoMode::DEFAULT};
 };
 
-} // namespace dialog
-
-} // namespace sight::ui::qt
+} // namespace sight::ui::qt::dialog
