@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2016 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,8 +23,7 @@
 #include "viz/base/IRender.hpp"
 
 #include <core/base.hpp>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <service/macros.hpp>
 
@@ -35,16 +34,14 @@ namespace sight::viz::base
 
 //-----------------------------------------------------------------------------
 
-IRender::IRender() noexcept
-{
-}
+IRender::IRender() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-IRender::~IRender() noexcept
-{
-}
+IRender::~IRender() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-}
+} // namespace sight::viz::base
