@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2021 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -51,14 +51,13 @@ IAdaptor::IAdaptor()
 //------------------------------------------------------------------------------
 
 IAdaptor::~IAdaptor()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void IAdaptor::configureParams()
 {
-    const ConfigType config = this->getConfigTree().get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration().get_child("config.<xmlattr>");
     m_isVisible = config.get<bool>(s_VISIBLE_CONFIG, m_isVisible);
 }
 
@@ -69,7 +68,7 @@ void IAdaptor::initialize()
     // Retrieve the render service attached to the adaptor.
     if(m_renderService.expired())
     {
-        auto servicesVector = service::OSR::getServices("sight::viz::qt3d::SRender");
+        auto servicesVector = service::getServices("sight::viz::qt3d::SRender");
 
         auto& registry       = viz::qt3d::registry::getAdaptorRegistry();
         auto renderServiceId = registry[this->getID()];
@@ -120,7 +119,7 @@ void IAdaptor::hide()
 
 //------------------------------------------------------------------------------
 
-void IAdaptor::setVisible(bool)
+void IAdaptor::setVisible(bool /*unused*/)
 {
     SIGHT_WARN("This adaptor has no method 'setVisible(bool)', it needs to be overridden to be called.");
 }
