@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2022 IRCAD France
  * Copyright (C) 2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::viz::qt3dTest
-{
-
-namespace ut
+namespace sight::viz::qt3dTest::ut
 {
 
 class MeshTest : public CPPUNIT_NS::TestFixture
@@ -47,11 +44,9 @@ public:
 
     void tearDown() override;
 
-    void setCubeMesh();
+    static void setCubeMesh();
 
-    void centerCameraOnCube();
+    static void centerCameraOnCube();
 };
 
-} // namespace ut.
-
-} // namespace sight::viz::qt3dTest.
+} // namespace sight::viz::qt3dTest::ut
