@@ -23,11 +23,12 @@
 #include "viz/scene3d/ITransformable.hpp"
 
 #include "viz/scene3d/helper/Scene.hpp"
+#include "viz/scene3d/IAdaptor.hpp"
 
 namespace sight::viz::scene3d
 {
 
-const std::string ITransformable::s_TRANSFORM_CONFIG = "transform";
+const std::string ITransformable::s_TRANSFORM_CONFIG = "config.<xmlattr>.transform";
 
 //------------------------------------------------------------------------------
 
@@ -57,7 +58,7 @@ Ogre::SceneNode* ITransformable::getOrCreateTransformNode(
 )
 {
     SIGHT_ASSERT("Transform id is not set.", !m_transformId.empty());
-    auto transformNode = viz::scene3d::helper::Scene::getNodeById(m_transformId, _parentNode);
+    auto* transformNode = viz::scene3d::helper::Scene::getNodeById(m_transformId, _parentNode);
     if(transformNode == nullptr)
     {
         transformNode = _parentNode->createChildSceneNode(m_transformId);
