@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,13 +22,13 @@
 
 #include "viz/scene3d/Layer.hpp"
 
+#include "helper/Scene.hpp"
+
 #include "viz/scene3d/compositor/Core.hpp"
-#include "viz/scene3d/factory/Text.hpp"
 #include "viz/scene3d/helper/Camera.hpp"
 #include "viz/scene3d/IAdaptor.hpp"
 #include "viz/scene3d/ILight.hpp"
 #include "viz/scene3d/ogre.hpp"
-#include "viz/scene3d/Text.hpp"
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
@@ -36,7 +36,7 @@
 
 #include <data/tools/Color.hpp>
 
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <boost/tokenizer.hpp>
 
@@ -55,10 +55,9 @@
 #include <OGRE/OgreSceneManager.h>
 #include <OGRE/OgreSceneNode.h>
 #include <OGRE/OgreTechnique.h>
-#include <OGRE/Overlay/OgreOverlay.h>
-#include <OGRE/Overlay/OgreOverlayContainer.h>
-#include <OGRE/Overlay/OgreOverlayManager.h>
 
+#include <cmath>
+#include <memory>
 #include <stack>
 
 namespace sight::viz::scene3d
@@ -68,7 +67,6 @@ namespace sight::viz::scene3d
 
 const core::com::Signals::SignalKeyType Layer::s_INIT_LAYER_SIG           = "layerInitialized";
 const core::com::Signals::SignalKeyType Layer::s_RESIZE_LAYER_SIG         = "layerResized";
-const core::com::Signals::SignalKeyType Layer::s_CAMERA_UPDATED_SIG       = "CameraUpdated";
 const core::com::Signals::SignalKeyType Layer::s_CAMERA_RANGE_UPDATED_SIG = "CameraRangeUpdated";
 
 const core::com::Slots::SlotKeyType Layer::s_INTERACTION_SLOT  = "interaction";
@@ -76,9 +74,6 @@ const core::com::Slots::SlotKeyType Layer::s_RESET_CAMERA_SLOT = "resetCamera";
 
 //-----------------------------------------------------------------------------
 
-const std::string Layer::DEFAULT_CAMERA_NAME = "DefaultCam";
-const std::string Layer::DEFAULT_LIGHT_NAME  = "DefaultLight";
-
 const std::string Layer::s_DEFAULT_CAMERA_NAME      = "DefaultCam";
 const std::string Layer::s_DEFAULT_LIGHT_NAME       = "DefaultLight";
 const std::string Layer::s_DEFAULT_CAMERA_NODE_NAME = "CameraNode";
@@ -92,14 +87,14 @@ struct Layer::LayerCameraListener : public Ogre::Camera::Listener
 
     //------------------------------------------------------------------------------
 
-    LayerCameraListener(Layer* renderer) :
+    explicit LayerCameraListener(Layer* renderer) :
         m_layer(renderer)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    void cameraPreRenderScene(Ogre::Camera*) final
+    void cameraPreRenderScene(Ogre::Camera* /*cam*/) final
     {
         SIGHT_ASSERT("Layer is not set", m_layer);
 
@@ -150,7 +145,6 @@ Layer::Layer()
 {
     newSignal<InitLayerSignalType>(s_INIT_LAYER_SIG);
     newSignal<ResizeLayerSignalType>(s_RESIZE_LAYER_SIG);
-    newSignal<CameraUpdatedSignalType>(s_CAMERA_UPDATED_SIG);
     newSignal<CameraUpdatedSignalType>(s_CAMERA_RANGE_UPDATED_SIG);
 
     newSlot(s_INTERACTION_SLOT, &Layer::interaction, this);
@@ -159,8 +153,9 @@ Layer::Layer()
 
 //-----------------------------------------------------------------------------
 
-Layer::~Layer()
+Ogre::RenderTarget* Layer::getRenderTarget() const
 {
+    return m_renderTarget;
 }
 
 //-----------------------------------------------------------------------------
@@ -181,7 +176,7 @@ void Layer::setID(const std::string& id)
 
 //-----------------------------------------------------------------------------
 
-const std::string Layer::getName() const
+std::string Layer::getName() const
 {
     return m_sceneManager->getName();
 }
@@ -204,46 +199,36 @@ Ogre::SceneManager* Layer::getSceneManager() const
 
 void Layer::createScene()
 {
+    if(initialized())
+    {
+        return;
+    }
+
     namespace fwc = viz::scene3d::compositor;
-
-    auto renderService = m_renderService.lock();
-
-    auto root = viz::scene3d::Utils::getOgreRoot();
-    m_sceneManager = root->createSceneManager("DefaultSceneManager", renderService->getID() + "_" + m_id);
-    m_sceneManager->addRenderQueueListener(viz::scene3d::Utils::getOverlaySystem());
+    {
+        auto renderService = m_renderService.lock();
+        auto* root         = viz::scene3d::Utils::getOgreRoot();
+        m_sceneManager = root->createSceneManager("DefaultSceneManager", renderService->getID() + "_" + m_id);
+    }
 
     SIGHT_ASSERT("Scene manager must be initialized", m_sceneManager);
     SIGHT_ASSERT("Render window must be initialized", m_renderTarget);
 
-    m_sceneManager->setAmbientLight(Ogre::ColourValue(0.8f, 0.8f, 0.8f));
-
-    for(const auto& overlayName : m_overlayScripts)
-    {
-        Ogre::Overlay* overlay = Ogre::OverlayManager::getSingleton().getByName(overlayName);
-        if(overlay)
-        {
-            overlay->hide(); // Hide the overlay for now and display it when rendering in this layer's viewport.
-            m_enabledOverlays.push_back(overlay);
-        }
-        else
-        {
-            SIGHT_ERROR("No overlay script named: '" + overlayName + "'.");
-        }
-    }
+    m_sceneManager->setAmbientLight(Ogre::ColourValue(0.8F, 0.8F, 0.8F));
 
     // Create the camera
     m_camera = m_sceneManager->createCamera(Layer::s_DEFAULT_CAMERA_NAME);
     m_camera->setNearClipDistance(1);
 
     const auto& [left, top, width, height] = m_viewportCfg;
-    m_viewport                             = m_renderTarget->addViewport(m_camera, m_order, left, top, width, height);
-    m_viewport->setOverlaysEnabled(m_enabledOverlays.size() > 0);
+    auto* viewport = m_renderTarget->addViewport(m_camera, m_order, left, top, width, height);
+    SIGHT_ASSERT("Could not create a viewport", viewport);
 
-    m_compositorChainManager = fwc::ChainManager::uptr(new fwc::ChainManager(m_viewport));
+    m_compositorChainManager = std::make_unique<fwc::ChainManager>(this->getSptr());
 
     if(m_order != 0)
     {
-        m_viewport->setClearEveryFrame(true, Ogre::FBT_DEPTH);
+        viewport->setClearEveryFrame(true, Ogre::FBT_DEPTH);
     } // Set the background material
     else
     {
@@ -259,29 +244,29 @@ void Layer::createScene()
         );
         defaultMaterial.get()->copyDetailsTo(material);
 
-        std::uint8_t color[4];
+        std::array<std::uint8_t, 4> color {};
         Ogre::Pass* pass                           = material->getTechnique(0)->getPass(0);
         Ogre::GpuProgramParametersSharedPtr params = pass->getFragmentProgramParameters();
 
         data::tools::Color::hexaStringToRGBA(m_topColor, color);
-        Ogre::ColourValue ogreTopColor(color[0] / 255.f,
-                                       color[1] / 255.f,
-                                       color[2] / 255.f,
-                                       1.f);
+        Ogre::ColourValue ogreTopColor(static_cast<float>(color[0]) / 255.F,
+                                       static_cast<float>(color[1]) / 255.F,
+                                       static_cast<float>(color[2]) / 255.F,
+                                       1.F);
         params->setNamedConstant("topColour", ogreTopColor);
 
         data::tools::Color::hexaStringToRGBA(m_bottomColor, color);
-        Ogre::ColourValue ogreBotColor(color[0] / 255.f,
-                                       color[1] / 255.f,
-                                       color[2] / 255.f,
-                                       1.f);
+        Ogre::ColourValue ogreBotColor(static_cast<float>(color[0]) / 255.F,
+                                       static_cast<float>(color[1]) / 255.F,
+                                       static_cast<float>(color[2]) / 255.F,
+                                       1.F);
         params->setNamedConstant("bottomColour", ogreBotColor);
 
         params->setNamedConstant("topScale", m_topScale);
         params->setNamedConstant("bottomScale", m_bottomScale);
 
         // Create background rectangle covering the whole screen
-        Ogre::Rectangle2D* rect = new Ogre::Rectangle2D();
+        auto* rect = new Ogre::Rectangle2D();
         rect->setCorners(-1.0, 1.0, 1.0, -1.0);
         rect->setMaterial(material);
 
@@ -299,7 +284,11 @@ void Layer::createScene()
     }
 
     // Alter the camera aspect ratio to match the viewport
-    m_camera->setAspectRatio(Ogre::Real(m_viewport->getActualWidth()) / Ogre::Real(m_viewport->getActualHeight()));
+    SIGHT_ASSERT(
+        "Width and height should be strictly positive",
+        viewport->getActualWidth() > 0 && viewport->getActualHeight() > 0
+    );
+    m_camera->setAspectRatio(Ogre::Real(viewport->getActualWidth()) / Ogre::Real(viewport->getActualHeight()));
 
     // Creating Camera Scene Node
     Ogre::SceneNode* cameraNode = m_sceneManager->getRootSceneNode()->createChildSceneNode(
@@ -310,6 +299,7 @@ void Layer::createScene()
 
     cameraNode->attachObject(m_camera);
 
+    auto renderService = m_renderService.lock();
     if(m_hasDefaultLight)
     {
         m_defaultLightDiffuseColor  = data::Color::New();
@@ -336,8 +326,6 @@ void Layer::createScene()
         this->setupCore();
     }
 
-    m_compositorChainManager->setOgreViewport(m_viewport);
-
     // Setup custom compositors and autostereo
     {
         boost::char_separator<char> sep(";");
@@ -355,11 +343,9 @@ void Layer::createScene()
             Ogre::MaterialManager::getSingleton().addListener(m_autostereoListener);
         }
 
-        m_compositorChainManager->setCompositorChain(compositorChain, m_id, renderService);
+        m_compositorChainManager->setCompositorChain(compositorChain);
     }
 
-    m_dpi = renderService->getInteractorManager()->getLogicalDotsPerInch();
-
     m_sceneCreated = true;
 
     this->signal<InitLayerSignalType>(s_INIT_LAYER_SIG)->asyncEmit(this->getSptr());
@@ -384,26 +370,28 @@ void Layer::destroyScene()
         m_lightAdaptor.reset();
     }
 
-    if(m_camera && m_cameraListener)
+    if((m_camera != nullptr) && (m_cameraListener != nullptr))
     {
         m_camera->removeListener(m_cameraListener);
         delete m_cameraListener;
         m_cameraListener = nullptr;
     }
 
-    if(m_autostereoListener)
+    if(m_autostereoListener != nullptr)
     {
         Ogre::MaterialManager::getSingleton().removeListener(m_autostereoListener);
         delete m_autostereoListener;
         m_autostereoListener = nullptr;
     }
 
-    if(m_sceneManager)
+    if(m_sceneManager != nullptr)
     {
         viz::scene3d::Utils::getOgreRoot()->destroySceneManager(m_sceneManager);
         m_sceneManager = nullptr;
     }
 
+    m_compositorChainManager = nullptr;
+
     m_camera = nullptr;
 }
 
@@ -421,7 +409,7 @@ void Layer::updateCompositorState(std::string compositorName, bool isEnabled)
     auto renderService = m_renderService.lock();
 
     renderService->makeCurrent();
-    m_compositorChainManager->updateCompositorState(compositorName, isEnabled, m_id, m_renderService.lock());
+    m_compositorChainManager->updateCompositorState(compositorName, isEnabled);
     renderService->requestRender();
 }
 
@@ -480,22 +468,6 @@ void Layer::interaction(viz::scene3d::IWindowInteractor::InteractionInfo info)
                 {
                     _i->resizeEvent(info.x, info.y);
                 });
-
-            auto renderService = m_renderService.lock();
-            const float newDpi = renderService->getInteractorManager()->getLogicalDotsPerInch();
-
-            if(m_dpi != newDpi)
-            {
-                m_dpi = newDpi;
-                auto& movableTextObjects = m_sceneManager->getMovableObjects(factory::Text::FACTORY_TYPE_NAME);
-                for(auto& [name, movObj] : movableTextObjects)
-                {
-                    Text* const textObj = dynamic_cast<Text*>(movObj);
-                    SIGHT_ASSERT("Movable object should be of type '::viz::scene3d::Text'", textObj);
-                    textObj->setDotsPerInch(newDpi);
-                }
-            }
-
             break;
         }
 
@@ -538,6 +510,54 @@ void Layer::interaction(viz::scene3d::IWindowInteractor::InteractionInfo info)
                 _i->buttonDoublePressEvent(info.button, info.modifiers, info.x, info.y);
             });
             break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::PINCH_GESTURE:
+            this->forAllInteractors(
+                [&info](const interactor::IInteractor::sptr& _i)
+            {
+                _i->pinchGestureEvent(info.delta, info.x, info.y);
+            });
+            break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::PAN_GESTURE_MOVE:
+            this->forAllInteractors(
+                [&info](const interactor::IInteractor::sptr& _i)
+            {
+                _i->panGestureMoveEvent(info.x, info.y, info.dx, info.dy);
+            });
+            break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::PAN_GESTURE_RELEASE:
+            this->forAllInteractors(
+                [&info](const interactor::IInteractor::sptr& _i)
+            {
+                _i->panGestureReleaseEvent(info.x, info.y, info.dx, info.dy);
+            });
+            break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::LONG_TAP_GESTURE:
+            this->forAllInteractors(
+                [&info](const interactor::IInteractor::sptr& _i)
+            {
+                _i->longTapGestureEvent(info.x, info.y);
+            });
+            break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::LEAVE:
+            this->forAllInteractors(
+                [](const interactor::IInteractor::sptr& _i)
+            {
+                _i->leaveEvent();
+            });
+            break;
+
+        case viz::scene3d::IWindowInteractor::InteractionInfo::ENTER:
+            this->forAllInteractors(
+                [](const interactor::IInteractor::sptr& _i)
+            {
+                _i->enterEvent();
+            });
+            break;
     }
 
     m_cancelFurtherInteraction = false;
@@ -620,78 +640,13 @@ void Layer::removeInteractor(const viz::scene3d::interactor::IInteractor::sptr&
 
 Ogre::AxisAlignedBox Layer::computeWorldBoundingBox() const
 {
-    // The bounding box in which all the object's bounding boxes will be merged
-    Ogre::AxisAlignedBox worldCoordBoundingBox;
-
     // Getting this render service scene manager
     Ogre::SceneNode* rootSceneNode = this->getSceneManager()->getRootSceneNode();
 
     // Needed to recompute world bounding boxes
     rootSceneNode->_update(true, false);
 
-    // This stack will be used for iterate through the scene nodes graph
-    std::stack<const Ogre::SceneNode*> childrenStack;
-    childrenStack.push(rootSceneNode);
-
-    while(!childrenStack.empty())
-    {
-        const Ogre::SceneNode* tempSceneNode = childrenStack.top();
-        childrenStack.pop();
-
-        // Retrieves an iterator pointing to the attached movable objects of the current scene node
-        const Ogre::SceneNode::ObjectMap& entities = tempSceneNode->getAttachedObjects();
-        for(const auto movable : entities)
-        {
-            const Ogre::Entity* entity = dynamic_cast<Ogre::Entity*>(movable);
-
-            if(entity)
-            {
-                if(entity->isVisible())
-                {
-                    worldCoordBoundingBox.merge(entity->getWorldBoundingBox());
-                }
-            }
-            else
-            {
-                // Then try to cast into a ManualObject*
-                const Ogre::ManualObject* manualObject = dynamic_cast<Ogre::ManualObject*>(movable);
-
-                if(manualObject)
-                {
-                    if(manualObject->isVisible())
-                    {
-                        worldCoordBoundingBox.merge(manualObject->getWorldBoundingBox());
-                    }
-                }
-                else
-                {
-                    // Last try to cast into a Camera*
-                    const Ogre::Camera* cameraObject = dynamic_cast<Ogre::Camera*>(movable);
-
-                    if(cameraObject && cameraObject != this->getDefaultCamera())
-                    {
-                        if(cameraObject->isDebugDisplayEnabled())
-                        {
-                            worldCoordBoundingBox.merge(cameraObject->getWorldBoundingBox());
-                        }
-                    }
-                }
-            }
-        }
-
-        for(auto* const childNode : tempSceneNode->getChildren())
-        {
-            // First, we must cast the Node* into a SceneNode*
-            const Ogre::SceneNode* childSceneNode = dynamic_cast<Ogre::SceneNode*>(childNode);
-            if(childSceneNode)
-            {
-                // Push the current node into the stack in order to continue iteration
-                childrenStack.push(childSceneNode);
-            }
-        }
-    }
-
-    return worldCoordBoundingBox;
+    return helper::Scene::computeBoundingBox(rootSceneNode);
 }
 
 //------------------------------------------------------------------------------
@@ -778,24 +733,24 @@ void Layer::removeDefaultLight()
 
 void Layer::resetCameraCoordinates()
 {
-    const Ogre::AxisAlignedBox worldCoordBoundingBox = this->computeWorldBoundingBox();
+    const Ogre::AxisAlignedBox worldBoundingBox = this->computeWorldBoundingBox();
 
-    if(m_camera && m_camera->getProjectionType() == Ogre::PT_PERSPECTIVE)
+    if((m_camera != nullptr))
     {
         // Check if bounding box is valid, otherwise, do nothing.
-        if(worldCoordBoundingBox == Ogre::AxisAlignedBox::EXTENT_NULL
-           || worldCoordBoundingBox == Ogre::AxisAlignedBox::EXTENT_INFINITE)
+        if(worldBoundingBox == Ogre::AxisAlignedBox::EXTENT_NULL
+           || worldBoundingBox == Ogre::AxisAlignedBox::EXTENT_INFINITE)
         {
             Ogre::SceneNode* camNode = m_camera->getParentSceneNode();
-            camNode->setPosition(0.f, 0.f, 0.f);
+            camNode->setPosition(0.F, 0.F, 0.F);
         }
         else
         {
             // Arbitrary coefficient
-            const Ogre::Real boundingBoxLength = worldCoordBoundingBox.getSize().length() > 0
-                                                 ? worldCoordBoundingBox.getSize().length() : 0;
+            const Ogre::Real boundingBoxLength = worldBoundingBox.getSize().length() > 0
+                                                 ? worldBoundingBox.getSize().length() : 0;
 
-            float coeffZoom = static_cast<float>(boundingBoxLength);
+            auto coeffZoom = static_cast<float>(boundingBoxLength);
             SIGHT_DEBUG("Zoom coefficient : " << coeffZoom);
 
             // Set the direction of the camera
@@ -804,7 +759,7 @@ void Layer::resetCameraCoordinates()
             const Ogre::Vector3 direction = quat.zAxis();
 
             // Set the position of the camera
-            camNode->setPosition((worldCoordBoundingBox.getCenter() + coeffZoom * direction));
+            camNode->setPosition((worldBoundingBox.getCenter() + coeffZoom * direction));
 
             // Update interactor's mouse scale
             this->forAllInteractors(
@@ -812,8 +767,6 @@ void Layer::resetCameraCoordinates()
                 {
                     _i->setSceneLength(coeffZoom);
                 });
-
-            this->resetCameraClippingRange(worldCoordBoundingBox);
         }
 
         m_renderService.lock()->requestRender();
@@ -824,20 +777,20 @@ void Layer::resetCameraCoordinates()
 
 void Layer::computeCameraParameters()
 {
-    const Ogre::AxisAlignedBox worldCoordBoundingBox = this->computeWorldBoundingBox();
+    const Ogre::AxisAlignedBox worldBoundingBox = this->computeWorldBoundingBox();
 
-    if(m_camera && m_camera->getProjectionType() == Ogre::PT_PERSPECTIVE)
+    if((m_camera != nullptr))
     {
         // Check if bounding box is valid, otherwise, do nothing.
-        if(worldCoordBoundingBox != Ogre::AxisAlignedBox::EXTENT_NULL
-           && worldCoordBoundingBox != Ogre::AxisAlignedBox::EXTENT_INFINITE)
+        if(worldBoundingBox != Ogre::AxisAlignedBox::EXTENT_NULL
+           && worldBoundingBox != Ogre::AxisAlignedBox::EXTENT_INFINITE)
         {
             Ogre::SceneNode* camNode      = m_camera->getParentSceneNode();
             const Ogre::Quaternion quat   = camNode->getOrientation();
             const Ogre::Vector3 direction = quat.zAxis();
             const Ogre::Vector3 position  = camNode->getPosition();
 
-            const Ogre::Vector3 div = (position - worldCoordBoundingBox.getCenter()) / direction;
+            const Ogre::Vector3 div = (position - worldBoundingBox.getCenter()) / direction;
             const float distance    = div.z;
 
             // Update interactor's mouse scale
@@ -846,8 +799,6 @@ void Layer::computeCameraParameters()
                 {
                     _i->setSceneLength(distance);
                 });
-
-            this->resetCameraClippingRange(worldCoordBoundingBox);
         }
     }
 }
@@ -856,18 +807,13 @@ void Layer::computeCameraParameters()
 
 void Layer::resetCameraClippingRange() const
 {
-    this->resetCameraClippingRange(this->computeWorldBoundingBox());
-}
+    auto worldBoundingBox = this->computeWorldBoundingBox();
 
-//-----------------------------------------------------------------------------
-
-void Layer::resetCameraClippingRange(const Ogre::AxisAlignedBox& worldCoordBoundingBox) const
-{
-    if(m_camera && m_camera->getProjectionType() == Ogre::PT_PERSPECTIVE)
+    if((m_camera != nullptr) and worldBoundingBox.isFinite())
     {
         // Check if bounding box is valid, otherwise, do nothing.
-        if(worldCoordBoundingBox == Ogre::AxisAlignedBox::EXTENT_NULL
-           || worldCoordBoundingBox == Ogre::AxisAlignedBox::EXTENT_INFINITE)
+        if(worldBoundingBox == Ogre::AxisAlignedBox::EXTENT_NULL
+           || worldBoundingBox == Ogre::AxisAlignedBox::EXTENT_INFINITE)
         {
             return;
         }
@@ -880,74 +826,83 @@ void Layer::resetCameraClippingRange(const Ogre::AxisAlignedBox& worldCoordBound
         Ogre::Vector3 position  = camNode->getPosition();
 
         // Set near and far plan
-        Ogre::Vector3 minimum = worldCoordBoundingBox.getMinimum();
-        Ogre::Vector3 maximum = worldCoordBoundingBox.getMaximum();
+        Ogre::Vector3 minimum = worldBoundingBox.getMinimum();
+        Ogre::Vector3 maximum = worldBoundingBox.getMaximum();
 
-        float a, b, c, d;
-        a = -direction.x;
-        b = -direction.y;
-        c = -direction.z;
-        d = -(a * position.x + b * position.y + c * position.z);
+        const float a = -direction.x;
+        const float b = -direction.y;
+        const float c = -direction.z;
+        const float d = -(a * position.x + b * position.y + c * position.z);
 
         // Max near and min far
         float maxNear = a * minimum.x + b * minimum.y + c * minimum.z + d;
-        float minFar  = 1e-18f;
-        float dist;
+        float minFar  = 1e-18F;
 
-        float corners[6];
-        corners[0] = minimum.x;
-        corners[1] = maximum.x;
-        corners[2] = minimum.y;
-        corners[3] = maximum.y;
-        corners[4] = minimum.z;
-        corners[5] = maximum.z;
+        std::array corners {
+            minimum.x,
+            maximum.x,
+            minimum.y,
+            maximum.y,
+            minimum.z,
+            maximum.z
+        };
         // Find the closest / farthest bounding box vertex
-        for(int k = 0 ; k < 2 ; k++)
+        for(std::size_t k = 0 ; k < 2 ; k++)
         {
-            for(int j = 0 ; j < 2 ; j++)
+            for(std::size_t j = 0 ; j < 2 ; j++)
             {
-                for(int i = 0 ; i < 2 ; i++)
+                for(std::size_t i = 0 ; i < 2 ; i++)
                 {
-                    dist    = a * corners[i] + b * corners[2 + j] + c * corners[4 + k] + d;
-                    maxNear = (dist < maxNear) ? dist : maxNear;
-                    minFar  = (dist > minFar) ? dist : minFar;
+                    const float dist = a * corners[i] + b * corners[2 + j] + c * corners[4 + k] + d;
+                    maxNear = std::min(dist, maxNear);
+                    minFar  = std::max(dist, minFar);
                 }
             }
         }
 
+        // Make sure near is not bigger than far
+        auto near = std::min(minFar, maxNear);
+        auto far  = std::max(minFar, maxNear);
+
         // Give ourselves a little breathing room
-        maxNear = 0.99f * maxNear - (minFar - maxNear) * 0.5f;
-        minFar  = 1.01f * minFar + (minFar - maxNear) * 0.5f;
+        auto range = std::max((far - near) * 0.25F, 2.F);
+        far  = far + range;
+        near = near - range;
 
         // Do not let the range behind the camera throw off the calculation.
-        if(maxNear < 0.1f)
-        {
-            maxNear = 0.1f;
-        }
-
-        // Make sure near is not bigger than far
-        maxNear = (maxNear >= minFar) ? (0.01f * minFar) : (maxNear);
+        near = std::max(near, 0.1F);
 
         const auto& chain          = this->getCompositorChain();
         const auto saoCompositorIt = std::find_if(
             chain.begin(),
             chain.end(),
-            viz::scene3d::compositor::ChainManager::FindCompositorByName("SAO")
-        );
+            [](const auto& _compositor)
+            {
+                return _compositor.first == "SAO";
+            });
 
-        const auto prevNear = m_camera->getNearClipDistance();
-        const auto prevFar  = m_camera->getFarClipDistance();
+        const auto prevFar = m_camera->getFarClipDistance();
         if(saoCompositorIt != chain.end() && saoCompositorIt->second)
         {
             // Near and far for SAO
-            maxNear = 1;
-            minFar  = 10000;
+            far = 10000;
         }
 
-        m_camera->setNearClipDistance(maxNear);
-        m_camera->setFarClipDistance(minFar);
+        if(m_cameraOrthographic && m_camera->getProjectionType() != Ogre::PT_PERSPECTIVE)
+        {
+            // Use height as the difference on y coordinates.
+            const auto y1     = worldBoundingBox.getMinimum().y;
+            const auto y2     = worldBoundingBox.getMaximum().y;
+            Ogre::Real h      = y2 - y1;
+            Ogre::Real margin = 0.1F;
+            m_camera->setOrthoWindowHeight(h + h * margin);
+        }
 
-        if(maxNear != prevNear || minFar != prevFar)
+        // Keep the near plane close all the time. We need this for instance to display the shape extruder tool
+        m_camera->setNearClipDistance(near);
+        m_camera->setFarClipDistance(far);
+
+        if(far != prevFar)
         {
             this->signal<CameraUpdatedSignalType>(s_CAMERA_RANGE_UPDATED_SIG)->asyncEmit();
         }
@@ -1016,7 +971,7 @@ void Layer::setCoreCompositorEnabled(
 {
     m_hasCoreCompositor = enabled;
     m_stereoMode        = stereoMode;
-    if(transparencyTechnique != "")
+    if(!transparencyTechnique.empty())
     {
         if(transparencyTechnique == "DepthPeeling")
         {
@@ -1034,7 +989,7 @@ void Layer::setCoreCompositorEnabled(
         {
             m_transparencyTechnique = viz::scene3d::compositor::WEIGHTEDBLENDEDOIT;
         }
-        else if(transparencyTechnique == "HybridTransparency")
+        else if(transparencyTechnique == "HybridTransparency" || transparencyTechnique == "Default")
         {
             m_transparencyTechnique = viz::scene3d::compositor::HYBRIDTRANSPARENCY;
         }
@@ -1071,20 +1026,27 @@ void Layer::setViewportConfig(const ViewportConfigType& _vpCfg)
 
 //-------------------------------------------------------------------------------------
 
-bool Layer::isCoreCompositorEnabled()
+bool Layer::isCoreCompositorEnabled() const
 {
     return m_hasCoreCompositor;
 }
 
 //-------------------------------------------------------------------------------------
 
-bool Layer::isCompositorChainEnabled()
+bool Layer::isCompositorChainEnabled() const
 {
     return m_hasCompositorChain;
 }
 
 //-------------------------------------------------------------------------------------
 
+bool Layer::initialized() const
+{
+    return m_sceneManager != nullptr;
+}
+
+//-------------------------------------------------------------------------------------
+
 compositor::Core::StereoModeType Layer::getStereoMode() const
 {
     return m_stereoMode;
@@ -1097,7 +1059,7 @@ void Layer::setupCore()
     // Needed to setup compositors in GL3Plus, Ogre creates render targets
     m_renderService.lock()->makeCurrent();
 
-    m_coreCompositor = std::make_shared<viz::scene3d::compositor::Core>(m_viewport);
+    m_coreCompositor = std::make_shared<viz::scene3d::compositor::Core>(this->getViewport());
     m_coreCompositor->setStereoMode(m_stereoMode);
     m_coreCompositor->setTransparencyTechnique(m_transparencyTechnique);
     m_coreCompositor->setTransparencyDepth(m_numPeels);
@@ -1116,7 +1078,7 @@ void Layer::restartAdaptors()
                       };
 
     // Only keep adaptors belonging to this layer.
-    adaptors.erase(std::remove_if(adaptors.begin(), adaptors.end(), notInLayer), adaptors.end());
+    std::erase_if(adaptors, notInLayer);
 
     // Search for all adaptors created as subservices by other adaptors.
     std::vector<service::IService::wptr> subAdaptors;
@@ -1131,7 +1093,7 @@ void Layer::restartAdaptors()
     }
 
     // Subadaptors should be started/stopped by their parent. Remove them from the list.
-    for(auto subSrv : subAdaptors)
+    for(const auto& subSrv : subAdaptors)
     {
         auto it = std::find(adaptors.begin(), adaptors.end(), subSrv.lock());
 
@@ -1168,14 +1130,14 @@ service::IHasServices::ServiceVector Layer::getRegisteredAdaptors() const
         return m_compositorChainManager->getRegisteredServices();
     }
 
-    return service::IHasServices::ServiceVector();
+    return {};
 }
 
 //-------------------------------------------------------------------------------------
 
 Ogre::Viewport* Layer::getViewport() const
 {
-    return m_viewport;
+    return m_renderTarget->getViewport(m_renderTarget->getNumViewports() - 1);
 }
 
 //-------------------------------------------------------------------------------------
@@ -1204,15 +1166,15 @@ Ogre::Matrix4 Layer::getCameraProjMat(const uint8_t cameraIdx) const
 
     if(m_stereoMode == viz::scene3d::compositor::Core::StereoModeType::AUTOSTEREO_5)
     {
-        const float eyeAngle = 0.02321f;
-        const float angle    = eyeAngle * (-2.f + float(cameraIdx));
+        const float eyeAngle = 0.02321F;
+        const float angle    = eyeAngle * (-2.F + float(cameraIdx));
 
         extrinsicTransform = viz::scene3d::helper::Camera::computeFrustumShearTransform(*m_camera, angle);
     }
     else if(m_stereoMode == viz::scene3d::compositor::Core::StereoModeType::AUTOSTEREO_8)
     {
-        const float eyeAngle = 0.01625f;
-        const float angle    = eyeAngle * (-3.5f + float(cameraIdx));
+        const float eyeAngle = 0.01625F;
+        const float angle    = eyeAngle * (-3.5F + float(cameraIdx));
 
         extrinsicTransform = viz::scene3d::helper::Camera::computeFrustumShearTransform(*m_camera, angle);
     }
@@ -1277,9 +1239,8 @@ int Layer::getLightsNumber() const
     auto lightAdaptors = this->getRenderService()->getAdaptors<viz::scene3d::ILight>();
     int lightsNumber(0);
 
-    std::for_each(
-        lightAdaptors.begin(),
-        lightAdaptors.end(),
+    std::ranges::for_each(
+        lightAdaptors,
         [&](viz::scene3d::ILight::sptr adaptor)
         {
             if(adaptor->getLayerID() == this->getLayerID())
@@ -1298,9 +1259,8 @@ std::vector<viz::scene3d::ILight::sptr> Layer::getLightAdaptors() const
     auto lightAdaptors = this->getRenderService()->getAdaptors<viz::scene3d::ILight>();
     std::vector<viz::scene3d::ILight::sptr> layerLightAdaptors;
 
-    std::for_each(
-        lightAdaptors.begin(),
-        lightAdaptors.end(),
+    std::ranges::for_each(
+        lightAdaptors,
         [&](viz::scene3d::ILight::sptr lightAdaptor)
         {
             if(lightAdaptor->getLayerID() == this->getLayerID())
@@ -1314,46 +1274,6 @@ std::vector<viz::scene3d::ILight::sptr> Layer::getLightAdaptors() const
 
 //-----------------------------------------------------------------------------
 
-Ogre::OverlayContainer* Layer::getOverlayTextPanel()
-{
-    if(m_overlayTextPanel == nullptr)
-    {
-        auto& overlayManager   = Ogre::OverlayManager::getSingleton();
-        const auto textPanelId = m_renderService.lock()->getID() + m_id + "_GUI";
-
-        m_overlayTextPanel =
-            static_cast<Ogre::OverlayContainer*>(overlayManager.createOverlayElement("Panel", textPanelId));
-
-        m_overlayTextPanel->setMetricsMode(Ogre::GMM_PIXELS);
-        m_overlayTextPanel->setPosition(0, 0);
-        m_overlayTextPanel->setDimensions(1.0f, 1.0f);
-
-        Ogre::Overlay* uiOverlay = overlayManager.create(textPanelId + "_UIOverlay");
-        uiOverlay->add2D(m_overlayTextPanel);
-
-        m_enabledOverlays.push_back(uiOverlay);
-        m_viewport->setOverlaysEnabled(true);
-    }
-
-    return m_overlayTextPanel;
-}
-
-//-----------------------------------------------------------------------------
-
-void Layer::setEnabledOverlays(const std::vector<std::string>& _overlayScripts)
-{
-    m_overlayScripts = _overlayScripts;
-}
-
-//-----------------------------------------------------------------------------
-
-const Layer::OverlaySetType& Layer::getEnabledOverlays() const
-{
-    return m_enabledOverlays;
-}
-
-//-----------------------------------------------------------------------------
-
 void Layer::cancelFurtherInteraction()
 {
     m_cancelFurtherInteraction = true;
@@ -1361,4 +1281,18 @@ void Layer::cancelFurtherInteraction()
 
 //-----------------------------------------------------------------------------
 
+void Layer::setOrthographicCamera(bool _ortho)
+{
+    m_cameraOrthographic = _ortho;
+}
+
+//-----------------------------------------------------------------------------
+
+bool Layer::isOrthographicCameraForce() const
+{
+    return m_cameraOrthographic;
+}
+
+//-----------------------------------------------------------------------------
+
 } // namespace sight::viz::scene3d.
