@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,25 +22,26 @@
 
 #pragma once
 
-#include "viz/scene3d/compositor/ChainManager.hpp"
-#include "viz/scene3d/compositor/Core.hpp"
-#include "viz/scene3d/compositor/listener/AutoStereo.hpp"
-#include "viz/scene3d/compositor/types.hpp"
 #include "viz/scene3d/config.hpp"
-#include "viz/scene3d/interactor/IInteractor.hpp"
-#include "viz/scene3d/IWindowInteractor.hpp"
 
 #include <core/com/HasSignals.hpp>
 #include <core/com/HasSlots.hpp>
+#include <core/com/helper/SigSlotConnection.hpp>
 #include <core/com/Slot.hpp>
 #include <core/thread/Worker.hpp>
 
+#include <viz/scene3d/compositor/ChainManager.hpp>
+#include <viz/scene3d/compositor/Core.hpp>
+#include <viz/scene3d/compositor/listener/AutoStereo.hpp>
+#include <viz/scene3d/compositor/types.hpp>
+#include <viz/scene3d/interactor/IInteractor.hpp>
+#include <viz/scene3d/IWindowInteractor.hpp>
+
 #include <OGRE/Ogre.h>
 #include <OGRE/OgreAxisAlignedBox.h>
 #include <OGRE/OgreRenderWindow.h>
 #include <OGRE/OgreSceneManager.h>
 #include <OGRE/OgreViewport.h>
-#include <OGRE/Overlay/OgreOverlay.h>
 
 #include <cstdint>
 #include <map>
@@ -50,9 +51,8 @@ namespace sight::data
 {
 
 class Color;
-class Matrix4;
 
-}
+} // namespace sight::data
 
 namespace sight::viz::scene3d
 {
@@ -61,14 +61,14 @@ class SRender;
 class IAdaptor;
 class ILight;
 
-}
+} // namespace sight::viz::scene3d
 
 namespace Ogre
 {
 
 class Camera;
 
-}
+} // namespace Ogre
 
 namespace sight::viz::scene3d
 {
@@ -91,9 +91,6 @@ public:
     /// Defines the extrinsic x Intrinsic camera calibrations.
     using CameraCalibrationsType = std::vector<Ogre::Matrix4>;
 
-    /// Defines the set of overlays enabled on a layer.
-    using OverlaySetType = std::vector<Ogre::Overlay*>;
-
     /// Defines the viewport parameters relatively to the screen: left, top, width ,height.
     using ViewportConfigType = std::tuple<float, float, float, float>;
 
@@ -105,16 +102,11 @@ public:
     VIZ_SCENE3D_API static const core::com::Signals::SignalKeyType s_RESIZE_LAYER_SIG;
     typedef core::com::Signal<void (int, int)> ResizeLayerSignalType;
 
-    /// @deprecated A listener is now in place in SCamera instead.
-    [[deprecated("Removed in sight 22.0.")]]
-    VIZ_SCENE3D_API static const core::com::Signals::SignalKeyType s_CAMERA_UPDATED_SIG;
-
     /// Contains signals sent when the camera is modified.
     VIZ_SCENE3D_API static const core::com::Signals::SignalKeyType s_CAMERA_RANGE_UPDATED_SIG;
     typedef core::com::Signal<void ()> CameraUpdatedSignalType;
 
-    typedef core::com::Slot<void (viz::scene3d::IWindowInteractor::InteractionInfo)>
-        InteractionSlotType;
+    typedef core::com::Slot<void (viz::scene3d::IWindowInteractor::InteractionInfo)> InteractionSlotType;
     typedef core::com::Slot<void ()> DestroySlotType;
 
     /// Contains the slot name that request the picker to do a ray cast according to the passed position.
@@ -123,14 +115,6 @@ public:
     /// Contains the slot name that request the reset of camera.
     VIZ_SCENE3D_API static const core::com::Slots::SlotKeyType s_RESET_CAMERA_SLOT;
 
-    /// @deprecated please used s_DEFAULT_CAMERA_NAME.
-    [[deprecated("Removed in sight 22.0.")]]
-    VIZ_SCENE3D_API static const std::string DEFAULT_CAMERA_NAME;
-
-    /// @deprecated please used s_DEFAULT_LIGHT_NAME
-    [[deprecated("Removed in sight 22.0.")]]
-    VIZ_SCENE3D_API static const std::string DEFAULT_LIGHT_NAME;
-
     /// Defines the default camera name.
     VIZ_SCENE3D_API static const std::string s_DEFAULT_CAMERA_NAME;
 
@@ -144,7 +128,10 @@ public:
     VIZ_SCENE3D_API Layer();
 
     /// Destoyres Ogre resources.
-    VIZ_SCENE3D_API virtual ~Layer();
+    VIZ_SCENE3D_API ~Layer() override = default;
+
+    /// Gets the render window containing this layer.
+    VIZ_SCENE3D_API Ogre::RenderTarget* getRenderTarget() const;
 
     /// Sets the render window containing this layer.
     VIZ_SCENE3D_API void setRenderTarget(Ogre::RenderTarget* _renderTarget);
@@ -153,12 +140,12 @@ public:
     VIZ_SCENE3D_API void setID(const std::string& id);
 
     /// @returns the name of this layer.
-    VIZ_SCENE3D_API const std::string getName() const;
+    VIZ_SCENE3D_API std::string getName() const;
 
     /// @returns the ID of this layer.
     VIZ_SCENE3D_API const std::string& getLayerID() const;
 
-    /// @returns the scene manager associated to this viewport.
+    /// @returns the scene manager associated to this viewport. Creates if it does not exists.
     VIZ_SCENE3D_API Ogre::SceneManager* getSceneManager() const;
 
     /// Creates the scene.
@@ -185,9 +172,6 @@ public:
     /// Resets the camera clipping range (near and far).
     VIZ_SCENE3D_API void resetCameraClippingRange() const;
 
-    /// Resets the camera clipping range (near and far).
-    VIZ_SCENE3D_API void resetCameraClippingRange(const Ogre::AxisAlignedBox& worldCoordBoundingBox) const;
-
     /// Appends a new interactor with the given priority. Interactors with higher priorities are executed first.
     VIZ_SCENE3D_API void addInteractor(
         const viz::scene3d::interactor::IInteractor::sptr& _interactor,
@@ -240,14 +224,17 @@ public:
     VIZ_SCENE3D_API void setViewportConfig(const ViewportConfigType& _vpCfg);
 
     /// @returns true if this layer needs a layer's 3D scene.
-    VIZ_SCENE3D_API bool isCoreCompositorEnabled();
+    VIZ_SCENE3D_API bool isCoreCompositorEnabled() const;
 
     /// @returns true if there is an XML configured compositor chain.
-    VIZ_SCENE3D_API bool isCompositorChainEnabled();
+    VIZ_SCENE3D_API bool isCompositorChainEnabled() const;
 
     /// @returns true if stereoscopic rendering is enabled.
     VIZ_SCENE3D_API bool is3D() const;
 
+    /// @returns true if the layer is initialized.
+    VIZ_SCENE3D_API bool initialized() const;
+
     /// @returns the stereoscopic mode.
     VIZ_SCENE3D_API compositor::Core::StereoModeType getStereoMode() const;
 
@@ -264,7 +251,7 @@ public:
     VIZ_SCENE3D_API Ogre::Camera* getDefaultCamera() const;
 
     /// Gets the projection matrix used to define nth viewpoint. The index must be lower than the number of viewpoints.
-    VIZ_SCENE3D_API Ogre::Matrix4 getCameraProjMat(const std::uint8_t cameraIdx) const;
+    VIZ_SCENE3D_API Ogre::Matrix4 getCameraProjMat(std::uint8_t cameraIdx) const;
 
     /// @returns the number of cameras (viewpoints) used by this layer. Defined by the stereo mode.
     VIZ_SCENE3D_API std::uint8_t numCameras() const;
@@ -297,27 +284,23 @@ public:
     VIZ_SCENE3D_API void setCameraCalibrations(const CameraCalibrationsType& calibrations);
 
     /// @returns true if a specified light is the default light in the layer.
-    VIZ_SCENE3D_API bool isDefaultLight(const CSPTR(viz::scene3d::ILight)&) const;
+    VIZ_SCENE3D_API bool isDefaultLight(const CSPTR(viz::scene3d::ILight)& /*_light*/) const;
 
     /// Removes the default light in the layer.
     VIZ_SCENE3D_API void removeDefaultLight();
 
-    /// @returns or create the overlay panel in which adaptors can render 2D text.
-    VIZ_SCENE3D_API Ogre::OverlayContainer* getOverlayTextPanel();
-
-    /// Defines the overlay scripts to enable on this layer's viewport.
-    VIZ_SCENE3D_API void setEnabledOverlays(const std::vector<std::string>& _overlayScripts);
-
-    /// @returns the overlays enabled on this layer's viewport.
-    VIZ_SCENE3D_API const OverlaySetType& getEnabledOverlays() const;
-
     /// Cancels interaction for all interactors with a lower priority than the one calling this.
     VIZ_SCENE3D_API void cancelFurtherInteraction();
 
+    /// Need to be enable if using SCamera with orthographic mode.
+    VIZ_SCENE3D_API void setOrthographicCamera(bool _ortho);
+    /// Returns value of setOrthographicCamera.
+    VIZ_SCENE3D_API bool isOrthographicCameraForce() const;
+
 private:
 
     /// Slot: interacts with the scene.
-    void interaction(viz::scene3d::IWindowInteractor::InteractionInfo);
+    void interaction(viz::scene3d::IWindowInteractor::InteractionInfo /*info*/);
 
     /// Setups default compositor for a layer's 3D scene.
     void setupCore();
@@ -334,17 +317,11 @@ private:
     /// Contains the Ogre render window containing this viewport.
     Ogre::RenderTarget* m_renderTarget {nullptr};
 
-    /// Contains the Ogre viewport representing this layer.
-    Ogre::Viewport* m_viewport {nullptr};
-
-    /// Contains the overlay panel to which all the UI's text is attached.
-    Ogre::OverlayContainer* m_overlayTextPanel {nullptr};
-
     /// Defines stereoscopic rendering mode.
     compositor::Core::StereoModeType m_stereoMode {compositor::Core::StereoModeType::NONE};
 
     /// Stores configured compositor chain raw string if there is a one.
-    std::string m_rawCompositorChain {""};
+    std::string m_rawCompositorChain;
 
     /// Contains the Ogre default compositor for this layer.
     SPTR(viz::scene3d::compositor::Core) m_coreCompositor {nullptr};
@@ -369,16 +346,16 @@ private:
     std::string m_bottomColor {"#333333"};
 
     /// Defines the top background scale : specific to background Layer.
-    float m_topScale {0.f};
+    float m_topScale {0.F};
 
     /// Defines the bottom background scale : specific to background Layer.
-    float m_bottomScale {1.f};
+    float m_bottomScale {1.F};
 
     /// Contains the Ogre camera.
     Ogre::Camera* m_camera {nullptr};
 
     /// Stores the list of interactors, sorted by priority.
-    std::multimap<int, viz::scene3d::interactor::IInteractor::wptr, std::greater<int> > m_interactors;
+    std::multimap<int, viz::scene3d::interactor::IInteractor::wptr, std::greater<> > m_interactors;
 
     /// Handles flag cancelling all further interaction when enabled.
     bool m_cancelFurtherInteraction {false};
@@ -390,7 +367,7 @@ private:
     WPTR(viz::scene3d::SRender) m_renderService;
 
     /// Defines the layer identifier as referenced in SRender.
-    std::string m_id {""};
+    std::string m_id;
 
     /// Enables default compositor's widgets (gui displays before scene creation).
     bool m_hasCoreCompositor {false};
@@ -423,17 +400,11 @@ private:
     /// Holds pairs of intrinsic/extrinsic calibrations for stereo cameras.
     CameraCalibrationsType m_stereoCameraCalibration;
 
-    /// Stores names of the enabled overlay scripts.
-    std::vector<std::string> m_overlayScripts;
-
-    /// Overlays enabled on this layer's viewport.
-    OverlaySetType m_enabledOverlays;
-
     /// Defines viewport parameters: left, top, width, height.
-    ViewportConfigType m_viewportCfg {0.f, 0.f, 1.f, 1.f};
+    ViewportConfigType m_viewportCfg {0.F, 0.F, 1.F, 1.F};
 
-    /// Defines the dpi number of the rendering screen.
-    float m_dpi {96.f};
+    /// True when we are using dedicated SCamera adaptor with orthographic projection.
+    bool m_cameraOrthographic {false};
 };
 
 } // namespace sight::viz::scene3d.
