@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,11 +28,11 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
+#include <data/Composite.hpp>
 
 #define FW_PROFILING_DISABLED
 #include <core/Profiling.hpp>
 
-#include <core/runtime/ConfigurationElementContainer.hpp>
 #include <core/runtime/utils/GenericExecutableFactoryRegistry.hpp>
 
 #include <service/helper/Config.hpp>
@@ -58,37 +58,30 @@ const std::string SRender::s_OGREBACKGROUNDID = "ogreBackground";
 
 //-----------------------------------------------------------------------------
 
-const core::com::Signals::SignalKeyType SRender::s_COMPOSITOR_UPDATED_SIG = "compositorUpdated";
-const core::com::Signals::SignalKeyType SRender::s_FULLSCREEN_SET_SIG     = "fullscreenSet";
+const core::com::Slots::SlotKeyType SRender::s_COMPUTE_CAMERA_ORIG_SLOT = "computeCameraParameters";
+const core::com::Slots::SlotKeyType SRender::s_RESET_CAMERAS_SLOT       = "resetCameras";
+const core::com::Slots::SlotKeyType SRender::s_REQUEST_RENDER_SLOT      = "requestRender";
+const core::com::Slots::SlotKeyType SRender::s_DISABLE_FULLSCREEN       = "disableFullscreen";
+const core::com::Slots::SlotKeyType SRender::s_ENABLE_FULLSCREEN        = "enableFullscreen";
+const core::com::Slots::SlotKeyType SRender::s_SET_MANUAL_MODE          = "setManualMode";
+const core::com::Slots::SlotKeyType SRender::s_SET_AUTO_MODE            = "setAutoMode";
 
 //-----------------------------------------------------------------------------
 
-const core::com::Slots::SlotKeyType SRender::s_COMPUTE_CAMERA_ORIG_SLOT     = "computeCameraParameters";
-const core::com::Slots::SlotKeyType SRender::s_RESET_CAMERAS_SLOT           = "resetCameras";
-const core::com::Slots::SlotKeyType SRender::s_COMPUTE_CAMERA_CLIPPING_SLOT = "computeCameraClipping";
-const core::com::Slots::SlotKeyType SRender::s_REQUEST_RENDER_SLOT          = "requestRender";
-const core::com::Slots::SlotKeyType SRender::s_DISABLE_FULLSCREEN           = "disableFullscreen";
-const core::com::Slots::SlotKeyType SRender::s_ENABLE_FULLSCREEN            = "enableFullscreen";
-
-static const core::com::Slots::SlotKeyType s_ADD_OBJECTS_SLOT    = "addObject";
-static const core::com::Slots::SlotKeyType s_CHANGE_OBJECTS_SLOT = "changeObject";
-static const core::com::Slots::SlotKeyType s_REMOVE_OBJECTS_SLOT = "removeObjects";
-
-//-----------------------------------------------------------------------------
-
-SRender::SRender() noexcept
+SRender::SRender() noexcept :
+    m_ogreRoot(viz::scene3d::Utils::getOgreRoot())
 {
-    m_ogreRoot = viz::scene3d::Utils::getOgreRoot();
-
-    newSignal<CompositorUpdatedSignalType>(s_COMPOSITOR_UPDATED_SIG);
-    m_fullscreenSetSig = newSignal<FullscreenSetSignalType>(s_FULLSCREEN_SET_SIG);
+    newSignal<signals::compositorUpdated_signal_t>(signals::COMPOSITOR_UPDATED);
+    newSignal<signals::void_signal_t>(signals::FULLSCREEN_SET);
+    newSignal<signals::void_signal_t>(signals::FULLSCREEN_UNSET);
 
     newSlot(s_COMPUTE_CAMERA_ORIG_SLOT, &SRender::resetCameraCoordinates, this);
     newSlot(s_RESET_CAMERAS_SLOT, &SRender::resetCameras, this);
-    newSlot(s_COMPUTE_CAMERA_CLIPPING_SLOT, &SRender::computeCameraClipping, this);
     newSlot(s_REQUEST_RENDER_SLOT, &SRender::requestRender, this);
     newSlot(s_DISABLE_FULLSCREEN, &SRender::disableFullscreen, this);
     newSlot(s_ENABLE_FULLSCREEN, &SRender::enableFullscreen, this);
+    newSlot(s_SET_MANUAL_MODE, [this](){this->m_renderMode = RenderMode::MANUAL;});
+    newSlot(s_SET_AUTO_MODE, [this](){this->m_renderMode = RenderMode::AUTO;});
 }
 
 //-----------------------------------------------------------------------------
@@ -102,7 +95,7 @@ SRender::~SRender() noexcept
 
 void SRender::configuring()
 {
-    const ConfigType config = this->getConfigTree();
+    const ConfigType config = this->getConfiguration();
 
     SIGHT_ERROR_IF("Only one scene must be configured.", config.count("scene") != 1);
     const ConfigType sceneCfg = config.get_child("scene");
@@ -112,7 +105,7 @@ void SRender::configuring()
 
     if(nbInouts == 1)
     {
-        const std::string key = config.get<std::string>("inout.<xmlattr>.key", "");
+        const auto key = config.get<std::string>("inout.<xmlattr>.key", "");
         m_offScreen = (key == s_OFFSCREEN_INOUT);
 
         SIGHT_ASSERT("'" + key + "' is not a valid key. Only '" << s_OFFSCREEN_INOUT << "' is accepted.", m_offScreen);
@@ -128,26 +121,52 @@ void SRender::configuring()
 
     m_fullscreen = sceneCfg.get<bool>("<xmlattr>.fullscreen", false);
 
-    const std::string renderMode = sceneCfg.get<std::string>("<xmlattr>.renderMode", "auto");
+    const auto renderMode = sceneCfg.get<std::string>("<xmlattr>.renderMode", "auto");
     if(renderMode == "auto")
     {
         m_renderMode = RenderMode::AUTO;
     }
-    else if(renderMode == "sync")
+    else if(renderMode == "manual" || renderMode == "sync") /* Keep sync for backwards compatibility */
     {
-        m_renderMode = RenderMode::SYNC;
+        m_renderMode = RenderMode::MANUAL;
     }
     else
     {
         SIGHT_ERROR("Unknown rendering mode '" + renderMode + "', use the default 'auto'.");
     }
 
-    auto adaptorConfigs = sceneCfg.equal_range("adaptor");
-    for(auto it = adaptorConfigs.first ; it != adaptorConfigs.second ; ++it)
+    auto& adaptorRegistry = viz::scene3d::registry::getAdaptorRegistry();
+
+    /// New config
+    auto layerConfigs = sceneCfg.equal_range("layer");
+    for(const auto& itLayer : boost::make_iterator_range(layerConfigs))
     {
-        const std::string uid = it->second.get<std::string>("<xmlattr>.uid");
-        auto& registry        = viz::scene3d::registry::getAdaptorRegistry();
-        registry[uid] = this->getID();
+        const auto layerId  = itLayer.second.get<std::string>("<xmlattr>.id");
+        auto adaptorConfigs = itLayer.second.equal_range("adaptor");
+        for(const auto& it : boost::make_iterator_range(adaptorConfigs))
+        {
+            const auto uid = it.second.get<std::string>("<xmlattr>.uid");
+            adaptorRegistry[uid] = {this->getID(), layerId};
+        }
+
+        //create resetcamera_layerID slot
+        const core::com::Slots::SlotKeyType resetcamera_slotkey = "resetCamera_" + layerId;
+        auto resetCameraLayerSlot                               = newSlot(
+            resetcamera_slotkey,
+            [this, layerId]()
+            {
+                this->resetCameraCoordinates(layerId);
+            });
+
+        resetCameraLayerSlot->setWorker(sight::core::thread::getDefaultWorker());
+    }
+
+    /// Old config
+    auto adaptorConfigs = sceneCfg.equal_range("adaptor");
+    for(const auto& it : boost::make_iterator_range(adaptorConfigs))
+    {
+        const auto uid = it.second.get<std::string>("<xmlattr>.uid");
+        adaptorRegistry[uid] = {this->getID(), ""};
     }
 }
 
@@ -162,7 +181,7 @@ void SRender::starting()
         this->create();
     }
 
-    const ConfigType config = this->getConfigTree();
+    const ConfigType config = this->getConfiguration();
 
     SIGHT_ERROR_IF("Only one scene must be configured.", config.count("scene") != 1);
 
@@ -199,43 +218,29 @@ void SRender::starting()
         ogreLayer->setRenderService(viz::scene3d::SRender::dynamicCast(this->shared_from_this()));
         ogreLayer->setID("backgroundLayer");
         ogreLayer->setOrder(0);
-        ogreLayer->setWorker(m_associatedWorker);
+        ogreLayer->setWorker(this->worker());
         ogreLayer->setBackgroundColor("#000000", "#000000");
         ogreLayer->setBackgroundScale(0, 0.5);
         ogreLayer->setHasDefaultLight(false);
-        ogreLayer->setViewportConfig({0.f, 0.f, 1.f, 1.f});
+        ogreLayer->setViewportConfig({0.F, 0.F, 1.F, 1.F});
 
         m_layers[s_OGREBACKGROUNDID] = ogreLayer;
     }
 
+    const std::string serviceID = getID().substr(getID().find_last_of('_') + 1);
     if(m_offScreen)
     {
         // Instantiate the manager that help to communicate between this service and the widget
         m_interactorManager = viz::scene3d::IWindowInteractor::createOffscreenManager(m_width, m_height);
         m_interactorManager->setRenderService(this->getSptr());
-        m_interactorManager->createContainer(nullptr, m_fullscreen);
+        m_interactorManager->createContainer(nullptr, m_fullscreen, serviceID);
     }
     else
     {
         // Instantiate the manager that help to communicate between this service and the widget
         m_interactorManager = viz::scene3d::IWindowInteractor::createManager();
         m_interactorManager->setRenderService(this->getSptr());
-        m_interactorManager->createContainer(this->getContainer(), m_fullscreen);
-    }
-
-    // Initialize resources to load overlay scripts.
-    Ogre::ResourceGroupManager::getSingleton().initialiseAllResourceGroups();
-
-    m_interactorManager->getRenderTarget()->addListener(&m_viewportListener);
-
-    for(auto it : m_layers)
-    {
-        viz::scene3d::Layer::sptr layer = it.second;
-        layer->setRenderTarget(m_interactorManager->getRenderTarget());
-        layer->createScene();
-
-        auto* vp = layer->getViewport();
-        m_viewportOverlaysMap.emplace(vp, layer->getEnabledOverlays());
+        m_interactorManager->createContainer(this->getContainer(), m_fullscreen, serviceID);
     }
 
     // Everything is started now, we can safely create connections and thus receive interactions from the widget
@@ -248,10 +253,7 @@ void SRender::stopping()
 {
     this->makeCurrent();
 
-    m_interactorManager->getRenderTarget()->removeAllListeners();
-    m_viewportOverlaysMap.clear();
-
-    for(auto it : m_layers)
+    for(const auto& it : m_layers)
     {
         viz::scene3d::Layer::sptr layer = it.second;
         layer->destroyScene();
@@ -288,7 +290,7 @@ void SRender::configureLayer(const ConfigType& _cfg)
     const ConfigType attributes             = _cfg.get_child("<xmlattr>");
     const std::string id                    = attributes.get<std::string>("id", "");
     const std::string compositors           = attributes.get<std::string>("compositors", "");
-    const std::string transparencyTechnique = attributes.get<std::string>("transparency", "HybridTransparency");
+    const std::string transparencyTechnique = attributes.get<std::string>("transparency", "");
     const std::string numPeels              = attributes.get<std::string>("numPeels", "4");
     const std::string stereoMode            = attributes.get<std::string>("stereoMode", "");
     const std::string defaultLight          = attributes.get<std::string>("defaultLight", "");
@@ -334,11 +336,10 @@ void SRender::configureLayer(const ConfigType& _cfg)
     ogreLayer->setRenderService(viz::scene3d::SRender::dynamicCast(this->shared_from_this()));
     ogreLayer->setID(id);
     ogreLayer->setOrder(layerOrder);
-    ogreLayer->setWorker(m_associatedWorker);
+    ogreLayer->setWorker(this->worker());
     ogreLayer->setCoreCompositorEnabled(true, transparencyTechnique, numPeels, layerStereoMode);
     ogreLayer->setCompositorChainEnabled(compositors);
     ogreLayer->setViewportConfig(viewportConfig);
-    ogreLayer->setEnabledOverlays(enabledOverlays);
 
     if(!defaultLight.empty() && defaultLight == "false")
     {
@@ -360,32 +361,32 @@ void SRender::configureBackgroundLayer(const ConfigType& _cfg)
     ogreLayer->setRenderService(viz::scene3d::SRender::dynamicCast(this->shared_from_this()));
     ogreLayer->setID(s_OGREBACKGROUNDID);
     ogreLayer->setOrder(0);
-    ogreLayer->setWorker(m_associatedWorker);
+    ogreLayer->setWorker(this->worker());
     ogreLayer->setHasDefaultLight(false);
 
-    if(attributes.count("color"))
+    if(attributes.count("color") != 0U)
     {
-        const std::string color = attributes.get<std::string>("color");
+        const auto color = attributes.get<std::string>("color");
         ogreLayer->setBackgroundColor(color, color);
     }
-    else if(attributes.count("topColor") && attributes.count("bottomColor"))
+    else if((attributes.count("topColor") != 0U) && (attributes.count("bottomColor") != 0U))
     {
-        const std::string topColor = attributes.get<std::string>("topColor");
-        const std::string botColor = attributes.get<std::string>("bottomColor");
+        const auto topColor = attributes.get<std::string>("topColor");
+        const auto botColor = attributes.get<std::string>("bottomColor");
 
         ogreLayer->setBackgroundColor(topColor, botColor);
     }
 
-    if(attributes.count("topScale") && attributes.count("bottomScale"))
+    if((attributes.count("topScale") != 0U) && (attributes.count("bottomScale") != 0U))
     {
-        const float topScaleVal = attributes.get<float>("topScale");
-        const float botScaleVal = attributes.get<float>("bottomScale");
+        const auto topScaleVal = attributes.get<float>("topScale");
+        const auto botScaleVal = attributes.get<float>("bottomScale");
 
         ogreLayer->setBackgroundScale(topScaleVal, botScaleVal);
     }
     else
     {
-        ogreLayer->setBackgroundScale(0.5f, 0.5f);
+        ogreLayer->setBackgroundScale(0.5F, 0.5F);
     }
 
     m_layers[s_OGREBACKGROUNDID] = ogreLayer;
@@ -395,27 +396,27 @@ void SRender::configureBackgroundLayer(const ConfigType& _cfg)
 
 Layer::ViewportConfigType SRender::configureLayerViewport(const service::IService::ConfigType& _cfg)
 {
-    Layer::ViewportConfigType cfgType {0.f, 0.f, 1.f, 1.f};
+    Layer::ViewportConfigType cfgType {0.F, 0.F, 1.F, 1.F};
     const auto _vpConfig = _cfg.get_child_optional("viewport.<xmlattr>");
     if(_vpConfig.has_value())
     {
-        const auto cfg = _vpConfig.get();
+        const auto& cfg = _vpConfig.get();
 
-        float xPos = cfg.get<float>("hOffset", 0.f);
-        float yPos = cfg.get<float>("vOffset", 0.f);
+        float xPos = cfg.get<float>("hOffset", 0.F);
+        float yPos = cfg.get<float>("vOffset", 0.F);
 
-        const float width  = cfg.get<float>("width");
-        const float height = cfg.get<float>("height");
+        const auto width  = cfg.get<float>("width");
+        const auto height = cfg.get<float>("height");
 
         const std::map<std::string, float> horizAlignToX {
             {"left", xPos},
-            {"center", 0.5f - width * 0.5f + xPos},
-            {"right", 1.f - width - xPos}
+            {"center", 0.5F - width * 0.5F + xPos},
+            {"right", 1.F - width - xPos}
         };
 
         const std::map<std::string, float> vertAlignToY {
-            {"bottom", 1.f - height - yPos},
-            {"center", 0.5f - height * 0.5f + yPos},
+            {"bottom", 1.F - height - yPos},
+            {"center", 0.5F - height * 0.5F + yPos},
             {"top", yPos}
         };
 
@@ -435,7 +436,7 @@ Layer::ViewportConfigType SRender::configureLayerViewport(const service::IServic
 
 void SRender::requestRender()
 {
-    if(m_renderMode == RenderMode::SYNC)
+    if(m_renderMode == RenderMode::MANUAL)
     {
         m_interactorManager->renderNow();
     }
@@ -479,7 +480,7 @@ void SRender::resetCameraCoordinates(const std::string& _layerId)
 
 void SRender::resetCameras()
 {
-    for(auto layer : m_layers)
+    for(const auto& layer : m_layers)
     {
         layer.second->resetCameraCoordinates();
     }
@@ -489,17 +490,6 @@ void SRender::resetCameras()
 
 //-----------------------------------------------------------------------------
 
-void SRender::computeCameraClipping()
-{
-    for(auto it : m_layers)
-    {
-        viz::scene3d::Layer::sptr layer = it.second;
-        layer->resetCameraClippingRange();
-    }
-}
-
-//-----------------------------------------------------------------------------
-
 void SRender::render()
 {
     this->requestRender();
@@ -552,8 +542,7 @@ void SRender::disableFullscreen()
 {
     m_fullscreen = false;
     m_interactorManager->setFullscreen(m_fullscreen, -1);
-
-    m_fullscreenSetSig->asyncEmit(false);
+    this->signal<signals::void_signal_t>(signals::FULLSCREEN_UNSET)->asyncEmit();
 }
 
 // ----------------------------------------------------------------------------
@@ -562,8 +551,7 @@ void SRender::enableFullscreen(int _screen)
 {
     m_fullscreen = true;
     m_interactorManager->setFullscreen(m_fullscreen, _screen);
-
-    m_fullscreenSetSig->asyncEmit(true);
+    this->signal<signals::void_signal_t>(signals::FULLSCREEN_SET)->asyncEmit();
 }
 
 // ----------------------------------------------------------------------------
