@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,37 +31,24 @@ namespace sight::viz::scene3d
 
 // ----------------------------------------------------------------------------
 
-void WindowManager::registerWindow(Ogre::RenderWindow* _window)
+void WindowManager::add(Ogre::RenderWindow* _window)
 {
-    if(m_windows.empty())
-    {
-        m_firstWindow = _window;
-    }
-
     m_windows.insert(_window);
 }
 
 // ----------------------------------------------------------------------------
 
-void WindowManager::unregisterWindow(Ogre::RenderWindow* _window)
+void WindowManager::remove(Ogre::RenderWindow* _window)
 {
     m_windows.erase(_window);
+}
 
-    if(_window != m_firstWindow)
-    {
-        Ogre::Root* root = viz::scene3d::Utils::getOgreRoot();
-        SIGHT_ASSERT("Ogre root not found", root);
-        root->destroyRenderTarget(_window);
-    }
+// ----------------------------------------------------------------------------
 
-    // If we are the last opened window, we shutdown Ogre completely.
-    if(m_windows.empty())
-    {
-        // We don't need to destroy the ogre target, it is done when shutting down ogre.
-        // Destroying the render target actually results in a double free segfault.
-        viz::scene3d::Utils::destroyOgreRoot();
-        m_firstWindow = nullptr;
-    }
+Ogre::RenderWindow* WindowManager::get(const std::string& _name) const
+{
+    auto it = std::find_if(m_windows.begin(), m_windows.end(), [&](auto _window){return _window->getName() == _name;});
+    return it != m_windows.end() ? *it : nullptr;
 }
 
 // ----------------------------------------------------------------------------
