@@ -26,13 +26,7 @@
 
 #include <OgreMaterialManager.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace compositor
-{
-
-namespace listener
+namespace sight::viz::scene3d::compositor::listener
 {
 
 //-----------------------------------------------------------------------------
@@ -45,16 +39,16 @@ public:
     AutoStereoCompositorListener(std::uint8_t _viewpointNumber);
 
     /// Destructor, destroys created techniques.
-    ~AutoStereoCompositorListener();
+    ~AutoStereoCompositorListener() override;
 
     /// Callback called each time a scheme is not found
-    virtual Ogre::Technique* handleSchemeNotFound(
-        unsigned short _schemeIndex,
+    Ogre::Technique* handleSchemeNotFound(
+        std::uint16_t _schemeIndex,
         const Ogre::String& _schemeName,
         Ogre::Material* _originalMaterial,
-        unsigned short _lodIndex,
+        std::uint16_t _lodIndex,
         const Ogre::Renderable* _renderable
-    );
+    ) override;
 
 private:
 
@@ -68,8 +62,4 @@ private:
     const std::uint8_t m_viewpointNumber;
 };
 
-} // namespace listener
-
-} // namespace compositor
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::compositor::listener
