@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  * Copyright (C) 2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,13 +26,7 @@
 
 #include <OgreMaterialManager.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace compositor
-{
-
-namespace listener
+namespace sight::viz::scene3d::compositor::listener
 {
 
 //-----------------------------------------------------------------------------
@@ -41,28 +35,24 @@ namespace listener
  * @brief Listener used in mixed surface/volume rendering.
  * Creates volume entry point computation techniques for meshes.
  */
-class RayExitDepthListener : public Ogre::MaterialManager::Listener
+class VIZ_SCENE3D_CLASS_API RayExitDepthListener final : public Ogre::MaterialManager::Listener
 {
 public:
 
     /// Constructor.
-    RayExitDepthListener();
+    VIZ_SCENE3D_API RayExitDepthListener() = default;
 
     /// Destructor.
-    ~RayExitDepthListener();
+    VIZ_SCENE3D_API ~RayExitDepthListener() final = default;
 
     /// Called when an entry point scheme isn't found, creates the missing technique.
-    virtual Ogre::Technique* handleSchemeNotFound(
-        unsigned short _schemeIndex,
+    VIZ_SCENE3D_API Ogre::Technique* handleSchemeNotFound(
+        std::uint16_t _schemeIndex,
         const Ogre::String& _schemeName,
         Ogre::Material* _originalMaterial,
-        unsigned short _lodIndex,
+        std::uint16_t _lodIndex,
         const Ogre::Renderable* _renderable
-    );
+    ) final;
 };
 
-} // namespace listener
-
-} // namespace compositor
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::compositor::listener
