@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,10 +28,7 @@
 
 #include <OGRE/OgreCamera.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace helper
+namespace sight::viz::scene3d::helper
 {
 
 class Camera
@@ -88,8 +85,17 @@ public:
         const Ogre::Camera& _camera,
         const Ogre::Vector3& _ndcPos
     );
+
+    /**
+     * @brief Converts from world space (x, y, z) to screen space (u, v, w).
+     * @param _camera ogre camera.
+     * @param _worldPos world position (x, y, z).
+     * @return screen space coordinates in pixels (x, y).
+     */
+    static VIZ_SCENE3D_API Ogre::Vector2 convertWorldSpaceToScreenSpace(
+        const Ogre::Camera& _camera,
+        const Ogre::Vector3& _worldPos
+    );
 };
 
-} // namespace helper
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::helper
