@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,12 +24,11 @@
 
 #include "viz/scene3d/ogre.hpp"
 
+#include <core/exceptionmacros.hpp>
+
 #include <OgreMath.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace helper
+namespace sight::viz::scene3d::helper
 {
 
 //-----------------------------------------------------------------------------
@@ -44,12 +43,12 @@ void ManualObject::createCylinder(
 )
 {
     // Data to create cylinder in x axis
-    const Ogre::Radian delta(Ogre::Degree(360.f / static_cast<float>(_sample)));
+    const Ogre::Radian delta(Ogre::Degree(360.F / static_cast<float>(_sample)));
     const Ogre::Quaternion rot(delta, Ogre::Vector3::UNIT_X);
-    Ogre::Vector3 normal = Ogre::Quaternion(delta / 2.f, Ogre::Vector3::UNIT_X) * Ogre::Vector3::UNIT_Y;
+    Ogre::Vector3 normal = Ogre::Quaternion(delta / 2.F, Ogre::Vector3::UNIT_X) * Ogre::Vector3::UNIT_Y;
 
-    Ogre::Vector3 p0(0.f, _radius, 0.f);
-    Ogre::Vector3 p1(_length, _radius, 0.f);
+    Ogre::Vector3 p0(0.F, _radius, 0.F);
+    Ogre::Vector3 p1(_length, _radius, 0.F);
     Ogre::Vector3 p2 = rot * p0;
     Ogre::Vector3 p3 = rot * p1;
 
@@ -59,7 +58,7 @@ void ManualObject::createCylinder(
     // Initial points of the basis
     _object->position(Ogre::Vector3::ZERO);
     _object->normal(Ogre::Vector3::NEGATIVE_UNIT_X);
-    _object->position(Ogre::Vector3(_length, 0.f, 0.f));
+    _object->position(Ogre::Vector3(_length, 0.F, 0.F));
     _object->normal(Ogre::Vector3::UNIT_X);
     for(unsigned int i = 0 ; i < _sample ; ++i)
     {
@@ -84,10 +83,10 @@ void ManualObject::createCylinder(
         _object->normal(Ogre::Vector3::NEGATIVE_UNIT_X);
 
         _object->position(p1);
-        _object->normal(Ogre::Vector3(_length, 0.f, 0.f));
+        _object->normal(Ogre::Vector3(_length, 0.F, 0.F));
 
         _object->position(p3);
-        _object->normal(Ogre::Vector3(_length, 0.f, 0.f));
+        _object->normal(Ogre::Vector3(_length, 0.F, 0.F));
 
         const unsigned int offset = 2 + (i * 8);
         // Cylinder
@@ -109,7 +108,7 @@ void ManualObject::createCylinder(
 
     _object->setBoundingBox(
         Ogre::AxisAlignedBox(
-            Ogre::Vector3(0.f, -_radius, -_radius),
+            Ogre::Vector3(0.F, -_radius, -_radius),
             Ogre::Vector3(_length, _radius, _radius)
         )
     );
@@ -127,12 +126,12 @@ void ManualObject::createCone(
 )
 {
     // Data to create cone in x axis
-    const Ogre::Radian delta(Ogre::Degree(360.f / static_cast<float>(_sample)));
+    const Ogre::Radian delta(Ogre::Degree(360.F / static_cast<float>(_sample)));
     const Ogre::Quaternion rot(delta, Ogre::Vector3::UNIT_X);
-    Ogre::Vector3 normal = Ogre::Quaternion(delta / 2.f, Ogre::Vector3::UNIT_X) * Ogre::Vector3::UNIT_Y;
+    Ogre::Vector3 normal = Ogre::Quaternion(delta / 2.F, Ogre::Vector3::UNIT_X) * Ogre::Vector3::UNIT_Y;
 
-    Ogre::Vector3 p0(0.f, _radius, 0.f);
-    Ogre::Vector3 p1(_length, 0, 0.f);
+    Ogre::Vector3 p0(0.F, _radius, 0.F);
+    Ogre::Vector3 p1(_length, 0, 0.F);
     Ogre::Vector3 p2 = rot * p0;
 
     // Compute real normal
@@ -180,7 +179,7 @@ void ManualObject::createCone(
 
     _object->setBoundingBox(
         Ogre::AxisAlignedBox(
-            Ogre::Vector3(0.f, -_radius, -_radius),
+            Ogre::Vector3(0.F, -_radius, -_radius),
             Ogre::Vector3(_length, _radius, _radius)
         )
     );
@@ -195,7 +194,7 @@ void ManualObject::createCube(
     float _length
 )
 {
-    float length = _length / 2.0f;
+    float length = _length / 2.0F;
 
     _object->begin(_material, Ogre::RenderOperation::OT_TRIANGLE_LIST, RESOURCE_GROUP);
     _object->colour(_color);
@@ -327,14 +326,86 @@ void ManualObject::createSphere(
 
     _object->end();
 
-    _object->setBoundingBox(
-        Ogre::AxisAlignedBox(
-            {-_radius, -_radius, -_radius},
-            {_radius, _radius, _radius
-            })
-    );
+    _object->setBoundingBox(Ogre::AxisAlignedBox({-_radius, -_radius, -_radius}, {_radius, _radius, _radius}));
 }
 
-} // namespace helper
+//------------------------------------------------------------------------------
 
-} // namespace sight::viz::scene3d
+void ManualObject::createFrustum(
+    Ogre::ManualObject* _object,
+    const std::string& _material,
+    const Ogre::Frustum& _frustum
+)
+{
+    _object->begin(_material, Ogre::RenderOperation::OT_LINE_LIST, RESOURCE_GROUP);
+
+    const Ogre::Frustum::Corners& corners = _frustum.getWorldSpaceCorners();
+
+    std::ranges::for_each(corners, [_object](const auto& corner){_object->position(corner);});
+
+    // see AxisAlignedBox::getAllCorners
+    const std::vector<Ogre::uint32> idx = {0, 1, 1, 2, 2, 3, 3, 0, 4, 5, 5, 6, 6, 7, 7, 4, 0, 6, 1, 5, 2, 4, 3, 7};
+
+    std::ranges::for_each(idx, [_object](const auto i){_object->index(i);});
+
+    _object->end();
+
+    Ogre::Vector3 min(std::numeric_limits<Ogre::Real>::max());
+    Ogre::Vector3 max(std::numeric_limits<Ogre::Real>::lowest());
+
+    for(size_t i = 0 ; i < 7 ; ++i)
+    {
+        std::tie(min.x, max.x) = std::minmax(corners[i].x, corners[i + 1].x);
+        std::tie(min.y, max.y) = std::minmax(corners[i].y, corners[i + 1].y);
+        std::tie(min.z, max.z) = std::minmax(corners[i].z, corners[i + 1].z);
+    }
+
+    _object->setBoundingBox(Ogre::AxisAlignedBox(min, max));
+}
+
+//------------------------------------------------------------------------------
+
+void ManualObject::drawDashedLine(
+    Ogre::ManualObject* _object,
+    const Ogre::Vector3& _p1,
+    const Ogre::Vector3& _p2,
+    const float _dashLength,
+    const float _dashSpacing,
+    std::optional<Ogre::ColourValue> _color
+)
+{
+    SIGHT_ASSERT("Invalid argument", _object != nullptr);
+
+    const auto vec    = _p2 - _p1;
+    const auto length = vec.length();
+
+    if(length <= (_dashLength + _dashSpacing))
+    {
+        // No need to draw a dashed line
+        return;
+    }
+
+    const auto numDashes  = length / (_dashLength + _dashSpacing);
+    const auto incDash    = vec * _dashLength / length;
+    const auto incSpacing = vec * _dashSpacing / length;
+    const auto inc        = vec / numDashes;
+    Ogre::Vector3 cur     = _p1 + incSpacing;
+    for(std::size_t i = 0 ; i < static_cast<std::size_t>(numDashes) ; ++i)
+    {
+        _object->position(cur);
+        if(_color.has_value())
+        {
+            _object->colour(_color.value());
+        }
+
+        _object->position(cur + incDash);
+        if(_color.has_value())
+        {
+            _object->colour(_color.value());
+        }
+
+        cur += inc;
+    }
+}
+
+} // namespace sight::viz::scene3d::helper
