@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -41,15 +41,9 @@
  * cspell:ignore SAMPLER1DSHADOW SAMPLER2DSHADOW
  */
 
-namespace sight::viz::scene3d
+namespace sight::viz::scene3d::helper
 {
 
-namespace helper
-{
-
-static const std::string s_EDGE_PASS    = "EdgePass";
-static const std::string s_NORMALS_PASS = "NormalsPass";
-
 static const std::regex s_PEEL_REGEX(".*/peel.*");
 static const std::regex s_WEIGHT_BLEND_REGEX(".*/weightBlend.*");
 static const std::regex s_TRANSMITTANCE_BLEND_REGEX(".*/transmittanceBlend.*");
@@ -67,11 +61,12 @@ bool Shading::isColorTechnique(const Ogre::Technique& _tech)
     const std::string& name = _tech.getName();
     const std::regex regexDualPeelInit("Dual.*/peelInit.*");
 
-    const bool peelTech     = std::regex_match(name, s_PEEL_REGEX);
-    const bool weightPass   = std::regex_match(name, s_WEIGHT_BLEND_REGEX);
-    const bool peelInitPass = std::regex_match(name, regexDualPeelInit);
+    const bool peelTech       = std::regex_match(name, s_PEEL_REGEX);
+    const bool weightPass     = std::regex_match(name, s_WEIGHT_BLEND_REGEX);
+    const bool peelInitPass   = std::regex_match(name, regexDualPeelInit);
+    const bool rayEntryPoints = name == "FrontFacesMin";
 
-    return name == "" || (peelTech && !peelInitPass) || weightPass;
+    return name.empty() || (peelTech && !peelInitPass) || weightPass || rayEntryPoints;
 }
 
 //-----------------------------------------------------------------------------
@@ -94,7 +89,7 @@ bool Shading::isGeometricTechnique(const Ogre::Technique& _tech)
     const bool weightBlend        = std::regex_match(name, s_WEIGHT_BLEND_REGEX);
     const bool transmittanceBlend = std::regex_match(name, s_TRANSMITTANCE_BLEND_REGEX);
 
-    return name == "" || peelPass || weightBlend || transmittanceBlend;
+    return name.empty() || peelPass || weightBlend || transmittanceBlend;
 }
 
 //-----------------------------------------------------------------------------
@@ -179,7 +174,7 @@ std::string Shading::getR2VBGeometryProgramName(
         suffix += "+PPColor";
     }
 
-    const std::string name = "R2VB/" + suffix + "_GP";
+    std::string name = "R2VB/" + suffix + "_GP";
 
     return name;
 }
@@ -290,9 +285,12 @@ Shading::ShaderConstantsType Shading::findShaderConstants(
             }
         }
 
-        if(!Ogre::StringUtil::endsWith(cstDef.first, "[0]") && !_params->findAutoConstantEntry(cstDef.first))
+        if(!Ogre::StringUtil::endsWith(
+               cstDef.first,
+               "[0]"
+           ) && (_params->findAutoConstantEntry(cstDef.first) == nullptr))
         {
-            ConstantValueType constantValue;
+            ConstantValueType constantValue {};
             bool found = false;
             if(cstDef.second.isDouble())
             {
@@ -359,7 +357,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({2}, core::tools::Type::s_FLOAT);
+            arrayObject->resize({2}, core::Type::FLOAT);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -374,7 +372,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({3}, core::tools::Type::s_FLOAT);
+            arrayObject->resize({3}, core::Type::FLOAT);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -410,7 +408,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({2}, core::tools::Type::s_INT32);
+            arrayObject->resize({2}, core::Type::INT32);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -425,7 +423,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({3}, core::tools::Type::s_INT32);
+            arrayObject->resize({3}, core::Type::INT32);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -441,7 +439,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({4}, core::tools::Type::s_INT32);
+            arrayObject->resize({4}, core::Type::INT32);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -466,7 +464,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({2}, core::tools::Type::s_DOUBLE);
+            arrayObject->resize({2}, core::Type::DOUBLE);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -481,7 +479,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({3}, core::tools::Type::s_DOUBLE);
+            arrayObject->resize({3}, core::Type::DOUBLE);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -497,7 +495,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
         {
             data::Array::sptr arrayObject = data::Array::New();
 
-            arrayObject->resize({4}, core::tools::Type::s_DOUBLE);
+            arrayObject->resize({4}, core::Type::DOUBLE);
 
             const auto dumpLock = arrayObject->dump_lock();
 
@@ -515,7 +513,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
             break;
 
         default:
-            std::string GpuConstantTypeNames[] =
+            [[maybe_unused]] static const std::array GpuConstantTypeNames
             {
                 "GCT_FLOAT1",
                 "GCT_FLOAT2",
@@ -558,9 +556,7 @@ data::Object::sptr Shading::createObjectFromShaderParameter(Ogre::GpuConstantTyp
                 "GCT_MATRIX_DOUBLE_4X4",
                 "GCT_UNKNOWN"
             };
-            SIGHT_WARN("Object type " + GpuConstantTypeNames[_type - 1] + " not supported yet");
-
-            (void) GpuConstantTypeNames; // Only there to avoid the 'unused' warning.
+            SIGHT_WARN("Object type " + std::string(GpuConstantTypeNames[_type - 1]) + " not supported yet");
     }
 
     return object;
@@ -614,11 +610,9 @@ Ogre::GpuProgramPtr Shading::createProgramFrom(
     params->copyMatchingNamedConstantsFrom(*baseParams);
 
     newProgram->load();
-    return Ogre::GpuProgramPtr(newProgram);
+    return {newProgram};
 }
 
 //-----------------------------------------------------------------------------
 
-} // namespace helper
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::helper
