@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,7 +23,6 @@
 #pragma once
 
 #include "viz/scene3d/interactor/IInteractor.hpp"
-#include "viz/scene3d/picker/IPicker.hpp"
 #include "viz/scene3d/widget/ClippingBox.hpp"
 
 #include <core/com/Signal.hpp>
@@ -31,10 +30,7 @@
 
 #include <OGRE/OgreMovableObject.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace interactor
+namespace sight::viz::scene3d::interactor
 {
 
 /// Picks VR widgets and updates clipping cube.
@@ -55,25 +51,59 @@ public:
     ) noexcept;
 
     /// Destroys the widget.
-    VIZ_SCENE3D_API ~ClippingBoxInteractor() noexcept override;
+    VIZ_SCENE3D_API ~ClippingBoxInteractor() noexcept final = default;
 
     /// Interacts with the widget if it was previously picked, behaves like a trackball otherwise.
-    VIZ_SCENE3D_API void mouseMoveEvent(MouseButton, Modifier, int, int, int, int) override;
+    VIZ_SCENE3D_API void mouseMoveEvent(
+        MouseButton /*button*/,
+        Modifier /*_mods*/,
+        int /*x*/,
+        int /*y*/,
+        int /*dx*/,
+        int /*dy*/
+    ) final;
 
     /// Ends all interactions with the widget.
-    VIZ_SCENE3D_API void buttonReleaseEvent(MouseButton, Modifier, int, int) override;
+    VIZ_SCENE3D_API void buttonReleaseEvent(
+        MouseButton /*_button*/,
+        Modifier /*_mods*/,
+        int /*_x*/,
+        int /*_y*/
+    ) final;
 
     /// Picks the object at the (x,y) position on a left click, scales or translates the widget otherwise.
-    VIZ_SCENE3D_API void buttonPressEvent(MouseButton, Modifier, int, int) override;
+    VIZ_SCENE3D_API void buttonPressEvent(MouseButton /*button*/, Modifier /*_mods*/, int /*x*/, int /*y*/) final;
+
+    /// Scales the widget.
+    /// @param _scalingFactor distance of the fingers
+    /// @param _centerX the width coordinate of the center of the pinch
+    /// @param _centerY the height coordinate of the center of the pinch
+    VIZ_SCENE3D_API void pinchGestureEvent(double _scaleFactor, int _centerX, int _centerY) final;
+
+    /// Ends all interactions with the widget.
+    /// @param _x current width coordinate.
+    /// @param _y current height coordinate.
+    /// @param _dx the width displacement since the last event.
+    /// @param _dy the height displacement since the last event.
+    VIZ_SCENE3D_API void panGestureMoveEvent(int _x, int _y, int _dx, int _dy) final;
+
+    /**
+     * @brief Listens to pan gesture release events.
+     * @param _x the last width coordinate of the finger
+     * @param _y the last height coordinate of the finger
+     * @param _dx width displacement of the finger since the last event.
+     * @param _dy height displacement of the finger since the last event.
+     */
+    VIZ_SCENE3D_API void panGestureReleaseEvent(int _x, int _y, int _dx, int _dy) final;
 
     /// Sets the visibility of the box widget.
     VIZ_SCENE3D_API void setBoxVisibility(bool _visibility);
 
     /// Retrieves the positions of the box in model space.
-    VIZ_SCENE3D_API Ogre::AxisAlignedBox getClippingBox() const;
+    [[nodiscard]] VIZ_SCENE3D_API Ogre::AxisAlignedBox getClippingBox() const;
 
     /// Retrieves the current clipping transform.
-    VIZ_SCENE3D_API Ogre::Matrix4 getClippingTransform() const;
+    [[nodiscard]] VIZ_SCENE3D_API Ogre::Matrix4 getClippingTransform() const;
 
     /// Sets the current clipping box positions from the input transform.
     VIZ_SCENE3D_API void updateFromTransform(const Ogre::Matrix4& _clippingTrf);
@@ -89,13 +119,8 @@ private:
     /// Defines the widget with whom we interact.
     widget::ClippingBox m_widget;
 
-    /// Defines the picker used by this interactor.
-    viz::scene3d::picker::IPicker m_picker;
-
     /// Attempts to pick the first object at screen coordinates (x, y), returns nullptr if no object was picked.
     Ogre::MovableObject* pickObject(int x, int y);
 };
 
-} // namespace interactor.
-
-} // namespace sight::viz::scene3d.
+} // namespace sight::viz::scene3d::interactor
