@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -31,10 +31,7 @@
 
 #include <service/macros.hpp>
 
-namespace sight::viz::scene3d
-{
-
-namespace interactor
+namespace sight::viz::scene3d::interactor
 {
 
 // ----------------------------------------------------------------------------
@@ -48,60 +45,102 @@ IInteractor::IInteractor(Layer::sptr _layer, bool _layerOrderDependant) :
 // ----------------------------------------------------------------------------
 
 IInteractor::~IInteractor()
-{
-}
+= default;
 
 // ----------------------------------------------------------------------------
 
-void IInteractor::setSceneLength(float)
+void IInteractor::setSceneLength(float /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::mouseMoveEvent(MouseButton, Modifier, int, int, int, int)
+void IInteractor::mouseMoveEvent(
+    MouseButton /*unused*/,
+    Modifier /*unused*/,
+    int /*unused*/,
+    int /*unused*/,
+    int /*unused*/,
+    int /*unused*/
+)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::wheelEvent(Modifier, int, int, int)
+void IInteractor::wheelEvent(Modifier /*unused*/, double /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::buttonReleaseEvent(MouseButton, Modifier, int, int)
+void IInteractor::buttonReleaseEvent(MouseButton /*unused*/, Modifier /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::buttonPressEvent(MouseButton, Modifier, int, int)
+void IInteractor::buttonPressEvent(MouseButton /*unused*/, Modifier /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::buttonDoublePressEvent(MouseButton, Modifier, int, int)
+void IInteractor::buttonDoublePressEvent(MouseButton /*unused*/, Modifier /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::keyPressEvent(int, Modifier, int, int)
+void IInteractor::keyPressEvent(int /*unused*/, Modifier /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::keyReleaseEvent(int, Modifier, int, int)
+void IInteractor::keyReleaseEvent(int /*unused*/, Modifier /*unused*/, int /*unused*/, int /*unused*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void IInteractor::resizeEvent(int, int)
+void IInteractor::resizeEvent(int /*unused*/, int /*unused*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::pinchGestureEvent(double /*_scaleFactor*/, int /*_centerX*/, int /*_centerY*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::panGestureMoveEvent(int /*_x*/, int /*_y*/, int /*_dx*/, int /*_dy*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::panGestureReleaseEvent(int /*_x*/, int /*_y*/, int /*_dx*/, int /*_dy*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::longTapGestureEvent(int /*_x*/, int /*_y*/)
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::leaveEvent()
+{
+}
+
+//------------------------------------------------------------------------------
+
+void IInteractor::enterEvent()
 {
 }
 
@@ -115,9 +154,9 @@ bool IInteractor::isInLayer(int _mouseX, int _mouseY, Layer::sptr _layer, bool _
     // Check if there's no layer above.
     if(_layerOrderDependant)
     {
-        auto* const renderWindow       = layerVp->getTarget();
-        const unsigned short numLayers = renderWindow->getNumViewports();
-        for(unsigned short i = 0 ; i < numLayers && isInLayer ; ++i)
+        auto* const renderWindow      = layerVp->getTarget();
+        const std::uint16_t numLayers = renderWindow->getNumViewports();
+        for(std::uint16_t i = 0 ; i < numLayers && isInLayer ; ++i)
         {
             const auto* const vp = renderWindow->getViewport(i);
             if(vp->getZOrder() > layerVp->getZOrder())
@@ -142,6 +181,4 @@ bool IInteractor::isInViewport(int _mouseX, int _mouseY, const Ogre::Viewport* c
     return _mouseX >= left && _mouseX <= right && _mouseY >= top && _mouseY <= bottom;
 }
 
-} // namespace interactor
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::interactor
