@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -107,7 +107,7 @@ public:
      * @param _x width coordinate of the mouse.
      * @param _y height coordinate of the mouse.
      */
-    VIZ_SCENE3D_API virtual void wheelEvent(Modifier _mods, int _angleDelta, int _x, int _y);
+    VIZ_SCENE3D_API virtual void wheelEvent(Modifier _mods, double _angleDelta, int _x, int _y);
 
     /**
      * @brief Listens to mouse move buttons being released.
@@ -154,6 +154,16 @@ public:
      */
     VIZ_SCENE3D_API virtual void keyReleaseEvent(int _key, Modifier _mods, int _mouseX, int _mouseY);
 
+    /**
+     * @brief Called when the mouse leaves the widget
+     */
+    VIZ_SCENE3D_API virtual void leaveEvent();
+
+    /**
+     * @brief Called when the mouse enters the widget
+     */
+    VIZ_SCENE3D_API virtual void enterEvent();
+
     /**
      * @brief Checks if the cursor is inside a layer's viewport.
      * @param mouseX width coordinate of the mouse in pixels.
@@ -170,6 +180,40 @@ public:
      */
     VIZ_SCENE3D_API virtual void resizeEvent(int _width, int _height);
 
+    /**
+     * @brief Listens to pinch gesture events.
+     * @param _scaleFactor the scale factor of the pinch
+     *                     (See @ref https://doc.qt.io/qt-5/qpinchgesture.html#scaleFactor-prop)
+     * @param _centerX the width coordinate of the center of the pinch
+     * @param _centerY the height coordinate of the center of the pinch
+     */
+    VIZ_SCENE3D_API virtual void pinchGestureEvent(double _scaleFactor, int _centerX, int _centerY);
+
+    /**
+     * @brief Listens to pan gesture move events.
+     * @param _x the current width coordinate of the finger
+     * @param _y the current height coordinate of the finger
+     * @param _dx width displacement of the finger since the last event.
+     * @param _dy height displacement of the finger since the last event.
+     */
+    VIZ_SCENE3D_API virtual void panGestureMoveEvent(int _x, int _y, int _dx, int _dy);
+
+    /**
+     * @brief Listens to pan gesture release events.
+     * @param _x the last width coordinate of the finger
+     * @param _y the last height coordinate of the finger
+     * @param _dx width displacement of the finger since the last event.
+     * @param _dy height displacement of the finger since the last event.
+     */
+    VIZ_SCENE3D_API virtual void panGestureReleaseEvent(int _x, int _y, int _dx, int _dy);
+
+    /**
+     * @brief Listens to long tap gesture events.
+     * @param _x the width coordinate of the finger
+     * @param _y the height coordinate of the finger
+     */
+    VIZ_SCENE3D_API virtual void longTapGestureEvent(int _x, int _y);
+
 protected:
 
     /// Weak reference to the layer on which the interactor interacts.
@@ -181,7 +225,7 @@ protected:
 private:
 
     /// Checks if the cursor is on top of the given viewport.
-    static bool isInViewport(int _mouseX, int _mouseY, const Ogre::Viewport* const _vp);
+    static bool isInViewport(int _mouseX, int _mouseY, const Ogre::Viewport* _vp);
 };
 
 //------------------------------------------------------------------------------
