@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,17 +34,12 @@ namespace sight::viz::scene3d::interactor
 MeshPickerInteractor::MeshPickerInteractor(Layer::sptr _layer, bool _layerOrderDependant) noexcept :
     IInteractor(_layer, _layerOrderDependant)
 {
-    if(_layer)
-    {
-        m_picker.setSceneManager(_layer->getSceneManager());
-    }
 }
 
 //------------------------------------------------------------------------------
 
-MeshPickerInteractor::~MeshPickerInteractor() noexcept
-{
-}
+MeshPickerInteractor::~MeshPickerInteractor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -64,19 +59,17 @@ void MeshPickerInteractor::setQueryMask(std::uint32_t _queryMask)
 
 void MeshPickerInteractor::pick(MouseButton _button, Modifier _mod, int _x, int _y, bool _pressed)
 {
-    if(m_picker.hasSceneManager())
+    if(auto layer = m_layer.lock())
     {
-        if(auto layer = m_layer.lock())
+        if(!isInLayer(_x, _y, layer, m_layerOrderDependant))
         {
-            if(!isInLayer(_x, _y, layer, m_layerOrderDependant))
-            {
-                return;
-            }
+            return;
         }
 
-        if(m_picker.executeRaySceneQuery(_x, _y, m_queryMask))
+        if(auto result = viz::scene3d::Utils::pickObject(_x, _y, m_queryMask, *layer->getSceneManager());
+           result != std::nullopt)
         {
-            Ogre::Vector3 click = m_picker.getIntersectionInWorldSpace();
+            Ogre::Vector3 click = result->second;
 
             data::tools::PickingInfo info;
             info.m_worldPos[0] = static_cast<double>(click.x);
@@ -126,10 +119,6 @@ void MeshPickerInteractor::pick(MouseButton _button, Modifier _mod, int _x, int
             }
         }
     }
-    else
-    {
-        SIGHT_ERROR("The picker scene hasn't been initialized, you are not using this interactor correctly");
-    }
 }
 
 //------------------------------------------------------------------------------
