@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -45,7 +45,7 @@ public:
     VIZ_SCENE3D_API TrackballInteractor(SPTR(Layer)_layer = nullptr, bool _layerOrderDependant = true);
 
     /// Destroys the trackball.
-    VIZ_SCENE3D_API ~TrackballInteractor() override;
+    VIZ_SCENE3D_API ~TrackballInteractor() final;
 
     /**
      * @brief Moves the camera according to the pressed button.
@@ -62,24 +62,41 @@ public:
      */
     VIZ_SCENE3D_API void mouseMoveEvent(
         MouseButton _button,
-        Modifier,
+        Modifier /*_mods*/,
         int _x,
         int _y,
         int _dx,
         int _dy
-    ) override;
+    ) final;
 
     /// Verifies if the button is pressed within the camera's viewport and enables mouse movements if that is the case.
-    VIZ_SCENE3D_API void buttonPressEvent(MouseButton _button, Modifier, int _x, int _y) override;
+    VIZ_SCENE3D_API void buttonPressEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y) final;
 
     /// Disables mouse movements.
-    VIZ_SCENE3D_API void buttonReleaseEvent(MouseButton _button, Modifier, int, int) override;
+    VIZ_SCENE3D_API void buttonReleaseEvent(MouseButton _button, Modifier /*_mods*/, int /*_x*/, int /*_y*/) final;
 
     /**
      * @brief Moves the camera towards or away from the focus point.
      * @param _delta distance that the wheel is rotated, in eighths of a degree.
      */
-    VIZ_SCENE3D_API void wheelEvent(Modifier, int _delta, int, int) override;
+    VIZ_SCENE3D_API void wheelEvent(Modifier /*_mods*/, double _delta, int /*x*/, int /*y*/) final;
+
+    /**
+     * @brief Moves the camera towards or away the central point.
+     * @param _scalingFactor distance of the fingers
+     * @param _centerX the width coordinate of the center of the pinch
+     * @param _centerY the height coordinate of the center of the pinch
+     */
+    VIZ_SCENE3D_API void pinchGestureEvent(double _scaleFactor, int _centerX, int _centerY) final;
+
+    /**
+     * @brief Moves the camera along the screen's axes.
+     * @param _x current width coordinate.
+     * @param _y current height coordinate.
+     * @param _dx the width displacement since the last event.
+     * @param _dy the height displacement since the last event.
+     */
+    VIZ_SCENE3D_API void panGestureMoveEvent(int _x, int _y, int _dx, int _dy) final;
 
     /**
      * @brief Defines camera actions when the keyboard is pressed.
@@ -89,15 +106,15 @@ public:
      * @param _mouseX the mouse's width position at the time of the key press.
      * @param _mouseY the mouse's height position at the time of the key press.
      */
-    VIZ_SCENE3D_API void keyPressEvent(int _key, Modifier, int _mouseX, int _mouseY) override;
+    VIZ_SCENE3D_API void keyPressEvent(int _key, Modifier /*_mods*/, int _mouseX, int _mouseY) final;
 
     /**
      * @brief Recomputes the camera's aspect ratio when the render window is resized.
      */
-    VIZ_SCENE3D_API void resizeEvent(int, int) override;
+    VIZ_SCENE3D_API void resizeEvent(int /*_width*/, int /*_height*/) final;
 
     /// Recomputes the mouse's scale and focus point from the updated scene length.
-    VIZ_SCENE3D_API void setSceneLength(float _sceneLength) override;
+    VIZ_SCENE3D_API void setSceneLength(float _sceneLength) final;
 
 private:
 
@@ -106,26 +123,26 @@ private:
      * @param dx The mouse's X displacement
      * @param dy The mouse's Y displacement
      */
-    void cameraRotate(int, int);
+    void cameraRotate(int /*dx*/, int /*dy*/);
 
     /**
      * @brief The camera's scene node will translate along its local vertical and horizontal axes.
      * @param dx The horizontal displacement
      * @param dy The vertical displacement
      */
-    void cameraTranslate(int, int);
+    void cameraTranslate(int /*x_move*/, int /*y_move*/);
 
     /// Resets the camera's focal length when the focus point changes.
     void updateCameraFocalLength();
 
     /// Current distance from the camera to the point of interest.
-    float m_lookAtZ {1.f};
+    float m_lookAtZ {1.F};
 
     /// Scale applied to mouse events.
-    float m_mouseScale {1.f};
+    float m_mouseScale {1.F};
 
     /// Current zoom factor.
-    float m_zoom {1.f};
+    float m_zoom {1.F};
 
     /// Default mouse scale factor (used to move the camera)
     static constexpr int MOUSE_SCALE_FACTOR = 200;
