@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  * Copyright (C) 2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,7 @@
 
 #include <OgreRoot.h>
 
-namespace sight::viz::scene3d
-{
-
-namespace ut
+namespace sight::viz::scene3d::ut
 {
 
 class CameraTest : public CPPUNIT_NS::TestFixture
@@ -37,6 +34,7 @@ class CameraTest : public CPPUNIT_NS::TestFixture
 CPPUNIT_TEST_SUITE(CameraTest);
 CPPUNIT_TEST(computeProjectionMatrix);
 CPPUNIT_TEST(convertPixelToWorldSpace);
+CPPUNIT_TEST(convertWorldSpaceToScreenSpace);
 CPPUNIT_TEST_SUITE_END();
 
 public:
@@ -44,10 +42,9 @@ public:
     void setUp() override;
     void tearDown() override;
 
-    void computeProjectionMatrix();
-    void convertPixelToWorldSpace();
+    static void computeProjectionMatrix();
+    static void convertPixelToWorldSpace();
+    static void convertWorldSpaceToScreenSpace();
 };
 
-} //namespace ut
-
-} //namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::ut
