@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,6 +25,7 @@
 #include "viz/scene3d/config.hpp"
 #include "viz/scene3d/factory/R2VBRenderable.hpp"
 #include "viz/scene3d/R2VBRenderable.hpp"
+#include "viz/scene3d/Texture.hpp"
 #include "viz/scene3d/TransferFunction.hpp"
 
 #include <data/Image.hpp>
@@ -35,10 +36,7 @@
 
 #include <array>
 
-namespace sight::viz::scene3d
-{
-
-namespace vr
+namespace sight::viz::scene3d::vr
 {
 
 /**
@@ -66,7 +64,8 @@ public:
     static VIZ_SCENE3D_API GridProxyGeometry* New(
         const std::string& _name,
         Ogre::SceneManager* _sceneManager,
-        Ogre::TexturePtr _3DImageTexture,
+        const viz::scene3d::Texture::sptr& _3DImageTexture,
+        const viz::scene3d::Texture::sptr& _maskTexture,
         const TransferFunction::sptr& _tf,
         const std::string& _mtlName
     );
@@ -88,10 +87,13 @@ public:
     VIZ_SCENE3D_API void clipGrid(const Ogre::AxisAlignedBox& _clippingBox);
 
     /// Get the object's type as a string.
-    VIZ_SCENE3D_API const Ogre::String& getMovableType(void) const override;
+    VIZ_SCENE3D_API const Ogre::String& getMovableType() const override;
 
     /// Sets the texture for which the grid is computed. Doesn't recompute the grid.
-    VIZ_SCENE3D_API void set3DImageTexture(const Ogre::TexturePtr& _texture);
+    VIZ_SCENE3D_API void set3DImageTexture(const viz::scene3d::Texture::sptr& _texture);
+
+    /// Sets the mask texture for which the grid is computed. Doesn't recompute the grid.
+    VIZ_SCENE3D_API void setMaskTexture(const viz::scene3d::Texture::sptr& _texture);
 
 private:
 
@@ -132,7 +134,10 @@ private:
     static constexpr std::array<int, 3> s_brickSize {{8, 8, 8}};
 
     /// Image from which we define a grid.
-    Ogre::TexturePtr m_3DImageTexture {nullptr};
+    viz::scene3d::Texture::sptr m_3DImageTexture {nullptr};
+
+    /// Image from which we define a grid.
+    viz::scene3d::Texture::sptr m_maskTexture {nullptr};
 
     /// Transfer function to be applied to the image.
     TransferFunction::wptr m_gpuTF;
@@ -154,19 +159,17 @@ public:
 
     /// Constructor, does nothing.
     VIZ_SCENE3D_API GridProxyGeometryFactory()
-    {
-    }
+    = default;
 
     /// Destructor, does nothing.
     VIZ_SCENE3D_API ~GridProxyGeometryFactory() override
-    {
-    }
+    = default;
 
     /// Produced object type name. (i.e. "GridProxyGeometry")
     VIZ_SCENE3D_API static inline const Ogre::String FACTORY_TYPE_NAME = "GridProxyGeometry";
 
     /// Returns the object type name.
-    VIZ_SCENE3D_API const Ogre::String& getType() const override
+    [[nodiscard]] VIZ_SCENE3D_API const Ogre::String& getType() const override
     {
         return GridProxyGeometryFactory::FACTORY_TYPE_NAME;
     }
@@ -188,6 +191,7 @@ protected:
     VIZ_SCENE3D_API Ogre::MovableObject* createInstanceImpl(
         const Ogre::String& name,
         const Ogre::NameValuePairList*
+        /*params*/
     ) override
     {
         return new viz::scene3d::vr::GridProxyGeometry(name);
@@ -204,11 +208,16 @@ inline const Ogre::String& GridProxyGeometry::getMovableType() const
 
 //------------------------------------------------------------------------------
 
-inline void GridProxyGeometry::set3DImageTexture(const Ogre::TexturePtr& _texture)
+inline void GridProxyGeometry::set3DImageTexture(const viz::scene3d::Texture::sptr& _texture)
 {
     m_3DImageTexture = _texture;
 }
 
-} // namespace vr
+//------------------------------------------------------------------------------
 
-} // namespace sight::viz::scene3d
+inline void GridProxyGeometry::setMaskTexture(const viz::scene3d::Texture::sptr& _texture)
+{
+    m_maskTexture = _texture;
+}
+
+} // namespace sight::viz::scene3d::vr
