@@ -29,34 +29,24 @@
 #include <viz/scene3d/ogre.hpp>
 #include <viz/scene3d/Utils.hpp>
 
-#include <boost/algorithm/clamp.hpp>
-
 #include <OGRE/OgreHardwarePixelBuffer.h>
+#include <OGRE/OgrePrerequisites.h>
 #include <OGRE/OgreTextureManager.h>
-#include <OGRE/OgreVector4.h>
 
 #include <algorithm>
 
-namespace sight::viz::scene3d
-{
-
-namespace vr
+namespace sight::viz::scene3d::vr
 {
 
 //-----------------------------------------------------------------------------
 
-PreIntegrationTable::PreIntegrationTable() :
-    m_table(nullptr),
-    m_integralTable(nullptr),
-    m_textureSize(0)
-{
-}
+PreIntegrationTable::PreIntegrationTable()
+= default;
 
 //-----------------------------------------------------------------------------
 
 PreIntegrationTable::~PreIntegrationTable()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -80,14 +70,14 @@ void PreIntegrationTable::removeTexture()
 //-----------------------------------------------------------------------------
 
 void PreIntegrationTable::imageUpdate(
-    const data::Image::sptr& _img,
-    const data::TransferFunction::sptr& _tf,
+    const data::Image::csptr& _img,
+    const data::TransferFunction::csptr& _tf,
     float _samplingRate
 )
 {
     FW_PROFILE("TF Init")
     {
-        Ogre::PixelFormat pixelFormat = viz::scene3d::Utils::getPixelFormatOgre(_img);
+        Ogre::PixelFormat pixelFormat = viz::scene3d::Utils::getPixelFormatOgre(*_img);
 
         const auto dumpLock = _img->dump_lock();
 
@@ -97,8 +87,8 @@ void PreIntegrationTable::imageUpdate(
         {
             case Ogre::PF_L8: //uint8
             {
-                uint8_t* ucharImgBuffer = static_cast<uint8_t*>(_img->getBuffer());
-                auto minMax             = std::minmax_element(ucharImgBuffer, ucharImgBuffer + nbPixels);
+                const auto* ucharImgBuffer = static_cast<const uint8_t*>(_img->getBuffer());
+                auto minMax                = std::minmax_element(ucharImgBuffer, ucharImgBuffer + nbPixels);
 
                 m_valueInterval.first  = *minMax.first;
                 m_valueInterval.second = *minMax.second;
@@ -108,8 +98,8 @@ void PreIntegrationTable::imageUpdate(
 
             case Ogre::PF_L16: //int16
             {
-                int16_t* ushortImgBuffer = static_cast<int16_t*>(_img->getBuffer());
-                auto minMax              = std::minmax_element(ushortImgBuffer, ushortImgBuffer + nbPixels);
+                const auto* ushortImgBuffer = static_cast<const int16_t*>(_img->getBuffer());
+                auto minMax                 = std::minmax_element(ushortImgBuffer, ushortImgBuffer + nbPixels);
 
                 m_valueInterval.first  = *minMax.first;
                 m_valueInterval.second = *minMax.second;
@@ -119,8 +109,8 @@ void PreIntegrationTable::imageUpdate(
 
             case ::Ogre::PF_R32_SINT: //int32
             {
-                int32_t* uintImgBuffer = static_cast<int32_t*>(_img->getBuffer());
-                auto minMax            = std::minmax_element(uintImgBuffer, uintImgBuffer + nbPixels);
+                const auto* uintImgBuffer = static_cast<const int32_t*>(_img->getBuffer());
+                auto minMax               = std::minmax_element(uintImgBuffer, uintImgBuffer + nbPixels);
 
                 m_valueInterval.first  = *minMax.first;
                 m_valueInterval.second = *minMax.second;
@@ -132,19 +122,19 @@ void PreIntegrationTable::imageUpdate(
                 SIGHT_FATAL("Invalid pixel format for pre-integration, pixels must be integers");
         }
 
-        unsigned textureSize = static_cast<unsigned>(m_valueInterval.second - m_valueInterval.first);
+        auto textureSize = static_cast<unsigned>(m_valueInterval.second - m_valueInterval.first);
 
         if(textureSize != m_textureSize)
         {
             m_textureSize = textureSize;
 
-            if(m_table)
+            if(m_table != nullptr)
             {
-                delete m_table;
-                delete m_integralTable;
+                delete[] m_table;
+                delete[] m_integralTable;
             }
 
-            m_table         = new TablePixel[m_textureSize * m_textureSize];
+            m_table         = new TablePixel[static_cast<std::size_t>(m_textureSize) * m_textureSize];
             m_integralTable = new IntegralPixel[m_textureSize];
 
             Utils::allocateTexture(
@@ -164,32 +154,21 @@ void PreIntegrationTable::imageUpdate(
 
 //-----------------------------------------------------------------------------
 
-void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, float _sampleDistance)
+void PreIntegrationTable::tfUpdate(const data::TransferFunction::csptr& _tf, float _sampleDistance)
 {
-    if(!m_table)
+    if(m_table == nullptr)
     {
         return;
     }
 
     FW_PROFILE("PreIntegration")
     {
-        const data::TransferFunction::TFValuePairType intensityMinMax = _tf->getWLMinMax();
-
-        const data::TransferFunction::TFValuePairType tfMinMax = _tf->getMinMaxTFValues();
-
-        const double invWindow = 1. / _tf->getWindow();
-
-        glm::vec4 tmp(0.f);
-
-        _tf->setIsClamped(false);
+        glm::vec4 tmp(0.F);
 
         for(int k = 0 ; k < static_cast<int>(m_textureSize) ; ++k)
         {
-            data::TransferFunction::TFValueType value = k + m_valueInterval.first;
-
-            value = (value - intensityMinMax.first) * (tfMinMax.second - tfMinMax.first) * invWindow + tfMinMax.first;
-
-            data::TransferFunction::TFColor interpolatedColor = _tf->getInterpolatedColor(value);
+            data::TransferFunction::value_t value             = k + m_valueInterval.first;
+            data::TransferFunction::color_t interpolatedColor = _tf->sample(value);
 
             // We use associated colours.
             double alpha = interpolatedColor.a;
@@ -204,20 +183,20 @@ void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, floa
         }
 
         // Inverse of the sampling accounted by the TF.
-        const float samplingAdjustmentFactor = 200.f;
+        const float samplingAdjustmentFactor = 200.F;
 
         #pragma omp parallel for schedule(dynamic)
         for(int sb = 0 ; sb < static_cast<int>(m_textureSize) ; ++sb)
         {
             for(int sf = 0 ; sf < static_cast<int>(m_textureSize) ; ++sf)
             {
-                glm::vec4 res(0.f);
+                glm::vec4 res(0.F);
 
                 const float d = (_sampleDistance * samplingAdjustmentFactor) / static_cast<float>(sb - sf);
 
                 if(sb != sf)
                 {
-                    const float opacity = 1.f - std::exp(-d * (m_integralTable[sb].a - m_integralTable[sf].a));
+                    const float opacity = 1.F - std::exp(-d * (m_integralTable[sb].a - m_integralTable[sf].a));
 
                     const glm::vec3 colour =
                         (d * (glm::vec3(m_integralTable[sb]) - glm::vec3(m_integralTable[sf]))) / opacity;
@@ -226,13 +205,8 @@ void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, floa
                 }
                 else
                 {
-                    data::TransferFunction::TFValueType value = sb + m_valueInterval.first;
-
-                    // intensity --> transfer function
-                    value = (value - intensityMinMax.first) * (tfMinMax.second - tfMinMax.first) * invWindow
-                            + tfMinMax.first;
-
-                    data::TransferFunction::TFColor interpolatedColor = _tf->getInterpolatedColor(value);
+                    data::TransferFunction::value_t value             = sb + m_valueInterval.first;
+                    data::TransferFunction::color_t interpolatedColor = _tf->sample(value);
 
                     res =
                         glm::vec4(
@@ -242,16 +216,16 @@ void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, floa
                             interpolatedColor.a
                         );
 
-                    res.a = 1.f - std::pow(1.f - res.a, _sampleDistance * samplingAdjustmentFactor);
+                    res.a = 1.F - std::pow(1.F - res.a, _sampleDistance * samplingAdjustmentFactor);
                 }
 
-                res = glm::clamp(res, 0.f, 1.f);
+                res = glm::clamp(res, 0.F, 1.F);
 
                 m_table[static_cast<unsigned>(sb) * m_textureSize + static_cast<unsigned>(sf)] = {
-                    static_cast<uint8_t>(res.b * 255.f),
-                    static_cast<uint8_t>(res.g * 255.f),
-                    static_cast<uint8_t>(res.r * 255.f),
-                    static_cast<uint8_t>(res.a * 255.f)
+                    static_cast<uint8_t>(res.b * 255.F),
+                    static_cast<uint8_t>(res.g * 255.F),
+                    static_cast<uint8_t>(res.r * 255.F),
+                    static_cast<uint8_t>(res.a * 255.F)
                 };
             }
         }
@@ -262,9 +236,9 @@ void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, floa
         // Discards the entire buffer while locking so that we can easily refill it from scratch
         pixBuffer->lock(Ogre::HardwareBuffer::HBL_DISCARD);
         Ogre::PixelBox pixBox = pixBuffer->getCurrentLock();
-        std::uint8_t* pDest   = static_cast<std::uint8_t*>(pixBox.data);
+        auto* pDest           = static_cast<std::uint8_t*>(pixBox.data);
 
-        std::memcpy(pDest, m_table, m_textureSize * m_textureSize * sizeof(TablePixel));
+        std::memcpy(pDest, m_table, static_cast<std::size_t>(m_textureSize) * m_textureSize * sizeof(TablePixel));
 
         pixBuffer->unlock();
     }
@@ -272,6 +246,4 @@ void PreIntegrationTable::tfUpdate(const data::TransferFunction::sptr& _tf, floa
 
 //-----------------------------------------------------------------------------
 
-} // namespace vr
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::vr
