@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -19,7 +19,7 @@
  * License along with Sight. If not, see <https://www.gnu.org/licenses/>.
  *
  ***********************************************************************/
-
+// cspell:ignore NOLINT hicpp
 #pragma once
 
 #include "viz/scene3d/config.hpp"
@@ -38,10 +38,7 @@
 #include <optional>
 #include <vector>
 
-namespace sight::viz::scene3d
-{
-
-namespace vr
+namespace sight::viz::scene3d::vr
 {
 
 /**
@@ -58,7 +55,7 @@ public:
         struct ambient_occlusion_info_t
         {
             bool enabled = false;
-            float factor = 1.f;
+            float factor = 1.F;
         };
 
         /// Colour-bleeding related information
@@ -71,7 +68,7 @@ public:
         };
 
         /// Constructor. Need for shadows_data_t.
-        inline shadows_parameters_t()
+        inline shadows_parameters_t() // NOLINT(hicpp-use-equals-default,modernize-use-equals-default)
         {
         }
 
@@ -85,7 +82,7 @@ public:
         colour_bleeding_info_t colour_bleeding {};
 
         /// Convenience function returning if one of the three parameters is enabled.
-        bool enabled() const
+        [[nodiscard]] bool enabled() const
         {
             return soft_shadows || ao.enabled || colour_bleeding.enabled;
         }
@@ -98,12 +95,12 @@ public:
         shadows_data_t(const shadows_parameters_t& parameters = {}) :
             parameters(parameters),
             factors(
-                {
-                    parameters.colour_bleeding.r,
-                    parameters.colour_bleeding.g,
-                    parameters.colour_bleeding.b,
-                    parameters.ao.factor
-                })
+            {
+                parameters.colour_bleeding.r,
+                parameters.colour_bleeding.g,
+                parameters.colour_bleeding.b,
+                parameters.ao.factor
+            })
         {
         }
 
@@ -120,7 +117,7 @@ public:
      * @param parentId                  ID of the service using this renderer
      * @param sceneManager              The scene manager being used.
      * @param volumeNode                This object's node.
-     * @param imageTexture (optional)   Texture holding the 3D image to be rendered. Created if not specified.
+     * @param image                     Texture holding the 3D image to be rendered. Created if not specified.
      * @param buffer (optional)         Enable buffering for the textures updates. Default is false.
      * @param preintegration (optional) Enable preintegration. Default is false.
      * @param shadows (optional)        Shadows parameters. Uses default if not specified.
@@ -130,31 +127,34 @@ public:
     VIZ_SCENE3D_API RayTracingVolumeRenderer(
         std::string parentId,
         Layer::sptr layer,
-        Ogre::SceneNode* const parentNode,
-        std::optional<Ogre::TexturePtr> imageTexture                         = {},
-        bool buffer                                                          = false,
-        bool preintegration                                                  = false,
-        const std::optional<shadows_parameters_t> shadows                    = {},
-        const std::optional<IllumAmbientOcclusionSAT::sat_parameters_t>& sat = {},
-        const std::optional<std::string>& shader                             = {});
+        Ogre::SceneNode* parentNode,
+        sight::data::Image::csptr image,
+        sight::data::Image::csptr mask,
+        sight::data::TransferFunction::csptr tf,
+        std::uint16_t samples,
+        bool buffer                                                   = false,
+        bool preintegration                                           = false,
+        std::optional<shadows_parameters_t> shadows                   = {},
+        std::optional<IllumAmbientOcclusionSAT::sat_parameters_t> sat = {},
+        std::optional<std::string> shader                             = {});
 
     /// Does nothing.
     VIZ_SCENE3D_API ~RayTracingVolumeRenderer() override;
 
     /// Updates the raycasting material and sample distance. Also creates the entry point if not done yet.
-    VIZ_SCENE3D_API void update() override;
+    VIZ_SCENE3D_API void update(const data::TransferFunction::csptr& tf) override;
 
     /// Function called when a new image is being rendered.
-    VIZ_SCENE3D_API void imageUpdate(
-        const data::Image::sptr image,
-        const data::TransferFunction::sptr tf
-    ) override;
+    VIZ_SCENE3D_API void updateImage(data::Image::csptr image, data::TransferFunction::csptr tf) override;
+
+    /// Function called when the mask is updated.
+    VIZ_SCENE3D_API void updateMask(data::Image::csptr mask);
 
     /// Called when the transfer function is updated.
-    VIZ_SCENE3D_API void updateVolumeTF(std::shared_ptr<data::TransferFunction>& tf) override;
+    VIZ_SCENE3D_API void updateVolumeTF(const data::TransferFunction::csptr& tf) override;
 
     /// Sets the number of samples per view ray.
-    VIZ_SCENE3D_API void setSampling(uint16_t nbSamples) override;
+    VIZ_SCENE3D_API void setSampling(uint16_t nbSamples, const data::TransferFunction::csptr& tf) override;
 
     /// Sets the opacity correction factor.
     VIZ_SCENE3D_API void setOpacityCorrection(int opacityCorrection);
@@ -202,10 +202,10 @@ public:
     VIZ_SCENE3D_API void clipImage(const Ogre::AxisAlignedBox& clippingBox) override;
 
     /// Returns whether or not the volume is visible.
-    VIZ_SCENE3D_API bool isVisible() const;
+    [[nodiscard]] VIZ_SCENE3D_API bool isVisible() const;
 
     /// Returns the current shadows data used by the renderer.
-    VIZ_SCENE3D_API const shadows_data_t& shadows() const;
+    [[nodiscard]] VIZ_SCENE3D_API const shadows_data_t& shadows() const;
 
     /**
      * @brief Sets the SAT size ratio.
@@ -293,9 +293,9 @@ protected:
     struct material_light_t
     {
         material_light_t(
-            const Ogre::ColourValue& diffuse  = Ogre::ColourValue(1.2f, 1.2f, 1.2f, 1.f),
-            const Ogre::ColourValue& specular = Ogre::ColourValue(2.5f, 2.5f, 2.5f, 1.f),
-            float shininess                   = 20.f
+            const Ogre::ColourValue& diffuse  = Ogre::ColourValue(1.2F, 1.2F, 1.2F, 1.F),
+            const Ogre::ColourValue& specular = Ogre::ColourValue(2.5F, 2.5F, 2.5F, 1.F),
+            float shininess                   = 20.F
         ) :
 
             diffuse(diffuse),
@@ -305,19 +305,19 @@ protected:
         }
 
         /// Diffuse component default is {1.2f, 1.2f, 1.2f, 1.f} in RGBA.
-        Ogre::ColourValue diffuse = Ogre::ColourValue(1.2f, 1.2f, 1.2f, 1.f);
+        Ogre::ColourValue diffuse = Ogre::ColourValue(1.2F, 1.2F, 1.2F, 1.F);
 
         /// Specular component. Default is {2.5f, 2.5f, 2.5f, 1.f} in RGBA
-        Ogre::ColourValue specular = Ogre::ColourValue(2.5f, 2.5f, 2.5f, 1.f);
+        Ogre::ColourValue specular = Ogre::ColourValue(2.5F, 2.5F, 2.5F, 1.F);
 
         /// Shininess. Default is 20.f.
-        float shininess = 20.f;
+        float shininess = 20.F;
     };
 
     //-----------------------------------------------------------------------------
 
     /// Sets all texture units needed by the material during the ray casting pass.
-    VIZ_SCENE3D_API virtual void setRayCastingPassTextureUnits(Ogre::Pass* const _rayCastingPass) const;
+    VIZ_SCENE3D_API virtual void setRayCastingPassTextureUnits(Ogre::Pass* _rayCastingPass) const;
 
     /**
      * @brief Generates the material used to render the volume.
@@ -350,10 +350,10 @@ protected:
     data::Image::Size m_imageSize = data::Image::Size({1, 1, 1});
 
     /// Inverse of the sampling rate accounted by the TF.
-    float m_opacityCorrectionFactor = 200.f;
+    float m_opacityCorrectionFactor = 200.F;
 
     /// Focal distance in object space : 0 = object front, 1 = object back.
-    float m_focalLength = 0.f;
+    float m_focalLength = 0.F;
 
     //------------------------------------------------------------
 
@@ -421,6 +421,4 @@ inline void RayTracingVolumeRenderer::setMaterialLightParams(
     mtl->setShininess(components.shininess);
 }
 
-} // namespace vr
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::vr
