@@ -26,6 +26,8 @@
 
 #include <viz/scene3d/ogre.hpp>
 
+#include <glm/glm.hpp>
+
 #include <OGRE/OgreCompositor.h>
 #include <OGRE/OgreCompositorChain.h>
 #include <OGRE/OgreCompositorInstance.h>
@@ -39,12 +41,9 @@
 #include <OGRE/OgreTextureManager.h>
 #include <OGRE/OgreViewport.h>
 
-#include <math.h>
+#include <cmath>
 
-namespace sight::viz::scene3d
-{
-
-namespace vr
+namespace sight::viz::scene3d::vr
 {
 
 /// Listener dedicated to watching the initialisation.
@@ -52,14 +51,14 @@ class SummedAreaTable::SummedAreaTableInitCompositorListener : public Ogre::Comp
 {
 public:
 
-    SummedAreaTableInitCompositorListener(float& currentSliceIndex) :
+    explicit SummedAreaTableInitCompositorListener(float& currentSliceIndex) :
         m_currentSliceDepth(currentSliceIndex)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    virtual void notifyMaterialRender(Ogre::uint32 /*pass_id*/, Ogre::MaterialPtr& mat)
+    void notifyMaterialRender(Ogre::uint32 /*pass_id*/, Ogre::MaterialPtr& mat) override
     {
         if(mat->getNumTechniques() > 0)
         {
@@ -94,7 +93,7 @@ public:
 
     //------------------------------------------------------------------------------
 
-    virtual void notifyMaterialRender(Ogre::uint32 /*pass_id*/, Ogre::MaterialPtr& mat)
+    void notifyMaterialRender(Ogre::uint32 /*pass_id*/, Ogre::MaterialPtr& mat) override
     {
         if(mat->getNumTechniques() > 0)
         {
@@ -133,13 +132,12 @@ private:
 SummedAreaTable::SummedAreaTable(std::string _parentId, Ogre::SceneManager* _sceneManager, float _sizeRatio) :
     m_satSizeRatio(_sizeRatio),
     m_satSize(
-        {
-            0, 0, 0
-        }),
+    {
+        0, 0, 0
+    }),
     m_currentImageSize({0, 0, 0}),
-    m_parentId(_parentId),
-    m_sceneManager(_sceneManager),
-    m_dummyCamera(nullptr)
+    m_parentId(std::move(_parentId)),
+    m_sceneManager(_sceneManager)
 {
 }
 
@@ -164,13 +162,13 @@ SummedAreaTable::~SummedAreaTable()
         m_sceneManager->destroyCamera(m_dummyCamera);
     }
 
-    //Members of m_listeners are freed by the manager upon desctruction. Freeing them here causes a double-free.
+    //Members of m_listeners are freed by the manager upon destruction. Freeing them here causes a double-free.
 }
 
 //-----------------------------------------------------------------------------
 
 void SummedAreaTable::computeParallel(
-    Ogre::TexturePtr _imgTexture,
+    const Texture::sptr& _imgTexture,
     const TransferFunction::sptr& _gpuTf,
     float _sampleDistance
 )
@@ -194,7 +192,7 @@ void SummedAreaTable::computeParallel(
                 Ogre::Pass* const satInitPass            = technique->getPass(0);
                 Ogre::TextureUnitState* const tex3DState = satInitPass->getTextureUnitState("image");
                 SIGHT_ASSERT("'image' texture unit is not found", tex3DState);
-                tex3DState->setTexture(_imgTexture);
+                tex3DState->setTexture(_imgTexture->get());
 
                 auto fpParams = satInitPass->getFragmentProgramParameters();
                 fpParams->setNamedConstant("u_sampleDistance", _sampleDistance);
@@ -325,20 +323,20 @@ void SummedAreaTable::computeParallel(
 
 //-----------------------------------------------------------------------------
 
-void SummedAreaTable::updateSatFromTexture(Ogre::TexturePtr _imgTexture)
+void SummedAreaTable::updateSatFromTexture(const Texture::sptr& _imgTexture)
 {
     SIGHT_ASSERT("texture cannot be nullptr", _imgTexture != nullptr);
 
     m_currentImageSize =
     {
-        static_cast<std::size_t>(_imgTexture->getWidth()),
-        static_cast<std::size_t>(_imgTexture->getHeight()),
-        static_cast<std::size_t>(_imgTexture->getDepth())
+        static_cast<std::size_t>(_imgTexture->width()),
+        static_cast<std::size_t>(_imgTexture->height()),
+        static_cast<std::size_t>(_imgTexture->depth())
     };
 
-    const std::size_t width  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[0]) * m_satSizeRatio);
-    const std::size_t height = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[1]) * m_satSizeRatio);
-    const std::size_t depth  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[2]) * m_satSizeRatio);
+    const auto width  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[0]) * m_satSizeRatio);
+    const auto height = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[1]) * m_satSizeRatio);
+    const auto depth  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[2]) * m_satSizeRatio);
 
     m_satSize = {width, height, depth};
 
@@ -351,9 +349,9 @@ void SummedAreaTable::updateSatFromRatio(float _sizeRatio)
 {
     m_satSizeRatio = _sizeRatio;
 
-    const std::size_t width  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[0]) * m_satSizeRatio);
-    const std::size_t height = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[1]) * m_satSizeRatio);
-    const std::size_t depth  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[2]) * m_satSizeRatio);
+    const auto width  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[0]) * m_satSizeRatio);
+    const auto height = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[1]) * m_satSizeRatio);
+    const auto depth  = static_cast<std::size_t>(static_cast<float>(m_currentImageSize[2]) * m_satSizeRatio);
 
     m_satSize = {width, height, depth};
 
@@ -364,9 +362,9 @@ void SummedAreaTable::updateSatFromRatio(float _sizeRatio)
 
 void SummedAreaTable::updateBuffers()
 {
-    const Ogre::uint width  = static_cast<Ogre::uint>(m_satSize[0]);
-    const Ogre::uint height = static_cast<Ogre::uint>(m_satSize[1]);
-    const Ogre::uint depth  = static_cast<Ogre::uint>(m_satSize[2]);
+    const auto width  = static_cast<Ogre::uint>(m_satSize[0]);
+    const auto height = static_cast<Ogre::uint>(m_satSize[1]);
+    const auto depth  = static_cast<Ogre::uint>(m_satSize[2]);
 
     Ogre::TextureManager& textureManager = Ogre::TextureManager::getSingleton();
 
@@ -419,10 +417,10 @@ void SummedAreaTable::updateBuffers()
         Ogre::CompositorManager& compositorManager = Ogre::CompositorManager::getSingleton();
 
         //Listeners updated with the current parameters
-        SummedAreaTableInitCompositorListener* const new_initlistener =
+        auto* const new_initlistener =
             new SummedAreaTableInitCompositorListener(m_currentSliceDepth);
 
-        SummedAreaTableCompositorListener* const new_tablelistener =
+        auto* const new_tablelistener =
             new SummedAreaTableCompositorListener(
                 m_readOffset,
                 m_passOrientation,
@@ -531,7 +529,7 @@ void SummedAreaTable::computeSequential(data::Image::sptr _image, data::Transfer
         {
             if(x < 0 || y < 0 || z < 0)
             {
-                return glm::vec4(0.f);
+                return glm::vec4(0.F);
             }
 
             const std::size_t index = static_cast<std::size_t>(x) + m_satSize[0]
@@ -569,7 +567,7 @@ void SummedAreaTable::computeSequential(data::Image::sptr _image, data::Transfer
                         static_cast<std::size_t>(z)
                     );
 
-                const glm::vec4 saturation = applyTf(_tf, imgValue)
+                const glm::vec4 saturation = glm::vec4(_tf->sample(imgValue))
                                              + value_at(buffer, x - 1, y - 1, z - 1)
                                              + value_at(buffer, x, y, z - 1)
                                              + value_at(buffer, x, y - 1, z)
@@ -589,7 +587,7 @@ void SummedAreaTable::computeSequential(data::Image::sptr _image, data::Transfer
     pixBuffer->lock(Ogre::HardwareBuffer::HBL_DISCARD);
     Ogre::PixelBox pixBox = pixBuffer->getCurrentLock();
 
-    std::uint8_t* const pDest = static_cast<std::uint8_t*>(pixBox.data);
+    auto* const pDest = static_cast<std::uint8_t*>(pixBox.data);
 
     std::memcpy(pDest, buffer.data(), buffer.size() * sizeof(glm::vec4));
 
@@ -598,27 +596,4 @@ void SummedAreaTable::computeSequential(data::Image::sptr _image, data::Transfer
 
 //-----------------------------------------------------------------------------
 
-glm::vec4 SummedAreaTable::applyTf(data::TransferFunction::sptr _tf, int16_t imgValue)
-{
-    //Window (extent)
-    const double invWindow = 1. / _tf->getWindow();
-
-    //Intensity min and max
-    const auto [i_min, i_max] = _tf->getWLMinMax();
-
-    //TF min and max
-    const auto [tf_min, tf_max] = _tf->getMinMaxTFValues();
-
-    //Scaled value, which needs to be interpolated
-    const double value = (imgValue - i_min) * (tf_max - tf_min) * invWindow + tf_min;
-
-    const data::TransferFunction::TFColor interpolatedColor = _tf->getInterpolatedColor(value);
-
-    return glm::vec4(interpolatedColor.r, interpolatedColor.g, interpolatedColor.b, interpolatedColor.a);
-}
-
-//-----------------------------------------------------------------------------
-
-} // namespace vr
-
-} // namespace sight::viz::scene3d
+} // namespace sight::viz::scene3d::vr
