@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2015 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,15 +28,13 @@ namespace sight::module::data
 //-----------------------------------------------------------------------------
 
 IWrapperSrv::IWrapperSrv()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 IWrapperSrv::~IWrapperSrv()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
-}
+} // namespace sight::module::data
