@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,19 +32,16 @@ namespace sight::module::data
 
 void SCopy::configuring()
 {
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
+    const auto& config = this->getConfiguration();
+    SIGHT_ASSERT("One 'in' tag is required.", config.get_optional<std::string>("in").has_value());
 
-    const ConfigurationType inCfg = m_configuration->findConfigurationElement("in");
-    SIGHT_ASSERT("One 'in' tag is required.", inCfg);
+    [[maybe_unused]] const auto inoutCfg = config.get_optional<std::string>("inout");
+    [[maybe_unused]] const auto outCfg   = config.get_optional<std::string>("out");
+    SIGHT_ASSERT("One 'inout' or one 'out' tag is required.", inoutCfg.has_value() + outCfg.has_value());
 
-    const std::vector<ConfigurationType> inoutCfg = m_configuration->find("inout");
-    const std::vector<ConfigurationType> outCfg   = m_configuration->find("out");
-    SIGHT_ASSERT("One 'inout' or one 'out' tag is required.", inoutCfg.size() + outCfg.size() == 1);
-
-    const ConfigurationType modeConfig = m_configuration->findConfigurationElement("mode");
-    if(modeConfig)
+    if(const auto modeConfig = config.get_optional<std::string>("mode"); modeConfig.has_value())
     {
-        auto mode = modeConfig->getValue();
+        const auto& mode = modeConfig.value();
         if(mode == "copyOnStart")
         {
             m_mode = ModeType::START;
@@ -132,20 +129,13 @@ void SCopy::copy()
                         sight::data::Object::s_MODIFIED_SIG
                     );
                     {
-                        core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+                        core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
                         sig->asyncEmit();
                     }
                 }
             };
 
-        if(source != sourceObject.get_shared())
-        {
-            setOutputData();
-        }
-        else
-        {
-            setOutputData();
-        }
+        setOutputData();
     }
 }
 
