@@ -32,10 +32,7 @@
 
 #include <sstream>
 
-namespace sight::module::debug
-{
-
-namespace action
+namespace sight::module::debug::action
 {
 
 /// Static variable shared by both actions
@@ -51,16 +48,16 @@ void MemoryConsumption::pushNewArray(std::size_t memorySizeInBytes)
     {
         data::Array::sptr buffer = data::Array::New();
         data::Array::SizeType size(1, memorySizeInBytes);
-        buffer->resize(size, core::tools::Type::s_UINT8_TYPENAME, true);
+        buffer->resize(size, core::Type::UINT8, true);
 
-        SIGHT_INFO("Creating a data::array consuming " << memorySizeInBytes / (1024 * 1024) << " Mo ");
+        SIGHT_INFO("Creating a data::array consuming " << memorySizeInBytes / (1024LL * 1024) << " Mo ");
 
         memoryConsumer.push_back(buffer);
     }
     catch(std::exception& e)
     {
         std::stringstream msg;
-        msg << "Cannot allocate buffer (" << memorySizeInBytes / (1024 * 1024) << " Mo) :\n" << e.what() << std::endl;
+        msg << "Cannot allocate buffer (" << memorySizeInBytes / (1024LL * 1024) << " Mo) :\n" << e.what() << std::endl;
         sight::ui::base::dialog::MessageDialog::show(
             "Action increase memory",
             msg.str(),
@@ -72,16 +69,15 @@ void MemoryConsumption::pushNewArray(std::size_t memorySizeInBytes)
 //------------------------------------------------------------------------------
 
 MemoryConsumption::MemoryConsumption() noexcept :
-    m_isIncreaseMode(true),
-    m_memorySizeInBytes(1024 * 1024 * 256) // 256 Mo
+
+    m_memorySizeInBytes(1024LL * 1024 * 256) // 256 Mo
 {
 }
 
 //------------------------------------------------------------------------------
 
-MemoryConsumption::~MemoryConsumption() noexcept
-{
-}
+MemoryConsumption::~MemoryConsumption() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -107,19 +103,16 @@ void MemoryConsumption::configuring()
 {
     this->sight::ui::base::IAction::initialize();
 
-    core::runtime::ConfigurationElement::sptr consumptionCfg;
-    consumptionCfg = m_configuration->findConfigurationElement("config");
-    SIGHT_ASSERT("Missing mode tag", consumptionCfg);
+    const auto& config = this->getConfiguration();
 
-    SIGHT_ASSERT("Missing attribute 'value'", consumptionCfg->hasAttribute("mode"));
-    std::string mode = consumptionCfg->getAttributeValue("mode");
+    const auto mode = config.get<std::string>("config.<xmlattr>.mode");
     SIGHT_ASSERT("Wrong value (" << mode << ") for mode tag", mode == "increase" || mode == "decrease");
     m_isIncreaseMode = (mode == "increase");
 
-    if(m_isIncreaseMode && consumptionCfg->hasAttribute("value"))
+    if(const auto value = config.get_optional<std::string>("config.<xmlattr>.value");
+       m_isIncreaseMode&& value.has_value())
     {
-        std::string value    = consumptionCfg->getAttributeValue("value");
-        std::size_t sizeInMo = boost::lexical_cast<std::size_t>(value);
+        auto sizeInMo = boost::lexical_cast<std::size_t>(value.value());
         m_memorySizeInBytes = sizeInMo * 1024 * 1024;
     }
 }
@@ -139,6 +132,4 @@ void MemoryConsumption::stopping()
 
 //------------------------------------------------------------------------------
 
-} // namespace action
-
-} // namespace basicOpCtrl
+} // namespace sight::module::debug::action
