@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,26 +29,22 @@
 namespace sight::module::memory
 {
 
-static const service::IService::KeyType s_TARGET_INOUT = "target";
+//-----------------------------------------------------------------------------
+
+LockDumpSrv::LockDumpSrv() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-LockDumpSrv::LockDumpSrv() noexcept
-{
-}
-
-//-----------------------------------------------------------------------------
-
-LockDumpSrv::~LockDumpSrv() noexcept
-{
-}
+LockDumpSrv::~LockDumpSrv() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
 void LockDumpSrv::starting()
 {
     const auto object = m_target.lock();
-    SIGHT_ASSERT("The inout key '" << s_TARGET_INOUT << "' is not correctly set.", object);
+    SIGHT_ASSERT("The inout key 'target' is not correctly set.", object);
 
     const auto buffered = std::dynamic_pointer_cast<core::memory::IBuffered>(object.get_shared());
 
@@ -73,22 +69,16 @@ void LockDumpSrv::configuring()
 
 //-----------------------------------------------------------------------------
 
-void LockDumpSrv::reconfiguring()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void LockDumpSrv::updating()
 {
 }
 
 //-----------------------------------------------------------------------------
 
-void LockDumpSrv::info(std::ostream&)
+void LockDumpSrv::info(std::ostream& /*_sstream*/)
 {
 }
 
 //-----------------------------------------------------------------------------
 
-} // ctrlMemory
+} // namespace sight::module::memory
