@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -54,7 +54,7 @@ public:
     MODULE_MEMORY_API LockDumpSrv() noexcept;
 
     /// Destructor. Does nothing
-    MODULE_MEMORY_API virtual ~LockDumpSrv() noexcept;
+    MODULE_MEMORY_API ~LockDumpSrv() noexcept override;
 
 protected:
 
@@ -64,9 +64,6 @@ protected:
     /// Dump unlock the associated data
     MODULE_MEMORY_API void stopping() override;
 
-    /// Does nothing
-    MODULE_MEMORY_API void reconfiguring() override;
-
     /// Does nothing
     MODULE_MEMORY_API void updating() override;
 
@@ -83,4 +80,4 @@ private:
     std::vector<core::memory::BufferObject::Lock> m_locks;
 };
 
-} // sight::module::memory
+} // namespace sight::module::memory
