@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,13 +32,13 @@ class Plugin : public core::runtime::Plugin
 public:
 
     /// PLugin destructor
-    ~Plugin() noexcept;
+    ~Plugin() noexcept override;
 
     /// This method is used by runtime to initialize the module.
-    void start();
+    void start() override;
 
     /// This method is used by runtime to stop the module.
-    void stop() noexcept;
+    void stop() noexcept override;
 };
 
-} // namespace sight::core::memory
+} // namespace sight::module::memory
