@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,9 +36,6 @@ namespace sight::module::sync
 // Public signal
 const core::com::Signals::SignalKeyType SSignalGate::s_ALL_RECEIVED_SIG = "allReceived";
 
-// Private slot
-static const core::com::Slots::SlotKeyType s_RECEIVE_SLOT = "receive";
-
 //-----------------------------------------------------------------------------
 
 SSignalGate::SSignalGate()
@@ -49,8 +46,7 @@ SSignalGate::SSignalGate()
 //-----------------------------------------------------------------------------
 
 SSignalGate::~SSignalGate()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -62,7 +58,7 @@ void SSignalGate::configuring()
 
 void SSignalGate::starting()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     const std::regex re("(.*)/(.*)");
     std::smatch match;
@@ -75,7 +71,8 @@ void SSignalGate::starting()
         {
             SIGHT_ASSERT("Wrong value for attribute src: " + signal, match.size() >= 3);
 
-            std::string uid, signalKey;
+            std::string uid;
+            std::string signalKey;
             uid.assign(match[1].first, match[1].second);
             signalKey.assign(match[2].first, match[2].second);
 
@@ -89,9 +86,9 @@ void SSignalGate::starting()
                 m_flags.push_back(false);
 
                 // Create a slot to our callback with a bound index to identify it
-                std::function<void()> task(std::bind(&SSignalGate::received, this, index));
+                std::function<void()> task([this, index](auto&& ...){received(index);});
                 auto slot = core::com::newSlot(task);
-                slot->setWorker(m_associatedWorker);
+                slot->setWorker(this->worker());
 
                 // Connect the configured signal to this slot
                 auto sig = signalsHolder->signal(signalKey);
