@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,9 +29,8 @@ SIGHT_REGISTER_PLUGIN("sight::module::utest::Plugin");
 
 //-----------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -41,22 +40,10 @@ void Plugin::start()
 
 //-----------------------------------------------------------------------------
 
-void Plugin::initialize()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-void Plugin::uninitialize()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void Plugin::stop() noexcept
 {
 }
 
 //-----------------------------------------------------------------------------
 
-} // namespace sight::module::service
+} // namespace sight::module::utest
