@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,11 +22,6 @@
 
 #include "SAutomaticRegistration.hpp"
 
-#include <core/com/Signal.hpp>
-#include <core/com/Signal.hxx>
-
-#include <filter/image/AutomaticRegistration.hpp>
-
 #include <service/macros.hpp>
 
 #include <ui/base/dialog/ProgressDialog.hpp>
@@ -48,20 +43,19 @@ SAutomaticRegistration::SAutomaticRegistration() :
 //------------------------------------------------------------------------------
 
 SAutomaticRegistration::~SAutomaticRegistration()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void SAutomaticRegistration::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_minStep = config.get<double>("minStep", -1.);
 
     SIGHT_FATAL_IF("Invalid or missing minStep.", m_minStep <= 0);
 
-    m_maxIterations = config.get<unsigned long>("maxIterations", 0);
+    m_maxIterations = config.get<std::uint64_t>("maxIterations", 0);
 
     SIGHT_FATAL_IF("Invalid or missing number of iterations.", m_maxIterations == 0);
 
@@ -85,7 +79,7 @@ void SAutomaticRegistration::configuring()
 
         SIGHT_ASSERT("There must be two parameters: shrink and sigma.", parameters.size() == 2);
 
-        const unsigned long shrink = std::stoul(parameters[0]);
+        const std::uint64_t shrink = std::stoul(parameters[0]);
         const double sigma         = std::stod(parameters[1]);
 
         m_multiResolutionParameters.push_back(std::make_pair(shrink, sigma));
@@ -127,7 +121,7 @@ void SAutomaticRegistration::updating()
     AutomaticRegistration::MultiResolutionParametersType
         multiResolutionParameters(m_multiResolutionParameters.size());
 
-    typedef AutomaticRegistration::MultiResolutionParametersType::value_type ParamPairType;
+    using ParamPairType = AutomaticRegistration::MultiResolutionParametersType::value_type;
 
     auto lastElt = std::remove_copy_if(
         m_multiResolutionParameters.begin(),
@@ -199,11 +193,11 @@ void SAutomaticRegistration::updating()
             {
                 std::stringstream transformStream;
 
-                for(std::uint8_t i = 0 ; i < 16 ; ++i)
+                for(std::uint8_t j = 0 ; j < 16 ; ++j)
                 {
-                    transformStream << transform->getCoefficients()[i];
+                    transformStream << (*transform)[j];
 
-                    if(i != 15)
+                    if(j != 15)
                     {
                         transformStream << ";";
                     }
@@ -270,14 +264,13 @@ void SAutomaticRegistration::stopping()
 
 service::IService::KeyConnectionsMap SAutomaticRegistration::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_TARGET_IN, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_TARGET_IN, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_REFERENCE_IN, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_REFERENCE_IN, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_TRANSFORM_INOUT, data::Matrix4::s_MODIFIED_SIG, s_UPDATE_SLOT);
-
-    return connections;
+    return {
+        {s_TARGET_IN, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_TARGET_IN, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_REFERENCE_IN, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_REFERENCE_IN, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_TRANSFORM_INOUT, data::Matrix4::s_MODIFIED_SIG, IService::slots::s_UPDATE}
+    };
 }
 
 //------------------------------------------------------------------------------
@@ -304,7 +297,7 @@ void SAutomaticRegistration::setDoubleParameter(double val, std::string key)
     }
     else if(key.find("sigma_") != std::string::npos)
     {
-        const unsigned long level = this->extractLevelFromParameterName(key);
+        const std::uint64_t level = this->extractLevelFromParameterName(key);
         m_multiResolutionParameters[level].second = val;
     }
     else if(key == "samplingPercentage")
@@ -324,11 +317,11 @@ void SAutomaticRegistration::setIntParameter(int val, std::string key)
     if(key == "maxIterations")
     {
         SIGHT_FATAL_IF("The number of iterations must be greater than 0 !!", val <= 0);
-        m_maxIterations = static_cast<unsigned long>(val);
+        m_maxIterations = static_cast<std::uint64_t>(val);
     }
     else if(key.find("shrink_") != std::string::npos)
     {
-        const unsigned long level = this->extractLevelFromParameterName(key);
+        const std::uint64_t level = this->extractLevelFromParameterName(key);
         m_multiResolutionParameters[level].first = itk::SizeValueType(val);
     }
     else
@@ -338,11 +331,11 @@ void SAutomaticRegistration::setIntParameter(int val, std::string key)
 }
 
 //------------------------------------------------------------------------------
-unsigned long SAutomaticRegistration::extractLevelFromParameterName(const std::string& name)
+std::uint64_t SAutomaticRegistration::extractLevelFromParameterName(const std::string& name)
 {
     // find the level
-    const std::string levelSuffix = name.substr(name.find("_") + 1);
-    const unsigned long level     = std::stoul(levelSuffix);
+    const std::string levelSuffix = name.substr(name.find('_') + 1);
+    const std::uint64_t level     = std::stoul(levelSuffix);
 
     if(level >= m_multiResolutionParameters.size())
     {
