@@ -24,10 +24,8 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
-#include <core/tools/TypeKeyTypeMapping.hpp>
 
 #include <data/helper/MedicalImage.hpp>
-#include <data/String.hpp>
 
 #include <filter/image/Labeling.hpp>
 
@@ -48,36 +46,29 @@ SLabelGeometryImage::SLabelGeometryImage()
 //-----------------------------------------------------------------------------
 
 SLabelGeometryImage::~SLabelGeometryImage()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SLabelGeometryImage::configuring()
 {
-    const core::runtime::ConfigurationElement::sptr clusters = m_configuration->findConfigurationElement("clusters");
-    if(clusters)
+    const auto& config = this->getConfiguration();
+
+    const auto& clusters = config.get_child("clusters");
+    for(const auto& elt : boost::make_iterator_range(clusters.equal_range("cluster")))
     {
-        SIGHT_ASSERT("pointList is needed in output key", m_configuration->findConfigurationElement("out"));
-        std::vector<core::runtime::ConfigurationElement::sptr> clusterVect = clusters->find("cluster");
+        const auto clusterStr = elt.second.get_value<std::string>();
+        std::vector<std::size_t> clusterLabels;
+        const boost::char_separator<char> separator(",");
+        const boost::tokenizer<boost::char_separator<char> > tok {clusterStr, separator};
 
-        SIGHT_ASSERT("Clusters must have cluster tag.", clusterVect.size() > 0);
-
-        for(std::size_t i = 0 ; i < clusterVect.size() ; ++i)
+        for(const auto& t : tok)
         {
-            std::string clusterStr = clusterVect[i]->getValue();
-            std::vector<std::size_t> clusterLabels;
-            const boost::char_separator<char> separator(",");
-            const boost::tokenizer<boost::char_separator<char> > tok {clusterStr, separator};
-
-            for(const auto& t : tok)
-            {
-                clusterLabels.push_back(std::stoi(t));
-            }
-
-            m_lPointListLabels.push_back(clusterLabels);
-            m_lPointListCentroids.push_back(data::PointList::New());
+            clusterLabels.push_back(std::stoul(t));
         }
+
+        m_lPointListLabels.push_back(clusterLabels);
+        m_lPointListCentroids.push_back(data::PointList::New());
     }
 }
 
@@ -124,13 +115,13 @@ void SLabelGeometryImage::stopping()
 
 //-----------------------------------------------------------------------------
 
-void SLabelGeometryImage::updateSelectedPointList(std::string value, std::string key)
+void SLabelGeometryImage::updateSelectedPointList(std::string value, std::string /*key*/)
 {
     SIGHT_ASSERT(
         "value: " << value << "should end by a number between 0 and 9",
         value.back() >= '0' && value.back() <= '9'
     );
-    int indexPlane = std::stoi(value);
+    std::size_t indexPlane = std::stoul(value);
     // if the XML enum is between 1 and n, instead of 0 and n-1
     if(indexPlane > 0)
     {
