@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -37,22 +37,22 @@
 #include <algorithm>
 #include <bitset>
 #include <functional>
+#include <utility>
 
 namespace sight::module::filter::image
 {
 
-typedef std::function<std::uint8_t(const std::uint8_t&)> FunctionType;
+using FunctionType = std::function<std::uint8_t(const std::uint8_t&)>;
 
 class LambdaFunctor
 {
 public:
 
     LambdaFunctor()
-    {
-    }
+    = default;
 
-    LambdaFunctor(const FunctionType& _f) :
-        m_function(_f)
+    explicit LambdaFunctor(FunctionType _f) :
+        m_function(std::move(_f))
     {
     }
 
@@ -65,7 +65,7 @@ public:
 
     // Needs to be implemented because it is called by the itkUnaryFunctorImageFilter when setting the functor.
     // Always return true to force-set the functor.
-    inline bool operator!=(const LambdaFunctor&)
+    inline bool operator!=(const LambdaFunctor& /*unused*/)
     {
         return true;
     }
@@ -78,20 +78,18 @@ private:
 //------------------------------------------------------------------------------
 
 SLabelImageToBinaryImage::SLabelImageToBinaryImage()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 SLabelImageToBinaryImage::~SLabelImageToBinaryImage()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 void SLabelImageToBinaryImage::configuring()
 {
-    const ConfigType config = this->getConfigTree();
+    const ConfigType config = this->getConfiguration();
 
     m_labelSetFieldName = config.get_optional<std::string>("config.<xmlattr>.labelsField");
 }
@@ -106,7 +104,7 @@ void SLabelImageToBinaryImage::starting()
 
 void SLabelImageToBinaryImage::updating()
 {
-    typedef typename itk::Image<std::uint8_t, 3> ImageType;
+    using ImageType = typename itk::Image<std::uint8_t, 3>;
 
     const auto labelImage = m_labelImage.lock();
     SIGHT_ASSERT("No " << s_LABEL_IMAGE_INPUT << " input.", labelImage);
@@ -116,7 +114,7 @@ void SLabelImageToBinaryImage::updating()
 
     SIGHT_ASSERT(
         "The label image must be a greyscale image with uint8 values.",
-        labelImage->getType() == core::tools::Type::s_UINT8 && labelImage->numComponents() == 1
+        labelImage->getType() == core::Type::UINT8 && labelImage->numComponents() == 1
     );
 
     LambdaFunctor functor;
@@ -142,24 +140,28 @@ void SLabelImageToBinaryImage::updating()
             {
                 data::Integer::csptr intObj = data::Integer::dynamicConstCast(_o);
                 SIGHT_ASSERT("The label vector should only contain integers.", intObj);
-                const int val = intObj->value();
+                const int val = int(intObj->value());
                 SIGHT_ASSERT("The integers in the vector must be in the [0, 255] range.", val >= 0 && val <= 255);
                 labelSet.set(static_cast<std::uint8_t>(val), true);
             });
 
-        functor = FunctionType(
-            [labelSet](const std::uint8_t& _in)
+        functor = LambdaFunctor(
+            FunctionType(
+                [labelSet](const std::uint8_t& _in)
             {
                 return labelSet[_in] ? 255 : 0;
-            });
+            })
+        );
     }
     else
     {
-        functor = FunctionType(
-            [](const std::uint8_t& _in)
+        functor = LambdaFunctor(
+            FunctionType(
+                [](const std::uint8_t& _in)
             {
                 return _in > 0 ? 255 : 0;
-            });
+            })
+        );
     }
 
     typename ImageType::Pointer itkLabelImg = io::itk::moveToItk<ImageType>(labelImage.get_shared());
@@ -191,10 +193,10 @@ void SLabelImageToBinaryImage::stopping()
 
 service::IService::KeyConnectionsMap SLabelImageToBinaryImage::getAutoConnections() const
 {
-    KeyConnectionsMap connections;
-    connections.push(s_LABEL_IMAGE_INPUT, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_LABEL_IMAGE_INPUT, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {
+        {s_LABEL_IMAGE_INPUT, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_LABEL_IMAGE_INPUT, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE}
+    };
 }
 
 //------------------------------------------------------------------------------
