@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -81,7 +81,7 @@ public:
     MODULE_FILTER_IMAGE_API SPlaneSlicer() noexcept;
 
     /// Destructor.
-    MODULE_FILTER_IMAGE_API virtual ~SPlaneSlicer() noexcept;
+    MODULE_FILTER_IMAGE_API ~SPlaneSlicer() noexcept override;
 
 protected:
 
@@ -93,12 +93,12 @@ protected:
     /**
      * @brief Returns proposals to connect service slots to associated object signals.
      *
-     * Connect image::s_MODIFIED_SIG to this::s_UPDATE_SLOT
-     * Connect image::s_BUFFER_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect image::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
+     * Connect image::s_BUFFER_MODIFIED_SIG to this::IService::slots::s_UPDATE
      * Connect image::s_BUFFER_MODIFIED_SIG to this::s_UPDATE_DEFAULT_VALUE_SLOT
      * Connect imageExtent::s_SLICE_INDEX_MODIFIED_SIG to this::s_UPDATE_SLICE_TYPE_SLOT
-     * Connect imageExtent::s_SLICE_TYPE_MODIFIED_SIG to this::s_UPDATE_SLOT
-     * Connect axes::s_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect imageExtent::s_SLICE_TYPE_MODIFIED_SIG to this::IService::slots::s_UPDATE
+     * Connect axes::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
      */
     MODULE_FILTER_IMAGE_API KeyConnectionsMap getAutoConnections() const override;
 
@@ -120,7 +120,7 @@ private:
     void updateDefaultValue();
 
     /// Slicing orientation. Determines the two axes defining the plane.
-    data::helper::MedicalImage::orientation_t m_orientation;
+    data::helper::MedicalImage::orientation_t m_orientation {data::helper::MedicalImage::orientation_t::Z_AXIS};
 
     /// Vtk reslicing algorithm.
     vtkSmartPointer<vtkImageReslice> m_reslicer;
