@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -49,10 +49,7 @@ static const core::com::Slots::SlotKeyType s_RESET_DRAWING        = "resetDrawin
 //-----------------------------------------------------------------------------
 
 SPropagator::SPropagator() :
-    IHasParameters(m_slots),
-    m_value(1),
-    m_overwrite(true),
-    m_drawing(false)
+    IHasParameters(m_slots)
 {
     newSlot(s_DRAW_SLOT, &SPropagator::draw, this);
     newSlot(s_SET_ORIENTATION_SLOT, &SPropagator::setOrientation, this);
@@ -64,14 +61,13 @@ SPropagator::SPropagator() :
 //-----------------------------------------------------------------------------
 
 SPropagator::~SPropagator()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SPropagator::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_value     = config.get<int>("value", 1);
     m_overwrite = config.get<bool>("overwrite", true);
@@ -327,7 +323,7 @@ void SPropagator::draw(data::tools::PickingInfo pickingInfo)
     if(imgBufferModified)
     {
         auto sig = imgOutLock->signal<data::Image::BufferModifiedSignalType>(data::Image::s_BUFFER_MODIFIED_SIG);
-        core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+        core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
         sig->asyncEmit();
     }
 }
@@ -376,12 +372,11 @@ sight::filter::image::MinMaxPropagation::SeedsType SPropagator::convertDiffToSee
 
 service::IService::KeyConnectionsMap SPropagator::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_IMAGE_IN, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_IMAGE_IN, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_SET_ORIENTATION_SLOT);
-    connections.push(s_IMAGE_IN, data::Image::s_SLICE_INDEX_MODIFIED_SIG, s_RESET_DRAWING);
-
-    return connections;
+    return {
+        {s_IMAGE_IN, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_IMAGE_IN, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_SET_ORIENTATION_SLOT},
+        {s_IMAGE_IN, data::Image::s_SLICE_INDEX_MODIFIED_SIG, s_RESET_DRAWING}
+    };
 }
 
 } // namespace sight::module::filter::image.
