@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2017 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,14 +35,12 @@ namespace sight::module::filter::image
 //------------------------------------------------------------------------------
 
 SResampler::SResampler()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
 SResampler::~SResampler()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -100,10 +98,10 @@ void SResampler::stopping()
 service::IService::KeyConnectionsMap SResampler::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_IMAGE_IN, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_IMAGE_IN, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_TRANSFORM_IN, data::Matrix4::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_TARGET_IN, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_IN, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_IMAGE_IN, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_TRANSFORM_IN, data::Matrix4::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_TARGET_IN, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
