@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,10 +33,7 @@
 
 #include <boost/math/constants/constants.hpp>
 
-namespace sight::module::filter::mesh
-{
-
-namespace generator
+namespace sight::module::filter::mesh::generator
 {
 
 // -----------------------------------------------------------------------------
@@ -69,14 +66,13 @@ SUltrasoundMesh::SUltrasoundMesh() noexcept
 // -----------------------------------------------------------------------------
 
 SUltrasoundMesh::~SUltrasoundMesh()
-{
-}
+= default;
 
 // -----------------------------------------------------------------------------
 
 void SUltrasoundMesh::configuring()
 {
-    const ConfigType configType = this->getConfigTree();
+    const ConfigType configType = this->getConfiguration();
     const ConfigType config     = configType.get_child("config.<xmlattr>");
 
     m_resolutionX = config.get<std::size_t>(s_RESOLUTION_X_CONFIG, m_resolutionX);
@@ -93,8 +89,8 @@ void SUltrasoundMesh::configuring()
 void SUltrasoundMesh::starting()
 {
     // Allocate position array
-    const long x = static_cast<long>(m_resolutionX);
-    const long y = static_cast<long>(m_resolutionY);
+    const auto x = static_cast<std::int64_t>(m_resolutionX);
+    const auto y = static_cast<std::int64_t>(m_resolutionY);
     m_meshPositionArray.resize(boost::extents[x][y][3]);
 
     const auto mesh = m_mesh.lock();
@@ -127,11 +123,11 @@ void SUltrasoundMesh::updateMeshPosition()
     // compute delta angle
     const double thetaInit   = (90. - m_angle / 2.) * boost::math::constants::pi<double>() / 180.;
     const double thetaEnd    = (90. + m_angle / 2.) * boost::math::constants::pi<double>() / 180.;
-    const double delta_theta = (thetaEnd - thetaInit) / (m_resolutionX - 1.);
+    const double delta_theta = (thetaEnd - thetaInit) / (double(m_resolutionX) - 1.);
 
     // compute delta lengths
-    const double dDepth = m_depth / (m_resolutionY - 1.);
-    const double dWidth = m_width / (m_resolutionX - 1.);
+    const double dDepth = m_depth / (double(m_resolutionY) - 1.);
+    const double dWidth = m_width / (double(m_resolutionX) - 1.);
 
     const fwVec3d centerPosition = {{0., 0., 0.}};
     const fwVec3d direction      = {{0., 1., 0.}};
@@ -145,14 +141,14 @@ void SUltrasoundMesh::updateMeshPosition()
         fwVec3d centerLive;
         if(m_shape)
         {
-            const double angleLive = thetaInit + delta_theta * (m_resolutionX - widthGrid - 1);
+            const double angleLive = thetaInit + delta_theta * double(m_resolutionX - widthGrid - 1);
             directionLive = std::cos(angleLive) * normal + std::sin(angleLive) * direction;
             centerLive    = centerPosition;
         }
         else
         {
             directionLive = direction;
-            centerLive    = centerPosition + (widthGrid * dWidth - m_width / 2.f) * normal;
+            centerLive    = centerPosition + (widthGrid * dWidth - double(m_width) / 2.F) * normal;
         }
 
         for(unsigned int depthGrid = 0 ;
@@ -179,15 +175,15 @@ void SUltrasoundMesh::createQuadMesh(const data::Mesh::sptr& _mesh) const
     const std::size_t numQuads       = (width - 1) * (height - 1);
 
     _mesh->resize(
-        numPointsTotal,
-        numQuads,
+        data::Mesh::size_t(numPointsTotal),
+        data::Mesh::size_t(numQuads),
         data::Mesh::CellType::QUAD,
         data::Mesh::Attributes::POINT_TEX_COORDS
         | data::Mesh::Attributes::POINT_NORMALS
     );
 
     // pointer on the positions buffer
-    const float* pointsIn = static_cast<const float*>(m_meshPositionArray.data());
+    const auto* pointsIn = static_cast<const float*>(m_meshPositionArray.data());
 
     // points position
     auto pointsItr = _mesh->zip_range<data::iterator::point::xyz, data::iterator::point::uv>().begin();
@@ -204,8 +200,8 @@ void SUltrasoundMesh::createQuadMesh(const data::Mesh::sptr& _mesh) const
             p.y             = *pointsIn++;
             p.z             = *pointsIn++;
 
-            tex.u = i / static_cast<data::Mesh::texcoord_t>(width - 1);
-            tex.v = j / static_cast<data::Mesh::texcoord_t>(height - 1);
+            tex.u = data::Mesh::texcoord_t(i) / static_cast<data::Mesh::texcoord_t>(width - 1);
+            tex.v = data::Mesh::texcoord_t(j) / static_cast<data::Mesh::texcoord_t>(height - 1);
             ++pointsItr;
         }
     }
@@ -215,9 +211,9 @@ void SUltrasoundMesh::createQuadMesh(const data::Mesh::sptr& _mesh) const
     {
         for(std::size_t j = 0 ; j < height - 1 ; ++j)
         {
-            const data::Mesh::cell_t idx1 = j + i * height;
+            const auto idx1               = data::Mesh::cell_t(j + i * height);
             const data::Mesh::cell_t idx2 = idx1 + 1;
-            const data::Mesh::cell_t idx4 = idx1 + height;
+            const auto idx4               = data::Mesh::cell_t(idx1 + height);
             const data::Mesh::cell_t idx3 = idx4 + 1;
 
             cellsItr->pt[0] = idx1;
@@ -232,7 +228,7 @@ void SUltrasoundMesh::createQuadMesh(const data::Mesh::sptr& _mesh) const
     geometry::data::Mesh::generatePointNormals(_mesh);
 
     const auto sig = _mesh->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
-    core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+    core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
     sig->asyncEmit();
 }
 
@@ -304,6 +300,4 @@ void SUltrasoundMesh::setBoolParameter(bool _val, std::string _key)
 
 // -----------------------------------------------------------------------------
 
-} // namespace generator
-
-} // namespace sight::module::filter::mesh
+} // namespace sight::module::filter::mesh::generator
