@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2021 IRCAD France
+ * Copyright (C) 2016-2022 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,13 +35,13 @@ struct Plugin : public core::runtime::Plugin
     /**
      * @brief   destructor
      */
-    ~Plugin() noexcept;
+    ~Plugin() noexcept override;
 
     // Overrides
-    void start();
+    void start() override;
 
     // Overrides
-    void stop() noexcept;
+    void stop() noexcept override;
 };
 
-} // namespace segmentation
+} // namespace sight::module::filter::vision
