@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,8 +28,7 @@
 #include <io/opencv/FrameTL.hpp>
 #include <io/opencv/Image.hpp>
 
-#include <service/macros.hpp>
-
+#include <boost/lexical_cast.hpp>
 #include <boost/tokenizer.hpp>
 
 namespace sight::module::filter::vision
@@ -46,14 +45,10 @@ const core::com::Slots::SlotKeyType s_CLEAR_MASKTL_SLOT              = "clearMas
 // ------------------------------------------------------------------------------
 
 SColourImageMasking::SColourImageMasking() noexcept :
-    m_lastVideoTimestamp(0.),
-    m_scaleFactor(1.),
+
     m_maskDownsize(cv::Size(0, 0)),
     m_lowerColor(cv::Scalar(0, 0, 0)),
-    m_upperColor(cv::Scalar(255, 255, 255)),
-    m_noise(0.),
-    m_backgroundComponents(5),
-    m_foregroundComponents(5)
+    m_upperColor(cv::Scalar(255, 255, 255))
 {
     newSlot(s_SET_BACKGROUND_SLOT, &SColourImageMasking::setBackground, this);
     newSlot(s_SET_FOREGROUND_SLOT, &SColourImageMasking::setForeground, this);
@@ -66,15 +61,14 @@ SColourImageMasking::SColourImageMasking() noexcept :
 
 // ------------------------------------------------------------------------------
 
-SColourImageMasking::~SColourImageMasking() noexcept
-{
-}
+SColourImageMasking::~SColourImageMasking() noexcept =
+    default;
 
 // ------------------------------------------------------------------------------
 
 void SColourImageMasking::configuring()
 {
-    const service::IService::ConfigType config = this->getConfigTree().get_child("config.<xmlattr>");
+    const service::IService::ConfigType config = this->getConfiguration().get_child("config.<xmlattr>");
 
     m_scaleFactor          = config.get<float>("scaleFactor", 1.0);
     m_noise                = config.get<double>("noise", 0.0);
@@ -98,7 +92,7 @@ void SColourImageMasking::configuring()
     m_lowerColor = cv::Scalar(0, 0, 0);
     m_upperColor = cv::Scalar(255, 255, 255);
 
-    const service::IService::ConfigType hsvConfig = this->getConfigTree().get_child("HSV");
+    const service::IService::ConfigType hsvConfig = this->getConfiguration().get_child("HSV");
     std::string s_lowerValue                      = hsvConfig.get<std::string>("lower", "");
     std::string s_upperValue                      = hsvConfig.get<std::string>("upper", "");
 
@@ -131,8 +125,8 @@ void SColourImageMasking::configuring()
 
 void SColourImageMasking::starting()
 {
-    using namespace sight::filter::vision;
-    m_masker = std::make_unique<Masker>(HSv, LLRatio);
+    namespace vision = sight::filter::vision;
+    m_masker         = std::make_unique<vision::Masker>(vision::HSv, vision::LLRatio);
     m_masker->setThreshold(1.);
 
     m_lastVideoTimestamp = 0.;
@@ -150,7 +144,7 @@ service::IService::KeyConnectionsMap SColourImageMasking::getAutoConnections() c
 {
     KeyConnectionsMap connections;
 
-    connections.push(s_VIDEO_TL_KEY, data::FrameTL::s_OBJECT_PUSHED_SIG, s_UPDATE_SLOT);
+    connections.push(s_VIDEO_TL_KEY, data::FrameTL::s_OBJECT_PUSHED_SIG, IService::slots::s_UPDATE);
     connections.push(s_VIDEO_TL_KEY, data::FrameTL::s_CLEARED_SIG, s_CLEAR_MASKTL_SLOT);
 
     return connections;
@@ -185,7 +179,7 @@ void SColourImageMasking::updating()
         auto sig_ = videoTL->signal<data::FrameTL::ObjectPushedSignalType>(
             data::FrameTL::s_OBJECT_PUSHED_SIG
         );
-        core::com::Connection::Blocker blocker(sig_->getConnection(m_slotUpdate));
+        core::com::Connection::Blocker blocker(sig_->getConnection(slot(IService::slots::s_UPDATE)));
 
         // Get the timestamp from the latest video frame
         core::HiResClock::HiResClockType currentTimestamp = videoTL->getNewerTimestamp();
@@ -294,14 +288,14 @@ void SColourImageMasking::setBackground()
     cv::erode(maskCV, maskCV, elementErode);
 
     // Learn background color model
-    m_masker->trainBackgroundModel(videoCV, maskCV, m_backgroundComponents);
+    m_masker->trainBackgroundModel(videoCV, maskCV, unsigned(m_backgroundComponents));
 
     // Initialize the mask timeline
     const auto videoMaskTL = m_videoMaskTL.lock();
     videoMaskTL->initPoolSize(
         videoTL->getWidth(),
         videoTL->getHeight(),
-        core::tools::Type::s_UINT8,
+        core::Type::UINT8,
         data::FrameTL::PixelFormat::RGBA
     );
 }
@@ -326,7 +320,8 @@ void SColourImageMasking::setForeground()
     cv::Mat videoCV = io::opencv::FrameTL::moveToCv(videoTL.get_shared(), frameBuffOutVideo);
 
     // Convert RGB to HSV
-    cv::Mat videoBGR, videoHSV;
+    cv::Mat videoBGR;
+    cv::Mat videoHSV;
     cv::cvtColor(videoCV, videoBGR, cv::COLOR_RGBA2BGR);
     cv::cvtColor(videoBGR, videoHSV, cv::COLOR_BGR2HSV);
 
@@ -350,7 +345,7 @@ void SColourImageMasking::setForeground()
     cv::erode(foregroundMask, openForegroundMask, elementErode);
 
     // Learn foreground color model
-    m_masker->trainForegroundModel(videoCV, openForegroundMask, m_foregroundComponents, m_noise);
+    m_masker->trainForegroundModel(videoCV, openForegroundMask, unsigned(m_foregroundComponents), m_noise);
 }
 
 // ------------------------------------------------------------------------------
