@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,6 +20,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE
+
 #include "modules/filter/vision/SOpticalFlow.hpp"
 
 #include <core/com/Signal.hxx>
@@ -38,12 +40,7 @@ static const core::com::Signals::SignalKeyType s_CAMERA_REMAINED_SIG = "cameraRe
 
 // ----------------------------------------------------------------------------
 
-SOpticalFlow::SOpticalFlow() noexcept :
-    m_latency(333),
-    m_imageScaleFactor(3.6f),
-    m_initialization(false),
-    m_motion(false),
-    m_lastTimestamp(0)
+SOpticalFlow::SOpticalFlow() noexcept
 {
     m_motionSignal   = newSignal<MotionSignalType>(s_CAMERA_MOVED_SIG);
     m_noMotionSignal = newSignal<NoMotionSignalType>(s_CAMERA_REMAINED_SIG);
@@ -51,15 +48,14 @@ SOpticalFlow::SOpticalFlow() noexcept :
 
 // ----------------------------------------------------------------------------
 
-SOpticalFlow::~SOpticalFlow() noexcept
-{
-}
+SOpticalFlow::~SOpticalFlow() noexcept =
+    default;
 
 // ----------------------------------------------------------------------------
 
 void SOpticalFlow::configuring()
 {
-    const auto configTree = this->getConfigTree();
+    const auto configTree = this->getConfiguration();
     const auto config     = configTree.get_child_optional("config.<xmlattr>");
 
     if(config)
@@ -87,7 +83,8 @@ void SOpticalFlow::updating()
         return;
     }
 
-    cv::Mat tempImg, grayImg;
+    cv::Mat tempImg;
+    cv::Mat grayImg;
 
     // Scope to lock frameTL
     {
@@ -102,7 +99,8 @@ void SOpticalFlow::updating()
         m_lastTimestamp = timestamp;
 
         CSPTR(data::FrameTL::BufferType) buffer = frameTL->getClosestBuffer(frameTL->getNewerTimestamp());
-        std::uint8_t* frameBuff = const_cast<std::uint8_t*>(&buffer->getElement(0));
+        // NOLINTNEXTLINE(cppcoreguidelines-pro-type-const-cast)
+        auto* frameBuff = const_cast<std::uint8_t*>(&buffer->getElement(0));
 
         tempImg = io::opencv::FrameTL::moveToCv(frameTL.get_shared(), frameBuff);
 
@@ -150,77 +148,75 @@ void SOpticalFlow::updating()
 
         return;
     }
-    else
+
+    cv::Mat currentCorners;
+    cv::Vec2f cornersDiff;
+    std::vector<uchar> status;
+    std::vector<float> err;
+    int acc         = 0; // Incremented each time the flow of a feature has been found.
+    long double RMS = 0; // Root mean square difference between each detected corners.
+    int n_move      = 0; // Incremented each time a corners has moved.
+
+    m_mainMutex.lock();
+
+    SIGHT_ASSERT(
+        "last image and current image should have same size: " << m_lastGrayImg.size << " , "
+        << grayImg.size
+        ,
+        m_lastGrayImg.size == grayImg.size
+    );
+
+    // Optical flow (Lucas-Kanade version).
+    cv::calcOpticalFlowPyrLK(m_lastGrayImg, grayImg, m_lastCorners, currentCorners, status, err);
+
+    for(int index = 0 ; index < m_lastCorners.size().height ; index++)
     {
-        cv::Mat currentCorners;
-        cv::Vec2f cornersDiff;
-        std::vector<uchar> status;
-        std::vector<float> err;
-        int acc         = 0; // Incremented each time the flow of a feature has been found.
-        long double RMS = 0; // Root mean square difference between each detected corners.
-        int n_move      = 0; // Incremented each time a corners has moved.
-
-        m_mainMutex.lock();
-
-        SIGHT_ASSERT(
-            "last image and current image should have same size: " << m_lastGrayImg.size << " , "
-            << grayImg.size
-            ,
-            m_lastGrayImg.size == grayImg.size
-        );
-
-        // Optical flow (Lucas-Kanade version).
-        cv::calcOpticalFlowPyrLK(m_lastGrayImg, grayImg, m_lastCorners, currentCorners, status, err);
-
-        for(int index = 0 ; index < m_lastCorners.size().height ; index++)
+        // Check if flow for feature 'index' has been found.
+        // Opencv doc for 'status' vector: Each element of the vector is set to 1 if
+        // the flow for the corresponding features has been found, otherwise, it is set to 0.
+        if(status[static_cast<std::size_t>(index)] != 0U)
         {
-            // Check if flow for feature 'index' has been found.
-            // Opencv doc for 'status' vector: Each element of the vector is set to 1 if
-            // the flow for the corresponding features has been found, otherwise, it is set to 0.
-            if(status[static_cast<std::size_t>(index)])
+            cornersDiff = m_lastCorners.at<cv::Vec2f>(index) - currentCorners.at<cv::Vec2f>(index);
+            RMS        +=
+                static_cast<long double>(cornersDiff[0] * cornersDiff[0] + cornersDiff[1] * cornersDiff[1]);
+
+            // Check if corners has moved.
+            if((cornersDiff[0] * cornersDiff[0] + cornersDiff[1] * cornersDiff[1]) > 2)
             {
-                cornersDiff = m_lastCorners.at<cv::Vec2f>(index) - currentCorners.at<cv::Vec2f>(index);
-                RMS        +=
-                    static_cast<long double>(cornersDiff[0] * cornersDiff[0] + cornersDiff[1] * cornersDiff[1]);
-
-                // Check if corners has moved.
-                if((cornersDiff[0] * cornersDiff[0] + cornersDiff[1] * cornersDiff[1]) > 2)
-                {
-                    ++n_move;
-                }
-
-                ++acc;
+                ++n_move;
             }
-        }
 
-        if(!acc)
-        {
-            RMS = RMS / static_cast<long double>(acc);
-            RMS = std::sqrt(RMS);
+            ++acc;
         }
-
-        // If movement is > 100 pixel and at least 80% of detected points has moved:
-        // we can say that the camera is moving (values find empirically).
-        if((RMS > 100) && ((static_cast<float>(n_move) / (static_cast<float>(acc))) > 0.8f) && !m_motion)
-        {
-            m_motion = !m_motion;
-            m_motionSignal->asyncEmit();
-        }
-        // No movement or movement on few points (ex: an object moving on the video):
-        // we can assume that camera is not moving.
-        else if((RMS < 1 || ((static_cast<float>(n_move) / (static_cast<float>(acc))) < 0.5f)) && m_motion)
-        {
-            m_motion = !m_motion;
-            m_noMotionSignal->asyncEmit();
-        }
-
-        // Keep last image.
-        m_lastGrayImg = grayImg;
-        // Detect "good" features in the frame. (parameters coming from opencv/samples/cpp/lkdemo.cpp).
-        cv::goodFeaturesToTrack(m_lastGrayImg, m_lastCorners, 2000, 0.01, 10);
-
-        m_mainMutex.unlock();
     }
+
+    if(acc != 0)
+    {
+        RMS = RMS / static_cast<long double>(acc);
+        RMS = std::sqrt(RMS);
+    }
+
+    // If movement is > 100 pixel and at least 80% of detected points has moved:
+    // we can say that the camera is moving (values find empirically).
+    if((RMS > 100) && ((static_cast<float>(n_move) / (static_cast<float>(acc))) > 0.8F) && !m_motion)
+    {
+        m_motion = !m_motion;
+        m_motionSignal->asyncEmit();
+    }
+    // No movement or movement on few points (ex: an object moving on the video):
+    // we can assume that camera is not moving.
+    else if((RMS < 1 || ((static_cast<float>(n_move) / (static_cast<float>(acc))) < 0.5F)) && m_motion)
+    {
+        m_motion = !m_motion;
+        m_noMotionSignal->asyncEmit();
+    }
+
+    // Keep last image.
+    m_lastGrayImg = grayImg;
+    // Detect "good" features in the frame. (parameters coming from opencv/samples/cpp/lkdemo.cpp).
+    cv::goodFeaturesToTrack(m_lastGrayImg, m_lastCorners, 2000, 0.01, 10);
+
+    m_mainMutex.unlock();
 }
 
 // ----------------------------------------------------------------------------
@@ -237,7 +233,7 @@ service::IService::KeyConnectionsMap SOpticalFlow::getAutoConnections() const
 {
     KeyConnectionsMap connections;
 
-    connections.push(s_FRAME_TIMELINE_INPUT, data::FrameTL::s_OBJECT_PUSHED_SIG, s_UPDATE_SLOT);
+    connections.push(s_FRAME_TIMELINE_INPUT, data::FrameTL::s_OBJECT_PUSHED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
