@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,6 +34,8 @@
 
 #include <glm/glm.hpp>
 
+#include <cmath>
+
 namespace sight::module::filter::vision
 {
 
@@ -41,17 +43,15 @@ const core::com::Slots::SlotKeyType SPointCloudFromDepthMap::s_SET_DEPTH_RANGE =
 
 //------------------------------------------------------------------------------
 
-SPointCloudFromDepthMap::SPointCloudFromDepthMap() noexcept :
-    service::IFilter()
+SPointCloudFromDepthMap::SPointCloudFromDepthMap() noexcept
 {
     newSlot(s_SET_DEPTH_RANGE, &SPointCloudFromDepthMap::setDepthRange, this);
 }
 
 //------------------------------------------------------------------------------
 
-SPointCloudFromDepthMap::~SPointCloudFromDepthMap() noexcept
-{
-}
+SPointCloudFromDepthMap::~SPointCloudFromDepthMap() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -83,7 +83,7 @@ void SPointCloudFromDepthMap::updating()
     SIGHT_ASSERT("Missing 'calibration' input", calibration);
     SIGHT_ASSERT("Missing 'depthMap' input", depthMap);
 
-    const auto depthCalibration = calibration->getCamera(0);
+    const auto depthCalibration = calibration->get_camera(0);
 
     const auto rgbMap = m_rgbMap.lock();
 
@@ -92,8 +92,8 @@ void SPointCloudFromDepthMap::updating()
 
     if(rgbMap)
     {
-        colorCalibration = calibration->getCamera(1);
-        extrinsicMatrix  = calibration->getExtrinsicMatrix(1);
+        colorCalibration = calibration->get_camera(1);
+        extrinsicMatrix  = calibration->get_extrinsic_matrix(1);
         SIGHT_ASSERT("Missing extrinsic matrix", extrinsicMatrix);
     }
 
@@ -112,7 +112,12 @@ void SPointCloudFromDepthMap::updating()
             attribute = data::Mesh::Attributes::POINT_COLORS;
         }
 
-        pointCloud->resize(nbPoints, nbPoints, data::Mesh::CellType::POINT, attribute);
+        pointCloud->resize(
+            data::Mesh::size_t(nbPoints),
+            data::Mesh::size_t(nbPoints),
+            data::Mesh::CellType::POINT,
+            attribute
+        );
 
         const auto dumpLock = pointCloud->dump_lock();
 
@@ -121,7 +126,7 @@ void SPointCloudFromDepthMap::updating()
         // to display the mesh, we need to create cells with one point.
         for(std::size_t i = 0 ; i < nbPoints ; ++i, ++itr)
         {
-            itr->pt = i;
+            itr->pt = data::Mesh::cell_t(i);
         }
 
         auto sig = pointCloud->signal<data::Mesh::ModifiedSignalType>(data::Mesh::s_MODIFIED_SIG);
@@ -185,7 +190,9 @@ void SPointCloudFromDepthMap::setDepthRange(int _val, std::string _key)
     }
     else
     {
-        SIGHT_ERROR("unknown key '" + _key + "' in slot '" + s_SET_DEPTH_RANGE + "'");
+        SIGHT_ERROR(
+            std::string("unknown key '") + _key + "' in slot '" + s_SET_DEPTH_RANGE + "'"
+        );
     }
 }
 
@@ -195,12 +202,12 @@ void SPointCloudFromDepthMap::depthMapToPointCloud(
     const data::Camera::csptr& depthCamera,
     const data::Image::csptr& depthMap,
     const data::Mesh::sptr& pointCloud
-)
+) const
 {
     SIGHT_INFO("Input RGB map was empty, skipping colors");
 
     const auto type = depthMap->getType();
-    if(type != core::tools::Type::s_UINT16)
+    if(type != core::Type::UINT16)
     {
         SIGHT_ERROR("Wrong input depth map format: " << type << ", uint16 is expected.");
         return;
@@ -214,16 +221,15 @@ void SPointCloudFromDepthMap::depthMapToPointCloud(
 
     auto depthItr = depthMap->begin<std::uint16_t>();
 
-    const double cx = depthCamera->getCx(),
-                 cy = depthCamera->getCy(),
-                 fx = depthCamera->getFx(),
-                 fy = depthCamera->getFy();
+    const double cx = depthCamera->getCx();
+    const double cy = depthCamera->getCy();
+    const double fx = depthCamera->getFx();
+    const double fy = depthCamera->getFy();
 
     const auto meshDumpLock = pointCloud->dump_lock();
 
     auto pointsItr = pointCloud->begin<data::iterator::point::xyz>();
 
-    std::size_t nbRealPoints = 0;
     for(std::size_t y = 0 ; y != height ; ++y)
     {
         for(std::size_t x = 0 ; x != width ; ++x)
@@ -231,13 +237,14 @@ void SPointCloudFromDepthMap::depthMapToPointCloud(
             const uint16_t depth = *depthItr;
             if(depth >= m_minDepth && depth <= m_maxDepth)
             {
-                double px, py, pz;
+                double px = NAN;
+                double py = NAN;
+                double pz = NAN;
                 sight::filter::vision::Projection::projectPixel<double>(x, y, depth, cx, cy, fx, fy, px, py, pz);
                 pointsItr->x = static_cast<float>(px);
                 pointsItr->y = static_cast<float>(py);
                 pointsItr->z = static_cast<float>(pz);
                 ++pointsItr;
-                ++nbRealPoints;
             }
 
             ++depthItr;
@@ -254,12 +261,12 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
     const data::Image::csptr& colorMap,
     const data::Matrix4::csptr& extrinsic,
     const data::Mesh::sptr& pointCloud
-)
+) const
 {
     SIGHT_INFO("Input RGB map was supplied, including colors");
 
     const auto type = depthMap->getType();
-    if(type != core::tools::Type::s_UINT16)
+    if(type != core::Type::UINT16)
     {
         SIGHT_ERROR("Wrong input depth map format: " << type << ", uint16 is expected.");
         return;
@@ -271,7 +278,7 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
     const std::size_t height = size[1];
 
     const auto rgbType = colorMap->getType();
-    if(rgbType != core::tools::Type::s_UINT8)
+    if(rgbType != core::Type::UINT8)
     {
         SIGHT_ERROR("Wrong input rgb format: " << rgbType << ", uint8 is expected.");
         return;
@@ -299,15 +306,15 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
     const auto rgbDumpLock = colorMap->dump_lock();
     const auto rgbBegin    = colorMap->begin<data::iterator::rgba>();
 
-    const double cx = depthCamera->getCx(),
-                 cy = depthCamera->getCy(),
-                 fx = depthCamera->getFx(),
-                 fy = depthCamera->getFy();
+    const double cx = depthCamera->getCx();
+    const double cy = depthCamera->getCy();
+    const double fx = depthCamera->getFx();
+    const double fy = depthCamera->getFy();
 
-    const double rgbCx = colorCamera->getCx(),
-                 rgbCy = colorCamera->getCy(),
-                 rgbFx = colorCamera->getFx(),
-                 rgbFy = colorCamera->getFy();
+    const double rgbCx = colorCamera->getCx();
+    const double rgbCy = colorCamera->getCy();
+    const double rgbFx = colorCamera->getFx();
+    const double rgbFy = colorCamera->getFy();
 
     const auto meshDumpLock = pointCloud->dump_lock();
 
@@ -329,7 +336,9 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
                 auto&& [p, c] = *pointsItr;
 
                 // get the 3D coordinates in the depth world
-                double px, py, pz;
+                double px = NAN;
+                double py = NAN;
+                double pz = NAN;
                 sight::filter::vision::Projection::projectPixel<double>(x, y, depth, cx, cy, fx, fy, px, py, pz);
                 p.x = static_cast<float>(px);
                 p.y = static_cast<float>(py);
@@ -340,7 +349,8 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
                 const glm::dvec4 rgbPoint = glmExtrinsicMatrix * point;
 
                 // project point to the rgb image
-                std::size_t rgbPx, rgbPy;
+                std::size_t rgbPx      = 0;
+                std::size_t rgbPy      = 0;
                 const bool isProjected = sight::filter::vision::Projection::projectPoint(
                     rgbPoint.x,
                     rgbPoint.y,
@@ -360,7 +370,7 @@ void SPointCloudFromDepthMap::depthMapToPointCloudRGB(
                     const std::size_t rgbIdx = rgbPy * rgbWidth + rgbPx;
                     if(rgbIdx < imageSize)
                     {
-                        const auto color = rgbBegin + rgbIdx;
+                        const auto color = rgbBegin + std::int64_t(rgbIdx);
                         c = *color;
                     }
                     else
