@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,9 +34,8 @@ namespace sight::module::geometry::base
 
 // ----------------------------------------------------------------------------
 
-SDecomposeMatrix::SDecomposeMatrix() noexcept
-{
-}
+SDecomposeMatrix::SDecomposeMatrix() noexcept =
+    default;
 
 // ----------------------------------------------------------------------------
 
@@ -60,9 +59,7 @@ void SDecomposeMatrix::stopping()
 
 service::IService::KeyConnectionsMap SDecomposeMatrix::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_SOURCE_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_SOURCE_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE}};
 }
 
 // ----------------------------------------------------------------------------
@@ -73,9 +70,9 @@ void SDecomposeMatrix::updating()
     SIGHT_ASSERT("input matrix '" << s_SOURCE_INPUT << "' is not defined", matrix);
 
     glm::dmat4 glmMatrix = sight::geometry::data::getMatrixFromTF3D(*matrix);
-    glm::dvec3 glmScale;
-    glm::dquat orientation;
-    glm::dvec3 glmTranslation;
+    glm::dvec3 glmScale {};
+    glm::dquat orientation {};
+    glm::dvec3 glmTranslation {};
     glm::dvec3 skew;
     glm::dvec4 perspective;
 
@@ -101,7 +98,7 @@ void SDecomposeMatrix::updating()
             sight::geometry::data::identity(*translation);
             for(std::size_t i = 0 ; i < 3 ; ++i)
             {
-                translation->setCoefficient(i, 3, glmTranslation[i]);
+                (*translation)(i, 3) = glmTranslation[int(i)];
             }
 
             auto transSig =
@@ -121,7 +118,7 @@ void SDecomposeMatrix::updating()
                 {
                     if(i == j)
                     {
-                        scale->setCoefficient(i, j, glmScale[i]);
+                        (*scale)(i, j) = glmScale[int(i)];
                     }
                 }
             }
