@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -38,8 +38,7 @@ const core::com::Slots::SlotKeyType s_REMOVE_POINT_SLOT             = "removePoi
 
 // -----------------------------------------------------------------------------
 
-SPointToLandmarkDistance::SPointToLandmarkDistance() noexcept :
-    m_landmarkSelected(false)
+SPointToLandmarkDistance::SPointToLandmarkDistance() noexcept
 {
     newSignal<DistanceChangedSignalType>(DISTANCE_CHANGED_SIG);
     newSlot(s_SELECTED_POINT_SLOT, &SPointToLandmarkDistance::updateSelectedPoint, this);
@@ -49,15 +48,14 @@ SPointToLandmarkDistance::SPointToLandmarkDistance() noexcept :
 
 // -----------------------------------------------------------------------------
 
-SPointToLandmarkDistance::~SPointToLandmarkDistance() noexcept
-{
-}
+SPointToLandmarkDistance::~SPointToLandmarkDistance() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
 void SPointToLandmarkDistance::configuring()
 {
-    const ConfigType config = this->getConfigTree().get_child("config.<xmlattr>.");
+    const ConfigType config = this->getConfiguration().get_child("config.<xmlattr>.");
     m_unit      = config.get<std::string>("unit", "");
     m_precision = config.get<int>("precision", 6);
     if(!m_unit.empty())
@@ -94,7 +92,7 @@ void SPointToLandmarkDistance::updating()
         const glm::dvec3 point = glm::dvec3(pointMatrix * originPoint);
 
         const glm::dvec3 direction = m_currentLandmark - point;
-        const float length         = static_cast<float>(glm::length(direction));
+        const auto length          = static_cast<float>(glm::length(direction));
 
         std::ostringstream out;
         out.precision(m_precision);
@@ -126,7 +124,7 @@ void SPointToLandmarkDistance::updating()
         auto sig =
             pointToLandmarkMat->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
         {
-            core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+            core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
             sig->asyncEmit();
         }
     }
@@ -142,7 +140,7 @@ void SPointToLandmarkDistance::updateSelectedPoint(std::string name, std::size_t
     const data::Landmarks::PointType& point = landmark->getPoint(name, index);
     for(int i = 0 ; i < 3 ; ++i)
     {
-        m_currentLandmark[i] = point[i];
+        m_currentLandmark[i] = point[std::size_t(i)];
     }
 
     this->update();
@@ -158,7 +156,7 @@ void SPointToLandmarkDistance::updatePoint(std::string name)
     const data::Landmarks::PointType& point = landmark->getPoint(name, size - 1);
     for(int i = 0 ; i < 3 ; ++i)
     {
-        m_currentLandmark[i] = point[i];
+        m_currentLandmark[i] = point[std::size_t(i)];
     }
 
     this->update();
@@ -181,4 +179,4 @@ void SPointToLandmarkDistance::removePoint()
 
 // -----------------------------------------------------------------------------
 
-} // maths
+} // namespace sight::module::geometry::base
