@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -51,9 +51,8 @@ SPointToLandmarkVector::SPointToLandmarkVector() noexcept
 
 // -----------------------------------------------------------------------------
 
-SPointToLandmarkVector::~SPointToLandmarkVector() noexcept
-{
-}
+SPointToLandmarkVector::~SPointToLandmarkVector() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
@@ -73,7 +72,7 @@ void SPointToLandmarkVector::stopping()
 
 void SPointToLandmarkVector::configuring()
 {
-    const ConfigType configuration = this->getConfigTree();
+    const ConfigType configuration = this->getConfiguration();
     m_originLabel    = configuration.get<std::string>("originLabel", m_originLabel);
     m_endLabel       = configuration.get<std::string>("endLabel", m_endLabel);
     m_groupLabel     = configuration.get<std::string>("computedLandmarkLabel", m_groupLabel);
@@ -85,10 +84,11 @@ void SPointToLandmarkVector::configuring()
 
 void SPointToLandmarkVector::updating()
 {
-    auto transform = m_transform.lock();
+    auto transform         = m_transform.lock();
     auto translationMatrix = m_translationMatrix.lock();
-    const auto landmark = m_landmark.lock();
-    std::array<double, 3> sourcePoint, targetPoint;
+    const auto landmark    = m_landmark.lock();
+    std::array<double, 3> sourcePoint {};
+    std::array<double, 3> targetPoint {};
     if(landmark->getGroup(m_originLabel).m_size >= 1)
     {
         sourcePoint = landmark->getPoint(m_originLabel, 0);
@@ -112,7 +112,7 @@ void SPointToLandmarkVector::updating()
     const glm::dvec3 sourcePt(sourcePoint[0], sourcePoint[1], sourcePoint[2]);
     const glm::dvec3 targetPt(targetPoint[0], targetPoint[1], targetPoint[2]);
     const glm::dvec3 pointToTarget = targetPt - sourcePt;
-    const float length             = static_cast<float>(glm::length(pointToTarget));
+    const auto length              = static_cast<float>(glm::length(pointToTarget));
     this->signal<LengthChangedSignalType>(LENGTH_CHANGED_SIG)->asyncEmit(length);
     const std::string lengthStr = std::to_string(length) + " mm";
     this->signal<LengthStrChangedSignalType>(LENGTH_STR_CHANGED_SIG)->asyncEmit(lengthStr);
@@ -146,9 +146,9 @@ void SPointToLandmarkVector::updating()
     auto sig1 = computedLandmark->signal<data::Landmarks::PointAddedSignalType>(data::Landmarks::s_POINT_ADDED_SIG);
     sig1->asyncEmit(m_groupLabel);
 
-    translationMatrix->setCoefficient(0, 3, pointToTarget[0]);
-    translationMatrix->setCoefficient(1, 3, pointToTarget[1]);
-    translationMatrix->setCoefficient(2, 3, pointToTarget[2]);
+    (*translationMatrix)(0, 3) = pointToTarget[0];
+    (*translationMatrix)(1, 3) = pointToTarget[1];
+    (*translationMatrix)(2, 3) = pointToTarget[2];
 
     auto sig2 = translationMatrix->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
     sig2->asyncEmit();
@@ -158,11 +158,9 @@ void SPointToLandmarkVector::updating()
 
 service::IService::KeyConnectionsMap SPointToLandmarkVector::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_LANDMARK_INPUT, data::Landmarks::s_POINT_ADDED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_LANDMARK_INPUT, data::Landmarks::s_POINT_ADDED_SIG, IService::slots::s_UPDATE}};
 }
 
 // -----------------------------------------------------------------------------
 
-} // maths
+} // namespace sight::module::geometry::base
