@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,8 +35,7 @@ const core::com::Slots::SlotKeyType SSwitchMatrices::s_SWITCH_TO_SLOT = "switchT
 
 // ----------------------------------------------------------------------------
 
-SSwitchMatrices::SSwitchMatrices() noexcept :
-    m_indexOfDesiredMatrix(0)
+SSwitchMatrices::SSwitchMatrices() noexcept
 {
     newSlot(s_SWITCH_SLOT, &SSwitchMatrices::switchMatrix, this);
     newSlot(s_SWITCH_TO_SLOT, &SSwitchMatrices::switchToMatrix, this);
@@ -65,9 +64,7 @@ void SSwitchMatrices::stopping()
 
 service::IService::KeyConnectionsMap SSwitchMatrices::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_MATRIX_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_MATRIX_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE}};
 }
 
 // ----------------------------------------------------------------------------
@@ -81,7 +78,7 @@ void SSwitchMatrices::updating()
 
     auto sig = matrix->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
     {
-        core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+        core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
         sig->asyncEmit();
     }
 }
@@ -101,11 +98,11 @@ void SSwitchMatrices::switchMatrix()
 
 // ----------------------------------------------------------------------------
 
-void SSwitchMatrices::switchToMatrix(std::size_t index)
+void SSwitchMatrices::switchToMatrix(int index)
 {
-    if(index < m_matrix.size())
+    if(index >= 0 && static_cast<std::size_t>(index) < m_matrix.size())
     {
-        m_indexOfDesiredMatrix = index;
+        m_indexOfDesiredMatrix = static_cast<std::size_t>(index);
     }
     else
     {
