@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -71,15 +71,14 @@ public:
     /**
      * @brief Destructor.
      */
-    virtual ~SSwitchMatrices() noexcept
-    {
-    }
+    ~SSwitchMatrices() noexcept override =
+        default;
 
     MODULE_GEOMETRY_BASE_API static const core::com::Slots::SlotKeyType s_SWITCH_SLOT;
     typedef core::com::Slot<void ()> SwitchSlotType;
 
     MODULE_GEOMETRY_BASE_API static const core::com::Slots::SlotKeyType s_SWITCH_TO_SLOT;
-    typedef core::com::Slot<void (std::size_t)> SwitchToSlotType;
+    typedef core::com::Slot<void (int)> SwitchToSlotType;
 
 protected:
 
@@ -99,13 +98,13 @@ protected:
     MODULE_GEOMETRY_BASE_API void switchMatrix();
 
     /// Switch to Matrix "index"
-    MODULE_GEOMETRY_BASE_API void switchToMatrix(std::size_t index);
+    MODULE_GEOMETRY_BASE_API void switchToMatrix(int index);
 
     MODULE_GEOMETRY_BASE_API KeyConnectionsMap getAutoConnections() const override;
 
 private:
 
-    std::size_t m_indexOfDesiredMatrix;
+    std::size_t m_indexOfDesiredMatrix {0};
 
     static constexpr std::string_view s_MATRIX_INPUT  = "matrix";
     static constexpr std::string_view s_MATRIX_OUTPUT = "output";
