@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -58,9 +58,8 @@ STargeting::STargeting() noexcept :
 
 // -----------------------------------------------------------------------------
 
-STargeting::~STargeting() noexcept
-{
-}
+STargeting::~STargeting() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
@@ -78,7 +77,7 @@ void STargeting::stopping()
 
 void STargeting::configuring()
 {
-    const ConfigType configuration = this->getConfigTree();
+    const ConfigType configuration = this->getConfiguration();
     m_label = configuration.get<std::string>("label", m_label);
     if(!m_label.empty())
     {
@@ -96,7 +95,7 @@ void STargeting::updating()
     {
         const auto landmark = m_landmark.lock();
         SIGHT_ASSERT("Input \"landmark\" is missing.", landmark);
-        if(landmark->getGroup(m_label).m_points.size() > 0)
+        if(!landmark->getGroup(m_label).m_points.empty())
         {
             const data::Landmarks::PointType point = landmark->getPoint(m_label, m_index);
             m_targetLandmark = glm::dvec3(point[0], point[1], point[2]);
@@ -184,7 +183,7 @@ void STargeting::updating()
 
         auto pointList = m_pointList.lock();
         SIGHT_ASSERT("InOut \"pointList\" is missing.", pointList);
-        if(pointList->getPoints().size() > 0)
+        if(!pointList->getPoints().empty())
         {
             pointList->clear();
         }
@@ -208,9 +207,7 @@ void STargeting::updating()
 
 service::IService::KeyConnectionsMap STargeting::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_MATRIX_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_MATRIX_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE}};
 }
 
 // -----------------------------------------------------------------------------
