@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -96,7 +96,7 @@ protected:
      * @brief Proposals to connect service slots to associated object signals.
      * @return A map of each proposed connection.
      *
-     * Connect data::Object::s_MODIFIED_SIG of s_MATRIX_INPUT to s_UPDATE_SLOT
+     * Connect data::Object::s_MODIFIED_SIG of s_MATRIX_INPUT to IService::slots::s_UPDATE
      */
     MODULE_GEOMETRY_BASE_API KeyConnectionsMap getAutoConnections() const override;
 
@@ -112,7 +112,7 @@ private:
     void removePoint();
 
     /// Label containing the landmark group name.
-    std::string m_label {""};
+    std::string m_label;
 
     /// Index of the point to modify in the landmark group.
     std::size_t m_index {0};
