@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -52,9 +52,8 @@ STransformLandmark::STransformLandmark() noexcept
 
 // -----------------------------------------------------------------------------
 
-STransformLandmark::~STransformLandmark() noexcept
-{
-}
+STransformLandmark::~STransformLandmark() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
@@ -72,7 +71,7 @@ void STransformLandmark::stopping()
 
 void STransformLandmark::configuring()
 {
-    const ConfigType configuration = this->getConfigTree();
+    const ConfigType configuration = this->getConfiguration();
     m_label = configuration.get<std::string>("label", m_label);
     if(!m_label.empty())
     {
@@ -91,10 +90,9 @@ void STransformLandmark::updating()
         try
         {
             data::Landmarks::PointType& point = landmark->getPoint(m_label, m_index);
-            data::Matrix4::TMCoefArray array  = transform->getCoefficients();
-            point[0] = array[3];
-            point[1] = array[7];
-            point[2] = array[11];
+            point[0] = (*transform)[3];
+            point[1] = (*transform)[7];
+            point[2] = (*transform)[11];
 
             //notify point is modified
             auto sig = landmark->signal<data::Landmarks::PointModifiedSigType>(
@@ -104,7 +102,7 @@ void STransformLandmark::updating()
         }
         catch(data::Exception& e)
         {
-            sight::ui::base::dialog::MessageDialog::showMessageDialog(
+            sight::ui::base::dialog::MessageDialog::show(
                 "Transform Landmarks",
                 "It is impossible to modify landmarks: "
                 + std::string(e.what()),
@@ -118,14 +116,12 @@ void STransformLandmark::updating()
 
 service::IService::KeyConnectionsMap STransformLandmark::getAutoConnections() const
 {
-    service::IService::KeyConnectionsMap connections;
-    connections.push(s_TRANSFORM_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {{s_TRANSFORM_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE}};
 }
 
 // -----------------------------------------------------------------------------
 
-void STransformLandmark::updateSelectedPoint(std::string name, std::size_t index)
+void STransformLandmark::updateSelectedPoint(std::string /*name*/, std::size_t index)
 {
     m_landmarkSelected = true;
     m_index            = index;
@@ -153,4 +149,4 @@ void STransformLandmark::removePoint()
 
 // -----------------------------------------------------------------------------
 
-} // maths
+} // namespace sight::module::geometry::base
