@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -93,11 +93,11 @@ public:
     MODULE_GEOMETRY_VISION_API SDistortion() noexcept;
 
     /// Destructor. Does nothing
-    MODULE_GEOMETRY_VISION_API virtual ~SDistortion() noexcept;
+    MODULE_GEOMETRY_VISION_API ~SDistortion() noexcept override;
 
     /**
-     * @brief Connect data::Image::s_MODIFIED_SIG to s_UPDATE_SLOT
-     * and data::Image::s_BUFFER_MODIFIED_SIG to s_UPDATE_SLOT
+     * @brief Connect data::Image::s_MODIFIED_SIG to IService::slots::s_UPDATE
+     * and data::Image::s_BUFFER_MODIFIED_SIG to IService::slots::s_UPDATE
      */
     MODULE_GEOMETRY_VISION_API service::IService::KeyConnectionsMap getAutoConnections() const override;
 
@@ -157,4 +157,4 @@ private:
     sight::data::ptr<sight::data::Image, sight::data::Access::inout> m_map {this, s_MAP_INOUT};
 };
 
-} // videoCalibration
+} // namespace sight::module::geometry::vision
