@@ -25,21 +25,15 @@
 #include <core/com/Signal.hxx>
 #include <core/com/Slot.hxx>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/tools/fwID.hpp>
-#include <core/tools/Object.hpp>
 
 #include <data/CalibrationInfo.hpp>
 #include <data/Camera.hpp>
-#include <data/CameraSeries.hpp>
+#include <data/CameraSet.hpp>
 #include <data/Matrix4.hpp>
 #include <data/PointList.hpp>
 
 #include <io/opencv/Matrix.hpp>
 
-#include <service/IService.hpp>
-#include <service/macros.hpp>
-
 #include <ui/base/Preferences.hpp>
 
 #include <opencv2/calib3d.hpp>
@@ -53,11 +47,7 @@ static const core::com::Signals::SignalKeyType s_ERROR_COMPUTED_SIG      = "erro
 
 // ----------------------------------------------------------------------------
 
-SOpenCVExtrinsic::SOpenCVExtrinsic() noexcept :
-    m_width(11),
-    m_height(8),
-    m_squareSize(20.0),
-    m_camIndex(1)
+SOpenCVExtrinsic::SOpenCVExtrinsic() noexcept
 {
     newSignal<ErrorComputedSignalType>(s_ERROR_COMPUTED_SIG);
     newSlot(s_UPDATE_CHESSBOARD_SIZE_SLOT, &SOpenCVExtrinsic::updateChessboardSize, this);
@@ -65,36 +55,27 @@ SOpenCVExtrinsic::SOpenCVExtrinsic() noexcept :
 
 // ----------------------------------------------------------------------------
 
-SOpenCVExtrinsic::~SOpenCVExtrinsic() noexcept
-{
-}
+SOpenCVExtrinsic::~SOpenCVExtrinsic() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SOpenCVExtrinsic::configuring()
 {
-    core::runtime::ConfigurationElement::sptr cfgIdx = m_configuration->findConfigurationElement("camIndex");
-    if(cfgIdx)
-    {
-        std::string idxStr = cfgIdx->getValue();
-        SIGHT_ASSERT("'camIndex' is empty.", !idxStr.empty());
-        m_camIndex = boost::lexical_cast<std::size_t>(idxStr);
-    }
+    const auto config = this->getConfiguration();
+    m_camIndex = config.get<std::size_t>("camIndex");
 
-    core::runtime::ConfigurationElement::sptr cfgBoard = m_configuration->findConfigurationElement("board");
-    SIGHT_ASSERT("Tag 'board' not found.", cfgBoard);
+    const auto cfgBoard = config.get_child("board.<xmlattr>");
 
-    SIGHT_ASSERT("Attribute 'width' is missing.", cfgBoard->hasAttribute("width"));
-    m_widthKey = cfgBoard->getAttributeValue("width");
+    m_widthKey = cfgBoard.get<std::string>("width");
     SIGHT_ASSERT("Attribute 'width' is empty", !m_widthKey.empty());
 
-    SIGHT_ASSERT("Attribute 'height' is missing.", cfgBoard->hasAttribute("height"));
-    m_heightKey = cfgBoard->getAttributeValue("height");
+    m_heightKey = cfgBoard.get<std::string>("height");
     SIGHT_ASSERT("Attribute 'height' is empty", !m_heightKey.empty());
 
-    if(cfgBoard->hasAttribute("squareSize"))
+    if(const auto squareSizeKey = cfgBoard.get_optional<std::string>("squareSize"); squareSizeKey.has_value())
     {
-        m_squareSizeKey = cfgBoard->getAttributeValue("squareSize");
+        m_squareSizeKey = squareSizeKey.value();
         SIGHT_ASSERT("Attribute 'squareSize' is empty", !m_squareSizeKey.empty());
     }
 }
@@ -132,12 +113,11 @@ void SOpenCVExtrinsic::updating()
         {
             for(unsigned int x = 0 ; x < m_width - 1 ; ++x)
             {
-                points.push_back(
-                    cv::Point3f(
-                        static_cast<float>(x) * m_squareSize,
-                        static_cast<float>(y) * m_squareSize,
-                        0
-                    )
+                points.emplace_back(
+                    static_cast<float>(x) * m_squareSize,
+                    static_cast<float>(y) * m_squareSize,
+                    0.F
+
                 );
             }
         }
@@ -157,30 +137,28 @@ void SOpenCVExtrinsic::updating()
 
             for( ; itr1 != itrEnd1 && itr2 != itrEnd2 ; ++itr1, ++itr2)
             {
-                data::PointList::csptr ptList1 = *itr1;
-                data::PointList::csptr ptList2 = *itr2;
+                const data::PointList::csptr& ptList1 = *itr1;
+                const data::PointList::csptr& ptList2 = *itr2;
                 std::vector<cv::Point2f> imgPoint1;
                 std::vector<cv::Point2f> imgPoint2;
 
                 for(data::Point::csptr point : ptList1->getPoints())
                 {
                     SIGHT_ASSERT("point is null", point);
-                    imgPoint1.push_back(
-                        cv::Point2f(
-                            static_cast<float>(point->getCoord()[0]),
-                            static_cast<float>(point->getCoord()[1])
-                        )
+                    imgPoint1.emplace_back(
+                        static_cast<float>(point->getCoord()[0]),
+                        static_cast<float>(point->getCoord()[1])
+
                     );
                 }
 
                 for(data::Point::csptr point : ptList2->getPoints())
                 {
                     SIGHT_ASSERT("point is null", point);
-                    imgPoint2.push_back(
-                        cv::Point2f(
-                            static_cast<float>(point->getCoord()[0]),
-                            static_cast<float>(point->getCoord()[1])
-                        )
+                    imgPoint2.emplace_back(
+                        static_cast<float>(point->getCoord()[0]),
+                        static_cast<float>(point->getCoord()[1])
+
                     );
                 }
 
@@ -201,18 +179,18 @@ void SOpenCVExtrinsic::updating()
         cv::Mat essentialMatrix;
         cv::Mat fundamentalMatrix;
 
-        const auto camSeries = m_cameraSeries.lock();
+        const auto camSeries = m_camera_set.lock();
 
         SIGHT_ASSERT(
-            "camera index must be > 0 and < camSeries->numCameras()",
-            m_camIndex > 0 && m_camIndex < camSeries->numCameras()
+            "camera index must be > 0 and < camSeries->size()",
+            m_camIndex > 0 && m_camIndex < camSeries->size()
         );
 
         data::Image::csptr img = calInfo1->getImageContainer().front();
         cv::Size2i imgsize(static_cast<int>(img->getSize()[0]), static_cast<int>(img->getSize()[1]));
         {
-            data::Camera::csptr cam1 = camSeries->getCamera(0);
-            data::Camera::csptr cam2 = camSeries->getCamera(m_camIndex);
+            data::Camera::csptr cam1 = camSeries->get_camera(0);
+            data::Camera::csptr cam2 = camSeries->get_camera(m_camIndex);
 
             data::mt::locked_ptr cam1Lock(cam1);
             data::mt::locked_ptr cam2Lock(cam2);
@@ -263,12 +241,12 @@ void SOpenCVExtrinsic::updating()
         io::opencv::Matrix::copyFromCv(cv4x4, matrix);
 
         {
-            camSeries->setExtrinsicMatrix(m_camIndex, matrix);
+            camSeries->set_extrinsic_matrix(m_camIndex, matrix);
         }
 
-        data::CameraSeries::ExtrinsicCalibratedSignalType::sptr sig;
-        sig = camSeries->signal<data::CameraSeries::ExtrinsicCalibratedSignalType>(
-            data::CameraSeries::s_EXTRINSIC_CALIBRATED_SIG
+        data::CameraSet::extrinsic_calibrated_signal_t::sptr sig;
+        sig = camSeries->signal<data::CameraSet::extrinsic_calibrated_signal_t>(
+            data::CameraSet::s_EXTRINSIC_CALIBRATED_SIG
         );
 
         sig->asyncEmit();
