@@ -41,10 +41,7 @@ static const core::com::Signals::SignalKeyType s_ERROR_COMPUTED_SIG = "errorComp
 
 // ----------------------------------------------------------------------------
 
-SOpenCVIntrinsic::SOpenCVIntrinsic() noexcept :
-    m_width(11),
-    m_height(8),
-    m_squareSize(20.0)
+SOpenCVIntrinsic::SOpenCVIntrinsic() noexcept
 {
     newSignal<ErrorComputedSignalType>(s_ERROR_COMPUTED_SIG);
     newSlot(s_UPDATE_CHESSBOARD_SIZE_SLOT, &SOpenCVIntrinsic::updateChessboardSize, this);
@@ -52,28 +49,25 @@ SOpenCVIntrinsic::SOpenCVIntrinsic() noexcept :
 
 // ----------------------------------------------------------------------------
 
-SOpenCVIntrinsic::~SOpenCVIntrinsic() noexcept
-{
-}
+SOpenCVIntrinsic::~SOpenCVIntrinsic() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SOpenCVIntrinsic::configuring()
 {
-    core::runtime::ConfigurationElement::sptr cfgBoard = m_configuration->findConfigurationElement("board");
-    SIGHT_ASSERT("Tag 'board' not found.", cfgBoard);
+    const auto config   = this->getConfiguration();
+    const auto cfgBoard = config.get_child("board.<xmlattr>");
 
-    SIGHT_ASSERT("Attribute 'width' is missing.", cfgBoard->hasAttribute("width"));
-    m_widthKey = cfgBoard->getAttributeValue("width");
+    m_widthKey = cfgBoard.get<std::string>("width");
     SIGHT_ASSERT("Attribute 'width' is empty", !m_widthKey.empty());
 
-    SIGHT_ASSERT("Attribute 'height' is missing.", cfgBoard->hasAttribute("height"));
-    m_heightKey = cfgBoard->getAttributeValue("height");
+    m_heightKey = cfgBoard.get<std::string>("height");
     SIGHT_ASSERT("Attribute 'height' is empty", !m_heightKey.empty());
 
-    if(cfgBoard->hasAttribute("squareSize"))
+    if(const auto squareSizeKey = cfgBoard.get_optional<std::string>("squareSize"); squareSizeKey.has_value())
     {
-        m_squareSizeKey = cfgBoard->getAttributeValue("squareSize");
+        m_squareSizeKey = squareSizeKey.value();
         SIGHT_ASSERT("Attribute 'squareSize' is empty", !m_squareSizeKey.empty());
     }
 }
@@ -109,30 +103,28 @@ void SOpenCVIntrinsic::updating()
         {
             for(unsigned int x = 0 ; x < m_width - 1 ; ++x)
             {
-                points.push_back(
-                    cv::Point3f(
-                        static_cast<float>(x) * m_squareSize,
-                        static_cast<float>(y) * m_squareSize,
-                        0
-                    )
+                points.emplace_back(
+                    static_cast<float>(x) * m_squareSize,
+                    static_cast<float>(y) * m_squareSize,
+                    0.F
+
                 );
             }
         }
 
         std::vector<std::vector<cv::Point2f> > imagePoints;
 
-        for(data::PointList::csptr capture : calInfo->getPointListContainer())
+        for(const data::PointList::csptr& capture : calInfo->getPointListContainer())
         {
             std::vector<cv::Point2f> dst;
 
             for(data::Point::csptr point : capture->getPoints())
             {
                 SIGHT_ASSERT("point is null", point);
-                dst.push_back(
-                    cv::Point2f(
-                        static_cast<float>(point->getCoord()[0]),
-                        static_cast<float>(point->getCoord()[1])
-                    )
+                dst.emplace_back(
+                    static_cast<float>(point->getCoord()[0]),
+                    static_cast<float>(point->getCoord()[1])
+
                 );
             }
 
@@ -155,7 +147,7 @@ void SOpenCVIntrinsic::updating()
         const auto poseCamera = m_poseVector.lock();
         if(poseCamera)
         {
-            poseCamera->getContainer().clear();
+            poseCamera->clear();
 
             for(std::size_t index = 0 ; index < rvecs.size() ; ++index)
             {
@@ -163,11 +155,11 @@ void SOpenCVIntrinsic::updating()
 
                 io::opencv::Matrix::copyFromCv(rvecs.at(index), tvecs.at(index), mat3D);
 
-                poseCamera->getContainer().push_back(mat3D);
-                auto sig = poseCamera->signal<data::Vector::AddedObjectsSignalType>(
+                poseCamera->push_back(mat3D);
+                auto sig = poseCamera->signal<data::Vector::added_signal_t>(
                     data::Vector::s_ADDED_OBJECTS_SIG
                 );
-                sig->asyncEmit(poseCamera->getContainer());
+                sig->asyncEmit(poseCamera->get_content());
             }
         }
 
