@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,8 @@
 
 #include "SPoseFrom2d.hpp"
 
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
+#include <core/com/Slots.hxx>
 
 #include <geometry/vision/helper.hpp>
 
@@ -34,28 +34,20 @@
 namespace sight::module::geometry::vision
 {
 
-//-----------------------------------------------------------------------------
+static const std::string s_UPDATE_CAMERA_SLOT = "updateCamera";
 
 //-----------------------------------------------------------------------------
 
-SPoseFrom2d::SPoseFrom2d() noexcept :
-    m_lastTimestamp(0),
-    m_patternWidth(80),
-    m_isInitialized(false)
-{
-}
-
-//-----------------------------------------------------------------------------
-
-SPoseFrom2d::~SPoseFrom2d() noexcept
+SPoseFrom2d::SPoseFrom2d() noexcept
 {
+    newSlot(s_UPDATE_CAMERA_SLOT, &SPoseFrom2d::initialize, this);
 }
 
 //-----------------------------------------------------------------------------
 
 void SPoseFrom2d::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
     m_patternWidth = config.get<double>("patternWidth", m_patternWidth);
     SIGHT_ASSERT("patternWidth setting is set to " << m_patternWidth << " but should be > 0.", m_patternWidth > 0);
 
@@ -68,7 +60,7 @@ void SPoseFrom2d::configuring()
             auto keyCfg = itCfg->second.equal_range("key");
             for(auto itKeyCfg = keyCfg.first ; itKeyCfg != keyCfg.second ; ++itKeyCfg)
             {
-                const data::MarkerMap::KeyType key = itKeyCfg->second.get<std::string>("<xmlattr>.id");
+                const auto key = itKeyCfg->second.get<std::string>("<xmlattr>.id");
                 m_matricesTag.push_back(key);
             }
 
@@ -82,12 +74,12 @@ void SPoseFrom2d::configuring()
 void SPoseFrom2d::starting()
 {
     //3D Points
-    const float halfWidth = static_cast<float>(m_patternWidth) * .5f;
+    const float halfWidth = static_cast<float>(m_patternWidth) * .5F;
 
-    m_3dModel.push_back(cv::Point3f(-halfWidth, halfWidth, 0));
-    m_3dModel.push_back(cv::Point3f(halfWidth, halfWidth, 0));
-    m_3dModel.push_back(cv::Point3f(halfWidth, -halfWidth, 0));
-    m_3dModel.push_back(cv::Point3f(-halfWidth, -halfWidth, 0));
+    m_3dModel.emplace_back(-halfWidth, halfWidth, 0.F);
+    m_3dModel.emplace_back(halfWidth, halfWidth, 0.F);
+    m_3dModel.emplace_back(halfWidth, -halfWidth, 0.F);
+    m_3dModel.emplace_back(-halfWidth, -halfWidth, 0.F);
 
     auto pl = m_pointList.lock();
     if(pl)
@@ -103,6 +95,8 @@ void SPoseFrom2d::starting()
         auto sig = pl->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
         sig->asyncEmit();
     }
+
+    this->initialize();
 }
 
 //-----------------------------------------------------------------------------
@@ -112,7 +106,6 @@ void SPoseFrom2d::stopping()
     m_cameras.clear();
     m_3dModel.clear();
     m_lastTimestamp = 0;
-    m_isInitialized = false;
 
     auto pl = m_pointList.lock();
     if(pl)
@@ -136,42 +129,34 @@ void SPoseFrom2d::updating()
 
 //-----------------------------------------------------------------------------
 
-void SPoseFrom2d::computeRegistration(core::HiResClock::HiResClockType timestamp)
+void SPoseFrom2d::computeRegistration(core::HiResClock::HiResClockType /*timestamp*/)
 {
-    SIGHT_WARN_IF("Invoking doRegistration while service is STOPPED", this->isStopped());
-
-    if(!m_isInitialized)
-    {
-        this->initialize();
-    }
+    SIGHT_WARN_IF("Invoking computeRegistration while service is STOPPED", this->isStopped());
 
     if(this->isStarted())
     {
         // For each marker
         unsigned int markerIndex = 0;
-        for(auto markerKey : m_matricesTag)
+        for(const auto& markerKey : m_matricesTag)
         {
             std::vector<Marker> markers;
-            std::size_t indexTL = 0;
 
             // For each camera timeline
             for(const auto& markerMap : m_markerMap)
             {
-                const auto marker_ptr = markerMap.second.lock();
+                const auto marker_ptr = markerMap.second->lock();
                 const auto* marker    = marker_ptr->getMarker(markerKey);
 
-                if(marker)
+                if(marker != nullptr)
                 {
                     Marker currentMarker;
                     for(std::size_t i = 0 ; i < 4 ; ++i)
                     {
-                        currentMarker.corners2D.push_back(cv::Point2f((*marker)[i][0], (*marker)[i][1]));
+                        currentMarker.corners2D.emplace_back((*marker)[i][0], (*marker)[i][1]);
                     }
 
                     markers.push_back(currentMarker);
                 }
-
-                ++indexTL;
             }
 
             auto matrix = m_matrix[markerIndex].lock();
@@ -183,7 +168,6 @@ void SPoseFrom2d::computeRegistration(core::HiResClock::HiResClockType timestamp
             }
             else
             {
-                data::Matrix4::TMCoefArray matrixValues;
                 cv::Matx44f Rt;
                 if(markers.size() == 1)
                 {
@@ -203,11 +187,9 @@ void SPoseFrom2d::computeRegistration(core::HiResClock::HiResClockType timestamp
                 {
                     for(std::uint8_t j = 0 ; j < 4 ; ++j)
                     {
-                        matrixValues[4 * i + j] = Rt(i, j);
+                        (*matrix)[4 * i + j] = Rt(i, j);
                     }
                 }
-
-                matrix->setCoefficients(matrixValues);
             }
 
             // Always send the signal even if we did not find anything.
@@ -224,6 +206,7 @@ void SPoseFrom2d::computeRegistration(core::HiResClock::HiResClockType timestamp
 
 void SPoseFrom2d::initialize()
 {
+    m_cameras.clear();
     for(std::size_t idx = 0 ; idx < m_camera.size() ; ++idx)
     {
         auto camera = m_camera[idx].lock();
@@ -246,29 +229,27 @@ void SPoseFrom2d::initialize()
             {
                 for(std::uint8_t j = 0 ; j < 3 ; ++j)
                 {
-                    m_extrinsicMat.rotation.at<double>(i, j)  = extrinsicMatrix->getCoefficient(i, j);
-                    m_extrinsicMat.Matrix4x4.at<double>(i, j) = extrinsicMatrix->getCoefficient(i, j);
+                    m_extrinsicMat.rotation.at<double>(i, j)  = (*extrinsicMatrix)(i, j);
+                    m_extrinsicMat.Matrix4x4.at<double>(i, j) = (*extrinsicMatrix)(i, j);
                 }
             }
 
-            m_extrinsicMat.translation.at<double>(0, 0) = extrinsicMatrix->getCoefficient(0, 3);
-            m_extrinsicMat.translation.at<double>(1, 0) = extrinsicMatrix->getCoefficient(1, 3);
-            m_extrinsicMat.translation.at<double>(2, 0) = extrinsicMatrix->getCoefficient(2, 3);
+            m_extrinsicMat.translation.at<double>(0, 0) = (*extrinsicMatrix)(0, 3);
+            m_extrinsicMat.translation.at<double>(1, 0) = (*extrinsicMatrix)(1, 3);
+            m_extrinsicMat.translation.at<double>(2, 0) = (*extrinsicMatrix)(2, 3);
 
-            m_extrinsicMat.Matrix4x4.at<double>(0, 3) = extrinsicMatrix->getCoefficient(0, 3);
-            m_extrinsicMat.Matrix4x4.at<double>(1, 3) = extrinsicMatrix->getCoefficient(1, 3);
-            m_extrinsicMat.Matrix4x4.at<double>(2, 3) = extrinsicMatrix->getCoefficient(2, 3);
+            m_extrinsicMat.Matrix4x4.at<double>(0, 3) = (*extrinsicMatrix)(0, 3);
+            m_extrinsicMat.Matrix4x4.at<double>(1, 3) = (*extrinsicMatrix)(1, 3);
+            m_extrinsicMat.Matrix4x4.at<double>(2, 3) = (*extrinsicMatrix)(2, 3);
         }
 
         m_cameras.push_back(cam);
     }
-
-    m_isInitialized = true;
 }
 
 //-----------------------------------------------------------------------------
 
-const cv::Matx44f SPoseFrom2d::cameraPoseFromStereo(
+cv::Matx44f SPoseFrom2d::cameraPoseFromStereo(
     const SPoseFrom2d::Marker& _markerCam1,
     const SPoseFrom2d::Marker& _markerCam2
 ) const
@@ -290,7 +271,7 @@ const cv::Matx44f SPoseFrom2d::cameraPoseFromStereo(
 
 //-----------------------------------------------------------------------------
 
-const cv::Matx44f SPoseFrom2d::cameraPoseFromMono(const SPoseFrom2d::Marker& _markerCam1) const
+cv::Matx44f SPoseFrom2d::cameraPoseFromMono(const SPoseFrom2d::Marker& _markerCam1) const
 {
     cv::Matx44f pose =
         sight::geometry::vision::helper::cameraPoseMonocular(
@@ -306,9 +287,11 @@ const cv::Matx44f SPoseFrom2d::cameraPoseFromMono(const SPoseFrom2d::Marker& _ma
 
 service::IService::KeyConnectionsMap SPoseFrom2d::getAutoConnections() const
 {
-    KeyConnectionsMap connections;
-    connections.push(s_MARKERMAP_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    return connections;
+    return {
+        {s_MARKERMAP_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE},
+        {s_CAMERA_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_CAMERA_SLOT},
+        {s_CAMERA_INPUT, data::Camera::s_INTRINSIC_CALIBRATED_SIG, s_UPDATE_CAMERA_SLOT}
+    };
 }
 
 //-----------------------------------------------------------------------------
