@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,6 +26,7 @@
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
+#include <core/tools/Failed.hpp>
 
 #include <data/DicomSeries.hpp>
 #include <data/Series.hpp>
@@ -45,28 +46,21 @@ namespace sight::module::io::dicomweb
 
 //------------------------------------------------------------------------------
 
-static const service::IService::KeyType s_SERIES_IN = "selectedSeries";
+SSeriesPusher::SSeriesPusher() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SSeriesPusher::SSeriesPusher() noexcept :
-    m_isPushing(false)
-{
-}
-
-//------------------------------------------------------------------------------
-
-SSeriesPusher::~SSeriesPusher() noexcept
-{
-}
+SSeriesPusher::~SSeriesPusher() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SSeriesPusher::configuring()
 {
-    service::IService::ConfigType configuration = this->getConfigTree();
+    service::IService::ConfigType configuration = this->getConfiguration();
     //Parse server port and hostname
-    if(configuration.count("server"))
+    if(configuration.count("server") != 0U)
     {
         const std::string serverInfo               = configuration.get("server", "");
         const std::string::size_type splitPosition = serverInfo.find(':');
@@ -157,21 +151,25 @@ void SSeriesPusher::pushSeries()
 
     const auto seriesVector = m_selectedSeries.lock();
 
-    const std::vector<data::DicomSeries::sptr> dataVector = seriesVector->getDataContainer<data::DicomSeries>();
-
     // Connect to PACS
-    const std::size_t seriesVectorSize = seriesVector->size();
-    std::size_t nbSeriesSuccess        = 0;
-    for(const auto& dicomSeries : dataVector)
+    std::size_t nbSeriesSuccess = 0;
+    for(const auto& series : *seriesVector)
     {
+        const auto& dicomSeries = data::DicomSeries::dynamicCast(series);
+
+        if(!dicomSeries)
+        {
+            continue;
+        }
+
         nbSeriesSuccess++;
 
         data::DicomSeries::DicomContainerType dicomContainer = dicomSeries->getDicomContainer();
         const std::size_t dicomContainerSize                 = dicomContainer.size();
 
-        std::size_t nbInstanceSuccess = 0;
         try
         {
+            std::size_t nbInstanceSuccess = 0;
             for(const auto& item : dicomContainer)
             {
                 const core::memory::BufferObject::sptr bufferObj = item.second;
@@ -179,7 +177,7 @@ void SSeriesPusher::pushSeries()
                 const char* buffer     = static_cast<char*>(lockerDest.getBuffer());
                 const std::size_t size = bufferObj->getSize();
 
-                const QByteArray fileBuffer = QByteArray::fromRawData(buffer, size);
+                const QByteArray fileBuffer = QByteArray::fromRawData(buffer, int(size));
 
                 /// Url PACS
                 const std::string pacsServer("http://" + m_serverHostname + ":" + std::to_string(m_serverPort));
@@ -197,9 +195,9 @@ void SSeriesPusher::pushSeries()
 
                 if(dicomContainerSize == nbInstanceSuccess)
                 {
-                    this->displayMessage(
+                    sight::module::io::dicomweb::SSeriesPusher::displayMessage(
                         "Upload successful: " + std::to_string(nbSeriesSuccess) + "/"
-                        + std::to_string(seriesVectorSize),
+                        + std::to_string(seriesVector->size()),
                         false
                     );
                 }
@@ -212,7 +210,7 @@ void SSeriesPusher::pushSeries()
             << "Please check your configuration: \n"
             << "Pacs host name: " << m_serverHostname << "\n"
             << "Pacs port: " << m_serverPort << "\n";
-            this->displayMessage(ss.str(), true);
+            sight::module::io::dicomweb::SSeriesPusher::displayMessage(ss.str(), true);
             SIGHT_WARN(exception.what());
         }
     }
@@ -223,7 +221,7 @@ void SSeriesPusher::pushSeries()
 
 //------------------------------------------------------------------------------
 
-void SSeriesPusher::displayMessage(const std::string& message, bool error) const
+void SSeriesPusher::displayMessage(const std::string& message, bool error)
 {
     SIGHT_WARN_IF("Error: " + message, error);
     sight::ui::base::dialog::MessageDialog messageBox;
