@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,18 +24,16 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
+#include <core/os/TempPath.hpp>
 #include <core/thread/Timer.hpp>
-#include <core/tools/System.hpp>
 
 #include <data/Array.hpp>
 #include <data/Composite.hpp>
-#include <data/helper/Composite.hpp>
 #include <data/helper/MedicalImage.hpp>
-#include <data/helper/SeriesDB.hpp>
 #include <data/Image.hpp>
 #include <data/ImageSeries.hpp>
 #include <data/Integer.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/base/service/IReader.hpp>
 #include <io/http/exceptions/Base.hpp>
@@ -46,6 +44,8 @@
 #include <ui/base/Preferences.hpp>
 #include <ui/qt/container/QtContainer.hpp>
 
+#include <boost/lexical_cast.hpp>
+
 #include <QApplication>
 #include <QComboBox>
 #include <QHBoxLayout>
@@ -60,16 +60,13 @@ namespace sight::module::io::dicomweb
 
 //------------------------------------------------------------------------------
 
-SSliceIndexDicomPullerEditor::SSliceIndexDicomPullerEditor() noexcept :
-    m_delay(500)
-{
-}
+SSliceIndexDicomPullerEditor::SSliceIndexDicomPullerEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SSliceIndexDicomPullerEditor::~SSliceIndexDicomPullerEditor() noexcept
-{
-}
+SSliceIndexDicomPullerEditor::~SSliceIndexDicomPullerEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -77,34 +74,14 @@ void SSliceIndexDicomPullerEditor::configuring()
 {
     sight::ui::base::IGuiContainer::initialize();
 
-    core::runtime::ConfigurationElement::sptr config = m_configuration->findConfigurationElement("config");
-    SIGHT_ASSERT(
-        "The service module::io::dicomweb::SPacsConfigurationInitializer must have "
-        "a \"config\" element.",
-        config
-    );
+    const auto& config = this->getConfiguration();
 
-    bool success;
+    m_dicomReaderType = config.get<std::string>("config.<xmlattr>.dicomReader", m_dicomReaderType);
+    m_delay           = config.get<unsigned int>("config.<xmlattr>.delay", m_delay);
 
-    // Reader
-    std::tie(success, m_dicomReaderType) = config->getSafeAttributeValue("dicomReader");
-    SIGHT_ASSERT(
-        "It should be a \"dicomReader\" tag in the module::io::dicomweb::SSliceIndexDicomPullerEditor "
-        "config element.",
-        success
-    );
-
-    // Reader configuration
-    core::runtime::ConfigurationElement::sptr readerConfig = config->findConfigurationElement("readerConfig");
-    m_readerConfig =
-        (readerConfig && readerConfig->size() == 1) ? readerConfig->getElements()[0] : nullptr;
-
-    // Delay
-    std::string delayStr;
-    std::tie(success, delayStr) = config->getSafeAttributeValue("delay");
-    if(success)
+    if(const auto readerConfig = config.get_child_optional("readerConfig"); readerConfig.has_value())
     {
-        m_delay = boost::lexical_cast<unsigned int>(delayStr);
+        m_readerConfig = readerConfig.value();
     }
 
     if(m_delayTimer && m_delayTimer->isRunning())
@@ -113,9 +90,9 @@ void SSliceIndexDicomPullerEditor::configuring()
         m_delayTimer.reset();
     }
 
-    m_delayTimer = m_associatedWorker->createTimer();
+    m_delayTimer = this->worker()->createTimer();
     m_delayTimer->setFunction(
-        [ = ]()
+        [ =, this]()
         {
             this->triggerNewSlice();
         });
@@ -130,7 +107,7 @@ void SSliceIndexDicomPullerEditor::starting()
     sight::ui::base::IGuiContainer::create();
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* layout = new QHBoxLayout();
 
     const auto dicomSeries = m_series.lock();
     SIGHT_ASSERT("DicomSeries should not be null !", dicomSeries);
@@ -157,8 +134,8 @@ void SSliceIndexDicomPullerEditor::starting()
     // Connect the signals
     QObject::connect(m_sliceIndexSlider, SIGNAL(valueChanged(int)), this, SLOT(changeSliceIndex(int)));
 
-    // Create temporary SeriesDB
-    m_tempSeriesDB = data::SeriesDB::New();
+    // Create temporary SeriesSet
+    m_tmp_series_set = data::SeriesSet::New();
 
     // Create reader
     auto dicomReader = service::add<sight::io::base::service::IReader>(m_dicomReaderType);
@@ -167,12 +144,8 @@ void SSliceIndexDicomPullerEditor::starting()
                                                                       "sight::module::io::dicomweb::SSliceIndexDicomPullerEditor.",
         dicomReader
     );
-    dicomReader->setInOut(m_tempSeriesDB, sight::io::base::service::s_DATA_KEY);
-    if(m_readerConfig)
-    {
-        dicomReader->setConfiguration(m_readerConfig);
-    }
-
+    dicomReader->setInOut(m_tmp_series_set, sight::io::base::service::s_DATA_KEY);
+    dicomReader->setConfiguration(m_readerConfig);
     dicomReader->configure();
     dicomReader->start();
 
@@ -227,7 +200,7 @@ void SSliceIndexDicomPullerEditor::updating()
 
 //------------------------------------------------------------------------------
 
-void SSliceIndexDicomPullerEditor::changeSliceIndex(int)
+void SSliceIndexDicomPullerEditor::changeSliceIndex(int /*unused*/)
 {
     // Update text
     std::stringstream ss;
@@ -281,9 +254,9 @@ void SSliceIndexDicomPullerEditor::readImage(sight::data::DicomSeries& dicomSeri
         return;
     }
 
-    // Creates unique temporary folder, no need to check if exists before (see core::tools::System::getTemporaryFolder)
-    std::filesystem::path path    = core::tools::System::getTemporaryFolder("dicom");
-    std::filesystem::path tmpPath = path / "tmp";
+    // Creates unique temporary folder
+    core::os::TempDir tmpDir;
+    std::filesystem::path tmpPath = tmpDir / "tmp";
 
     SIGHT_INFO("Create " + tmpPath.string());
     std::filesystem::create_directories(tmpPath);
@@ -323,50 +296,45 @@ void SSliceIndexDicomPullerEditor::readImage(sight::data::DicomSeries& dicomSeri
     //Copy image
     data::ImageSeries::sptr imageSeries;
 
-    if(m_tempSeriesDB->getContainer().size() > 0)
+    if(!m_tmp_series_set->empty())
     {
-        imageSeries = data::ImageSeries::dynamicCast(*(m_tempSeriesDB->getContainer().begin()));
+        imageSeries = data::ImageSeries::dynamicCast(m_tmp_series_set->front());
     }
 
     if(imageSeries)
     {
-        data::Image::sptr newImage      = imageSeries->getImage();
-        const data::Image::Size newSize = newImage->getSize();
+        const data::Image::Size newSize = imageSeries->getSize();
 
         m_frontalIndex->setValue(static_cast<int>(newSize[0] / 2));
         m_sagittalIndex->setValue(static_cast<int>(newSize[1] / 2));
 
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::AXIAL,
             m_axialIndex->value()
         );
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::AXIAL,
             m_frontalIndex->value()
         );
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::AXIAL,
             m_sagittalIndex->value()
         );
 
-        this->setOutput("image", newImage);
+        this->setOutput("image", imageSeries);
     }
-
-    std::error_code ec;
-    std::filesystem::remove_all(path, ec);
-    SIGHT_ERROR_IF("remove_all error for path " + path.string() + ": " + ec.message(), ec.value());
 }
 
 //------------------------------------------------------------------------------
 
 void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomSeries)
 {
-    service::IService::ConfigType configuration = this->getConfigTree();
+    service::IService::ConfigType configuration = this->getConfiguration();
     //Parse server port and hostname
-    if(configuration.count("server"))
+    if(configuration.count("server") != 0U)
     {
         const std::string serverInfo               = configuration.get("server", "");
         const std::string::size_type splitPosition = serverInfo.find(':');
@@ -407,7 +375,7 @@ void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomS
         std::size_t selectedSliceIndex = static_cast<std::size_t>(m_sliceIndexSlider->value())
                                          + dicomSeries.getFirstInstanceNumber();
 
-        std::string seriesInstanceUID = dicomSeries.getInstanceUID();
+        std::string seriesInstanceUID = dicomSeries.getSeriesInstanceUID();
 
         // Find Series according to SeriesInstanceUID
         QJsonObject query;
@@ -438,19 +406,18 @@ void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomS
             << "Pacs host name: " << m_serverHostname << "\n"
             << "Pacs port: " << m_serverPort << "\n";
 
-            this->displayErrorMessage(ss.str());
+            sight::module::io::dicomweb::SSliceIndexDicomPullerEditor::displayErrorMessage(ss.str());
             SIGHT_WARN(exception.what());
         }
         QJsonDocument jsonResponse    = QJsonDocument::fromJson(seriesAnswer);
         const QJsonArray& seriesArray = jsonResponse.array();
 
         // Should be one Series, so take the first of the array.
-        const std::string& seriesUID = seriesArray.at(0).toString().toStdString();
+        const std::string seriesUID(seriesArray.at(0).toString().toStdString());
         // GET all Instances by Series.
-        const std::string& instancesUrl(pacsServer + "/series/" + seriesUID);
+        const std::string instancesUrl(pacsServer + "/series/" + seriesUID);
 
-        const QByteArray& instancesAnswer =
-            m_clientQt.get(sight::io::http::Request::New(instancesUrl));
+        const QByteArray& instancesAnswer = m_clientQt.get(sight::io::http::Request::New(instancesUrl));
         jsonResponse = QJsonDocument::fromJson(instancesAnswer);
         const QJsonObject& jsonObj       = jsonResponse.object();
         const QJsonArray& instancesArray = jsonObj["Instances"].toArray();
@@ -459,7 +426,7 @@ void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomS
 
         // GET frame by Slice.
         std::string instancePath;
-        const std::string& instanceUrl(pacsServer + "/instances/" + instanceUID + "/file");
+        const std::string instanceUrl(pacsServer + "/instances/" + instanceUID + "/file");
         try
         {
             instancePath = m_clientQt.getFile(sight::io::http::Request::New(instanceUrl));
@@ -470,7 +437,7 @@ void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomS
             ss << "Content not found:  \n"
             << "Unable download the DICOM instance. \n";
 
-            this->displayErrorMessage(ss.str());
+            sight::module::io::dicomweb::SSliceIndexDicomPullerEditor::displayErrorMessage(ss.str());
             SIGHT_WARN(exception.what());
         }
 
@@ -482,14 +449,14 @@ void SSliceIndexDicomPullerEditor::pullInstance(sight::data::DicomSeries& dicomS
     {
         std::stringstream ss;
         ss << "Unknown error.";
-        this->displayErrorMessage(ss.str());
+        sight::module::io::dicomweb::SSliceIndexDicomPullerEditor::displayErrorMessage(ss.str());
         SIGHT_WARN(exception.what());
     }
 }
 
 //------------------------------------------------------------------------------
 
-void SSliceIndexDicomPullerEditor::displayErrorMessage(const std::string& message) const
+void SSliceIndexDicomPullerEditor::displayErrorMessage(const std::string& message)
 {
     SIGHT_WARN("Error: " + message);
     sight::ui::base::dialog::MessageDialog messageBox;
