@@ -43,31 +43,24 @@ namespace core::thread
 
 class Timer;
 
-}
+} // namespace core::thread
 
 namespace io::base::service
 {
 
 class IReader;
 
-}
+} // namespace io::base::service
 
 namespace data
 {
 
 class Integer;
-class SeriesDB;
+class SeriesSet;
 
-}
+} // namespace data
 
-namespace core::runtime
-{
-
-struct ConfigurationElement;
-
-}
-
-}
+} // namespace sight
 
 namespace sight::module::io::dicomweb
 {
@@ -89,7 +82,7 @@ public:
     /**
      * @brief Destructor
      */
-    MODULE_IO_DICOMWEB_API virtual ~SSliceIndexDicomPullerEditor() noexcept;
+    MODULE_IO_DICOMWEB_API ~SSliceIndexDicomPullerEditor() noexcept override;
 
 private Q_SLOTS:
 
@@ -130,7 +123,7 @@ private:
     /**
      * @brief Displays a dialog box with the error message
      */
-    void displayErrorMessage(const std::string& message) const;
+    static void displayErrorMessage(const std::string& message);
 
     /// Slice index slider
     QPointer<QSlider> m_sliceIndexSlider;
@@ -139,7 +132,7 @@ private:
     QPointer<QLineEdit> m_sliceIndexLineEdit;
 
     /// Number of instances
-    std::size_t m_numberOfSlices;
+    std::size_t m_numberOfSlices {};
 
     /// IODICOMWEB Reader
     std::string m_dicomReaderType;
@@ -150,8 +143,8 @@ private:
     /// Image Key
     std::string m_imageKey;
 
-    /// Temporary SeriesDB
-    SPTR(data::SeriesDB) m_tempSeriesDB;
+    /// Temporary SeriesSet
+    SPTR(data::SeriesSet) m_tmp_series_set;
 
     /// Axial slice index
     SPTR(data::Integer) m_axialIndex;
@@ -167,10 +160,10 @@ private:
     SPTR(core::thread::Timer) m_delayTimer;
 
     /// Delay
-    unsigned int m_delay;
+    unsigned int m_delay {500};
 
     /// Optional configuration to set to reader implementation
-    SPTR(core::runtime::ConfigurationElement) m_readerConfig;
+    IService::ConfigType m_readerConfig;
 
     /// Server hostname preference key
     std::string m_serverHostnameKey;
