@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,7 +26,7 @@
 #include <data/String.hpp>
 
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/base/Preferences.hpp>
 
@@ -45,15 +45,13 @@ static const std::string s_RetrieveMethod("retrieveMethod");
 
 //------------------------------------------------------------------------------
 
-SPacsConfigurationInitializer::SPacsConfigurationInitializer() noexcept
-{
-}
+SPacsConfigurationInitializer::SPacsConfigurationInitializer() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SPacsConfigurationInitializer::~SPacsConfigurationInitializer() noexcept
-{
-}
+SPacsConfigurationInitializer::~SPacsConfigurationInitializer() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -66,7 +64,7 @@ std::string SPacsConfigurationInitializer::getKey(const std::string& subKey) con
 
 void SPacsConfigurationInitializer::configuring()
 {
-    const ConfigType configTree = this->getConfigTree();
+    const ConfigType configTree = this->getConfiguration();
     const auto config           = configTree.get_child("config.<xmlattr>");
 
     // Local application title.
@@ -79,11 +77,11 @@ void SPacsConfigurationInitializer::configuring()
     m_SCPAppEntityTitle = config.get<std::string>(s_PacsApplicationTitle);
 
     // Pacs port.
-    const std::string pacsApplicationPort = config.get<std::string>(s_PacsApplicationPort);
+    const auto pacsApplicationPort = config.get<std::string>(s_PacsApplicationPort);
     m_SCPPort = static_cast<decltype(m_SCPPort)>(std::stoi(pacsApplicationPort));
 
     // Retrieve Method.
-    const std::string retrieveMethod = config.get<std::string>(s_RetrieveMethod);
+    const auto retrieveMethod = config.get<std::string>(s_RetrieveMethod);
     m_retrieveMethod = (retrieveMethod == "MOVE")
                        ? (sight::io::dimse::data::PacsConfiguration::MOVE_RETRIEVE_METHOD)
                        : (sight::io::dimse::data::PacsConfiguration::GET_RETRIEVE_METHOD);
@@ -92,7 +90,7 @@ void SPacsConfigurationInitializer::configuring()
     m_moveAppEntityTitle = config.get<std::string>(s_MoveApplicationTitle);
 
     // Move application port.
-    const std::string moveApplicationPort = config.get<std::string>(s_MoveApplicationPort);
+    const auto moveApplicationPort = config.get<std::string>(s_MoveApplicationPort);
     m_movePort = static_cast<decltype(m_movePort)>(std::stoi(moveApplicationPort));
 
     // Preference Key.
@@ -123,7 +121,7 @@ void SPacsConfigurationInitializer::starting()
                 preferences.get(getKey(s_RetrieveMethod), static_cast<int>(m_retrieveMethod))
             );
         }
-        catch(const ui::base::PreferencesDisabled& e)
+        catch(const ui::base::PreferencesDisabled& /*e*/)
         {
             // Nothing to do..
         }
@@ -144,7 +142,11 @@ service::IService::KeyConnectionsMap SPacsConfigurationInitializer::getAutoConne
 {
     service::IService::KeyConnectionsMap connections;
 
-    connections.push(s_CONFIG_INOUT, sight::io::dimse::data::PacsConfiguration::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(
+        s_CONFIG_INOUT,
+        sight::io::dimse::data::PacsConfiguration::s_MODIFIED_SIG,
+        IService::slots::s_UPDATE
+    );
 
     return connections;
 }
@@ -189,7 +191,7 @@ void SPacsConfigurationInitializer::updating()
             preferences.put(getKey(s_MoveApplicationPort), m_movePort);
             preferences.put(getKey(s_RetrieveMethod), static_cast<int>(m_retrieveMethod));
         }
-        catch(const ui::base::PreferencesDisabled& e)
+        catch(const ui::base::PreferencesDisabled& /*e*/)
         {
             // Nothing to do..
         }
