@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -78,7 +78,7 @@ public:
     MODULE_IO_DIMSE_API SPacsConfigurationInitializer() noexcept;
 
     /// Destroyes the service.
-    MODULE_IO_DIMSE_API virtual ~SPacsConfigurationInitializer() noexcept;
+    MODULE_IO_DIMSE_API ~SPacsConfigurationInitializer() noexcept override;
 
 protected:
 
@@ -93,7 +93,7 @@ protected:
      * @return A map of each proposed connection.
      *
      * Connect sight::io::dimse::data::PacsConfiguration::s_MODIFIED_SIG of s_CONFIG_INOUT to
-     *::module::io::dimse::SPacsConfigurationInitializer::s_UPDATE_SLOT.
+     *::module::io::dimse::SPacsConfigurationInitializer::IService::slots::s_UPDATE.
      */
     MODULE_IO_DIMSE_API service::IService::KeyConnectionsMap getAutoConnections() const final;
 
@@ -119,10 +119,12 @@ private:
     std::string m_SCPHostName;
 
     /// Defines the SCP port (server port).
-    unsigned short m_SCPPort {0};
+    std::uint16_t m_SCPPort {0};
 
     /// Defines the request mode, GET or MOVE. Usually, most SCU use the C-MOVE method.
-    sight::io::dimse::data::PacsConfiguration::RETRIEVE_METHOD m_retrieveMethod;
+    sight::io::dimse::data::PacsConfiguration::RETRIEVE_METHOD m_retrieveMethod {sight::io::dimse::data::
+                                                                                 PacsConfiguration::MOVE_RETRIEVE_METHOD
+    };
 
     /**
      * @brief Defines the move AET. This AET is used to receive C-MOVE responses.
@@ -135,7 +137,7 @@ private:
     std::string m_moveAppEntityTitle;
 
     /// Defines the move port. This port is use to receive C-MOVE responses.
-    unsigned short m_movePort {0};
+    std::uint16_t m_movePort {0};
 
     /// Defines the key to save/load preferences.
     std::string m_preferenceKey;
