@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,10 +22,10 @@
 
 #include "SQueryEditor.hpp"
 
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <data/DicomSeries.hpp>
-#include <data/helper/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/dimse/exceptions/Base.hpp>
 #include <io/dimse/helper/Series.hpp>
@@ -53,19 +53,10 @@ static const std::string s_ICON_PATH_CONFIG   = "icon";
 static const std::string s_ICON_WIDTH_CONFIG  = "width";
 static const std::string s_ICON_HEIGHT_CONFIG = "height";
 
-static const service::IService::KeyType s_PACS_INPUT = "pacsConfig";
-
-static const service::IService::KeyType s_SERIESDB_INOUT = "seriesDB";
-
 //------------------------------------------------------------------------------
 
-SQueryEditor::SQueryEditor() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
-SQueryEditor::~SQueryEditor() noexcept
+SQueryEditor::SQueryEditor() noexcept :
+    service::INotifier(m_signals)
 {
 }
 
@@ -75,7 +66,7 @@ void SQueryEditor::configuring()
 {
     sight::ui::base::IGuiContainer::initialize();
 
-    const auto configTree = this->getConfigTree();
+    const auto configTree = this->getConfiguration();
     const auto config     = configTree.get_child_optional("config.<xmlattr>");
     if(config)
     {
@@ -102,7 +93,7 @@ void SQueryEditor::starting()
     sight::ui::base::IGuiContainer::create();
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
-    QVBoxLayout* const mainLayout = new QVBoxLayout();
+    auto* const mainLayout = new QVBoxLayout();
 
     m_searchEdit = new QLineEdit();
     m_searchEdit->setPlaceholderText("Find by name, birth date, ID, date, description or modality");
@@ -114,11 +105,11 @@ void SQueryEditor::starting()
         m_searchButton->setIcon(QIcon(QString::fromStdString(m_iconPath.string())));
         if(m_iconWidth > 0 && m_iconHeight > 0)
         {
-            m_searchButton->setIconSize(QSize(m_iconWidth, m_iconHeight));
+            m_searchButton->setIconSize(QSize(int(m_iconWidth), int(m_iconHeight)));
         }
     }
 
-    QHBoxLayout* const search_layout = new QHBoxLayout();
+    auto* const search_layout = new QHBoxLayout();
     search_layout->setObjectName("SQueryEditor_search");
 
     search_layout->addWidget(m_searchEdit);
@@ -130,25 +121,25 @@ void SQueryEditor::starting()
 
     if(m_advanced)
     {
-        QHBoxLayout* const advancedLayout = new QHBoxLayout();
+        auto* const advancedLayout = new QHBoxLayout();
         advancedLayout->setObjectName("SQueryEditor_advanced");
 
-        QVBoxLayout* const labelLayout = new QVBoxLayout();
+        auto* const labelLayout = new QVBoxLayout();
         labelLayout->setObjectName("SQueryEditor_labels");
 
-        QLabel* const dateLabel = new QLabel("Date of the study");
+        auto* const dateLabel = new QLabel("Date of the study");
         dateLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const nameLabel = new QLabel("Patient's name");
+        auto* const nameLabel = new QLabel("Patient's name");
         nameLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const birthDateLabel = new QLabel("Patient's birth date");
+        auto* const birthDateLabel = new QLabel("Patient's birth date");
         birthDateLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const idLabel = new QLabel("Patient's ID");
+        auto* const idLabel = new QLabel("Patient's ID");
         idLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const seriesUIDLabel = new QLabel("Series's ID");
+        auto* const seriesUIDLabel = new QLabel("Series' ID");
         seriesUIDLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const descriptionLabel = new QLabel("Series's description");
+        auto* const descriptionLabel = new QLabel("Series' description");
         descriptionLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const modalityLabel = new QLabel("Modality");
+        auto* const modalityLabel = new QLabel("Modality");
         modalityLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
         labelLayout->addWidget(dateLabel);
@@ -160,19 +151,19 @@ void SQueryEditor::starting()
         labelLayout->addWidget(descriptionLabel);
         labelLayout->addWidget(modalityLabel);
 
-        QHBoxLayout* const dateLayout = new QHBoxLayout();
+        auto* const dateLayout = new QHBoxLayout();
 
-        QVBoxLayout* const dateLabelLayout = new QVBoxLayout();
+        auto* const dateLabelLayout = new QVBoxLayout();
 
-        QLabel* const fromLabel = new QLabel("from");
+        auto* const fromLabel = new QLabel("from");
         fromLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
-        QLabel* const toLabel = new QLabel("to");
+        auto* const toLabel = new QLabel("to");
         toLabel->setAlignment(Qt::AlignRight | Qt::AlignVCenter);
 
         dateLabelLayout->addWidget(fromLabel);
         dateLabelLayout->addWidget(toLabel);
 
-        QVBoxLayout* const dateEditLayout = new QVBoxLayout();
+        auto* const dateEditLayout = new QVBoxLayout();
 
         m_beginStudyDateEdit = new QDateEdit();
         m_beginStudyDateEdit->setDate(QDate());
@@ -186,19 +177,19 @@ void SQueryEditor::starting()
         dateLayout->addLayout(dateLabelLayout, 0);
         dateLayout->addLayout(dateEditLayout, 1);
 
-        QVBoxLayout* const editLayout = new QVBoxLayout();
+        auto* const editLayout = new QVBoxLayout();
         editLayout->setObjectName("SQueryEditor_editors");
 
         m_patientNameEdit = new QLineEdit();
 
-        QHBoxLayout* const birthDateEditLayout = new QHBoxLayout();
+        auto* const birthDateEditLayout = new QHBoxLayout();
 
         m_birthDateEdit = new QDateEdit();
         m_birthDateEdit->setDate(QDate());
         m_birthDateEdit->setDisplayFormat("MM.dd.yyyy");
         m_birthDateEdit->setEnabled(false);
 
-        QCheckBox* const birthDateEnabler = new QCheckBox();
+        auto* const birthDateEnabler = new QCheckBox();
 
         birthDateEditLayout->addWidget(birthDateEnabler, 0);
         birthDateEditLayout->addWidget(m_birthDateEdit, 1);
@@ -265,11 +256,11 @@ void SQueryEditor::executeQueryAsync()
 {
     if(!m_isQuerying)
     {
-        m_requestWorker->post(std::bind(&module::io::dimse::SQueryEditor::executeQuery, this));
+        m_requestWorker->post([this](auto&& ...){executeQuery();});
     }
     else
     {
-        this->notify(NotificationType::INFO, "Already querying");
+        this->INotifier::info("Already querying");
         return;
     }
 }
@@ -298,7 +289,7 @@ void SQueryEditor::executeQuery()
     catch(const sight::io::dimse::exceptions::Base& _e)
     {
         SIGHT_ERROR("Can't establish a connection with the PACS: " + std::string(_e.what()));
-        this->notify(NotificationType::FAILURE, "Can't connect to the PACS");
+        this->INotifier::failure("Can't connect to the PACS");
         m_isQuerying = false;
         return;
     }
@@ -321,15 +312,15 @@ void SQueryEditor::executeQuery()
     try
     {
         // Execute find requests.
-        const std::string searchValue      = standardise(m_searchEdit->text().toStdString());
-        std::string beginDataSearchValue   = "";
-        std::string endDateSearchValue     = "";
-        std::string nameSearchValue        = "";
-        std::string birthDateSearchValue   = "";
-        std::string patientUIDSearchValue  = "";
-        std::string seriesUIDSearchValue   = "";
-        std::string descriptionSearchValue = "";
-        std::string modalitySearchValue    = "";
+        const std::string searchValue = standardise(m_searchEdit->text().toStdString());
+        std::string beginDataSearchValue;
+        std::string endDateSearchValue;
+        std::string nameSearchValue;
+        std::string birthDateSearchValue;
+        std::string patientUIDSearchValue;
+        std::string seriesUIDSearchValue;
+        std::string descriptionSearchValue;
+        std::string modalitySearchValue;
 
         if(m_advanced)
         {
@@ -402,12 +393,7 @@ void SQueryEditor::executeQuery()
                     {
                         OFString data;
                         _res->m_dataset->findAndGetOFStringArray(DCM_SeriesInstanceUID, data);
-                        if(data.compare(seriesUID) == 0)
-                        {
-                            return true;
-                        }
-
-                        return false;
+                        return data == seriesUID;
                     });
                 // If it's not already added, we check if the series match advanced request.
                 if(findedIt == seriesResponse.end())
@@ -508,26 +494,26 @@ void SQueryEditor::executeQuery()
             ofSeriesResponse.push_back(res);
         }
 
-        data::SeriesDB::ContainerType series = sight::io::dimse::helper::Series::toFwMedData(ofSeriesResponse);
+        data::SeriesSet::container_type series = sight::io::dimse::helper::Series::toFwMedData(ofSeriesResponse);
 
         // Clean memory.
         sight::io::dimse::helper::Series::releaseResponses(responses);
 
         // Check whether the instance number start at 1 or 0.
-        for(data::Series::sptr s : series)
+        for(const data::Series::sptr& s : series)
         {
             data::DicomSeries::sptr dicomSeries = data::DicomSeries::dynamicCast(s);
             SIGHT_ASSERT("The PACS response should contain only DicomSeries", dicomSeries);
-            const std::string instanceUID = seriesEnquirer->findSOPInstanceUID(dicomSeries->getInstanceUID(), 0);
+            const std::string instanceUID = seriesEnquirer->findSOPInstanceUID(dicomSeries->getSeriesInstanceUID(), 0);
             dicomSeries->setFirstInstanceNumber((instanceUID.empty() ? 1 : 0));
         }
 
-        this->updateSeriesDB(series);
+        this->updateSeriesSet(series);
     }
     catch(const sight::io::dimse::exceptions::Base& _e)
     {
         SIGHT_ERROR("Can't execute query to the PACS: " + std::string(_e.what()));
-        this->notify(NotificationType::FAILURE, "Can't execute query");
+        this->INotifier::failure("Can't execute query");
     }
 
     if(seriesEnquirer->isConnectedToPacs())
@@ -540,31 +526,26 @@ void SQueryEditor::executeQuery()
 
 //------------------------------------------------------------------------------
 
-void SQueryEditor::updateSeriesDB(const data::SeriesDB::ContainerType& _series)
+void SQueryEditor::updateSeriesSet(const data::SeriesSet::container_type& _series)
 {
-    const auto seriesDB = m_seriesDB.lock();
+    const auto series_set     = m_series_set.lock();
+    const auto scoped_emitter = series_set->scoped_emit();
 
-    data::helper::SeriesDB seriesDBHelper(*seriesDB);
+    // Delete old series from the SeriesSet.
+    series_set->clear();
 
-    // Delete old series from the SeriesDB.
-    seriesDBHelper.clear();
-
-    // Push new series in the SeriesDB.
-    for(const data::Series::sptr& s : _series)
+    // Push new series in the SeriesSet.
+    for(const auto& s : _series)
     {
-        data::DicomSeries::sptr dicomSeries = data::DicomSeries::dynamicCast(s);
-        seriesDBHelper.add(dicomSeries);
+        series_set->push_back(data::DicomSeries::dynamicCast(s));
     }
-
-    // Notify the SeriesDB.
-    seriesDBHelper.notify();
 }
 
 //------------------------------------------------------------------------------
 
 void SQueryEditor::enableBirthDateEdit(int _enable)
 {
-    m_birthDateEdit->setEnabled(_enable);
+    m_birthDateEdit->setEnabled(_enable != 0);
 }
 
 } // namespace sight::module::io::dimse
