@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,9 +24,9 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
-#include <core/tools/System.hpp>
+#include <core/os/TempPath.hpp>
 
-#include <data/helper/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/dimse/exceptions/Base.hpp>
 #include <io/dimse/helper/Series.hpp>
@@ -48,7 +48,8 @@ static const core::com::Slots::SlotKeyType s_REMOVE_SERIES_SLOT = "removeSeries"
 static const std::string s_DICOM_READER_CONFIG = "dicomReader";
 static const std::string s_READER_CONFIG       = "readerConfig";
 
-SSeriesPuller::SSeriesPuller() noexcept
+SSeriesPuller::SSeriesPuller() noexcept :
+    service::INotifier(m_signals)
 {
     m_slotStoreInstance = this->newSlot(
         sight::io::dimse::SeriesRetriever::s_PROGRESS_CALLBACK_SLOT,
@@ -65,15 +66,9 @@ SSeriesPuller::SSeriesPuller() noexcept
 
 //------------------------------------------------------------------------------
 
-SSeriesPuller::~SSeriesPuller() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void SSeriesPuller::configuring()
 {
-    const ConfigType config = this->getConfigTree().get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration().get_child("config.<xmlattr>");
 
     m_dicomReaderImplementation = config.get(s_DICOM_READER_CONFIG, m_dicomReaderImplementation);
     SIGHT_ERROR_IF("'" + s_DICOM_READER_CONFIG + "' attribute not set", m_dicomReaderImplementation.empty())
@@ -89,15 +84,15 @@ void SSeriesPuller::starting()
     m_requestWorker = core::thread::Worker::New();
 
     // Create the DICOM reader.
-    m_seriesDB = data::SeriesDB::New();
+    m_series_set = data::SeriesSet::New();
 
     m_dicomReader = this->registerService<sight::io::base::service::IReader>(m_dicomReaderImplementation);
     SIGHT_ASSERT("Unable to create a reader of type '" + m_dicomReaderImplementation + "'", m_dicomReader);
     m_dicomReader->setWorker(m_requestWorker);
-    m_dicomReader->setInOut(m_seriesDB, sight::io::base::service::s_DATA_KEY);
+    m_dicomReader->setInOut(m_series_set, sight::io::base::service::s_DATA_KEY);
     if(!m_readerConfig.empty())
     {
-        core::runtime::ConfigurationElement::csptr readerConfig =
+        const auto readerConfig =
             service::extension::Config::getDefault()->getServiceConfig(
                 m_readerConfig,
                 "sight::io::base::service::IReader"
@@ -105,10 +100,10 @@ void SSeriesPuller::starting()
 
         SIGHT_ASSERT(
             "No service configuration " << m_readerConfig << " for sight::io::base::service::IReader",
-            readerConfig
+            !readerConfig.empty()
         );
 
-        m_dicomReader->setConfiguration(core::runtime::ConfigurationElement::constCast(readerConfig));
+        m_dicomReader->setConfiguration(readerConfig);
     }
 
     m_dicomReader->configure();
@@ -124,11 +119,11 @@ void SSeriesPuller::updating()
 
     if(selectedSeries->empty())
     {
-        this->notify(NotificationType::INFO, "No series selected");
+        this->INotifier::info("No series selected");
     }
     else
     {
-        m_requestWorker->post(std::bind(&SSeriesPuller::pullSeries, this));
+        m_requestWorker->post([this](auto&& ...){pullSeries();});
     }
 }
 
@@ -159,35 +154,36 @@ void SSeriesPuller::pullSeries()
 
     // Retrieve data.
     const auto selectedSeries = m_selectedSeries.lock();
-    const auto localEnd       = m_localSeries.end();
 
     // Find which selected series must be pulled.
     DicomSeriesContainerType pullSeriesVector;
     DicomSeriesContainerType selectedSeriesVector;
-    data::Vector::ConstIteratorType it          = selectedSeries->begin();
-    const data::Vector::ConstIteratorType itEnd = selectedSeries->end();
-    for( ; it != itEnd ; ++it)
+    for(const auto& object : *selectedSeries)
     {
         // Check that the series is a DICOM series.
-        data::DicomSeries::sptr series = data::DicomSeries::dynamicCast(*it);
+        const auto& series = data::DicomSeries::dynamicCast(object);
 
         // Check if the series must be pulled.
-        if(series && std::find(m_localSeries.begin(), m_localSeries.end(), series->getInstanceUID()) == localEnd)
+        if(series)
         {
-            // Add series in the pulling series map.
-            m_pullingDicomSeriesMap[series->getInstanceUID()] = series;
+            const auto& seriesInstanceUID = series->getSeriesInstanceUID();
+            if(m_localSeries.find(seriesInstanceUID) == m_localSeries.cend())
+            {
+                // Add series in the pulling series map.
+                m_pullingDicomSeriesMap[seriesInstanceUID] = series;
 
-            pullSeriesVector.push_back(series);
-            m_instanceCount += series->numInstances();
+                pullSeriesVector.push_back(series);
+                m_instanceCount += series->numInstances();
+            }
+
+            selectedSeriesVector.push_back(series);
         }
-
-        selectedSeriesVector.push_back(series);
     }
 
     // Pull series.
     if(!pullSeriesVector.empty())
     {
-        this->notify(NotificationType::INFO, "Downloading series...");
+        this->INotifier::info("Downloading series...");
 
         // Notify Progress Dialog.
         m_sigProgressStarted->asyncEmit(m_progressbarId);
@@ -212,7 +208,7 @@ void SSeriesPuller::pullSeries()
         catch(const sight::io::dimse::exceptions::Base& _e)
         {
             SIGHT_ERROR("Unable to establish a connection with the PACS: " + std::string(_e.what()));
-            this->notify(NotificationType::FAILURE, "Unable to connect to the PACS");
+            this->INotifier::failure("Unable to connect to the PACS");
             return;
         }
 
@@ -241,7 +237,7 @@ void SSeriesPuller::pullSeries()
                 );
 
                 // Start series retriever in a worker.
-                worker->post(std::bind(&sight::io::dimse::SeriesRetriever::start, seriesRetriever));
+                worker->post([seriesRetriever](auto&& ...){seriesRetriever->start();});
 
                 // Pull Selected Series.
                 seriesEnquirer->pullSeriesUsingMoveRetrieveMethod(
@@ -263,7 +259,7 @@ void SSeriesPuller::pullSeries()
         catch(const sight::io::dimse::exceptions::Base& _e)
         {
             SIGHT_ERROR("Unable to execute query to the PACS: " + std::string(_e.what()));
-            this->notify(NotificationType::FAILURE, "Unable to execute query");
+            this->INotifier::failure("Unable to execute query");
             success = false;
         }
 
@@ -279,19 +275,19 @@ void SSeriesPuller::pullSeries()
     }
     else
     {
-        this->notify(NotificationType::INFO, "Series already downloaded");
+        this->INotifier::info("Series already downloaded");
         return;
     }
 
     // Read series if there is no error.
     if(success)
     {
-        this->notify(NotificationType::SUCCESS, "Series downloaded");
+        this->INotifier::success("Series downloaded");
         this->readLocalSeries(selectedSeriesVector);
     }
     else
     {
-        this->notify(NotificationType::FAILURE, "Series download failed");
+        this->INotifier::failure("Series download failed");
     }
 
     // Notify Progress Dialog.
@@ -302,60 +298,56 @@ void SSeriesPuller::pullSeries()
 
 void SSeriesPuller::readLocalSeries(DicomSeriesContainerType _selectedSeries)
 {
-    const auto destinationSeriesDB = m_destSeriesDB.lock();
+    const auto dest_series_set = m_destSeriesSet.lock();
 
-    // Read only series that are not in the series DB.
-    std::vector<std::string> alreadyLoadedSeries =
-        sight::io::dimse::helper::Series::toSeriesInstanceUIDContainer(destinationSeriesDB->getContainer());
+    // Read only series that are not in the series set.
 
     // Create temporary series helper.
-    data::helper::SeriesDB readerSeriesHelper(*m_seriesDB);
+    const auto scoped_emitter = m_series_set->scoped_emit();
 
-    for(const data::Series::sptr& series : _selectedSeries)
+    for(const auto& series : _selectedSeries)
     {
-        const std::string modality = series->getModality();
+        const std::string& modality = series->getModality();
         if(modality != "CT" && modality != "MR" && modality != "XA")
         {
-            this->notify(NotificationType::INFO, "Unable to read the modality '" + modality + "'");
+            this->INotifier::info("Unable to read the modality '" + modality + "'");
             return;
         }
 
-        const std::string selectedSeriesUID = series->getInstanceUID();
+        const std::string& selectedSeriesUID = series->getSeriesInstanceUID();
 
         // Check if the series is loaded.
-        if(std::find(
-               alreadyLoadedSeries.begin(),
-               alreadyLoadedSeries.end(),
-               selectedSeriesUID
-           ) == alreadyLoadedSeries.end())
+        if(std::find_if(
+               dest_series_set->cbegin(),
+               dest_series_set->cend(),
+               [&selectedSeriesUID](const data::Series::sptr& already_loaded_series)
+            {
+                return already_loaded_series->getSeriesInstanceUID() == selectedSeriesUID;
+            }) == dest_series_set->cend())
         {
-            this->notify(NotificationType::INFO, "Reading series...");
+            this->INotifier::info("Reading series...");
 
             // Clear temporary series.
-            readerSeriesHelper.clear();
+            m_series_set->clear();
 
-            std::filesystem::path path = core::tools::System::getTemporaryFolder() / "dicom/";
+            const auto& path = core::os::TempDir::sharedDirectory() / "dicom/";
             m_dicomReader->setFolder(path.string() + selectedSeriesUID + "/");
             m_dicomReader->update();
 
             // Merge series.
-            if(!m_dicomReader->hasFailed() && m_seriesDB->getContainer().size() > 0)
+            if(!m_dicomReader->hasFailed() && !m_series_set->empty())
             {
-                this->notify(NotificationType::SUCCESS, "Series read");
+                this->INotifier::success("Series read");
 
                 // Add the series to the local series vector.
-                if(std::find(m_localSeries.begin(), m_localSeries.end(), selectedSeriesUID) == m_localSeries.end())
-                {
-                    m_localSeries.push_back(selectedSeriesUID);
-                }
+                m_localSeries.insert(selectedSeriesUID);
 
-                data::helper::SeriesDB seriesHelper(*destinationSeriesDB);
-                seriesHelper.merge(m_seriesDB);
-                seriesHelper.notify();
+                const auto destination_notifier = dest_series_set->scoped_emit();
+                std::copy(m_series_set->cbegin(), m_series_set->cend(), sight::data::inserter(*dest_series_set));
             }
             else
             {
-                this->notify(NotificationType::FAILURE, "Failed to read series");
+                this->INotifier::failure("Failed to read series");
             }
         }
     }
@@ -363,19 +355,16 @@ void SSeriesPuller::readLocalSeries(DicomSeriesContainerType _selectedSeries)
 
 //------------------------------------------------------------------------------
 
-void SSeriesPuller::removeSeries(data::SeriesDB::ContainerType _removedSeries)
+void SSeriesPuller::removeSeries(data::SeriesSet::container_type _removedSeries)
 {
     // Find which series to delete
     if(!m_localSeries.empty())
     {
         for(const auto& series : _removedSeries)
         {
-            const auto it = std::find(m_localSeries.begin(), m_localSeries.end(), series->getInstanceUID());
-            if(it != m_localSeries.end())
+            if(m_localSeries.erase(series->getSeriesInstanceUID()) > 0)
             {
-                m_localSeries.erase(it);
-
-                this->notify(NotificationType::INFO, "Local series deleted");
+                this->INotifier::info("Local series deleted");
             }
         }
     }
@@ -412,7 +401,7 @@ void SSeriesPuller::storeInstanceCallback(
 service::IService::KeyConnectionsMap SSeriesPuller::getAutoConnections() const
 {
     KeyConnectionsMap connections;
-    connections.push(s_SERIES_DB_INOUT, data::SeriesDB::s_REMOVED_SERIES_SIG, s_REMOVE_SERIES_SLOT);
+    connections.push(s_SERIES_SET_INOUT, data::SeriesSet::s_REMOVED_OBJECTS_SIG, s_REMOVE_SERIES_SLOT);
 
     return connections;
 }
