@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,7 +23,7 @@
 #include "SSliceIndexDicomEditor.hpp"
 
 #include <core/com/Slots.hxx>
-#include <core/tools/System.hpp>
+#include <core/os/TempPath.hpp>
 
 #include <data/helper/MedicalImage.hpp>
 #include <data/ImageSeries.hpp>
@@ -47,13 +47,8 @@ static const std::string s_READER_CONFIG       = "readerConfig";
 
 //------------------------------------------------------------------------------
 
-SSliceIndexDicomEditor::SSliceIndexDicomEditor() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
-SSliceIndexDicomEditor::~SSliceIndexDicomEditor() noexcept
+SSliceIndexDicomEditor::SSliceIndexDicomEditor() noexcept :
+    service::INotifier(m_signals)
 {
 }
 
@@ -63,7 +58,7 @@ void SSliceIndexDicomEditor::configuring()
 {
     sight::ui::base::IGuiContainer::initialize();
 
-    const ConfigType configType = this->getConfigTree();
+    const ConfigType configType = this->getConfiguration();
     const ConfigType config     = configType.get_child("config.<xmlattr>");
 
     m_delay                     = config.get<unsigned>(s_DELAY_CONFIG, m_delay);
@@ -81,16 +76,16 @@ void SSliceIndexDicomEditor::starting()
     m_requestWorker = core::thread::Worker::New();
 
     // Create the DICOM reader.
-    m_seriesDB = data::SeriesDB::New();
+    m_series_set = data::SeriesSet::New();
 
     m_dicomReader = this->registerService<sight::io::base::service::IReader>(m_dicomReaderImplementation);
     SIGHT_ASSERT("Unable to create a reader of type '" + m_dicomReaderImplementation + "'", m_dicomReader);
     m_dicomReader->setWorker(m_requestWorker);
-    m_dicomReader->setInOut(m_seriesDB, "data");
+    m_dicomReader->setInOut(m_series_set, "data");
 
     if(!m_readerConfig.empty())
     {
-        core::runtime::ConfigurationElement::csptr readerConfig =
+        const auto readerConfig =
             service::extension::Config::getDefault()->getServiceConfig(
                 m_readerConfig,
                 "sight::io::base::service::IReader"
@@ -98,10 +93,10 @@ void SSliceIndexDicomEditor::starting()
 
         SIGHT_ASSERT(
             "No service configuration " << m_readerConfig << " for sight::io::base::service::IReader",
-            readerConfig
+            !readerConfig.empty()
         );
 
-        m_dicomReader->setConfiguration(core::runtime::ConfigurationElement::constCast(readerConfig));
+        m_dicomReader->setConfiguration(readerConfig);
     }
 
     m_dicomReader->configure();
@@ -109,7 +104,7 @@ void SSliceIndexDicomEditor::starting()
     SIGHT_ASSERT("'" + m_dicomReaderImplementation + "' is not started", m_dicomReader->isStarted());
 
     // Create the timer used to retrieve a slice.
-    m_sliceTrigger = m_associatedWorker->createTimer();
+    m_sliceTrigger = this->worker()->createTimer();
     m_sliceTrigger->setFunction(
         [&]()
         {
@@ -122,7 +117,7 @@ void SSliceIndexDicomEditor::starting()
     sight::ui::base::IGuiContainer::create();
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* layout = new QHBoxLayout();
 
     m_slider = new QSlider(Qt::Horizontal);
     layout->addWidget(m_slider, 1);
@@ -151,7 +146,7 @@ void SSliceIndexDicomEditor::starting()
 service::IService::KeyConnectionsMap SSliceIndexDicomEditor::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_DICOMSERIES_INOUT, data::DicomSeries::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_DICOMSERIES_INOUT, data::DicomSeries::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -222,13 +217,13 @@ void SSliceIndexDicomEditor::retrieveSlice()
 {
     // Check if the slice already exists.
     const auto dicomSeries               = m_series.lock();
-    const std::size_t selectedSliceIndex = m_slider->value() + dicomSeries->getFirstInstanceNumber();
+    const std::size_t selectedSliceIndex = std::size_t(m_slider->value()) + dicomSeries->getFirstInstanceNumber();
     const bool isInstanceAvailable       = dicomSeries->isInstanceAvailable(selectedSliceIndex);
 
     // If the slice is not pulled, pull it.
     if(!isInstanceAvailable)
     {
-        m_requestWorker->post(std::bind(&SSliceIndexDicomEditor::pullSlice, this, selectedSliceIndex));
+        m_requestWorker->post([this, selectedSliceIndex](auto&& ...){pullSlice(selectedSliceIndex);});
     }
     else
     {
@@ -262,7 +257,7 @@ void SSliceIndexDicomEditor::pullSlice(std::size_t _selectedSliceIndex) const
     catch(const sight::io::dimse::exceptions::Base& _e)
     {
         SIGHT_ERROR("Unable to establish a connection with the PACS: " + std::string(_e.what()));
-        this->notify(NotificationType::FAILURE, "Unable to connect to PACS");
+        this->INotifier::failure("Unable to connect to PACS");
     }
 
     const auto dicomSeries = m_series.lock();
@@ -270,7 +265,7 @@ void SSliceIndexDicomEditor::pullSlice(std::size_t _selectedSliceIndex) const
     // Get selected slice.
     try
     {
-        const std::string seriesInstanceUID = dicomSeries->getInstanceUID();
+        const std::string seriesInstanceUID = dicomSeries->getSeriesInstanceUID();
         const std::string sopInstanceUID    =
             seriesEnquirer->findSOPInstanceUID(seriesInstanceUID, static_cast<unsigned int>(_selectedSliceIndex));
 
@@ -295,7 +290,7 @@ void SSliceIndexDicomEditor::pullSlice(std::size_t _selectedSliceIndex) const
             }
 
             // Compute the path and add it to the DICOM series.
-            std::filesystem::path tmpPath      = core::tools::System::getTemporaryFolder() / "dicom";
+            std::filesystem::path tmpPath      = core::os::TempDir::sharedDirectory() / "dicom";
             std::filesystem::path downloadPath = tmpPath / seriesInstanceUID / sopInstanceUID;
             dicomSeries->addDicomPath(_selectedSliceIndex, downloadPath);
 
@@ -303,13 +298,13 @@ void SSliceIndexDicomEditor::pullSlice(std::size_t _selectedSliceIndex) const
         }
         else
         {
-            this->notify(NotificationType::FAILURE, "No instance found");
+            this->INotifier::failure("No instance found");
         }
     }
     catch(const sight::io::dimse::exceptions::Base& _e)
     {
         SIGHT_ERROR("Unable to execute query to the PACS: " + std::string(_e.what()));
-        this->notify(NotificationType::FAILURE, "Unable to execute query");
+        this->INotifier::failure("Unable to execute query");
     }
     catch(const std::filesystem::filesystem_error& _e)
     {
@@ -339,7 +334,7 @@ void SSliceIndexDicomEditor::readSlice(
     const std::string modality = _dicomSeries->getModality();
     if(modality != "CT" && modality != "MR" && modality != "XA")
     {
-        this->notify(NotificationType::INFO, "Unable to read the modality '" + modality + "'");
+        this->INotifier::info("Unable to read the modality '" + modality + "'");
         return;
     }
 
@@ -353,11 +348,11 @@ void SSliceIndexDicomEditor::readSlice(
     const std::size_t bufferSize = bufferObj->getSize();
 
     // Creates unique temporary folder to save the DICOM instance.
-    std::filesystem::path tmpPath = core::tools::System::getTemporaryFolder("dicom");
-    std::filesystem::create_directories(tmpPath);
+    // Do not delete the folder, as we may use the file in the DicomReference.
+    const auto tmpDir = core::os::TempDir::sharedDirectory("do_not_delete_");
 
     // Open the temporary folder and write the buffer.
-    std::filesystem::path path = tmpPath / std::to_string(_selectedSliceIndex);
+    std::filesystem::path path = tmpDir / std::to_string(_selectedSliceIndex);
     std::ofstream fs(path, std::ios::binary | std::ios::trunc);
     if(!fs.good())
     {
@@ -365,25 +360,24 @@ void SSliceIndexDicomEditor::readSlice(
         return;
     }
 
-    fs.write(buffer, bufferSize);
+    fs.write(buffer, std::streamsize(bufferSize));
     fs.close();
 
     // Read the image.
-    m_dicomReader->setFolder(tmpPath);
+    m_dicomReader->setFolder(tmpDir);
     m_dicomReader->update().wait();
 
-    if(!m_dicomReader->hasFailed() && m_seriesDB->getContainer().size() > 0)
+    if(!m_dicomReader->hasFailed() && !m_series_set->empty())
     {
         // Copy the read series to the image.
-        const auto imageSeries           = data::ImageSeries::dynamicCast(*(m_seriesDB->getContainer().begin()));
-        const data::Image::sptr newImage = imageSeries->getImage();
+        const auto imageSeries = data::ImageSeries::dynamicCast(m_series_set->front());
 
         const auto image = m_image.lock();
-        image->deepCopy(newImage);
+        image->deepCopy(imageSeries);
 
         data::Integer::sptr axialIndex    = data::Integer::New(0);
-        data::Integer::sptr frontalIndex  = data::Integer::New(image->getSize()[0] / 2);
-        data::Integer::sptr sagittalIndex = data::Integer::New(image->getSize()[1] / 2);
+        data::Integer::sptr frontalIndex  = data::Integer::New(static_cast<std::int64_t>(image->getSize()[0] / 2));
+        data::Integer::sptr sagittalIndex = data::Integer::New(static_cast<std::int64_t>(image->getSize()[1] / 2));
 
         data::helper::MedicalImage::setSliceIndex(
             *image,
@@ -408,7 +402,7 @@ void SSliceIndexDicomEditor::readSlice(
     else
     {
         SIGHT_ERROR("Unable to read the image");
-        this->notify(NotificationType::FAILURE, "Unable to read the image");
+        this->INotifier::failure("Unable to read the image");
     }
 }
 
