@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,12 +29,13 @@
 
 #include <data/DicomSeries.hpp>
 #include <data/Image.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/base/service/IReader.hpp>
 #include <io/dimse/data/PacsConfiguration.hpp>
 
 #include <service/IHasServices.hpp>
+#include <service/INotifier.hpp>
 
 #include <ui/base/IEditor.hpp>
 
@@ -56,7 +57,7 @@ namespace sight::module::io::dimse
         <in key="pacsConfig" uid="..." />
         <inout key="series" uid="..." />
         <inout key="image" uid="..." />
-        <config delay="500" dicomReader="sight::module::io::dicom::SSeriesDBReader" readerConfig="config" />
+        <config delay="500" dicomReader="sight::module::io::dicom::SSeriesSetReader" readerConfig="config" />
     </service>
    @endcode
  *
@@ -75,7 +76,8 @@ namespace sight::module::io::dimse
 class MODULE_IO_DIMSE_CLASS_API SSliceIndexDicomEditor final :
     public QObject,
     public sight::ui::base::IEditor,
-    public service::IHasServices
+    public service::IHasServices,
+    private service::INotifier
 {
 Q_OBJECT;
 
@@ -88,7 +90,7 @@ public:
     MODULE_IO_DIMSE_API SSliceIndexDicomEditor() noexcept;
 
     /// Destroys the service.
-    MODULE_IO_DIMSE_API virtual ~SSliceIndexDicomEditor() noexcept;
+    MODULE_IO_DIMSE_API ~SSliceIndexDicomEditor() noexcept override = default;
 
 protected:
 
@@ -102,7 +104,7 @@ protected:
      * @brief Proposals to connect service slots to associated object signals.
      * @return A map of each proposed connection.
      *
-     * Connect data::DicomSeries::s_MODIFIED_SIG of s_DICOMSERIES_INOUT to s_UPDATE_SLOT
+     * Connect data::DicomSeries::s_MODIFIED_SIG of s_DICOMSERIES_INOUT to IService::slots::s_UPDATE
      */
     MODULE_IO_DIMSE_API service::IService::KeyConnectionsMap getAutoConnections() const override;
 
@@ -157,16 +159,16 @@ private:
     unsigned int m_delay {500};
 
     /// Defines the DICOM reader implementation.
-    std::string m_dicomReaderImplementation {""};
+    std::string m_dicomReaderImplementation;
 
     /// Contains the optional configuration to set to reader implementation.
-    std::string m_readerConfig {""};
+    std::string m_readerConfig;
 
     /// Contains the DICOM reader.
     sight::io::base::service::IReader::sptr m_dicomReader;
 
-    /// Contains the seriesDB where the DICOM reader sets its output.
-    data::SeriesDB::sptr m_seriesDB;
+    /// Contains the series_set where the DICOM reader sets its output.
+    data::SeriesSet::sptr m_series_set;
 
     data::ptr<sight::io::dimse::data::PacsConfiguration, data::Access::in> m_config {this, "pacsConfig"};
     data::ptr<sight::data::Image, data::Access::inout> m_image {this, "image"};
