@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,17 +34,16 @@ const core::com::Signals::SignalKeyType INetworkSender::s_DISCONNECTED_SIGNAL =
 
 //-----------------------------------------------------------------------------
 
-INetworkSender::INetworkSender()
+INetworkSender::INetworkSender() :
+    m_sigConnected(newSignal<ConnectedSignalType>(s_CONNECTED_SIGNAL)),
+    m_sigDisconnected(newSignal<DisconnectSignalType>(s_DISCONNECTED_SIGNAL))
 {
-    m_sigConnected    = newSignal<ConnectedSignalType>(s_CONNECTED_SIGNAL);
-    m_sigDisconnected = newSignal<DisconnectSignalType>(s_DISCONNECTED_SIGNAL);
 }
 
 //-----------------------------------------------------------------------------
 
 INetworkSender::~INetworkSender()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -71,7 +70,7 @@ void INetworkSender::updating()
 service::IService::KeyConnectionsMap INetworkSender::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_OBJECTS_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_OBJECTS_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE);
     return connections;
 }
 
