@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,6 +23,7 @@
 #include "SClientListener.hpp"
 
 #include <core/com/Signal.hxx>
+#include <core/tools/Failed.hpp>
 
 #include <data/FrameTL.hpp>
 #include <data/Image.hpp>
@@ -30,8 +31,6 @@
 #include <data/MatrixTL.hpp>
 #include <data/Object.hpp>
 
-#include <service/macros.hpp>
-
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/base/Preferences.hpp>
 
@@ -41,32 +40,27 @@
 namespace sight::module::io::igtl
 {
 
-const service::IService::KeyType s_OBJECTS_GROUP = "objects";
-
 //-----------------------------------------------------------------------------
 
-SClientListener::SClientListener() :
-    m_tlInitialized(false)
-{
-}
+SClientListener::SClientListener()
+= default;
 
 //-----------------------------------------------------------------------------
 
 SClientListener::~SClientListener()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SClientListener::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     const ConfigType configInOut = config.get_child("inout");
 
     SIGHT_ASSERT(
-        "configured group must be '" + s_OBJECTS_GROUP + "'",
-        configInOut.get<std::string>("<xmlattr>.group", "") == s_OBJECTS_GROUP
+        "configured group must be 'objects'",
+        configInOut.get<std::string>("<xmlattr>.group", "") == "objects"
     );
 
     const auto keyCfg = configInOut.equal_range("key");
@@ -117,7 +111,7 @@ void SClientListener::runClient()
         if(this->getStatus() == STARTED)
         {
             sight::ui::base::dialog::MessageDialog::show("Connection error", ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
         else
         {
@@ -169,7 +163,7 @@ void SClientListener::runClient()
         if(this->getStatus() == STARTED)
         {
             sight::ui::base::dialog::MessageDialog::show("Error", ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
         else
         {
@@ -183,7 +177,7 @@ void SClientListener::runClient()
 
 void SClientListener::starting()
 {
-    m_clientFuture = std::async(std::launch::async, std::bind(&SClientListener::runClient, this));
+    m_clientFuture = std::async(std::launch::async, [this](auto&& ...){runClient();});
 }
 
 //-----------------------------------------------------------------------------
@@ -230,22 +224,14 @@ void SClientListener::manageTimeline(data::Object::sptr obj, std::size_t index)
 
         SPTR(data::MatrixTL::BufferType) matrixBuf;
         matrixBuf = matTL->createBuffer(timestamp);
-        data::Matrix4::TMCoefArray values;
+
         data::Matrix4::sptr t = data::Matrix4::dynamicCast(obj);
-        values = t->getCoefficients();
-        float matrixValues[16];
+        std::array<float, 16> floatValues {};
+        std::transform(t->begin(), t->end(), floatValues.begin(), boost::numeric_cast<float, double>);
 
-        for(unsigned int i = 0 ; i < 16 ; ++i)
-        {
-            matrixValues[i] = static_cast<float>(values[i]);
-        }
-
-        matrixBuf->setElement(matrixValues, 0);
+        matrixBuf->setElement(floatValues, 0);
         matTL->pushObject(matrixBuf);
-        data::TimeLine::ObjectPushedSignalType::sptr sig;
-        sig = matTL->signal<data::TimeLine::ObjectPushedSignalType>(
-            data::TimeLine::s_OBJECT_PUSHED_SIG
-        );
+        auto sig = matTL->signal<data::TimeLine::ObjectPushedSignalType>(data::TimeLine::s_OBJECT_PUSHED_SIG);
         sig->asyncEmit(timestamp);
     }
     //FrameTL
@@ -287,7 +273,7 @@ void SClientListener::manageTimeline(data::Object::sptr obj, std::size_t index)
 
         SPTR(data::FrameTL::BufferType) buffer = frameTL->createBuffer(timestamp);
 
-        std::uint8_t* destBuffer = reinterpret_cast<std::uint8_t*>(buffer->addElement(0));
+        auto* destBuffer = reinterpret_cast<std::uint8_t*>(buffer->addElement(0));
 
         const auto dumpLock = im->dump_lock();
         auto itr            = im->begin<std::uint8_t>();
