@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,31 +33,27 @@
 namespace sight::module::io::igtl
 {
 
-const service::IService::KeyType s_OBJECTS_GROUP = "objects";
-
 //-----------------------------------------------------------------------------
 
 SClientSender::SClientSender()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 SClientSender::~SClientSender()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SClientSender::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     const ConfigType configIn = config.get_child("in");
 
     SIGHT_ASSERT(
-        "configured group must be '" + s_OBJECTS_GROUP + "'",
-        configIn.get<std::string>("<xmlattr>.group", "") == s_OBJECTS_GROUP
+        "configured group must be 'objects'",
+        configIn.get<std::string>("<xmlattr>.group", "") == "objects"
     );
 
     const auto keyCfg = configIn.equal_range("key");
@@ -102,7 +98,7 @@ void SClientSender::starting()
         {
             sight::ui::base::dialog::MessageDialog::show("Connection error", ex.what());
             SIGHT_ERROR(ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
     }
 }
