@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,22 +36,21 @@ namespace sight::module::io::igtl
 
 //-----------------------------------------------------------------------------
 
-SServerListener::SServerListener()
+SServerListener::SServerListener() :
+    m_server(std::make_shared<sight::io::igtl::Server>())
 {
-    m_server = std::make_shared<sight::io::igtl::Server>();
 }
 
 //-----------------------------------------------------------------------------
 
 SServerListener::~SServerListener()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SServerListener::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_portConfig = config.get("port", "4242");
 
@@ -79,9 +78,9 @@ void SServerListener::starting()
 
         m_server->start(port);
 
-        m_serverFuture = std::async(std::launch::async, std::bind(&sight::io::igtl::Server::runServer, m_server));
+        m_serverFuture = std::async(std::launch::async, [this](auto&& ...){m_server->runServer();});
         m_sigConnected->asyncEmit();
-        m_receiveFuture = std::async(std::launch::async, std::bind(&SServerListener::receiveObject, this));
+        m_receiveFuture = std::async(std::launch::async, [this](auto&& ...){receiveObject();});
     }
     catch(core::Exception& e)
     {
@@ -93,7 +92,7 @@ void SServerListener::starting()
         );
         // Only report the error on console (this normally happens only if we have requested the disconnection)
         SIGHT_ERROR(e.what());
-        this->slot(s_STOP_SLOT)->asyncRun();
+        this->slot(IService::slots::s_STOP)->asyncRun();
     }
 }
 
@@ -166,7 +165,7 @@ void SServerListener::receiveObject()
         if(this->getStatus() == STARTED)
         {
             sight::ui::base::dialog::MessageDialog::show("Error", ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
         else
         {
