@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,34 +36,31 @@
 namespace sight::module::io::igtl
 {
 
-const service::IService::KeyType s_OBJECTS_GROUP = "objects";
-
 //-----------------------------------------------------------------------------
 
-SServerSender::SServerSender()
+SServerSender::SServerSender() :
+    m_server(std::make_shared<sight::io::igtl::Server>())
 {
-    m_server = std::make_shared<sight::io::igtl::Server>();
 }
 
 //-----------------------------------------------------------------------------
 
 SServerSender::~SServerSender()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
 void SServerSender::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_portConfig = config.get("port", "4242");
 
     const ConfigType configIn = config.get_child("in");
 
     SIGHT_ASSERT(
-        "configured group must be '" + s_OBJECTS_GROUP + "'",
-        configIn.get<std::string>("<xmlattr>.group", "") == s_OBJECTS_GROUP
+        "configured group must be 'objects'",
+        configIn.get<std::string>("<xmlattr>.group", "") == "objects"
     );
 
     const auto keyCfg = configIn.equal_range("key");
@@ -86,7 +83,7 @@ void SServerSender::starting()
 
         m_server->start(port);
 
-        m_serverFuture = std::async(std::launch::async, std::bind(&sight::io::igtl::Server::runServer, m_server));
+        m_serverFuture = std::async(std::launch::async, [this](auto&& ...){m_server->runServer();});
         m_sigConnected->asyncEmit();
     }
     catch(core::Exception& e)
@@ -99,7 +96,7 @@ void SServerSender::starting()
         );
         // Only report the error on console (this normally happens only if we have requested the disconnection)
         SIGHT_ERROR(e.what());
-        this->slot(s_STOP_SLOT)->asyncRun();
+        this->slot(IService::slots::s_STOP)->asyncRun();
     }
 }
 
