@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,6 +34,7 @@
 #include <ui/base/Preferences.hpp>
 
 #include <boost/lexical_cast.hpp>
+#include <boost/range/iterator_range_core.hpp>
 
 #include <functional>
 #include <string>
@@ -43,53 +44,34 @@ namespace sight::module::io::igtl
 
 //-----------------------------------------------------------------------------
 
-STDataListener::STDataListener()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-STDataListener::~STDataListener()
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void STDataListener::configuring()
 {
-    SIGHT_ASSERT("Configuration not found", m_configuration != NULL);
-    if(m_configuration->findConfigurationElement("server"))
-    {
-        const std::string serverInfo = m_configuration->findConfigurationElement("server")->getValue();
-        SIGHT_INFO("OpenIGTLinkListener::configure server: " + serverInfo);
-        const std::string::size_type splitPosition = serverInfo.find(':');
-        SIGHT_ASSERT("Server info not formatted correctly", splitPosition != std::string::npos);
+    const auto configuration = this->getConfiguration();
 
-        m_hostnameConfig = serverInfo.substr(0, splitPosition);
-        m_portConfig     = serverInfo.substr(splitPosition + 1, serverInfo.size());
-    }
-    else
-    {
-        throw core::tools::Failed("Server element not found");
-    }
+    const auto serverInfo = configuration.get<std::string>("server");
+    SIGHT_INFO("OpenIGTLinkListener::configure server: " + serverInfo);
+    const std::string::size_type splitPosition = serverInfo.find(':');
+    SIGHT_ASSERT("Server info not formatted correctly", splitPosition != std::string::npos);
 
-    m_deviceNamesConfig = m_configuration->find("deviceName");
+    m_hostnameConfig = serverInfo.substr(0, splitPosition);
+    m_portConfig     = serverInfo.substr(splitPosition + 1, serverInfo.size());
 
-    core::runtime::ConfigurationElement::sptr tdata = m_configuration->findConfigurationElement("TData");
-
-    if(tdata)
-    {
-        std::vector<core::runtime::ConfigurationElement::sptr> matrices = tdata->find("matrix");
-
-        for(const auto& m : matrices)
+    const auto devices = configuration.equal_range("deviceName");
+    std::transform(
+        devices.first,
+        devices.second,
+        std::back_inserter(m_deviceNamesConfig),
+        [](const auto& device)
         {
-            const unsigned long index = boost::lexical_cast<unsigned long>(m->getAttributeValue("index"));
-            m_matrixNameIndex[m->getAttributeValue("name")] = index;
-        }
-    }
-    else
+            return device.second.template get_value<std::string>();
+        });
+
+    const auto tdata = configuration.get_child("TData");
+
+    for(const auto& m : boost::make_iterator_range(tdata.equal_range("matrix")))
     {
-        SIGHT_WARN("Element 'TData' is missing, the listener will do nothing !");
+        const auto index = m.second.get<std::uint64_t>("<xmlattr>.index");
+        m_matrixNameIndex[m.second.get<std::string>("<xmlattr>.name")] = index;
     }
 }
 
@@ -97,8 +79,6 @@ void STDataListener::configuring()
 
 void STDataListener::runClient()
 {
-    sight::ui::base::dialog::MessageDialog msgDialog;
-
     data::Composite::sptr composite = data::Composite::New();
 
     // 1. Connection
@@ -112,7 +92,7 @@ void STDataListener::runClient()
         {
             for(const auto& dn : m_deviceNamesConfig)
             {
-                m_client.addAuthorizedDevice(preferences.delimited_get<std::string>(dn->getValue()));
+                m_client.addAuthorizedDevice(preferences.delimited_get<std::string>(dn));
             }
 
             m_client.setFilteringByDeviceName(true);
@@ -128,8 +108,8 @@ void STDataListener::runClient()
         // in this case opening a dialog will result in a deadlock
         if(this->getStatus() == STARTED)
         {
-            msgDialog.show("Connection error", ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            sight::ui::base::dialog::MessageDialog::show("Connection error", ex.what());
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
         else
         {
@@ -162,8 +142,8 @@ void STDataListener::runClient()
         // in this case opening a dialog will result in a deadlock
         if(this->getStatus() == STARTED)
         {
-            msgDialog.show("Error", ex.what());
-            this->slot(s_STOP_SLOT)->asyncRun();
+            sight::ui::base::dialog::MessageDialog::show("Error", ex.what());
+            this->slot(IService::slots::s_STOP)->asyncRun();
         }
         else
         {
@@ -181,7 +161,7 @@ void STDataListener::starting()
     matTL->setMaximumSize(10);
     matTL->initPoolSize(static_cast<unsigned int>(m_matrixNameIndex.size()));
 
-    m_clientFuture = std::async(std::launch::async, std::bind(&STDataListener::runClient, this));
+    m_clientFuture = std::async(std::launch::async, [this](auto&& ...){runClient();});
 }
 
 //-----------------------------------------------------------------------------
@@ -201,26 +181,23 @@ void STDataListener::manageTimeline(const data::Composite::sptr& obj, double tim
     SPTR(data::MatrixTL::BufferType) matrixBuf;
     matrixBuf = matTL->createBuffer(timestamp);
 
-    for(const data::Composite::ContainerType::value_type& elt : obj->getContainer())
+    for(const auto& elt : *obj)
     {
-        data::Matrix4::csptr transfoMatrix =
-            data::Matrix4::dynamicConstCast(elt.second);
+        data::Matrix4::csptr transfoMatrix = data::Matrix4::dynamicConstCast(elt.second);
 
-        MatrixNameIndexType::const_iterator it = m_matrixNameIndex.find(elt.first);
+        auto it = m_matrixNameIndex.find(elt.first);
 
         if(transfoMatrix && it != m_matrixNameIndex.end())
         {
-            unsigned long index = it->second;
+            std::uint64_t index = it->second;
 
-            data::Matrix4::TMCoefArray values;
-            values = transfoMatrix->getCoefficients();
-            float matrixValues[16];
+            std::array<float, 16> matrixValues {};
             bool isZero = true;
             for(unsigned int i = 0 ; i < 16 ; ++i)
             {
-                matrixValues[i] = static_cast<float>(values[i]);
+                matrixValues[i] = static_cast<float>((*transfoMatrix)[i]);
                 //Test if matrix contains only '0' except last value (always '1)
-                isZero &= i < 15 ? (matrixValues[i] == 0.f) : true;
+                isZero &= i < 15 ? (matrixValues[i] == 0.F) : true;
             }
 
             //don't push the matrix if it contains only '0'
