@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,18 +22,17 @@
 
 #include "IoItkTest.hpp"
 
-#include <core/runtime/EConfigurationElement.hpp>
+#include <core/os/TempPath.hpp>
 #include <core/thread/Worker.hpp>
 #include <core/tools/dateAndTime.hpp>
-#include <core/tools/System.hpp>
 
 #include <data/ImageSeries.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/base/service/ioTypes.hpp>
 
 #include <service/op/Add.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <utestData/Data.hpp>
 #include <utestData/generator/Image.hpp>
@@ -43,10 +42,7 @@
 // Registers the fixture into the 'registry'
 CPPUNIT_TEST_SUITE_REGISTRATION(sight::module::io::itk::ut::IoItkTest);
 
-namespace sight::module::io::itk
-{
-
-namespace ut
+namespace sight::module::io::itk::ut
 {
 
 static const double EPSILON = 0.00001;
@@ -68,7 +64,7 @@ void IoItkTest::tearDown()
 void executeService(
     const SPTR(data::Object)& obj,
     const std::string& srvImpl,
-    const SPTR(core::runtime::EConfigurationElement)& cfg,
+    const boost::property_tree::ptree& cfg,
     const data::Access access = data::Access::inout
 )
 {
@@ -89,7 +85,7 @@ void executeService(
     CPPUNIT_ASSERT_NO_THROW(srv->start().wait());
     CPPUNIT_ASSERT_NO_THROW(srv->update().wait());
     CPPUNIT_ASSERT_NO_THROW(srv->stop().wait());
-    service::OSR::unregisterService(srv);
+    service::unregisterService(srv);
 }
 
 //------------------------------------------------------------------------------
@@ -97,53 +93,20 @@ void executeService(
 void IoItkTest::testImageSeriesWriterJPG()
 {
     // Create image series
-    data::Image::sptr image = data::Image::New();
-    utestData::generator::Image::generateRandomImage(image, core::tools::Type::create("int16"));
-
-    data::ImageSeries::sptr imageSeries = data::ImageSeries::New();
-    imageSeries->setImage(image);
+    auto imageSeries = data::ImageSeries::New();
+    utestData::generator::Image::generateRandomImage(imageSeries, core::Type::INT16);
 
     // Create path
-    const std::filesystem::path path = core::tools::System::getTemporaryFolder() / "imageSeriesJPG";
-    std::filesystem::create_directories(path);
+    core::os::TempDir tmpDir;
 
     // Create Config
-    core::runtime::EConfigurationElement::sptr srvCfg    = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr folderCfg = core::runtime::EConfigurationElement::New("folder");
-    folderCfg->setValue(path.string());
-    srvCfg->addConfigurationElement(folderCfg);
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("folder", tmpDir.string());
 
     // Create and execute service
     executeService(
         imageSeries,
-        "sight::module::io::itk::SJpgImageSeriesWriter",
-        srvCfg,
-        data::Access::in
-    );
-}
-
-//------------------------------------------------------------------------------
-
-void IoItkTest::testImageWriterJPG()
-{
-    // Create Image
-    data::Image::sptr image = data::Image::New();
-    utestData::generator::Image::generateRandomImage(image, core::tools::Type::create("int16"));
-
-    // Create path
-    const std::filesystem::path path = core::tools::System::getTemporaryFolder() / "imageJPG";
-    std::filesystem::create_directories(path);
-
-    // Create Config
-    core::runtime::EConfigurationElement::sptr srvCfg    = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr folderCfg = core::runtime::EConfigurationElement::New("folder");
-    folderCfg->setValue(path.string());
-    srvCfg->addConfigurationElement(folderCfg);
-
-    // Create and execute service
-    executeService(
-        image,
-        "sight::module::io::itk::JpgImageWriterService",
+        "sight::module::io::itk::SSlicedImageSeriesWriter",
         srvCfg,
         data::Access::in
     );
@@ -161,26 +124,24 @@ double tolerance(double num)
 void IoItkTest::testSaveLoadInr()
 {
     data::Image::sptr image = data::Image::New();
-    utestData::generator::Image::generateRandomImage(image, core::tools::Type::s_INT16);
+    utestData::generator::Image::generateRandomImage(image, core::Type::INT16);
 
     // inr only support image origin (0,0,0)
     const data::Image::Origin origin = {0., 0., 0.};
     image->setOrigin(origin);
 
     // save image in inr
-    const std::filesystem::path path = core::tools::System::getTemporaryFolder() / "imageInrTest/image.inr.gz";
-    std::filesystem::create_directories(path.parent_path());
+    core::os::TempDir tmpDir;
+    const auto& path = tmpDir / "image.inr.gz";
 
     // Create Config
-    core::runtime::EConfigurationElement::sptr srvCfg  = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr fileCfg = core::runtime::EConfigurationElement::New("file");
-    fileCfg->setValue(path.string());
-    srvCfg->addConfigurationElement(fileCfg);
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("file", path.string());
 
     // Create and execute service
     executeService(
         image,
-        "sight::module::io::itk::InrImageWriterService",
+        "sight::module::io::itk::SImageWriter",
         srvCfg,
         data::Access::in
     );
@@ -189,7 +150,53 @@ void IoItkTest::testSaveLoadInr()
     data::Image::sptr image2 = data::Image::New();
     executeService(
         image2,
-        "sight::module::io::itk::InrImageReaderService",
+        "sight::module::io::itk::SImageReader",
+        srvCfg,
+        data::Access::inout
+    );
+
+    data::Image::Spacing spacing = image2->getSpacing();
+    std::transform(spacing.begin(), spacing.end(), spacing.begin(), tolerance);
+    image2->setSpacing(spacing);
+
+    // check Image
+    image2->setWindowCenter(image->getWindowCenter());
+    image2->setWindowWidth(image->getWindowWidth());
+
+    CPPUNIT_ASSERT(*image == *image2);
+}
+
+//------------------------------------------------------------------------------
+
+void IoItkTest::testSaveLoadNifti()
+{
+    data::Image::sptr image = data::Image::New();
+    utestData::generator::Image::generateRandomImage(image, core::Type::INT16);
+
+    const data::Image::Origin origin = {0.5F, 0.2F, 1.2F};
+    image->setOrigin(origin);
+
+    // save image in inr
+    core::os::TempDir tmpDir;
+    const auto& path = tmpDir / "image.nii";
+
+    // Create Config
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("file", path.string());
+
+    // Create and execute service
+    executeService(
+        image,
+        "sight::module::io::itk::SImageWriter",
+        srvCfg,
+        data::Access::in
+    );
+
+    // load Image
+    data::Image::sptr image2 = data::Image::New();
+    executeService(
+        image2,
+        "sight::module::io::itk::SImageReader",
         srvCfg,
         data::Access::inout
     );
@@ -209,25 +216,20 @@ void IoItkTest::testSaveLoadInr()
 
 void IoItkTest::ImageSeriesInrTest()
 {
-    data::Image::sptr image             = data::Image::New();
-    data::ImageSeries::sptr imageSeries = data::ImageSeries::New();
-    utestData::generator::Image::generateRandomImage(image, core::tools::Type::create("int16"));
-
-    imageSeries->setImage(image);
+    auto imageSeries = data::ImageSeries::New();
+    utestData::generator::Image::generateRandomImage(imageSeries, core::Type::INT16);
 
     // inr only support image origin (0,0,0)
     const data::Image::Origin origin = {0., 0., 0.};
-    image->setOrigin(origin);
+    imageSeries->setOrigin(origin);
 
     // save image in inr
-    const std::filesystem::path path = core::tools::System::getTemporaryFolder() / "imageInrTest/imageseries.inr.gz";
-    std::filesystem::create_directories(path.parent_path());
+    core::os::TempDir tmpDir;
+    const auto& path = tmpDir / "imageseries.inr.gz";
 
     // Create Config
-    core::runtime::EConfigurationElement::sptr srvCfg  = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr fileCfg = core::runtime::EConfigurationElement::New("file");
-    fileCfg->setValue(path.string());
-    srvCfg->addConfigurationElement(fileCfg);
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("file", path.string());
 
     // Create and execute service
     executeService(
@@ -238,28 +240,87 @@ void IoItkTest::ImageSeriesInrTest()
     );
 
     // load Image
-    data::Image::sptr image2 = data::Image::New();
+    auto imageSeries2 = data::ImageSeries::New();
     executeService(
-        image2,
-        "sight::module::io::itk::InrImageReaderService",
+        imageSeries2,
+        "sight::module::io::itk::SImageSeriesReader",
         srvCfg,
         data::Access::inout
     );
 
-    data::Image::Spacing spacing = image2->getSpacing();
+    data::Image::Spacing spacing = imageSeries2->getSpacing();
     std::transform(spacing.begin(), spacing.end(), spacing.begin(), tolerance);
-    image2->setSpacing(spacing);
+    imageSeries2->setSpacing(spacing);
 
     // check Image
-    image2->setWindowCenter(image->getWindowCenter());
-    image2->setWindowWidth(image->getWindowWidth());
+    imageSeries2->setWindowCenter(imageSeries->getWindowCenter());
+    imageSeries2->setWindowWidth(imageSeries->getWindowWidth());
+
+    // ITK reader change the description of the image, the modality is set to "OT", etc ...
+    // We only compare "Image" part...
+    const auto image  = data::Image::dynamicCast(imageSeries);
+    const auto image2 = data::Image::dynamicCast(imageSeries2);
+    image2->setDescription(image->getDescription());
 
     CPPUNIT_ASSERT(*image == *image2);
 }
 
 //------------------------------------------------------------------------------
 
-void IoItkTest::SeriesDBInrTest()
+void IoItkTest::ImageSeriesNiftiTest()
+{
+    auto imageSeries = data::ImageSeries::New();
+    utestData::generator::Image::generateRandomImage(imageSeries, core::Type::INT16);
+
+    // inr only support image origin (0,0,0)
+    const data::Image::Origin origin = {0., 0., 0.};
+    imageSeries->setOrigin(origin);
+
+    // save image in inr
+    core::os::TempDir tmpDir;
+    const auto& path = tmpDir / "imageseries.nii";
+
+    // Create Config
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("file", path.string());
+
+    // Create and execute service
+    executeService(
+        imageSeries,
+        "sight::module::io::itk::SImageSeriesWriter",
+        srvCfg,
+        data::Access::in
+    );
+
+    // load Image
+    data::ImageSeries::sptr imageSeries2 = data::ImageSeries::New();
+    executeService(
+        imageSeries2,
+        "sight::module::io::itk::SImageSeriesReader",
+        srvCfg,
+        data::Access::inout
+    );
+
+    data::Image::Spacing spacing = imageSeries2->getSpacing();
+    std::transform(spacing.begin(), spacing.end(), spacing.begin(), tolerance);
+    imageSeries2->setSpacing(spacing);
+
+    // check Image
+    imageSeries2->setWindowCenter(imageSeries->getWindowCenter());
+    imageSeries2->setWindowWidth(imageSeries->getWindowWidth());
+
+    // ITK reader change the description of the image, the modality is set to "OT", etc ...
+    // We only compare "Image" part...
+    const auto image  = data::Image::dynamicCast(imageSeries);
+    const auto image2 = data::Image::dynamicCast(imageSeries2);
+    image2->setDescription(image->getDescription());
+
+    CPPUNIT_ASSERT(*image == *image2);
+}
+
+//------------------------------------------------------------------------------
+
+void IoItkTest::SeriesSetInrTest()
 {
     /*
      * - image.inr.gz : CT, type int16, size: 512x512x134, spacing 0.781:0.781:1.6
@@ -279,20 +340,15 @@ void IoItkTest::SeriesDBInrTest()
     );
 
     // Create Config
-    core::runtime::EConfigurationElement::sptr srvCfg       = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr fileImageCfg = core::runtime::EConfigurationElement::New("file");
-    fileImageCfg->setValue(imageFile.string());
-    srvCfg->addConfigurationElement(fileImageCfg);
+    service::IService::ConfigType srvCfg;
+    srvCfg.add("file", imageFile.string());
+    srvCfg.add("file", skinFile.string());
 
-    core::runtime::EConfigurationElement::sptr fileSkinCfg = core::runtime::EConfigurationElement::New("file");
-    fileSkinCfg->setValue(skinFile.string());
-    srvCfg->addConfigurationElement(fileSkinCfg);
-
-    // load SeriesDB
-    data::SeriesDB::sptr sdb = data::SeriesDB::New();
+    // load SeriesSet
+    auto series_set = data::SeriesSet::New();
     executeService(
-        sdb,
-        "sight::module::io::itk::SInrSeriesDBReader",
+        series_set,
+        "sight::module::io::itk::SSeriesSetReader",
         srvCfg,
         data::Access::inout
     );
@@ -300,35 +356,28 @@ void IoItkTest::SeriesDBInrTest()
     const data::Image::Spacing spacing = {0.781, 0.781, 1.6};
     const data::Image::Size size       = {512, 512, 134};
 
-    CPPUNIT_ASSERT_EQUAL(std::size_t(2), sdb->getContainer().size());
-    data::ImageSeries::sptr imgSeries = data::ImageSeries::dynamicCast(sdb->getContainer()[0]);
+    CPPUNIT_ASSERT_EQUAL(std::size_t(2), series_set->size());
+    data::ImageSeries::sptr imgSeries = data::ImageSeries::dynamicCast(series_set->at(0));
     CPPUNIT_ASSERT(imgSeries);
     CPPUNIT_ASSERT_EQUAL(std::string("OT"), imgSeries->getModality());
 
-    data::Image::sptr image = imgSeries->getImage();
-    CPPUNIT_ASSERT(image);
-    CPPUNIT_ASSERT_EQUAL(std::string("int16"), image->getType().string());
-    CPPUNIT_ASSERT(size == image->getSize());
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[0], image->getSpacing()[0], EPSILON);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[1], image->getSpacing()[1], EPSILON);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[2], image->getSpacing()[2], EPSILON);
+    CPPUNIT_ASSERT_EQUAL(std::string("int16"), imgSeries->getType().name());
+    CPPUNIT_ASSERT(size == imgSeries->getSize());
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[0], imgSeries->getSpacing()[0], EPSILON);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[1], imgSeries->getSpacing()[1], EPSILON);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[2], imgSeries->getSpacing()[2], EPSILON);
 
-    imgSeries = data::ImageSeries::dynamicCast(sdb->getContainer()[1]);
+    imgSeries = data::ImageSeries::dynamicCast(series_set->at(1));
     CPPUNIT_ASSERT(imgSeries);
     CPPUNIT_ASSERT_EQUAL(std::string("OT"), imgSeries->getModality());
-    CPPUNIT_ASSERT(imgSeries->getImage());
 
-    image = imgSeries->getImage();
-    CPPUNIT_ASSERT(image);
-    CPPUNIT_ASSERT_EQUAL(std::string("uint8"), image->getType().string());
-    CPPUNIT_ASSERT(size == image->getSize());
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[0], image->getSpacing()[0], EPSILON);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[1], image->getSpacing()[1], EPSILON);
-    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[2], image->getSpacing()[2], EPSILON);
+    CPPUNIT_ASSERT_EQUAL(std::string("uint8"), imgSeries->getType().name());
+    CPPUNIT_ASSERT(size == imgSeries->getSize());
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[0], imgSeries->getSpacing()[0], EPSILON);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[1], imgSeries->getSpacing()[1], EPSILON);
+    CPPUNIT_ASSERT_DOUBLES_EQUAL(spacing[2], imgSeries->getSpacing()[2], EPSILON);
 }
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::module::io::itk
+} // namespace sight::module::io::itk::ut
