@@ -53,6 +53,8 @@ namespace sight::module::io::matrix
  * - \b readPrevious() : read previous matrices
  * - \b setStep(int step, std::string key) : set the step value between two matrices when calling readNext/readPrevious
  * slots on oneShot mode (supported key: "step")
+ * - \b toggleLoopMode() : changes the loop mode. If active, the reader loops over the file,
+ * if false, it reads the file once only
  *
  * @section XML XML Configuration
  *
@@ -81,6 +83,7 @@ namespace sight::module::io::matrix
  * - \b useTimelapse: if set to true, ignore the fps value and use the matrix
  *     timestamps to figure out at which speed to read the matrices. (default: false)
  * - \b step (optional): value to jump between two matrices when calling readNext/readPrevious slots (default: 1)
+ * - \b loop (optional): specifies if the reader loops over the file or not (default: false)
  */
 
 class MODULE_IO_MATRIX_CLASS_API SMatricesReader : public sight::io::base::service::IReader
@@ -93,7 +96,7 @@ public:
     MODULE_IO_MATRIX_API SMatricesReader() noexcept;
 
     /// Destructor. Does nothing
-    MODULE_IO_MATRIX_API virtual ~SMatricesReader() noexcept;
+    MODULE_IO_MATRIX_API ~SMatricesReader() noexcept override;
 
     /// Display a location dialog allowing to select the video file to save
     MODULE_IO_MATRIX_API void openLocationDialog() override;
@@ -107,7 +110,7 @@ public:
     struct TimeStampedMatrices
     {
         ///timestamp
-        core::HiResClock::HiResClockType timestamp;
+        core::HiResClock::HiResClockType timestamp {};
         ///vector of matrices (std::array<float, 16>).
         std::vector<std::array<float, 16> > matrices;
     };
@@ -145,12 +148,15 @@ private:
     /// SLOT: Set step used on readPrevious/readNext slots
     void setStep(int _step, std::string _key);
 
+    /// SLOT: toggle the loop mode
+    void toggleLoopMode();
+
     /// Read matrices (this function is set to the worker)
     void readMatrices();
 
-    bool m_isPlaying; ///<flag if the service is playing.
+    bool m_isPlaying {false}; ///<flag if the service is playing.
 
-    std::ifstream* m_filestream; ///< input filestream
+    std::ifstream* m_filestream {nullptr}; ///< input filestream
 
     std::vector<TimeStampedMatrices> m_tsMatrices; ///< vector of TimeStampedMatrices read from csv file.
 
@@ -158,24 +164,30 @@ private:
 
     core::thread::Worker::sptr m_worker; ///< Worker for the readMatrices timer
 
-    std::size_t m_tsMatricesCount; ///< counter used by matrices reader
+    std::size_t m_tsMatricesCount {0}; ///< counter used by matrices reader
 
-    bool m_createNewTS; ///< bool to handle if we create a new timestamp
+    bool m_createNewTS {false}; ///< bool to handle if we create a new timestamp
 
-    unsigned int m_fps; ///< fps used to read matrices (represent the matrices-per-second rate)
+    unsigned int m_fps {30}; ///< fps used to read matrices (represent the matrices-per-second rate)
 
-    bool m_oneShot; ///< oneShot mode (read matrices one-by-one)
+    bool m_oneShot {false}; ///< oneShot mode (read matrices one-by-one)
 
     /// If set to true, ignore the fps value and use the interval between timestamps for the timer
-    bool m_useTimelapse;
+    bool m_useTimelapse {false};
+
+    /// If true: the grabber is paused.
+    bool m_isPaused {false};
+
+    /// If set to true, loop over the file
+    bool m_loopMatrix {false};
 
     /// Step between two matrices when calling readNext()/readPrevious() slots
-    unsigned long m_step;
+    std::uint64_t m_step {1};
     /// Step value updated in setStep() slot used to compute a shift value when calling readPrevious()/readNext() slots
-    unsigned long m_stepChanged;
+    std::uint64_t m_stepChanged {1};
 
     static constexpr std::string_view s_MATRIXTL = "matrixTL";
     sight::data::ptr<sight::data::MatrixTL, sight::data::Access::inout> m_matrixTL {this, s_MATRIXTL};
 };
 
-} // ioTimeline
+} // namespace sight::module::io::matrix
