@@ -49,17 +49,7 @@ using sight::io::base::service::IGrabber;
 //------------------------------------------------------------------------------
 
 SFrameGrabber::SFrameGrabber() noexcept :
-    m_loopVideo(false),
-    m_isInitialized(false),
-    m_fps(30),
-    m_imageCount(0)
-{
-    m_worker = core::thread::Worker::New();
-}
-
-//------------------------------------------------------------------------------
-
-SFrameGrabber::~SFrameGrabber() noexcept
+    m_worker(core::thread::Worker::New())
 {
 }
 
@@ -80,7 +70,7 @@ void SFrameGrabber::stopping()
 
 void SFrameGrabber::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_fps = config.get<unsigned int>("fps", 30);
 
@@ -97,9 +87,10 @@ void SFrameGrabber::updating()
 
 void SFrameGrabber::startCamera()
 {
-    if(m_timer)
+    if(this->started())
     {
-        this->stopCamera();
+        // Do not reset if we are already started
+        return;
     }
 
     const auto camera = m_camera.lock();
@@ -223,7 +214,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
         if(width != 0 && height != 0)
         {
             const auto frameTL = m_frame.lock();
-            frameTL->initPoolSize(width, height, core::tools::Type::s_FLOAT, data::FrameTL::PixelFormat::RGB);
+            frameTL->initPoolSize(width, height, core::Type::FLOAT, data::FrameTL::PixelFormat::RGB);
         }
         else
         {
