@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -19,6 +19,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINT
+
 #include "modules/io/session/SReader.hpp"
 
 #include <core/com/Signal.hxx>
@@ -56,9 +58,9 @@ public:
     ReaderImpl& operator=(ReaderImpl&&)      = delete;
 
     /// Constructor
-    inline ReaderImpl(SReader* const reader) noexcept :
+    inline explicit ReaderImpl(SReader* const reader) noexcept :
         m_reader(reader),
-        m_job_created_signal(reader->newSignal<JobCreatedSignal>("jobCreated"))
+        m_job_created_signal(reader->newSignal<signals::JobCreatedSignal>("jobCreated"))
     {
     }
 
@@ -75,19 +77,19 @@ public:
     std::string m_extension_description {"Sight session"};
 
     /// Dialog policy to use for the file location
-    DialogPolicy m_dialog_policy = {DialogPolicy::DEFAULT};
+    DialogPolicy m_dialog_policy = {DialogPolicy::NEVER};
 
     /// Password policy to use
-    PasswordKeeper::PasswordPolicy m_password_policy {PasswordKeeper::PasswordPolicy::DEFAULT};
+    PasswordKeeper::PasswordPolicy m_password_policy {PasswordKeeper::PasswordPolicy::NEVER};
 
     /// Encryption policy to use
-    PasswordKeeper::EncryptionPolicy m_encryption_policy {PasswordKeeper::EncryptionPolicy::DEFAULT};
+    PasswordKeeper::EncryptionPolicy m_encryption_policy {PasswordKeeper::EncryptionPolicy::PASSWORD};
 
     /// Archive format to use
     Archive::ArchiveFormat m_archive_format {Archive::ArchiveFormat::DEFAULT};
 
     /// Signal emitted when job created.
-    JobCreatedSignal::sptr m_job_created_signal;
+    signals::JobCreatedSignal::sptr m_job_created_signal;
 
     /// Used in case of bad password
     int m_password_retry {0};
@@ -96,6 +98,8 @@ public:
 SReader::SReader() noexcept :
     m_pimpl(std::make_unique<ReaderImpl>(this))
 {
+    newSignal<signals::SessionPathSignal>(signals::SESSION_LOADED);
+    newSignal<signals::SessionPathSignal>(signals::SESSION_LOADING_FAILED);
 }
 
 // Defining the destructor here, allows us to use PImpl with a unique_ptr
@@ -112,7 +116,10 @@ void SReader::starting()
 void SReader::stopping()
 {
     m_pimpl->m_password_retry = 0;
-    clearLocations();
+    if(m_pimpl->m_dialog_policy != DialogPolicy::NEVER)
+    {
+        clearLocations();
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -121,7 +128,7 @@ void SReader::configuring()
 {
     sight::io::base::service::IReader::configuring();
 
-    const auto& tree = this->getConfigTree();
+    const auto& tree = this->getConfiguration();
 
     // Extension configuration
     const auto& dialog = tree.get_child_optional("dialog.<xmlattr>");
@@ -216,35 +223,26 @@ void SReader::updating()
                 // No password management
                 return secure_string();
             }
-            else
-            {
-                const secure_string& globalPassword = PasswordKeeper::get_global_password();
 
-                if(m_pimpl->m_password_retry > 0
-                   || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ALWAYS)
-                   || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ONCE
-                       && globalPassword.empty()))
-                {
-                    sight::ui::base::dialog::InputDialog inputDialog;
-                    const auto& newPassword = secure_string(
-                        inputDialog.showInputDialog(
-                            "Enter Password",
-                            "Password:",
-                            globalPassword.c_str(),
-                            sight::ui::base::dialog::InputDialog::EchoMode::PASSWORD
-                        )
+            const secure_string& globalPassword = PasswordKeeper::get_global_password();
+
+            if(m_pimpl->m_password_retry > 0
+               || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ALWAYS)
+               || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::GLOBAL
+                   && globalPassword.empty()))
+            {
+                const auto& [newPassword, ok] =
+                    sight::ui::base::dialog::InputDialog::showInputDialog(
+                        "Enter Password",
+                        "Password:",
+                        globalPassword.c_str(), // NOLINT(readability-redundant-string-cstr)
+                        sight::ui::base::dialog::InputDialog::EchoMode::PASSWORD
                     );
 
-                    if(m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ONCE)
-                    {
-                        PasswordKeeper::set_global_password(newPassword);
-                    }
-
-                    return newPassword;
-                }
-
-                return globalPassword;
+                return secure_string(newPassword);
             }
+
+            return globalPassword;
         }();
 
     const auto readJob = core::jobs::Job::New(
@@ -256,7 +254,7 @@ void SReader::updating()
             // Create the session reader
             auto reader = sight::io::session::SessionReader::New();
             reader->setFile(filepath);
-            reader->set_password(password);
+            reader->setPassword(password);
             reader->setEncryptionPolicy(m_pimpl->m_encryption_policy);
             reader->setArchiveFormat(m_pimpl->m_archive_format);
 
@@ -275,13 +273,13 @@ void SReader::updating()
 
             auto sig = data->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
             {
-                core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+                core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
                 sig->asyncEmit();
             }
 
             runningJob.done();
         },
-        m_associatedWorker
+        this->worker()
     );
 
     core::jobs::Aggregator::sptr jobs = core::jobs::Aggregator::New(filepath.string() + " reader");
@@ -295,6 +293,9 @@ void SReader::updating()
         jobs->run().get();
         m_readFailed              = false;
         m_pimpl->m_password_retry = 0;
+
+        // Signal that we successfully read this file
+        this->signal<signals::SessionPathSignal>(signals::SESSION_LOADED)->asyncEmit(filepath);
     }
     catch(sight::io::zip::exception::BadPassword&)
     {
@@ -316,23 +317,23 @@ void SReader::updating()
         else
         {
             m_pimpl->m_password_retry = 0;
-
-            // Reset old wrong password
-            if(m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ONCE)
-            {
-                PasswordKeeper::reset_global_password();
-            }
         }
+
+        // Signal that we failed to read this file
+        this->signal<signals::SessionPathSignal>(signals::SESSION_LOADING_FAILED)->asyncEmit(filepath);
     }
-    catch(std::exception& _e)
+    catch(const std::exception& e)
     {
         // Handle the error.
-        SIGHT_ERROR(_e.what());
+        SIGHT_ERROR(e.what());
         sight::ui::base::dialog::MessageDialog::show(
             "Session reader failed",
-            _e.what(),
+            e.what(),
             sight::ui::base::dialog::IMessageDialog::CRITICAL
         );
+
+        // Signal that we failed to read this file
+        this->signal<signals::SessionPathSignal>(signals::SESSION_LOADING_FAILED)->asyncEmit(filepath);
     }
     catch(...)
     {
@@ -342,6 +343,9 @@ void SReader::updating()
             "Reading process aborted",
             sight::ui::base::dialog::IMessageDialog::WARNING
         );
+
+        // Signal that we failed to read this file
+        this->signal<signals::SessionPathSignal>(signals::SESSION_LOADING_FAILED)->asyncEmit(filepath);
     }
 }
 
@@ -376,7 +380,7 @@ void SReader::openLocationDialog()
     {
         const auto& filepath = result->getFile();
         setFile(filepath);
-        m_pimpl->m_extension_name = locationDialog.getCurrentSelection();
+        m_pimpl->m_extension_name = locationDialog.getSelectedExtensions().front();
 
         // Save default location for later use
         defaultLocation->setFolder(filepath.parent_path());
