@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021-2022 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -19,6 +19,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINT
+
 #include "modules/io/session/SWriter.hpp"
 
 #include <core/com/Signal.hxx>
@@ -27,6 +29,7 @@
 #include <core/jobs/Aggregator.hpp>
 #include <core/jobs/Job.hpp>
 #include <core/location/SingleFolder.hpp>
+#include <core/os/TempPath.hpp>
 #include <core/tools/System.hpp>
 
 #include <io/session/SessionWriter.hpp>
@@ -55,7 +58,7 @@ public:
     WriterImpl& operator=(WriterImpl&&)      = delete;
 
     /// Constructor
-    inline WriterImpl(SWriter* const writer) noexcept :
+    inline explicit WriterImpl(SWriter* const writer) noexcept :
         m_writer(writer),
         m_job_created_signal(writer->newSignal<JobCreatedSignal>("jobCreated"))
     {
@@ -74,13 +77,13 @@ public:
     std::string m_extension_description {"Sight session"};
 
     /// Dialog policy to use for the file location
-    DialogPolicy m_dialog_policy = {DialogPolicy::DEFAULT};
+    DialogPolicy m_dialog_policy = {DialogPolicy::NEVER};
 
     /// Password policy to use
-    PasswordKeeper::PasswordPolicy m_password_policy {PasswordKeeper::PasswordPolicy::DEFAULT};
+    PasswordKeeper::PasswordPolicy m_password_policy {PasswordKeeper::PasswordPolicy::NEVER};
 
     /// Encryption policy to use
-    PasswordKeeper::EncryptionPolicy m_encryption_policy {PasswordKeeper::EncryptionPolicy::DEFAULT};
+    PasswordKeeper::EncryptionPolicy m_encryption_policy {PasswordKeeper::EncryptionPolicy::PASSWORD};
 
     /// Archive format to use
     Archive::ArchiveFormat m_archive_format {Archive::ArchiveFormat::DEFAULT};
@@ -116,7 +119,7 @@ void SWriter::configuring()
 {
     sight::io::base::service::IWriter::configuring();
 
-    const auto& tree = this->getConfigTree();
+    const auto& tree = this->getConfiguration();
 
     // Dialog configuration
     const auto& dialog = tree.get_child_optional("dialog.<xmlattr>");
@@ -197,10 +200,16 @@ void SWriter::updating()
         filepath += m_pimpl->m_extension_name;
     }
 
+    // In case the path is computed instead of user-selected, make sure it exists
+    if(filepath.has_parent_path() && !std::filesystem::exists(filepath.parent_path()))
+    {
+        std::filesystem::create_directories(filepath.parent_path());
+    }
+
     SIGHT_THROW_IF("The file '" << filepath << "' is an existing folder.", std::filesystem::is_directory(filepath));
 
     // Generate temporary file
-    const core::tools::System::TemporaryFile temporaryFile;
+    const core::os::TempFile tempFile;
 
     // Ask password if needed
     const secure_string& password =
@@ -211,38 +220,30 @@ void SWriter::updating()
                 // No password management
                 return secure_string();
             }
-            else
-            {
-                const secure_string& globalPassword = PasswordKeeper::get_global_password();
 
-                if((m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ALWAYS)
-                   || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ONCE
-                       && globalPassword.empty()))
-                {
-                    sight::ui::base::dialog::InputDialog inputDialog;
-                    const auto& newPassword = secure_string(
-                        inputDialog.showInputDialog(
-                            "Enter Password",
-                            "Password:",
-                            globalPassword.c_str(),
-                            sight::ui::base::dialog::InputDialog::EchoMode::PASSWORD
-                        )
+            const secure_string& globalPassword = PasswordKeeper::get_global_password();
+
+            if((m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ALWAYS)
+               || (m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::GLOBAL
+                   && globalPassword.empty()))
+            {
+                const auto& [newPassword, ok] =
+                    sight::ui::base::dialog::InputDialog::showInputDialog(
+                        "Enter Password",
+                        "Password:",
+                        globalPassword.c_str(), // NOLINT(readability-redundant-string-cstr)
+                        sight::ui::base::dialog::InputDialog::EchoMode::PASSWORD
+
                     );
 
-                    if(m_pimpl->m_password_policy == PasswordKeeper::PasswordPolicy::ONCE)
-                    {
-                        PasswordKeeper::set_global_password(newPassword);
-                    }
-
-                    return newPassword;
-                }
-
-                return globalPassword;
+                return secure_string(newPassword);
             }
+
+            return globalPassword;
         }();
 
     const auto writeJob = core::jobs::Job::New(
-        "Writing " + temporaryFile.getTemporaryFilePath().string() + " file",
+        "Writing " + tempFile.string() + " file",
         [&](core::jobs::Job& runningJob)
         {
             runningJob.doneWork(10);
@@ -253,8 +254,8 @@ void SWriter::updating()
                 // The object must be unlocked since it will be locked again when writing
                 auto data = m_data.lock();
                 writer->setObject(data.get_shared());
-                writer->setFile(temporaryFile.getTemporaryFilePath());
-                writer->set_password(password);
+                writer->setFile(tempFile);
+                writer->setPassword(password);
                 writer->setEncryptionPolicy(m_pimpl->m_encryption_policy);
                 writer->setArchiveFormat(m_pimpl->m_archive_format);
             }
@@ -267,21 +268,21 @@ void SWriter::updating()
 
             runningJob.done();
         },
-        m_associatedWorker
+        this->worker()
     );
 
     const auto renameJob = core::jobs::Job::New(
-        "Rename file" + temporaryFile.getTemporaryFilePath().string() + " to " + filepath.string() + ".",
+        "Rename file" + tempFile.string() + " to " + filepath.string() + ".",
         [&](core::jobs::Job& runningJob)
         {
             runningJob.doneWork(80);
 
             // Robust rename
-            core::tools::System::robustRename(temporaryFile.getTemporaryFilePath(), filepath, true);
+            core::tools::System::robustRename(tempFile, filepath, true);
 
             runningJob.done();
         },
-        m_associatedWorker
+        this->worker()
     );
 
     core::jobs::Aggregator::sptr jobs = core::jobs::Aggregator::New(filepath.string() + " writer");
@@ -296,13 +297,13 @@ void SWriter::updating()
         jobs->run().get();
         m_writeFailed = false;
     }
-    catch(std::exception& _e)
+    catch(const std::exception& e)
     {
         // Handle the error.
-        SIGHT_ERROR(_e.what());
+        SIGHT_ERROR(e.what());
         sight::ui::base::dialog::MessageDialog::show(
             "Session writer failed",
-            _e.what(),
+            e.what(),
             sight::ui::base::dialog::IMessageDialog::CRITICAL
         );
     }
@@ -347,7 +348,7 @@ void SWriter::openLocationDialog()
     {
         const auto& filepath = result->getFile();
         setFile(filepath);
-        m_pimpl->m_extension_name = locationDialog.getCurrentSelection();
+        m_pimpl->m_extension_name = locationDialog.getSelectedExtensions().front();
 
         // Save default location for later use
         defaultLocation->setFolder(filepath.parent_path());
