@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2021 IRCAD France
+ * Copyright (C) 2021-2023 IRCAD France
  *
  * This file is part of Sight.
  *
@@ -23,32 +23,47 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::module::io::session
-{
-
-namespace ut
+namespace sight::module::io::session::ut
 {
 
 /**
- * @brief Test basic reader/writer for SeriesDB.
+ * @brief Test basic reader/writer for SeriesSet.
  */
 class SessionTest : public CPPUNIT_NS::TestFixture
 {
 CPPUNIT_TEST_SUITE(SessionTest);
 CPPUNIT_TEST(basicArchiveTest);
 CPPUNIT_TEST(basicRawTest);
+CPPUNIT_TEST(readerBadDialogPolicyTest);
+CPPUNIT_TEST(readerBadPasswordPolicyTest);
+CPPUNIT_TEST(readerBadPasswordEncryptionTest);
+CPPUNIT_TEST(readerBadFile);
+CPPUNIT_TEST(writerBadDialogPolicyTest);
+CPPUNIT_TEST(writerBadPasswordPolicyTest);
+CPPUNIT_TEST(writerBadPasswordEncryptionTest);
+CPPUNIT_TEST(fileDialogTest);
+CPPUNIT_TEST(passwordTest);
 CPPUNIT_TEST_SUITE_END();
 
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void basicArchiveTest();
-    void basicRawTest();
+    static void basicArchiveTest();
+    static void basicRawTest();
+
+    static void readerBadDialogPolicyTest();
+    static void readerBadPasswordPolicyTest();
+    static void readerBadPasswordEncryptionTest();
+    static void readerBadFile();
+    static void writerBadDialogPolicyTest();
+    static void writerBadPasswordPolicyTest();
+    static void writerBadPasswordEncryptionTest();
+
+    static void fileDialogTest();
+    static void passwordTest();
 };
 
-} // namespace ut
-
-} // namespace sight::module::io::session
+} // namespace sight::module::io::session::ut
