@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,14 +26,10 @@
 #include <core/com/Signal.hxx>
 #include <core/com/Slot.hxx>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/tools/Type.hpp>
 
 #include <data/Camera.hpp>
 #include <data/FrameTL.hpp>
 
-#include <service/macros.hpp>
-
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/base/Preferences.hpp>
 
@@ -41,40 +37,24 @@
 #include <opencv2/imgproc.hpp>
 
 #include <chrono>
+#include <cmath>
 #include <filesystem>
 #include <regex>
 
 namespace sight::module::io::video
 {
 
-static const core::com::Slots::SlotKeyType s_SET_STEP_SLOT = "setStep";
-
-using sight::io::base::service::IGrabber;
-
 // -----------------------------------------------------------------------------
 
-SFrameGrabber::SFrameGrabber() noexcept :
-    m_loopVideo(false),
-    m_isInitialized(false),
-    m_fps(30),
-    m_imageCount(0),
-    m_oneShot(false),
-    m_createNewTS(false),
-    m_useTimelapse(true),
-    m_isPaused(false),
-    m_defaultDuration(5000),
-    m_step(1),
-    m_stepChanged(1),
-    m_videoFramesNb(0)
+SFrameGrabber::SFrameGrabber() noexcept
 {
     newSlot(s_SET_STEP_SLOT, &SFrameGrabber::setStep, this);
 }
 
 // -----------------------------------------------------------------------------
 
-SFrameGrabber::~SFrameGrabber() noexcept
-{
-}
+SFrameGrabber::~SFrameGrabber() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
@@ -97,7 +77,7 @@ void SFrameGrabber::stopping()
 
 void SFrameGrabber::configuring()
 {
-    service::IService::ConfigType config = this->getConfigTree();
+    service::IService::ConfigType config = this->getConfiguration();
 
     m_fps = config.get<unsigned int>("fps", 30);
 
@@ -111,7 +91,7 @@ void SFrameGrabber::configuring()
 
     SIGHT_FATAL_IF("Fps setting is set to " << m_fps << " but should be in ]0;60].", m_fps == 0 || m_fps > 60);
 
-    m_step = config.get<unsigned long>("step", m_step);
+    m_step = config.get<std::uint64_t>("step", m_step);
     SIGHT_ASSERT("Step value is set to " << m_step << " but should be > 0.", m_step > 0);
     m_stepChanged = m_step;
 }
@@ -126,9 +106,17 @@ void SFrameGrabber::updating()
 
 void SFrameGrabber::startCamera()
 {
-    if(m_timer)
+    // Make sure the video is not paused
+    if(m_timer && m_isPaused)
     {
-        this->stopCamera();
+        m_isPaused = false;
+        m_timer->start();
+    }
+
+    if(this->started())
+    {
+        // Do not reset if we are already started
+        return;
     }
 
     const auto camera = m_camera.lock();
@@ -223,7 +211,7 @@ void SFrameGrabber::stopCamera()
         sigDuration->asyncEmit(static_cast<std::int64_t>(-1));
 
         const auto frameTL = m_frame.lock();
-        this->clearTimeline(*frameTL);
+        sight::module::io::video::SFrameGrabber::clearTimeline(*frameTL);
 
         const auto sig = this->signal<IGrabber::CameraStoppedSignalType>(IGrabber::s_CAMERA_STOPPED_SIG);
         sig->asyncEmit();
@@ -246,7 +234,7 @@ void SFrameGrabber::readVideo(const std::filesystem::path& file)
     {
         m_timer = m_worker->createTimer();
 
-        const std::size_t fps = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FPS));
+        const auto fps = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FPS));
         m_videoFramesNb = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FRAME_COUNT));
 
         if(fps == 0)
@@ -267,7 +255,7 @@ void SFrameGrabber::readVideo(const std::filesystem::path& file)
 
         core::thread::Timer::TimeDurationType duration = std::chrono::milliseconds(1000 / fps);
 
-        m_timer->setFunction(std::bind(&SFrameGrabber::grabVideo, this));
+        m_timer->setFunction([this](auto&& ...){grabVideo();});
         m_timer->setDuration(duration);
         m_timer->start();
 
@@ -335,7 +323,7 @@ void SFrameGrabber::readDevice(const data::Camera& _camera)
     {
         m_timer = m_worker->createTimer();
         float fps = _camera.getMaximumFrameRate();
-        fps = fps <= 0.f ? 30.f : fps;
+        fps = fps <= 0.F ? 30.F : fps;
         const std::size_t height = _camera.getHeight();
         const std::size_t width  = _camera.getWidth();
 
@@ -346,7 +334,7 @@ void SFrameGrabber::readDevice(const data::Camera& _camera)
         core::thread::Timer::TimeDurationType duration =
             std::chrono::milliseconds(1000 / static_cast<std::size_t>(fps));
 
-        m_timer->setFunction(std::bind(&SFrameGrabber::grabVideo, this));
+        m_timer->setFunction([this](auto&& ...){grabVideo();});
         m_timer->setDuration(duration);
         m_timer->start();
 
@@ -377,7 +365,7 @@ void SFrameGrabber::readStream(const data::Camera& _camera)
     {
         m_timer = m_worker->createTimer();
         float fps = _camera.getMaximumFrameRate();
-        fps = fps <= 0.f ? 30.f : fps;
+        fps = fps <= 0.F ? 30.F : fps;
         const std::size_t height = _camera.getHeight();
         const std::size_t width  = _camera.getWidth();
 
@@ -388,7 +376,7 @@ void SFrameGrabber::readStream(const data::Camera& _camera)
         const core::thread::Timer::TimeDurationType duration =
             std::chrono::milliseconds(1000 / static_cast<std::size_t>(fps));
 
-        m_timer->setFunction(std::bind(&SFrameGrabber::grabVideo, this));
+        m_timer->setFunction([this](auto&& ...){grabVideo();});
         m_timer->setDuration(duration);
         m_timer->start();
 
@@ -463,8 +451,8 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
 
         if(width > 0 && height > 0)
         {
-            const std::size_t w = static_cast<std::size_t>(width);
-            const std::size_t h = static_cast<std::size_t>(height);
+            const auto w = static_cast<std::size_t>(width);
+            const auto h = static_cast<std::size_t>(height);
 
             auto frameTL = m_frame.lock();
 
@@ -474,7 +462,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                     frameTL->initPoolSize(
                         w,
                         h,
-                        core::tools::Type::s_UINT8,
+                        core::Type::UINT8,
                         sight::data::FrameTL::PixelFormat::GRAY_SCALE
                     );
                     break;
@@ -483,7 +471,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                     frameTL->initPoolSize(
                         w,
                         h,
-                        core::tools::Type::s_UINT8,
+                        core::Type::UINT8,
                         sight::data::FrameTL::PixelFormat::RGB
                     );
                     break;
@@ -492,7 +480,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                     frameTL->initPoolSize(
                         w,
                         h,
-                        core::tools::Type::s_UINT8,
+                        core::Type::UINT8,
                         sight::data::FrameTL::PixelFormat::RGBA
                     );
                     break;
@@ -501,7 +489,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                     frameTL->initPoolSize(
                         w,
                         h,
-                        core::tools::Type::s_UINT16,
+                        core::Type::UINT16,
                         sight::data::FrameTL::PixelFormat::GRAY_SCALE
                     );
                     break;
@@ -520,7 +508,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
 
         const auto sigDuration = this->signal<DurationModifiedSignalType>(s_DURATION_MODIFIED_SIG);
 
-        std::int64_t videoDuration;
+        std::int64_t videoDuration = 0;
         if(!m_useTimelapse)
         {
             videoDuration = static_cast<std::int64_t>(m_imageToRead.size() * m_fps);
@@ -540,7 +528,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
         {
             m_timer = m_worker->createTimer();
             m_timer->setOneShot(true);
-            m_timer->setFunction(std::bind(&SFrameGrabber::grabImage, this));
+            m_timer->setFunction([this](auto&& ...){grabImage();});
             m_timer->setDuration(std::chrono::milliseconds(0));
             m_timer->start();
         }
@@ -566,7 +554,7 @@ void SFrameGrabber::readImages(const std::filesystem::path& folder, const std::s
                 return;
             }
 
-            m_timer->setFunction(std::bind(&SFrameGrabber::grabImage, this));
+            m_timer->setFunction([this](auto&& ...){grabImage();});
             m_timer->setDuration(duration);
             m_timer->start();
         }
@@ -596,10 +584,12 @@ void SFrameGrabber::grabVideo()
             cv::Mat image;
             m_videoCapture.retrieve(image);
 
+            this->updateZoom(image);
+
             if(!m_isInitialized)
             {
-                const std::size_t width  = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FRAME_WIDTH));
-                const std::size_t height = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FRAME_HEIGHT));
+                const auto width  = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FRAME_WIDTH));
+                const auto height = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_FRAME_HEIGHT));
 
                 const std::size_t w = static_cast<std::size_t>(image.size().width);
                 const std::size_t h = static_cast<std::size_t>(image.size().height);
@@ -619,7 +609,7 @@ void SFrameGrabber::grabVideo()
                         frameTL->initPoolSize(
                             width,
                             height,
-                            core::tools::Type::s_UINT8,
+                            core::Type::UINT8,
                             sight::data::FrameTL::PixelFormat::GRAY_SCALE
                         );
                         break;
@@ -628,7 +618,7 @@ void SFrameGrabber::grabVideo()
                         frameTL->initPoolSize(
                             width,
                             height,
-                            core::tools::Type::s_UINT8,
+                            core::Type::UINT8,
                             sight::data::FrameTL::PixelFormat::RGB
                         );
                         break;
@@ -637,7 +627,7 @@ void SFrameGrabber::grabVideo()
                         frameTL->initPoolSize(
                             width,
                             height,
-                            core::tools::Type::s_UINT8,
+                            core::Type::UINT8,
                             sight::data::FrameTL::PixelFormat::RGBA
                         );
                         break;
@@ -646,7 +636,7 @@ void SFrameGrabber::grabVideo()
                         frameTL->initPoolSize(
                             width,
                             height,
-                            core::tools::Type::s_UINT16,
+                            core::Type::UINT16,
                             sight::data::FrameTL::PixelFormat::GRAY_SCALE
                         );
                         break;
@@ -663,7 +653,7 @@ void SFrameGrabber::grabVideo()
             }
 
             // Get time slider position.
-            const std::size_t ms   = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_POS_MSEC));
+            const auto ms          = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_POS_MSEC));
             const auto sigPosition = this->signal<PositionModifiedSignalType>(s_POSITION_MODIFIED_SIG);
             sigPosition->asyncEmit(static_cast<std::int64_t>(ms));
 
@@ -699,7 +689,7 @@ void SFrameGrabber::grabVideo()
         if(m_loopVideo)
         {
             // Loop the video.
-            const std::size_t currentF = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_POS_FRAMES));
+            const auto currentF = static_cast<std::size_t>(m_videoCapture.get(cv::CAP_PROP_POS_FRAMES));
 
             if(currentF == m_videoFramesNb)
             {
@@ -725,8 +715,8 @@ void SFrameGrabber::grabImage()
 
         const std::filesystem::path imagePath = m_imageToRead[m_imageCount];
 
-        const cv::Mat image = cv::imread(imagePath.string(), cv::IMREAD_UNCHANGED);
-        core::HiResClock::HiResClockType timestamp;
+        const cv::Mat image                        = cv::imread(imagePath.string(), cv::IMREAD_UNCHANGED);
+        core::HiResClock::HiResClockType timestamp = NAN;
 
         //create a new timestamp
         if(m_createNewTS)
@@ -739,6 +729,8 @@ void SFrameGrabber::grabImage()
             timestamp = m_imageTimestamps[m_imageCount];
         }
 
+        this->updateZoom(image);
+
         SIGHT_DEBUG("Reading image index " << m_imageCount << " with timestamp " << timestamp);
 
         const std::size_t width  = static_cast<std::size_t>(image.size().width);
@@ -800,6 +792,7 @@ void SFrameGrabber::grabImage()
                     m_timer->stop();
                     if(m_loopVideo)
                     {
+                        frameTL->clearTimeline();
                         m_imageCount = 0;
                         core::thread::Timer::TimeDurationType duration = std::chrono::milliseconds(1000 / m_fps);
                         m_timer->setDuration(duration);
@@ -827,10 +820,45 @@ void SFrameGrabber::grabImage()
     }
     else if(!m_isPaused && m_loopVideo)
     {
+        const auto frameTL = m_frame.lock();
+        frameTL->clearTimeline();
         m_imageCount = 0;
     }
 }
 
+//------------------------------------------------------------------------------
+
+void SFrameGrabber::updateZoom(cv::Mat image)
+{
+    if(m_zoomCenter.has_value())
+    {
+        // Compute zoom parameters
+        const int width             = image.size().width;
+        const int height            = image.size().height;
+        const int croppedAreaWidth  = width / m_zoomFactor;
+        const int croppedAreaHeight = height / m_zoomFactor;
+
+        // Compute correct position for zoom center
+        const int centerXPix = (m_zoomCenter.value()[0] + width / 2);
+        const int centerYPix = -(m_zoomCenter.value()[1]) + height / 2;
+
+        // Compute starting area of zoom rectangle in pixels
+        const int x1 = centerXPix - croppedAreaWidth / 2;
+        const int y1 = centerYPix - croppedAreaHeight / 2;
+
+        // Compute a padded zoomed area image
+        const auto imageRect    = cv::Rect({}, image.size());
+        const auto roi          = cv::Rect(x1, y1, croppedAreaWidth, croppedAreaHeight);
+        const auto intersection = imageRect & roi;
+        const auto interRoi     = intersection - roi.tl();
+        cv::Mat crop            = cv::Mat::zeros(roi.size(), image.type());
+        image(intersection).copyTo(crop(interRoi));
+
+        // Rescale the zoomed image
+        cv::resize(crop, image, image.size());
+    }
+}
+
 // -----------------------------------------------------------------------------
 
 void SFrameGrabber::toggleLoopMode()
@@ -850,7 +878,7 @@ void SFrameGrabber::setPosition(int64_t position)
     }
     else if(!m_imageToRead.empty())
     {
-        const std::size_t newPos = static_cast<std::size_t>(position / 30);
+        const auto newPos = static_cast<std::size_t>(position / 30);
         if(newPos < m_imageToRead.size())
         {
             m_imageCount = newPos;
@@ -865,10 +893,11 @@ void SFrameGrabber::nextImage()
     if(m_oneShot)
     {
         // Compute difference between a possible step change in setStep() slot and the current step value
-        const long shift             = static_cast<long>(m_stepChanged) - static_cast<long>(m_step);
-        const long shiftedImageCount = static_cast<long>(m_imageCount) + shift;
+        const std::int64_t shift = static_cast<std::int64_t>(m_stepChanged)
+                                   - static_cast<std::int64_t>(m_step);
+        const std::int64_t shiftedImageCount = static_cast<std::int64_t>(m_imageCount) + shift;
 
-        if(shiftedImageCount < static_cast<long>(m_imageToRead.size()))
+        if(shiftedImageCount < static_cast<std::int64_t>(m_imageToRead.size()))
         {
             // Update image position index
             m_imageCount = static_cast<std::size_t>(shiftedImageCount);
@@ -896,8 +925,9 @@ void SFrameGrabber::previousImage()
         if(m_imageCount - m_step >= m_stepChanged)
         {
             // Compute difference between a possible step change in setStep() slot and the current step value
-            const long shift             = static_cast<long>(m_stepChanged) - static_cast<long>(m_step);
-            const long shiftedimageCount = static_cast<long>(m_imageCount) - shift;
+            const std::int64_t shift = static_cast<std::int64_t>(m_stepChanged)
+                                       - static_cast<std::int64_t>(m_step);
+            const std::int64_t shiftedimageCount = static_cast<std::int64_t>(m_imageCount) - shift;
 
             // Update image position index
             // m_imageCount is pointing to next image, so -1 = present image
@@ -919,13 +949,14 @@ void SFrameGrabber::previousImage()
 
 //-----------------------------------------------------------------------------
 
-void SFrameGrabber::setStep(int step, std::string key)
+void SFrameGrabber::setParameter(ui::base::parameter_t value, std::string key)
 {
     if(key == "step")
     {
+        const int step = std::get<int>(value);
         SIGHT_ASSERT("Needed step value (" << step << ") should be > 0.", step > 0);
         // Save the changed step value
-        m_stepChanged = static_cast<unsigned long>(step);
+        m_stepChanged = static_cast<std::uint64_t>(step);
     }
     else
     {
@@ -935,4 +966,27 @@ void SFrameGrabber::setStep(int step, std::string key)
 
 //------------------------------------------------------------------------------
 
+void SFrameGrabber::setStep(int step, std::string key)
+{
+    this->setParameter(step, key);
+}
+
+//------------------------------------------------------------------------------
+
+void SFrameGrabber::addROICenter(sight::data::Point::sptr p)
+{
+    const auto& coord = p->getCoord();
+
+    m_zoomCenter = {{static_cast<int>(std::nearbyint(coord[0])), static_cast<int>(std::nearbyint(coord[1]))}};
+}
+
+//------------------------------------------------------------------------------
+
+void SFrameGrabber::removeROICenter(sight::data::Point::sptr /*p*/)
+{
+    m_zoomCenter.reset();
+}
+
+//------------------------------------------------------------------------------
+
 } // namespace sight::module::io::video
