@@ -41,7 +41,7 @@ namespace sight::data
 
 class Camera;
 
-}
+} // namespace sight::data
 
 namespace sight::module::io::video
 {
@@ -71,6 +71,8 @@ namespace sight::module::io::video
  * - \b previousImage() : Read the previous image (in frame-by-frame mode).
  * - \b setStep(int step, std::string key) : set the step value between two images when calling nextImage/previousImage
  * slots on oneShot mode (supported key: "step")
+ * - \b addROICenter(sight::data::Point::sptr): Adds a new region fo interest center.
+ * - \b removeROICenter(sight::data::Point::sptr): Removes a region of interest via its center.
  *
  * @section XML XML Configuration
  *
@@ -114,7 +116,9 @@ public:
     MODULE_IO_VIDEO_API SFrameGrabber() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_IO_VIDEO_API virtual ~SFrameGrabber() noexcept;
+    MODULE_IO_VIDEO_API ~SFrameGrabber() noexcept override;
+
+    MODULE_IO_VIDEO_API void setParameter(ui::base::parameter_t value, std::string key) override;
 
 protected:
 
@@ -154,6 +158,14 @@ protected:
     /// SLOT: Set step used on readPrevious/readNext slots
     void setStep(int step, std::string key) override;
 
+    /// SLOT: Adds a region of interest center. Currently this function implements image zoom.
+    ///       The added point can be forwarded from a picker in singlePointMode for example.
+    void addROICenter(sight::data::Point::sptr p) final;
+
+    /// SLOT: Removes a region of interest center. Currently this function relates to image zoom.
+    ///       The removed point can be forwarded from a picker in singlePointMode for example.
+    void removeROICenter(sight::data::Point::sptr p) final;
+
 private:
 
     typedef std::vector<std::filesystem::path> ImageFilesType;
@@ -177,17 +189,20 @@ private:
     /// Reads the next image.
     void grabImage();
 
+    /// Updates the image if zoom is requested
+    void updateZoom(cv::Mat image);
+
     /// State of the loop mode.
-    bool m_loopVideo;
+    bool m_loopVideo {false};
 
     /// State of the timeline initialization.
-    bool m_isInitialized;
+    bool m_isInitialized {false};
 
     /// Fps used to read the video.
-    unsigned int m_fps;
+    unsigned int m_fps {30};
 
     /// Counter used by the image reader.
-    std::size_t m_imageCount;
+    std::size_t m_imageCount {0};
 
     core::thread::Timer::sptr m_timer;
 
@@ -203,32 +218,38 @@ private:
     /// List of the image timestamps.
     ImageTimestampsType m_imageTimestamps;
 
+    /// Zoom factor
+    int m_zoomFactor {2};
+
+    /// Zoom center, if defined
+    std::optional<std::array<int, 2> > m_zoomCenter;
+
     /// Mutex to protect concurrent access for m_videoCapture and m_imageToRead.
     mutable core::mt::Mutex m_mutex;
 
     /// Frame -by-frame mode (true if enabled, false otherwise).
-    bool m_oneShot;
+    bool m_oneShot {false};
 
     /// If true: create a new timestamp when reading image, if false: use the name of the image file as timestamp.
-    bool m_createNewTS;
+    bool m_createNewTS {false};
 
     /// If true: the difference between two image's timestamps will be use as timer duration.
-    bool m_useTimelapse;
+    bool m_useTimelapse {true};
 
     /// If true: the grabber is paused.
-    bool m_isPaused;
+    bool m_isPaused {false};
 
     /// If timestamp cannot be deduced from filename use the default duration (5000ms).
-    double m_defaultDuration;
+    double m_defaultDuration {5000};
 
     /// Step between two images when calling nexImage()/previousImage() slots
-    unsigned long m_step;
+    std::uint64_t m_step {1};
 
     /// Step value updated in setStep() slot used to compute a shift value when calling nextImage()/previousImage()
-    unsigned long m_stepChanged;
+    std::uint64_t m_stepChanged {1};
 
     /// Total number of frames in a video file.
-    std::size_t m_videoFramesNb;
+    std::size_t m_videoFramesNb {0};
 
     data::ptr<data::Camera, data::Access::in> m_camera {this, s_CAMERA_INPUT};
 };
