@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,12 +26,12 @@
 #include <core/com/Slots.hxx>
 
 #include <data/Camera.hpp>
-#include <data/CameraSeries.hpp>
+#include <data/CameraSet.hpp>
 #include <data/FrameTL.hpp>
 
 #include <service/extension/Config.hpp>
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/base/dialog/SelectorDialog.hpp>
@@ -44,36 +44,31 @@ namespace sight::module::io::video
 
 //-----------------------------------------------------------------------------
 
-const core::com::Slots::SlotKeyType SGrabberProxy::s_RECONFIGURE_SLOT = "reconfigure";
-
-const core::com::Slots::SlotKeyType s_MODIFY_POSITION = "modifyPosition";
-const core::com::Slots::SlotKeyType s_MODIFY_DURATION = "modifyDuration";
-
-const core::com::Slots::SlotKeyType s_FWD_START_CAMERA_SLOT = "forwardStartCamera";
-const core::com::Slots::SlotKeyType s_FWD_STOP_CAMERA_SLOT  = "forwardStopCamera";
-
-const core::com::Slots::SlotKeyType s_FWD_PRESENT_FRAME_SLOT = "forwardPresentFrame";
-
 using sight::io::base::service::IGrabber;
 
 //-----------------------------------------------------------------------------
 
 SGrabberProxy::SGrabberProxy() noexcept
 {
-    newSlot(s_RECONFIGURE_SLOT, &SGrabberProxy::reconfigure, this);
+    newSlot(slots::RECONFIGURE, &SGrabberProxy::reconfigure, this);
+    newSlot(slots::START_TARGET_CAMERA, &SGrabberProxy::startTargetCamera, this);
 
-    newSlot(s_MODIFY_POSITION, &SGrabberProxy::modifyPosition, this);
-    newSlot(s_MODIFY_DURATION, &SGrabberProxy::modifyDuration, this);
-    newSlot(s_FWD_START_CAMERA_SLOT, &SGrabberProxy::fwdStartCamera, this);
-    newSlot(s_FWD_STOP_CAMERA_SLOT, &SGrabberProxy::fwdStopCamera, this);
-    newSlot(s_FWD_PRESENT_FRAME_SLOT, &SGrabberProxy::fwdPresentFrame, this);
+    newSlot(slots::MODIFY_POSITION, &SGrabberProxy::modifyPosition, this);
+    newSlot(slots::MODIFY_DURATION, &SGrabberProxy::modifyDuration, this);
+    newSlot(slots::FWD_START_CAMERA, &SGrabberProxy::fwdStartCamera, this);
+    newSlot(slots::FWD_STOP_CAMERA, &SGrabberProxy::fwdStopCamera, this);
+    newSlot(slots::FWD_PRESENT_FRAME, &SGrabberProxy::fwdPresentFrame, this);
+
+    newSlot(slots::FWD_NOTIFY, &SGrabberProxy::fwdNotify, this);
+
+    newSlot(slots::FWD_SET_PARAMETER, &SGrabberProxy::fwdSetParameter, this);
+    newSlot(slots::FWD_CREATE_JOB, &SGrabberProxy::fwdCreateJob, this);
 }
 
 //-----------------------------------------------------------------------------
 
-SGrabberProxy::~SGrabberProxy() noexcept
-{
-}
+SGrabberProxy::~SGrabberProxy() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -102,7 +97,7 @@ void SGrabberProxy::stopping()
 
 void SGrabberProxy::configuring()
 {
-    const auto config = this->getConfigTree();
+    const auto config = this->getConfiguration();
 
     auto itSubConfig = config.find("config");
 
@@ -129,7 +124,7 @@ void SGrabberProxy::configuring()
         const auto selectionCfg = subConfig.equal_range("addSelection");
         for(auto itSelection = selectionCfg.first ; itSelection != selectionCfg.second ; ++itSelection)
         {
-            const std::string service = itSelection->second.get<std::string>("<xmlattr>.service");
+            const auto service = itSelection->second.get<std::string>("<xmlattr>.service");
             m_selectedServices.insert(service);
             SIGHT_DEBUG("add selection => " + service);
 
@@ -137,17 +132,21 @@ void SGrabberProxy::configuring()
             // Check if service is not empty.
             SIGHT_ASSERT("add selection with config but service is missing", !service.empty());
             m_serviceToConfig[service].push_back(configId);
-            SIGHT_DEBUG("add config '" + configId + "' for service '" + service + "'");
+            SIGHT_DEBUG(
+                std::string("add config '") + configId + "' for service '" + service + "'"
+            );
         }
 
         const auto configCfg = subConfig.equal_range("config");
         for(auto itCfg = configCfg.first ; itCfg != configCfg.second ; ++itCfg)
         {
-            const std::string service  = itCfg->second.get<std::string>("<xmlattr>.service");
-            const std::string configId = itCfg->second.get<std::string>("<xmlattr>.id");
+            const auto service  = itCfg->second.get<std::string>("<xmlattr>.service");
+            const auto configId = itCfg->second.get<std::string>("<xmlattr>.id");
 
             m_serviceToConfig[service].push_back(configId);
-            SIGHT_DEBUG("add config '" + configId + "' for service '" + service + "'");
+            SIGHT_DEBUG(
+                std::string("add config '") + configId + "' for service '" + service + "'"
+            );
         }
 
         m_guiTitle = subConfig.get<std::string>("gui.<xmlattr>.title", m_guiTitle);
@@ -163,6 +162,13 @@ void SGrabberProxy::updating()
 //-----------------------------------------------------------------------------
 
 void SGrabberProxy::startCamera()
+{
+    this->startTargetCamera("");
+}
+
+//-----------------------------------------------------------------------------
+
+void SGrabberProxy::startTargetCamera(std::string impl)
 {
     if(m_services.empty())
     {
@@ -184,6 +190,18 @@ void SGrabberProxy::startCamera()
 
             std::move(rgbGrabbersImpl.begin(), rgbGrabbersImpl.end(), std::back_inserter(grabbersImpl));
 
+            // If we asked for a specific implementation
+            // Filter the other out
+            if(!impl.empty())
+            {
+                std::erase_if(
+                    grabbersImpl,
+                    [&](std::string g)
+                    {
+                        return g != impl;
+                    });
+            }
+
             data::Camera::SourceType sourceType = data::Camera::UNKNOWN;
 
             std::size_t numCamerasInSeries = 1;
@@ -197,14 +215,14 @@ void SGrabberProxy::startCamera()
                 }
                 else
                 {
-                    auto cameraSeries = std::dynamic_pointer_cast<const data::CameraSeries>(cameraInput.get_shared());
-                    if(cameraSeries)
+                    auto camera_set = std::dynamic_pointer_cast<const data::CameraSet>(cameraInput.get_shared());
+                    if(camera_set)
                     {
-                        numCamerasInSeries = cameraSeries->numCameras();
+                        numCamerasInSeries = camera_set->size();
                         SIGHT_ASSERT("Camera Series is empty", numCamerasInSeries);
 
                         // Assume same source on all cameras
-                        sourceType = cameraSeries->getCamera(0)->getCameraSource();
+                        sourceType = camera_set->get_camera(0)->getCameraSource();
                     }
                 }
             }
@@ -218,7 +236,7 @@ void SGrabberProxy::startCamera()
                 {
                     SIGHT_DEBUG("Evaluating if implementation '" + srvImpl + "' is suitable...");
                     auto objectsType  = srvFactory->getServiceObjects(srvImpl);
-                    const auto config = this->getConfigTree();
+                    const auto config = this->getConfiguration();
 
                     // 1. Verify that we have the same number of timelines
                     objectsType.erase(
@@ -238,9 +256,9 @@ void SGrabberProxy::startCamera()
                     {
                         service::IService::ConfigType parameterCfg;
 
-                        const std::string key = itCfg->second.get<std::string>("<xmlattr>.key");
+                        const auto key = itCfg->second.get<std::string>("<xmlattr>.key");
                         SIGHT_DEBUG("Evaluating if key '" + key + "' is suitable...");
-                        const auto obj = this->getInOut<data::Object>(key).lock();
+                        const auto obj = this->getInOut(key).lock();
                         SIGHT_ASSERT("Object key '" + key + "' not found", obj);
                         if(obj->getClassname() == "data::FrameTL")
                         {
@@ -334,7 +352,7 @@ void SGrabberProxy::startCamera()
                     {
                         // Find all configurations for the given grabber.
                         selectableConfigs = srvConfigFactory->getAllConfigForService(extension, true);
-                        selectableConfigs.push_back(""); // Add the empty config (default grabber).
+                        selectableConfigs.emplace_back(""); // Add the empty config (default grabber).
 
                         // Remove configs from the grabber's list.
                         if(configsIt != m_serviceToConfig.end())
@@ -372,7 +390,7 @@ void SGrabberProxy::startCamera()
                 }
 
                 std::string selectedDesc;
-                if(descriptions.size() == 0)
+                if(descriptions.empty())
                 {
                     const std::string msg = "No video grabber implementation found.\n";
                     sight::ui::base::dialog::MessageDialog::show(
@@ -382,7 +400,8 @@ void SGrabberProxy::startCamera()
                     );
                     return;
                 }
-                else if(descriptions.size() == 1)
+
+                if(descriptions.size() == 1)
                 {
                     /// Select the only remaining description.
                     selectedDesc = descriptions[0];
@@ -425,44 +444,48 @@ void SGrabberProxy::startCamera()
                 }
                 else
                 {
-                    auto cameraSeries = data::CameraSeries::dynamicConstCast(cameraInput.get_shared());
-                    if(cameraSeries)
+                    auto camera_set = data::CameraSet::dynamicConstCast(cameraInput.get_shared());
+                    if(camera_set)
                     {
                         #ifdef DEBUG
-                        const std::size_t numCameras = cameraSeries->numCameras();
+                        const std::size_t numCameras = camera_set->size();
                         SIGHT_ASSERT(
                             "Not enough cameras in series to emulate the grabber",
                             srvCount < numCameras
                         );
                         #endif
 
-                        srv->setInput(cameraSeries->getCamera(srvCount), s_CAMERA_INPUT);
+                        srv->setInput(camera_set->get_camera(srvCount), s_CAMERA_INPUT);
                     }
                 }
 
                 std::size_t inputTLCount = 0;
-                const auto proxyConfig   = this->getConfigTree();
+                const auto proxyConfig   = this->getConfiguration();
                 auto inoutsCfg           = proxyConfig.equal_range("inout");
                 for(auto itCfg = inoutsCfg.first ; itCfg != inoutsCfg.second ; ++itCfg)
                 {
-                    const std::string key = itCfg->second.get<std::string>("<xmlattr>.key");
+                    const auto key = itCfg->second.get<std::string>("<xmlattr>.key");
                     SIGHT_ASSERT("Missing 'key' tag.", !key.empty());
 
-                    auto frameTL = this->getInOut<data::FrameTL>(key).lock();
-                    if(frameTL)
+                    auto inout = this->getInOut(key).lock();
+                    if(inout)
                     {
-                        if(m_services.size() > 1)
+                        if(key == IGrabber::s_FRAMETL_INOUT)
                         {
-                            if(inputTLCount == srvCount)
+                            auto frameTL = data::FrameTL::dynamicCast(inout.get_shared());
+                            if(m_services.size() > 1)
                             {
-                                // We are emulating a grabber with several ones, reuse the first TL slot
-                                srv->setInOut(frameTL.get_shared(), s_FRAMETL_INOUT);
-                                break;
+                                if(inputTLCount == srvCount)
+                                {
+                                    // We are emulating a grabber with several ones, reuse the first TL slot
+                                    srv->setInOut(frameTL, IGrabber::s_FRAMETL_INOUT);
+                                    break;
+                                }
+                            }
+                            else
+                            {
+                                srv->setInOut(frameTL, IGrabber::s_FRAMETL_INOUT);
                             }
-                        }
-                        else
-                        {
-                            srv->setInOut(frameTL.get_shared(), key);
                         }
                     }
 
@@ -472,21 +495,42 @@ void SGrabberProxy::startCamera()
                 if(!m_grabberConfig.empty())
                 {
                     const auto& srvConfigRegistry = service::extension::Config::getDefault();
-
-                    core::runtime::ConfigurationElement::csptr srvCfg =
-                        srvConfigRegistry->getServiceConfig(m_grabberConfig, m_grabberImpl);
-                    srv->setConfiguration(core::runtime::ConfigurationElement::constCast(srvCfg));
+                    const auto srvCfg             = srvConfigRegistry->getServiceConfig(m_grabberConfig, m_grabberImpl);
+                    srv->setConfiguration(srvCfg);
                     srv->configure();
                 }
 
-                srv->setWorker(m_associatedWorker);
+                srv->setWorker(this->worker());
                 srv->start();
 
-                m_connections.connect(srv, IGrabber::s_POSITION_MODIFIED_SIG, this->getSptr(), s_MODIFY_POSITION);
-                m_connections.connect(srv, IGrabber::s_DURATION_MODIFIED_SIG, this->getSptr(), s_MODIFY_DURATION);
-                m_connections.connect(srv, IGrabber::s_CAMERA_STARTED_SIG, this->getSptr(), s_FWD_START_CAMERA_SLOT);
-                m_connections.connect(srv, IGrabber::s_CAMERA_STOPPED_SIG, this->getSptr(), s_FWD_STOP_CAMERA_SLOT);
-                m_connections.connect(srv, IGrabber::s_FRAME_PRESENTED_SIG, this->getSptr(), s_FWD_PRESENT_FRAME_SLOT);
+                m_connections.connect(srv, IGrabber::s_POSITION_MODIFIED_SIG, this->getSptr(), slots::MODIFY_POSITION);
+                m_connections.connect(srv, IGrabber::s_DURATION_MODIFIED_SIG, this->getSptr(), slots::MODIFY_DURATION);
+                m_connections.connect(srv, IGrabber::s_CAMERA_STARTED_SIG, this->getSptr(), slots::FWD_START_CAMERA);
+                m_connections.connect(srv, IGrabber::s_CAMERA_STOPPED_SIG, this->getSptr(), slots::FWD_STOP_CAMERA);
+                m_connections.connect(srv, IGrabber::s_FRAME_PRESENTED_SIG, this->getSptr(), slots::FWD_PRESENT_FRAME);
+
+                m_connections.connect(srv, INotifier::signals::s_NOTIFIED, this->getSptr(), slots::FWD_NOTIFY);
+
+                m_connections.connect(
+                    srv,
+                    IGrabber::s_PARAMETER_CHANGED_SIG,
+                    this->getSptr(),
+                    slots::FWD_SET_PARAMETER
+                );
+
+                m_connections.connect(
+                    srv,
+                    IGrabber::s_JOB_CREATED_SIG,
+                    this->getSptr(),
+                    slots::FWD_CREATE_JOB
+                );
+
+                m_connections.connect(
+                    srv,
+                    IGrabber::s_FPS_CHANGED_SIG,
+                    this->getSptr(),
+                    IGrabber::s_FORWARD_FPS_CHANGED_SLOT
+                );
 
                 ++srvCount;
             }
@@ -585,7 +629,72 @@ void SGrabberProxy::setStep(int step, std::string key)
     {
         if(srv != nullptr)
         {
-            srv->setStep(step, key);
+            srv->setParameter(step, key);
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::setParameter(ui::base::parameter_t value, std::string key)
+{
+    for(auto& srv : m_services)
+    {
+        if(srv != nullptr)
+        {
+            srv->setParameter(value, key);
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::requestSettings()
+{
+    for(auto& srv : m_services)
+    {
+        if(srv != nullptr)
+        {
+            srv->requestSettings();
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::optimize()
+{
+    for(auto& srv : m_services)
+    {
+        if(srv != nullptr)
+        {
+            srv->optimize();
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::addROICenter(sight::data::Point::sptr p)
+{
+    for(auto& srv : m_services)
+    {
+        if(srv != nullptr)
+        {
+            srv->addROICenter(p);
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::removeROICenter(sight::data::Point::sptr p)
+{
+    for(auto& srv : m_services)
+    {
+        if(srv != nullptr)
+        {
+            srv->removeROICenter(p);
         }
     }
 }
@@ -653,4 +762,35 @@ void SGrabberProxy::fwdPresentFrame()
 
 //-----------------------------------------------------------------------------
 
+void SGrabberProxy::fwdNotify(service::Notification notification)
+{
+    INotifier::m_notified_sig->asyncEmit(std::move(notification));
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::fwdSetParameter(ui::base::parameter_t value, std::string key)
+{
+    auto sig = this->signal<IGrabber::ParameterChangedSignalType>(IGrabber::s_PARAMETER_CHANGED_SIG);
+    sig->asyncEmit(value, key);
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::fwdCreateJob(sight::core::jobs::IJob::sptr job)
+{
+    auto sig = this->signal<IGrabber::JobCreatedSignalType>(IGrabber::s_JOB_CREATED_SIG);
+    sig->asyncEmit(job);
+}
+
+//------------------------------------------------------------------------------
+
+void SGrabberProxy::forwardFPSChanged(double fps)
+{
+    auto sig = this->signal<IGrabber::FPSChangedSignalType>(IGrabber::s_FPS_CHANGED_SIG);
+    sig->asyncEmit(fps);
+}
+
+//------------------------------------------------------------------------------
+
 } // namespace sight::module::io::video
