@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2021 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,13 +29,14 @@
 #include <io/base/service/IGrabber.hpp>
 
 #include <service/IHasServices.hpp>
+#include <service/INotifier.hpp>
 
 namespace sight::data
 {
 
 class Camera;
 
-}
+} // namespace sight::data
 
 namespace sight::module::io::video
 {
@@ -48,22 +49,26 @@ namespace sight::module::io::video
  * implementation available, a dialog proposes the user to make a choice.
  *
  * @section Signals Signals
- * - \b positionModified(std::int64_t) : Emitted when the position in the video is modified during playing.
- * - \b durationModified(std::int64_t) : Emitted when the duration of the video is modified.
+ * - \b positionModified(std::int64_t): Emitted when the position in the video is modified during playing.
+ * - \b durationModified(std::int64_t): Emitted when the duration of the video is modified.
  *
  * @section Slots Slots
- * - \b startCamera() : Start playing the camera or the video.
- * - \b stopCamera() : Stop playing the camera or the video.
- * - \b pauseCamera() : Pause the video, it has no effect when playing a camera.
- * - \b loopVideo() : Toggle the loop of the playing.
- * - \b setPositionVideo(int) : Force the current time in the video.
- * - \b reconfigure() : Allows to erase the implementation choice, so that the selection routine is ran again, thus,
+ * - \b startCamera(): Start playing the camera or the video.
+ * - \b startTargetCamera(std::string): Start playing the specified camera or the video.
+ * - \b stopCamera(): Stop playing the camera or the video.
+ * - \b pauseCamera(): Pause the video, it has no effect when playing a camera.
+ * - \b loopVideo(): Toggle the loop of the playing.
+ * - \b setPositionVideo(int): Force the current time in the video.
+ * - \b reconfigure(): Allows to erase the implementation choice, so that the selection routine is ran again, thus,
  * potentially the selection dialog is shown.
  * - \b nextImage(): display the next image in step by step mode. Does nothing if not supported by the selected grabber.
  * - \b previousImage(): display the previous image in step by step mode. Does nothing if not supported by the
  * selected grabber.
  * - \b setStep(): set the step value between two images when calling nextImage/previousImage. Does nothing if not
  * supported by the selected grabber.
+ * - \b requestSettings(): Requests the grabber internal settings.
+ * - \b addROICenter(sight::data::Point::sptr): Adds a new region fo interest center.
+ * - \b removeROICenter(sight::data::Point::sptr): Removes a region of interest via its center.
  *
  * @section XML XML Configuration
  *
@@ -110,30 +115,40 @@ public:
     MODULE_IO_VIDEO_API SGrabberProxy() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_IO_VIDEO_API virtual ~SGrabberProxy() noexcept;
+    MODULE_IO_VIDEO_API ~SGrabberProxy() noexcept override;
 
-    /**
-     * @name Slots API
-     *
-     * @{
-     */
-    /// Slot: called to start the tracking.
-    MODULE_IO_VIDEO_API static const core::com::Slots::SlotKeyType s_RECONFIGURE_SLOT;
-/** @} */
+    /// Internal wrapper holding slots keys.
+    struct slots
+    {
+        using key_t = sight::core::com::Slots::SlotKeyType;
+
+        static inline const key_t RECONFIGURE         = "reconfigure";
+        static inline const key_t START_TARGET_CAMERA = "startTargetCamera";
+
+        static inline const key_t MODIFY_POSITION = "modifyPosition";
+        static inline const key_t MODIFY_DURATION = "modifyDuration";
+
+        static inline const key_t FWD_START_CAMERA  = "forwardStartCamera";
+        static inline const key_t FWD_STOP_CAMERA   = "forwardStopCamera";
+        static inline const key_t FWD_NOTIFY        = "forwardNotify";
+        static inline const key_t FWD_SET_PARAMETER = "forwardSetParameter";
+        static inline const key_t FWD_PRESENT_FRAME = "forwardPresentFrame";
+        static inline const key_t FWD_CREATE_JOB    = "forwardCreateJob";
+    };
 
 protected:
 
     /// Does nothing.
-    MODULE_IO_VIDEO_API virtual void starting() final;
+    MODULE_IO_VIDEO_API void starting() final;
 
     /// Stop the underlying grabber, destroy it, and empty the input FrameTl.
-    MODULE_IO_VIDEO_API virtual void stopping() final;
+    MODULE_IO_VIDEO_API void stopping() final;
 
     /// Does nothing.
-    MODULE_IO_VIDEO_API virtual void updating() final;
+    MODULE_IO_VIDEO_API void updating() final;
 
     /// Parses the XML configuration of the service.
-    MODULE_IO_VIDEO_API virtual void configuring() final;
+    MODULE_IO_VIDEO_API void configuring() final;
 
     /**
      * @name Slots methods
@@ -141,19 +156,22 @@ protected:
      * @{
      */
     /// Initialize and start camera (restart camera if is already started).
-    MODULE_IO_VIDEO_API virtual void startCamera() final;
+    MODULE_IO_VIDEO_API void startCamera() final;
+
+    /// Initialize and start camera (restart camera if is already started).
+    MODULE_IO_VIDEO_API void startTargetCamera(std::string impl);
 
     /// Stop camera.
-    MODULE_IO_VIDEO_API virtual void stopCamera() final;
+    MODULE_IO_VIDEO_API void stopCamera() final;
 
     /// Pause camera.
-    MODULE_IO_VIDEO_API virtual void pauseCamera() final;
+    MODULE_IO_VIDEO_API void pauseCamera() final;
 
     /// Enable/disable loop in video.
-    MODULE_IO_VIDEO_API virtual void toggleLoopMode() final;
+    MODULE_IO_VIDEO_API void toggleLoopMode() final;
 
     /// Set the new position in the video.
-    MODULE_IO_VIDEO_API virtual void setPosition(std::int64_t position) final;
+    MODULE_IO_VIDEO_API void setPosition(std::int64_t position) final;
 
     /// Get the previous image in frame by frame mode.
     MODULE_IO_VIDEO_API void previousImage() override;
@@ -163,16 +181,31 @@ protected:
 
     /// Set step used on readPrevious/readNext slots.
     MODULE_IO_VIDEO_API void setStep(int step, std::string key) override;
+
+    /// Sets internal parameters values.
+    MODULE_IO_VIDEO_API void setParameter(ui::base::parameter_t value, std::string key) final;
+
+    /// SLOT: Requests the grabber internal settings.
+    MODULE_IO_VIDEO_API void requestSettings() final;
+
+    /// SLOT: Calls optimization functions defined in the grabber (e.g. hardware related).
+    MODULE_IO_VIDEO_API void optimize() final;
+
+    /// SLOT: Adds a region of interest center.
+    MODULE_IO_VIDEO_API void addROICenter(sight::data::Point::sptr p) final;
+
+    /// SLOT: Removes a region of interest center.
+    MODULE_IO_VIDEO_API void removeROICenter(sight::data::Point::sptr p) final;
 /** @} */
 
 private:
 
-    typedef std::pair<std::string, core::runtime::ConfigurationElement::csptr> ServiceConfigPair;
+    typedef std::pair<std::string, IService::ConfigType> ServiceConfigPair;
 
     enum class CameraType : std::uint8_t
     {
         RGB,
-        RGBD,
+        RGBD
     };
 
     /**
@@ -187,7 +220,7 @@ private:
     void modifyPosition(int64_t position);
 
     /// Duration of the video has changed.
-    void modifyDuration(int64_t position);
+    void modifyDuration(int64_t duration);
 
     /// The playback has started in the sub-service.
     void fwdStartCamera();
@@ -197,8 +230,20 @@ private:
 
     /// A frame is presented in the sub-service.
     void fwdPresentFrame();
+
+    /// A named parameter has been emitted in the sub-service.
+    void fwdSetParameter(ui::base::parameter_t value, std::string key);
+
+    /// A job has been created in the proxied service.
+    void fwdCreateJob(sight::core::jobs::IJob::sptr job);
+
+    // Forwards notifications
+    void fwdNotify(service::Notification notification);
     /** @} */
 
+    /// Forward FPS data
+    void forwardFPSChanged(double fps) final;
+
     /// Camera type (RGB, RGBD,...)
     CameraType m_type {CameraType::RGB};
 
@@ -226,7 +271,7 @@ private:
     /// Configure if selected services are excluded (true) or included (false).
     bool m_exclude {true};
 
-    /// Camera can be either a data::Camera or a data::CameraSeries depending on the implementation
+    /// Camera can be either a data::Camera or a data::CameraSet depending on the implementation
     data::ptr<data::Object, data::Access::in> m_camera {this, s_CAMERA_INPUT};
 };
 
