@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,7 +32,7 @@ class Plugin : public core::runtime::Plugin
 public:
 
     //! @brief Destructor.
-    ~Plugin() noexcept;
+    ~Plugin() noexcept override;
 
     /**
      * @brief Start method.
@@ -41,14 +41,14 @@ public:
      *
      * @exception core::runtime::RuntimeException
      */
-    void start();
+    void start() override;
 
     /**
      * @brief Stop method.
      *
      * This method is used by runtime in order to close the module.
      */
-    void stop() noexcept;
+    void stop() noexcept override;
 };
 
 } // namespace sight::module::io::vtk
