@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -78,14 +78,14 @@ void SImageReader::openLocationDialog()
     /* Initialize the available extensions for BitmapImageReader */
     std::vector<std::string> ext;
     sight::io::vtk::BitmapImageReader::getAvailableExtensions(ext);
-    std::string availableExtensions = "";
+    std::string availableExtensions;
 
-    if(ext.size() > 0)
+    if(!ext.empty())
     {
         availableExtensions = "*" + ext.at(0);
         for(std::size_t i = 1 ; i < ext.size() ; i++)
         {
-            availableExtensions = availableExtensions + " *" + ext.at(i);
+            availableExtensions.append(" *").append(ext.at(i));
         }
     }
 
@@ -179,7 +179,7 @@ void SImageReader::updating()
 
                 auto sig = image->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
                 {
-                    core::com::Connection::Blocker block(sig->getConnection(m_slotUpdate));
+                    core::com::Connection::Blocker block(sig->getConnection(slot(IService::slots::s_UPDATE)));
                     sig->asyncEmit();
                 }
             }
@@ -251,10 +251,10 @@ bool SImageReader::loadImage(
         if(i == availableExtensions.size())
         {
             i = 0;
-            std::string bitmapExtensions = "";
+            std::string bitmapExtensions;
             for( ; i < availableExtensions.size() ; i++)
             {
-                bitmapExtensions = bitmapExtensions + availableExtensions.at(i) + ", ";
+                bitmapExtensions.append(availableExtensions.at(i)).append(", ");
             }
 
             SIGHT_THROW_EXCEPTION(
@@ -315,4 +315,4 @@ bool SImageReader::loadImage(
     return ok;
 }
 
-} // namespace ioVtk
+} // namespace sight::module::io::vtk
