@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,8 @@
 
 #include "ImageReaderWriterTest.hpp"
 
-#include <core/runtime/EConfigurationElement.hpp>
-#include <core/thread/Worker.hpp>
-#include <core/tools/System.hpp>
+#include <core/os/TempPath.hpp>
+#include <core/tools/Failed.hpp>
 
 #include <data/Image.hpp>
 #include <data/ImageSeries.hpp>
@@ -34,6 +33,8 @@
 #include <utestData/Data.hpp>
 #include <utestData/generator/Image.hpp>
 
+#include <boost/property_tree/xml_parser.hpp>
+
 #include <filesystem>
 #include <fstream>
 
@@ -42,17 +43,14 @@ CPPUNIT_TEST_SUITE_REGISTRATION(sight::module::io::vtk::ut::ImageReaderWriterTes
 
 static const double epsilon = 0.00001;
 
-namespace sight::module::io::vtk
-{
-
-namespace ut
+namespace sight::module::io::vtk::ut
 {
 
 //------------------------------------------------------------------------------
 
 void runImageSrv(
     const std::string& srvname,
-    const SPTR(core::runtime::EConfigurationElement)& cfg,
+    const boost::property_tree::ptree& cfg,
     const SPTR(data::Object)& image
 )
 {
@@ -91,12 +89,10 @@ void ImageReaderWriterTest::tearDown()
 
 //------------------------------------------------------------------------------
 
-core::runtime::EConfigurationElement::sptr getIOConfiguration(const std::filesystem::path& file)
+boost::property_tree::ptree getIOConfiguration(const std::filesystem::path& file)
 {
-    core::runtime::EConfigurationElement::sptr readerSrvCfg = core::runtime::EConfigurationElement::New("service");
-    core::runtime::EConfigurationElement::sptr readerCfg    = core::runtime::EConfigurationElement::New("file");
-    readerCfg->setValue(file.string());
-    readerSrvCfg->addConfigurationElement(readerCfg);
+    service::IService::ConfigType readerSrvCfg;
+    readerSrvCfg.add("file", file.string());
 
     return readerSrvCfg;
 }
@@ -184,7 +180,7 @@ void ImageReaderWriterTest::testVtiImageReader()
     sizeExpected[1] = 256;
     sizeExpected[2] = 178;
 
-    core::tools::Type expectedType("int8"); // MHD File image type : MET_CHAR
+    core::Type expectedType("int8"); // MHD File image type : MET_CHAR
 
     // Data read.
     data::Image::Spacing spacingRead = image->getSpacing();
@@ -239,7 +235,7 @@ void ImageReaderWriterTest::testMhdImageReader()
     sizeExpected[1] = 256;
     sizeExpected[2] = 178;
 
-    core::tools::Type expectedType("int8"); // MHD File image type : MET_CHAR
+    core::Type expectedType("int8"); // MHD File image type : MET_CHAR
 
     // Data read.
     data::Image::Spacing spacingRead = image->getSpacing();
@@ -269,10 +265,9 @@ void ImageReaderWriterTest::testMhdImageReader()
 
 void ImageReaderWriterTest::testImageReaderExtension()
 {
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "img.xxx";
+    core::os::TempFile tmpFile;
 
-    std::ofstream o_file;
-    o_file.open(file.string().c_str());
+    std::ofstream o_file(tmpFile, std::ios::out | std::ios::trunc | std::ios::binary);
     o_file.close();
 
     data::Image::sptr image = data::Image::New();
@@ -286,102 +281,20 @@ void ImageReaderWriterTest::testImageReaderExtension()
 
         srv->setInOut(image, "data");
 
-        CPPUNIT_ASSERT_NO_THROW(srv->setConfiguration(getIOConfiguration(file)));
+        CPPUNIT_ASSERT_NO_THROW(srv->setConfiguration(getIOConfiguration(tmpFile)));
         CPPUNIT_ASSERT_NO_THROW(srv->configure());
         CPPUNIT_ASSERT_NO_THROW(srv->start().wait());
         CPPUNIT_ASSERT_THROW(srv->update().get(), core::tools::Failed);
         CPPUNIT_ASSERT_NO_THROW(srv->stop().wait());
         service::remove(srv);
     }
-    std::filesystem::remove(file);
-}
-
-//------------------------------------------------------------------------------
-
-void ImageReaderWriterTest::testBitmapImageWriter()
-{
-    // Data to write
-    const core::tools::Type type         = core::tools::Type::s_UINT8;
-    const data::Image::Size sizeExpected = {10, 20, 0};
-
-    // Use standard information for spacing and origin
-    // As the data will be lost in the file format
-    const data::Image::Spacing spacingExpected = {1., 1., 0
-    };
-    const data::Image::Origin originExpected = {0., 0., 0.
-    };
-
-    data::Image::sptr image = data::Image::New();
-    utestData::generator::Image::generateImage(
-        image,
-        sizeExpected,
-        spacingExpected,
-        originExpected,
-        type,
-        data::Image::RGB
-    );
-
-    // Test all teh available extensions
-    std::vector<std::string> extensions;
-    extensions.push_back("bmp");
-    extensions.push_back("jpeg");
-    extensions.push_back("jpg");
-    extensions.push_back("png");
-    extensions.push_back("tiff");
-
-    for(const std::string& ext : extensions)
-    {
-        // Write to bitmap image.
-        const std::filesystem::path file = core::tools::System::getTemporaryFolder() / ("temporaryFile." + ext);
-
-        runImageSrv("sight::module::io::vtk::SImageWriter", getIOConfiguration(file), image);
-
-        // Read image from disk
-        const data::Image::sptr imageFromDisk = data::Image::New();
-        runImageSrv("sight::module::io::vtk::SImageReader", getIOConfiguration(file), imageFromDisk);
-
-        std::filesystem::remove(file);
-
-        // Data read
-        data::Image::Spacing spacingRead = image->getSpacing();
-        data::Image::Origin originRead   = image->getOrigin();
-        data::Image::Size sizeRead       = image->getSize();
-
-        CPPUNIT_ASSERT_EQUAL(spacingExpected.size(), spacingRead.size());
-        CPPUNIT_ASSERT_EQUAL(originExpected.size(), originRead.size());
-        CPPUNIT_ASSERT_EQUAL(sizeExpected.size(), sizeRead.size());
-
-        CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Incorrect spacing on x", spacingExpected[0], spacingRead[0], epsilon);
-        CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Incorrect spacing on y", spacingExpected[1], spacingRead[1], epsilon);
-
-        CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Incorrect origin on x", originExpected[0], originRead[0], epsilon);
-        CPPUNIT_ASSERT_DOUBLES_EQUAL_MESSAGE("Incorrect origin on y", originExpected[1], originRead[1], epsilon);
-
-        CPPUNIT_ASSERT_EQUAL_MESSAGE("Incorrect size on x", sizeExpected[0], sizeRead[0]);
-        CPPUNIT_ASSERT_EQUAL_MESSAGE("Incorrect size on y", sizeExpected[1], sizeRead[1]);
-
-        const auto imageDumpLock         = image->dump_lock();
-        const auto imageFromDiskDumpLock = imageFromDisk->dump_lock();
-
-        const char* const ptrOnGeneratedImage = static_cast<char*>(image->getBuffer());
-        const char* const ptrOnReadImage      = static_cast<char*>(imageFromDisk->getBuffer());
-
-        CPPUNIT_ASSERT_EQUAL(image->getType(), imageFromDisk->getType());
-        CPPUNIT_ASSERT(
-            std::equal(
-                ptrOnGeneratedImage,
-                ptrOnGeneratedImage + image->getSizeInBytes(),
-                ptrOnReadImage
-            )
-        );
-    }
 }
 
 //------------------------------------------------------------------------------
 void ImageReaderWriterTest::testVtkImageWriter()
 {
     // Data to write
-    core::tools::Type type               = core::tools::Type::s_UINT8;
+    core::Type type                      = core::Type::UINT8;
     const data::Image::Size sizeExpected = {10, 20, 30
     };
     const data::Image::Spacing spacingExpected = {0.24, 1.07, 2.21
@@ -396,12 +309,13 @@ void ImageReaderWriterTest::testVtkImageWriter()
         spacingExpected,
         originExpected,
         type,
-        data::Image::RGBA
+        data::Image::RGBA,
+        0
     );
-    utestData::generator::Image::randomizeImage(image);
 
     // Write to vtk image.
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "temporaryFile.vtk";
+    core::os::TempDir tmpDir;
+    const auto file = tmpDir / "tempFile.vtk";
 
     runImageSrv("sight::module::io::vtk::SImageWriter", getIOConfiguration(file), image);
 
@@ -409,8 +323,6 @@ void ImageReaderWriterTest::testVtkImageWriter()
     data::Image::sptr imageFromDisk = data::Image::New();
     runImageSrv("sight::module::io::vtk::SImageReader", getIOConfiguration(file), imageFromDisk);
 
-    std::filesystem::remove(file);
-
     // Data read
     data::Image::Spacing spacingRead = image->getSpacing();
     data::Image::Origin originRead   = image->getOrigin();
@@ -446,26 +358,24 @@ void ImageReaderWriterTest::testVtkImageWriter()
 
 void ImageReaderWriterTest::testVtkImageSeriesWriter()
 {
-    core::tools::Type type  = core::tools::Type::s_FLOAT;
-    data::Image::sptr image = data::Image::New();
-    utestData::generator::Image::generateRandomImage(image, type);
+    core::Type type  = core::Type::FLOAT;
+    auto imageSeries = data::ImageSeries::New();
+    utestData::generator::Image::generateRandomImage(imageSeries, type);
 
-    data::ImageSeries::sptr imageSeries = data::ImageSeries::New();
-    imageSeries->setImage(image);
-
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "imageSeries.vtk";
+    core::os::TempDir tmpDir;
+    const auto file = tmpDir / "imageSeries.vtk";
 
     // Write image series
     runImageSrv("sight::module::io::vtk::SImageSeriesWriter", getIOConfiguration(file), imageSeries);
 
     // Read image series
-    data::Image::sptr image2 = data::Image::New();
-    runImageSrv("sight::module::io::vtk::SImageReader", getIOConfiguration(file), image2);
+    auto imageSeries2 = data::ImageSeries::New();
+    runImageSrv("sight::module::io::vtk::SImageReader", getIOConfiguration(file), imageSeries2);
 
-    image2->setWindowCenter(image->getWindowCenter());
-    image2->setWindowWidth(image->getWindowWidth());
+    imageSeries2->setWindowCenter(imageSeries->getWindowCenter());
+    imageSeries2->setWindowWidth(imageSeries->getWindowWidth());
 
-    CPPUNIT_ASSERT(*image == *image2);
+    CPPUNIT_ASSERT(*imageSeries == *imageSeries2);
 }
 
 //------------------------------------------------------------------------------
@@ -473,7 +383,7 @@ void ImageReaderWriterTest::testVtkImageSeriesWriter()
 void ImageReaderWriterTest::testVtiImageWriter()
 {
     // Data to write
-    core::tools::Type type               = core::tools::Type::s_UINT8;
+    core::Type type                      = core::Type::UINT8;
     const data::Image::Size sizeExpected = {10, 20, 30
     };
     const data::Image::Spacing spacingExpected = {0.24, 1.07, 2.21
@@ -488,12 +398,13 @@ void ImageReaderWriterTest::testVtiImageWriter()
         spacingExpected,
         originExpected,
         type,
-        data::Image::GRAY_SCALE
+        data::Image::GRAY_SCALE,
+        0
     );
-    utestData::generator::Image::randomizeImage(image);
 
     // Write to vtk image.
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "temporaryFile.vti";
+    core::os::TempDir tmpDir;
+    const auto file = tmpDir / "tempFile.vti";
 
     runImageSrv("sight::module::io::vtk::SImageWriter", getIOConfiguration(file), image);
 
@@ -537,7 +448,7 @@ void ImageReaderWriterTest::testVtiImageWriter()
 void ImageReaderWriterTest::testMhdImageWriter()
 {
     // Data to write
-    core::tools::Type type               = core::tools::Type::s_UINT8;
+    core::Type type                      = core::Type::UINT8;
     const data::Image::Size sizeExpected = {10, 20, 30
     };
     const data::Image::Spacing spacingExpected = {0.24, 1.07, 2.21
@@ -552,12 +463,13 @@ void ImageReaderWriterTest::testMhdImageWriter()
         spacingExpected,
         originExpected,
         type,
-        data::Image::RGB
+        data::Image::RGB,
+        0
     );
-    utestData::generator::Image::randomizeImage(image);
 
     // Write to vtk image.
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "temporaryFile.mhd";
+    core::os::TempDir tmpDir;
+    const auto file = tmpDir / "tempFile.mhd";
 
     runImageSrv("sight::module::io::vtk::SImageWriter", getIOConfiguration(file), image);
 
@@ -601,13 +513,10 @@ void ImageReaderWriterTest::testMhdImageWriter()
 void ImageReaderWriterTest::testImageWriterExtension()
 {
     // Data to write
-    core::tools::Type type               = core::tools::Type::s_UINT8;
-    const data::Image::Size sizeExpected = {10, 20, 30
-    };
-    const data::Image::Spacing spacingExpected = {0.24, 1.07, 2.21
-    };
-    const data::Image::Origin originExpected = {-5.6, 15.16, 11.11
-    };
+    const auto type = core::Type::UINT8;
+    const data::Image::Size sizeExpected {10, 20, 30};
+    const data::Image::Spacing spacingExpected {0.24, 1.07, 2.21};
+    const data::Image::Origin originExpected {-5.6, 15.16, 11.11};
 
     data::Image::sptr image = data::Image::New();
     utestData::generator::Image::generateImage(
@@ -616,12 +525,13 @@ void ImageReaderWriterTest::testImageWriterExtension()
         spacingExpected,
         originExpected,
         type,
-        data::Image::GRAY_SCALE
+        data::Image::GRAY_SCALE,
+        0
     );
-    utestData::generator::Image::randomizeImage(image);
 
     // Write to vtk image.
-    const std::filesystem::path file = core::tools::System::getTemporaryFolder() / "temporaryFile.xxx";
+    core::os::TempDir tmpDir;
+    const auto file = tmpDir / "tempFile.xxx";
 
     {
         const std::string srvname("sight::module::io::vtk::SImageWriter");
@@ -642,6 +552,4 @@ void ImageReaderWriterTest::testImageWriterExtension()
 
 //------------------------------------------------------------------------------
 
-} //namespace ut
-
-} //namespace sight::module::io::vtk
+} // namespace sight::module::io::vtk::ut
