@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,31 +29,27 @@
 namespace sight::module::navigation::calibration
 {
 
-static const service::IService::KeyType s_MATRIX_CENTER_OUTPUT      = "matrixCenter";
 static const service::IService::KeyType s_MATRIX_CALIBRATION_OUTPUT = "matrixCalibration";
-static const service::IService::KeyType s_MATRICES_VECTOR_INPUT     = "matricesVector";
 
 // -----------------------------------------------------------------------------
 
-SToolCalibration::SToolCalibration() noexcept
-{
-}
+SToolCalibration::SToolCalibration() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
-SToolCalibration::~SToolCalibration() noexcept
-{
-}
+SToolCalibration::~SToolCalibration() noexcept =
+    default;
 
 // -----------------------------------------------------------------------------
 
 void SToolCalibration::configuring()
 {
-    const auto configTree = this->getConfigTree();
+    const auto configTree = this->getConfiguration();
     const auto outputs    = configTree.equal_range("out");
     for(auto it = outputs.first ; it != outputs.second ; ++it)
     {
-        const std::string key = it->second.get<std::string>("<xmlattr>.key");
+        const auto key = it->second.get<std::string>("<xmlattr>.key");
         if(key == s_MATRIX_CENTER_OUTPUT)
         {
             m_hasOutputCenter = true;
@@ -86,7 +82,7 @@ void SToolCalibration::updating()
 
 // -----------------------------------------------------------------------------
 
-void SToolCalibration::computeRegistration(core::HiResClock::HiResClockType)
+void SToolCalibration::computeRegistration(core::HiResClock::HiResClockType /*timestamp*/)
 {
     const auto matricesVector = m_matricesVector.lock();
 
@@ -104,4 +100,4 @@ void SToolCalibration::computeRegistration(core::HiResClock::HiResClockType)
     }
 }
 
-} // trackingCalibration
+} // namespace sight::module::navigation::calibration
