@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,6 +20,8 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE
+
 #include "SArucoTracker.hpp"
 
 #include <core/com/Signal.hxx>
@@ -30,8 +32,10 @@
 #include <io/opencv/Image.hpp>
 
 #include <boost/foreach.hpp>
+#include <boost/lexical_cast.hpp>
 #include <boost/tokenizer.hpp>
 
+#include <opencv2/calib3d.hpp>
 #include <opencv2/core.hpp>
 #include <opencv2/opencv.hpp>
 
@@ -45,23 +49,16 @@ namespace sight::module::navigation::optics
 const core::com::Signals::SignalKeyType SArucoTracker::s_DETECTION_DONE_SIG  = "detectionDone";
 const core::com::Signals::SignalKeyType SArucoTracker::s_MARKER_DETECTED_SIG = "markerDetected";
 
-const core::com::Slots::SlotKeyType SArucoTracker::s_SET_DOUBLE_PARAMETER_SLOT = "setDoubleParameter";
-const core::com::Slots::SlotKeyType SArucoTracker::s_SET_INT_PARAMETER_SLOT    = "setIntParameter";
-const core::com::Slots::SlotKeyType SArucoTracker::s_SET_BOOL_PARAMETER_SLOT   = "setBoolParameter";
+const core::com::Slots::SlotKeyType SArucoTracker::s_SET_PARAMETER_SLOT = "setParameter";
 
 //-----------------------------------------------------------------------------
 
 SArucoTracker::SArucoTracker() noexcept :
-    m_isInitialized(false),
-    m_debugMarkers(false)
+    m_sigDetectionDone(newSignal<DetectionDoneSignalType>(s_DETECTION_DONE_SIG))
 {
-    m_sigDetectionDone = newSignal<DetectionDoneSignalType>(s_DETECTION_DONE_SIG);
-
     newSignal<MarkerDetectedSignalType>(s_MARKER_DETECTED_SIG);
 
-    newSlot(s_SET_DOUBLE_PARAMETER_SLOT, &SArucoTracker::setDoubleParameter, this);
-    newSlot(s_SET_INT_PARAMETER_SLOT, &SArucoTracker::setIntParameter, this);
-    newSlot(s_SET_BOOL_PARAMETER_SLOT, &SArucoTracker::setBoolParameter, this);
+    newSlot(s_SET_PARAMETER_SLOT, &SArucoTracker::setParameter, this);
 
     // Initialize detector parameters
     m_detectorParams = cv::aruco::DetectorParameters::create();
@@ -85,9 +82,8 @@ SArucoTracker::SArucoTracker() noexcept :
 
 //-----------------------------------------------------------------------------
 
-SArucoTracker::~SArucoTracker() noexcept
-{
-}
+SArucoTracker::~SArucoTracker() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -95,8 +91,8 @@ service::IService::KeyConnectionsMap SArucoTracker::getAutoConnections() const
 {
     KeyConnectionsMap connections;
 
-    connections.push(s_FRAME_INOUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_FRAME_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_FRAME_INOUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_FRAME_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -107,14 +103,15 @@ void SArucoTracker::configuring()
 {
     this->service::ITracker::configuring();
 
-    const auto config = this->getConfigTree();
+    const auto config = this->getConfiguration();
 
     const auto& trackCfg = config.get_child("track");
 
+    // NOLINTNEXTLINE(bugprone-branch-clone)
     BOOST_FOREACH(const auto& elt, trackCfg.equal_range("marker"))
     {
-        const auto& cfg                = elt.second;
-        const std::string markersIDStr = cfg.get<std::string>("<xmlattr>.id");
+        const auto& cfg         = elt.second;
+        const auto markersIDStr = cfg.get<std::string>("<xmlattr>.id");
         boost::tokenizer<> tok(markersIDStr);
         MarkerIDType markersID;
         for(const auto& it : tok)
@@ -188,7 +185,8 @@ void SArucoTracker::tracking(core::HiResClock::HiResClockType& timestamp)
         // Check number of components of image.
         const auto nbOfComponents = inImage.channels();
 
-        cv::Mat grey, bgr;
+        cv::Mat grey;
+        cv::Mat bgr;
 
         if(nbOfComponents == 4) // RGBA or BGRA.
         {
@@ -217,16 +215,27 @@ void SArucoTracker::tracking(core::HiResClock::HiResClockType& timestamp)
         std::vector<std::vector<cv::Point2f> > detectedMarkers;
         std::vector<int> detectedMarkersIds;
 
+        cv::Mat undistortGrey;
+        {
+            const auto arCam = m_camera.lock();
+            if(arCam->getIsCalibrated())
+            {
+                cv::undistort(grey, undistortGrey, m_cameraParams.intrinsic, m_cameraParams.distorsion);
+            }
+            else
+            {
+                undistortGrey = grey;
+            }
+        }
+
         // Ok, let's detect
         cv::aruco::detectMarkers(
-            grey,
+            undistortGrey,
             m_dictionary,
             detectedMarkers,
             detectedMarkersIds,
             m_detectorParams,
-            cv::noArray(),
-            m_cameraParams.intrinsic,
-            m_cameraParams.distorsion
+            cv::noArray()
         );
 
         //Note: This draws all detected markers
@@ -250,7 +259,6 @@ void SArucoTracker::tracking(core::HiResClock::HiResClockType& timestamp)
         std::size_t tagTLIndex = 0;
         for(const auto& markersID : m_markers)
         {
-            unsigned int markerPosition = 0;
             for(const auto& markerID : markersID)
             {
                 for(unsigned int i = 0 ; i < detectedMarkersIds.size() ; i++)
@@ -274,8 +282,6 @@ void SArucoTracker::tracking(core::HiResClock::HiResClockType& timestamp)
                         markerMap->setMarker(std::to_string(markerID), marker);
                     }
                 }
-
-                ++markerPosition;
             }
 
             auto markerMap = m_markerMap[tagTLIndex].lock();
@@ -296,12 +302,12 @@ void SArucoTracker::tracking(core::HiResClock::HiResClockType& timestamp)
 
 //-----------------------------------------------------------------------------
 
-void SArucoTracker::setIntParameter(int _val, std::string _key)
+void SArucoTracker::setParameter(sight::ui::base::parameter_t _val, std::string _key)
 {
     if(_key == "adaptiveThreshWinSizeMin")
     {
         static const int s_ADAPTIVE_THRESH_WIN_SIZE_MIN_VALUE = 3;
-        int val                                               = _val;
+        int val                                               = std::get<int>(_val);
         if(m_detectorParams->adaptiveThreshWinSizeMin < s_ADAPTIVE_THRESH_WIN_SIZE_MIN_VALUE)
         {
             SIGHT_ERROR("Tried to set adaptiveThreshWinSizeMin < 3, let it set to 3");
@@ -318,7 +324,7 @@ void SArucoTracker::setIntParameter(int _val, std::string _key)
     }
     else if(_key == "adaptiveThreshWinSizeMax")
     {
-        int val = _val;
+        int val = std::get<int>(_val);
         if(m_detectorParams->adaptiveThreshWinSizeMin >= val)
         {
             val = m_detectorParams->adaptiveThreshWinSizeMin + 1;
@@ -329,19 +335,19 @@ void SArucoTracker::setIntParameter(int _val, std::string _key)
     }
     else if(_key == "adaptiveThreshWinSizeStep")
     {
-        m_detectorParams->adaptiveThreshWinSizeStep = _val;
+        m_detectorParams->adaptiveThreshWinSizeStep = std::get<int>(_val);
     }
     else if(_key == "minDistanceToBorder")
     {
-        m_detectorParams->minDistanceToBorder = _val;
+        m_detectorParams->minDistanceToBorder = std::get<int>(_val);
     }
     else if(_key == "cornerRefinementWinSize")
     {
-        m_detectorParams->cornerRefinementWinSize = _val;
+        m_detectorParams->cornerRefinementWinSize = std::get<int>(_val);
     }
     else if(_key == "cornerRefinementMaxIterations")
     {
-        int val = _val;
+        int val = std::get<int>(_val);
         if(val <= 0)
         {
             val = 1;
@@ -352,49 +358,39 @@ void SArucoTracker::setIntParameter(int _val, std::string _key)
     }
     else if(_key == "markerBorderBits")
     {
-        m_detectorParams->markerBorderBits = _val;
+        m_detectorParams->markerBorderBits = std::get<int>(_val);
     }
     else if(_key == "perspectiveRemovePixelPerCell")
     {
-        m_detectorParams->perspectiveRemovePixelPerCell = _val;
+        m_detectorParams->perspectiveRemovePixelPerCell = std::get<int>(_val);
     }
-    else
+    else if(_key == "adaptiveThreshConstant")
     {
-        SIGHT_ERROR("The slot key : '" + _key + "' is not handled");
-    }
-}
-
-//-----------------------------------------------------------------------------
-
-void SArucoTracker::setDoubleParameter(double _val, std::string _key)
-{
-    if(_key == "adaptiveThreshConstant")
-    {
-        m_detectorParams->adaptiveThreshConstant = _val;
+        m_detectorParams->adaptiveThreshConstant = std::get<double>(_val);
     }
     else if(_key == "minMarkerPerimeterRate")
     {
-        m_detectorParams->minMarkerPerimeterRate = _val;
+        m_detectorParams->minMarkerPerimeterRate = std::get<double>(_val);
     }
     else if(_key == "maxMarkerPerimeterRate")
     {
-        m_detectorParams->maxMarkerPerimeterRate = _val;
+        m_detectorParams->maxMarkerPerimeterRate = std::get<double>(_val);
     }
     else if(_key == "polygonalApproxAccuracyRate")
     {
-        m_detectorParams->polygonalApproxAccuracyRate = _val;
+        m_detectorParams->polygonalApproxAccuracyRate = std::get<double>(_val);
     }
     else if(_key == "minCornerDistanceRate")
     {
-        m_detectorParams->minCornerDistanceRate = _val;
+        m_detectorParams->minCornerDistanceRate = std::get<double>(_val);
     }
     else if(_key == "minMarkerDistanceRate")
     {
-        m_detectorParams->minMarkerDistanceRate = _val;
+        m_detectorParams->minMarkerDistanceRate = std::get<double>(_val);
     }
     else if(_key == "cornerRefinementMinAccuracy")
     {
-        double val = _val;
+        double val = std::get<double>(_val);
         if(val <= 0.)
         {
             val = 0.01;
@@ -405,37 +401,27 @@ void SArucoTracker::setDoubleParameter(double _val, std::string _key)
     }
     else if(_key == "perspectiveRemoveIgnoredMarginPerCell")
     {
-        m_detectorParams->perspectiveRemoveIgnoredMarginPerCell = _val;
+        m_detectorParams->perspectiveRemoveIgnoredMarginPerCell = std::get<double>(_val);
     }
     else if(_key == "maxErroneousBitsInBorderRate")
     {
-        m_detectorParams->maxErroneousBitsInBorderRate = _val;
+        m_detectorParams->maxErroneousBitsInBorderRate = std::get<double>(_val);
     }
     else if(_key == "minOtsuStdDev")
     {
-        m_detectorParams->minOtsuStdDev = _val;
+        m_detectorParams->minOtsuStdDev = std::get<double>(_val);
     }
     else if(_key == "errorCorrectionRate")
     {
-        m_detectorParams->errorCorrectionRate = _val;
+        m_detectorParams->errorCorrectionRate = std::get<double>(_val);
     }
-    else
+    else if(_key == "debugMode")
     {
-        SIGHT_ERROR("The slot key : '" + _key + "' is not handled");
-    }
-}
-
-//-----------------------------------------------------------------------------
-
-void SArucoTracker::setBoolParameter(bool _val, std::string _key)
-{
-    if(_key == "debugMode")
-    {
-        m_debugMarkers = _val;
+        m_debugMarkers = std::get<bool>(_val);
     }
     else if(_key == "corner")
     {
-        if(_val)
+        if(std::get<bool>(_val))
         {
             m_detectorParams->cornerRefinementMethod = cv::aruco::CornerRefineMethod::CORNER_REFINE_SUBPIX;
         }
