@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,9 +26,6 @@
 
 #include <core/com/Signal.hpp>
 #include <core/com/Signals.hpp>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/EConfigurationElement.hpp>
-#include <core/tools/Failed.hpp>
 
 #include <service/helper/ConfigLauncher.hpp>
 
@@ -53,16 +50,23 @@ namespace sight::module::ui::base
  * @section Slots Slots
  * - \b stopConfig(): called to stop the running configuration
  *
- *
  * @section XML XML Configuration
  *
  * @code{.xml}
         <service type="sight::service::SConfigController" >
             <appConfig id="IdOfConfig" />
+            <inout group="data">
+                <key name="object1" uid="..." />
+                <key name="object2" uid="..." />
+                ...
+            </inout>
             <parameter replace="channel" by="changeValueChannel"  />
             <parameter replace="service" by="serviceUid" />
         </service>
    @endcode
+ * @subsection In-Out In-Out:
+ * - \b data [sight::data::Object]: \b key specifies the name of the parameter in the target configuration and \b uid
+ * identifies the objects whose uid are passed as value of the parameter.
  * @subsection Configuration Configuration:
  * - \b parameter: \b replace specifies the name of the parameter in the target configuration and \b by the value of
  * this parameter. The variable GENERIC_UID can be used as unique identifier when the configuration is launched.
@@ -77,10 +81,10 @@ public:
     MODULE_UI_BASE_API SConfigLauncher() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_BASE_API virtual ~SConfigLauncher() noexcept;
+    MODULE_UI_BASE_API ~SConfigLauncher() noexcept override;
 
     /// Set the action service is activated/disable.
-    MODULE_UI_BASE_API void setIsActive(bool isActive) override;
+    MODULE_UI_BASE_API void setChecked(bool isChecked) override;
 
     // Launched signal key
     MODULE_UI_BASE_API static const core::com::Signals::SignalKeyType s_LAUNCHED_SIG;
@@ -114,11 +118,12 @@ protected:
      * @code{.xml}
        <service impl="sight::module::ui::base::SConfigLauncher" type="ui::base::IAction">
            <config>
-                <appConfig id="Visu2DID" >
-                    <parameters>
-                        <parameter replace="SERIESDB" by="medicalData" />
-                    </parameters>
-                </appConfig>
+                <appConfig id="Visu2DID" />
+                <inout group="data">
+                    <key name="param1" uid="..." />
+                    <key name="param2" uid="..." />
+                </inout>
+                <parameter replace="SERIES_SET" by="medicalData" />
             </config>
        </service>
         @endcode
@@ -137,6 +142,9 @@ protected:
 
     service::helper::ConfigLauncher::uptr m_configLauncher;
     std::string m_proxychannel; ///< Name of the channel used to connect stopConfig slot to the config frame closing.
+
+    /// Input data to pass to the configuration
+    data::ptr_vector<data::Object, data::Access::inout> m_data {this, service::helper::ConfigLauncher::s_DATA_GROUP};
 };
 
-} // gui
+} // namespace sight::module::ui::base
