@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,21 +29,18 @@
 namespace sight::module::ui::base
 {
 
-SFrame::SFrame() noexcept
-{
-}
+SFrame::SFrame() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-SFrame::~SFrame() noexcept
-{
-}
+SFrame::~SFrame() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
 void SFrame::configuring()
 {
-    SIGHT_ASSERT("<service> tag is required.", m_configuration->getName() == "service");
     this->initialize();
 }
 
@@ -63,7 +60,7 @@ void SFrame::stopping()
 
 //-----------------------------------------------------------------------------
 
-void SFrame::info(std::ostream&)
+void SFrame::info(std::ostream& /*_sstream*/)
 {
 }
 
@@ -75,4 +72,4 @@ void SFrame::updating()
 
 //-----------------------------------------------------------------------------
 
-}
+} // namespace sight::module::ui::base
