@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -50,9 +50,8 @@ SJobBar::SJobBar() noexcept
 
 //-----------------------------------------------------------------------------
 
-SJobBar::~SJobBar() noexcept
-{
-}
+SJobBar::~SJobBar() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -105,13 +104,13 @@ void SJobBar::showJob(core::jobs::IJob::sptr iJob)
         });
 
     iJob->addStateHook(
-        [ = ](core::jobs::IJob::State state)
+        [ =, this](core::jobs::IJob::State state)
         {
             if(state == core::jobs::IJob::CANCELED || state == core::jobs::IJob::FINISHED)
             {
                 m_sigEnded->emit();
-                m_associatedWorker->postTask<void>(
-                    [ = ]
+                this->worker()->postTask<void>(
+                    [ =, this]
                 {
                     m_progressDialogs.erase(progressDialog);
                 });
