@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -42,7 +42,7 @@ public:
     MODULE_UI_BASE_API SMenu() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_BASE_API virtual ~SMenu() noexcept;
+    MODULE_UI_BASE_API ~SMenu() noexcept override;
 
 protected:
 
@@ -103,4 +103,4 @@ protected:
     ///@}
 };
 
-}
+} // namespace sight::module::ui::base
