@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,15 +32,13 @@ namespace sight::module::ui::base
 
 //-----------------------------------------------------------------------------
 
-SQuit::SQuit() noexcept
-{
-}
+SQuit::SQuit() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-SQuit::~SQuit() noexcept
-{
-}
+SQuit::~SQuit() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -82,4 +80,4 @@ void SQuit::updating()
 
 //-----------------------------------------------------------------------------
 
-}
+} // namespace sight::module::ui::base
