@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -48,7 +48,7 @@ public:
     /**
      * @brief Destructor. Do nothing.
      */
-    MODULE_UI_BASE_API virtual ~SQuit() noexcept;
+    MODULE_UI_BASE_API ~SQuit() noexcept override;
 
 protected:
 
