@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,14 +26,12 @@
 
 #include <ui/base/IAction.hpp>
 
-namespace sight::module::ui::base
-{
-
-namespace com
+namespace sight::module::ui::base::com
 {
 
 /**
  * @brief   Action that sends a signal when it is triggered
+ * * @deprecated Replaced by sight::module::ui::base::SAction since Sight 22.0, will be removed in Sight 24.0
  *
  * @section Signals Signals
  * - \b triggered(bool) : Emitted when the action is triggered, with the state of the action as parameter.
@@ -54,7 +52,6 @@ class MODULE_UI_BASE_CLASS_API SSignal : public sight::ui::base::IAction
 public:
 
     SIGHT_DECLARE_SERVICE(SSignal, sight::ui::base::IAction);
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
 
     /// Type of triggered signal
     typedef core::com::Signal<void (bool)> TriggeredSignalType;
@@ -67,7 +64,7 @@ public:
     /**
      * @brief Destructor. Do nothing.
      */
-    MODULE_UI_BASE_API virtual ~SSignal() noexcept;
+    MODULE_UI_BASE_API ~SSignal() noexcept override;
 
 protected:
 
@@ -92,6 +89,4 @@ protected:
     SPTR(TriggeredSignalType) m_sigCancelled;
 };
 
-} // namespace com
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::com
