@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,32 +22,29 @@
 
 #include "SStarter.hpp"
 
-#include <core/base.hpp>
-
-#include <service/macros.hpp>
 #include <service/op/Get.hpp>
 
 #include <ui/base/dialog/MessageDialog.hpp>
 
 #include <boost/range/adaptor/reversed.hpp>
 
-namespace sight::module::ui::base
-{
-
-namespace com
+namespace sight::module::ui::base::com
 {
 
 //-----------------------------------------------------------------------------
 
 SStarter::SStarter() noexcept
 {
+    SIGHT_WARN(
+        "'sight::module::ui::base::com::SStarter' is deprecated and will be removed in Sight 24.0,"
+        " start and stop connections are now supported directly in XML."
+    );
 }
 
 //-----------------------------------------------------------------------------
 
-SStarter::~SStarter() noexcept
-{
-}
+SStarter::~SStarter() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -62,7 +59,7 @@ void SStarter::stopping()
 {
     std::vector<service::IService::SharedFutureType> futures;
 
-    for(VectPairIDActionType::value_type serviceUid : boost::adaptors::reverse(m_uuidServices))
+    for(const VectPairIDActionType::value_type& serviceUid : boost::adaptors::reverse(m_uuidServices))
     {
         bool srv_exists = core::tools::fwID::exist(serviceUid.first);
         if(srv_exists && (m_idStartedSrvSet.find(serviceUid.first) != m_idStartedSrvSet.end()))
@@ -75,7 +72,7 @@ void SStarter::stopping()
         }
     }
 
-    std::for_each(futures.begin(), futures.end(), std::mem_fn(&std::shared_future<void>::wait));
+    std::ranges::for_each(futures, std::mem_fn(&std::shared_future<void>::wait));
 
     this->actionServiceStopping();
 }
@@ -91,10 +88,10 @@ void SStarter::info(std::ostream& _sstream)
 
 void SStarter::updating()
 {
-    for(std::size_t i = 0 ; i < m_uuidServices.size() ; i++)
+    for(auto& m_uuidService : m_uuidServices)
     {
-        ActionType action = m_uuidServices.at(i).second;
-        IDSrvType uid     = m_uuidServices.at(i).first;
+        ActionType action = m_uuidService.second;
+        IDSrvType uid     = m_uuidService.first;
         bool srv_exists   = core::tools::fwID::exist(uid);
 
         // Manage special action
@@ -214,7 +211,7 @@ void SStarter::updating()
                 sight::ui::base::dialog::IMessageDialog::WARNING
             );
 
-            SIGHT_INFO("Do nothing for Service " << m_uuidServices.at(i).first);
+            SIGHT_INFO("Do nothing for Service " << m_uuidService.first);
         }
     }
 }
@@ -225,12 +222,10 @@ void SStarter::configuring()
 {
     this->initialize();
 
-    for(ConfigurationType actionCfg : m_configuration->getElements())
+    for(const auto& actionCfg : this->getConfiguration())
     {
-        SIGHT_INFO("SStarter " << actionCfg->getName());
-
-        std::string actionType = actionCfg->getName();
-        ActionType action;
+        std::string actionType = actionCfg.first;
+        ActionType action {ActionType::DO_NOTHING};
         if(actionType == "start")
         {
             action = START;
@@ -259,14 +254,19 @@ void SStarter::configuring()
         {
             action = START_ONLY;
         }
+        else if(actionType == "state" || actionType == "<xmlattr>")
+        {
+            // Ignore
+            continue;
+        }
         else
         {
             SIGHT_WARN("The \"actionType\":" << actionType << " is not managed by SStarter");
             continue;
         }
 
-        SIGHT_ASSERT("Attribute uid missing", actionCfg->hasAttribute("uid"));
-        IDSrvType uuid = actionCfg->getExistingAttributeValue("uid");
+        SIGHT_INFO("SStarter " << actionCfg.first);
+        const auto uuid = actionCfg.second.get<std::string>("<xmlattr>.uid");
 
         m_uuidServices.push_back(std::make_pair(uuid, action));
     }
@@ -274,6 +274,4 @@ void SStarter::configuring()
 
 //-----------------------------------------------------------------------------
 
-} // namespace com
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::com
