@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,15 +30,15 @@
 
 #include <vector>
 
-namespace sight::module::ui::base
-{
-
-namespace com
+namespace sight::module::ui::base::com
 {
 
 /**
  * @brief   Apply an action (start, stop, ...) on a service specify by uid.
  *
+ * @deprecated Deprecated in Sight 23.0, will be removed in Sight 24.0.
+ * Start and stop connections are now supported directly in XML.
+ *
  * This action works on a data::Object. It does the action specify by the specify config.
  * This action can be :
  *   - Start a service :
@@ -115,7 +115,6 @@ class MODULE_UI_BASE_CLASS_API SStarter : public sight::ui::base::IAction
 public:
 
     SIGHT_DECLARE_SERVICE(SStarter, sight::ui::base::IAction);
-    typedef core::runtime::ConfigurationElement::sptr ConfigurationType;
 
     /**
      * @brief Constructor. Do nothing.
@@ -125,7 +124,7 @@ public:
     /**
      * @brief Destructor. Do nothing.
      */
-    MODULE_UI_BASE_API virtual ~SStarter() noexcept;
+    MODULE_UI_BASE_API ~SStarter() noexcept override;
 
 protected:
 
@@ -177,6 +176,4 @@ private:
     SetIDSrvType m_idStartedSrvSet;
 };
 
-} // namespace com
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::com
