@@ -26,51 +26,32 @@
 #include <core/com/Slots.hxx>
 #include <core/HiResClock.hpp>
 
-#include <data/Camera.hpp>
-#include <data/CameraSeries.hpp>
+#include <boost/range/iterator_range_core.hpp>
 
 #include <regex>
 
-namespace sight::module::ui::base
+namespace sight::module::ui::base::com
 {
 
-namespace com
-{
-
-//-----------------------------------------------------------------------------
-
-STimestampSlotCaller::STimestampSlotCaller()
-{
-}
-
-//-----------------------------------------------------------------------------
-
-STimestampSlotCaller::~STimestampSlotCaller()
-{
-}
-
 //-----------------------------------------------------------------------------
 
 void STimestampSlotCaller::configuring()
 {
     this->initialize();
 
-    ConfigurationType cfg = m_configuration->findConfigurationElement("slots");
+    const auto& config = this->getConfiguration();
 
-    core::runtime::ConfigurationElementContainer slotCfgs = cfg->findAllConfigurationElement("slot");
+    const std::regex re("(.*)/(.*)");
 
-    std::regex re("(.*)/(.*)");
-    std::smatch match;
-    std::string src, uid, key;
-
-    for(ConfigurationType elem : slotCfgs.getElements())
+    const auto& slots = config.get_child("slots");
+    for(const auto& elem : boost::make_iterator_range(slots.equal_range("slot")))
     {
-        src = elem->getValue();
-        if(std::regex_match(src, match, re))
+        const auto src = elem.second.get_value<std::string>();
+        if(std::smatch match; std::regex_match(src, match, re))
         {
             SIGHT_ASSERT("Wrong value for attribute src: " << src, match.size() >= 3);
-            uid.assign(match[1].first, match[1].second);
-            key.assign(match[2].first, match[2].second);
+            const std::string uid(match[1].first, match[1].second);
+            const std::string key(match[2].first, match[2].second);
 
             SIGHT_ASSERT("Missing hasSlotsId attribute", !uid.empty());
             SIGHT_ASSERT("Missing slotKey attribute", !key.empty());
@@ -93,7 +74,7 @@ void STimestampSlotCaller::updating()
 {
     core::HiResClock::HiResClockType timestamp = core::HiResClock::getTimeInMilliSec();
 
-    for(SlotInfoType info : m_slotInfos)
+    for(const SlotInfoType& info : m_slotInfos)
     {
         HasSlotIDType HasSlotId               = info.first;
         core::com::Slots::SlotKeyType slotKey = info.second;
@@ -120,6 +101,4 @@ void STimestampSlotCaller::stopping()
 
 //-----------------------------------------------------------------------------
 
-} // namespace com
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::com
