@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,33 +26,28 @@
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-
-#include <data/Composite.hpp>
-#include <data/helper/Composite.hpp>
 
 #include <io/base/service/IReader.hpp>
 #include <io/base/service/IWriter.hpp>
 
 #include <service/extension/Config.hpp>
 #include <service/extension/Factory.hpp>
-#include <service/macros.hpp>
 #include <service/op/Add.hpp>
 
 #include <ui/base/Cursor.hpp>
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/base/dialog/SelectorDialog.hpp>
 
+#include <boost/property_tree/xml_parser.hpp>
+#include <boost/range/iterator_range_core.hpp>
+
 #include <sstream>
 #include <string>
 
-namespace sight::module::ui::base
+namespace sight::module::ui::base::io
 {
 
-namespace io
-{
-
-using namespace sight::io;
+namespace io = sight::io;
 
 //------------------------------------------------------------------------------
 
@@ -65,27 +60,23 @@ static const core::com::Slots::SlotKeyType FORWARD_JOB_SLOT = "forwardJob";
 //------------------------------------------------------------------------------
 
 SSelector::SSelector() :
-    m_mode(READER_MODE),
-    m_servicesAreExcluded(true)
+    m_sigJobCreated(newSignal<JobCreatedSignalType>(JOB_CREATED_SIGNAL)),
+    m_sigJobFailed(newSignal<JobFailedSignalType>(JOB_FAILED_SIGNAL)),
+    m_sigJobSucceeded(newSignal<JobSucceededSignalType>(JOB_SUCCEEDED_SIGNAL)),
+    m_slotForwardJob(newSlot(FORWARD_JOB_SLOT, &SSelector::forwardJob, this))
 {
-    m_sigJobCreated   = newSignal<JobCreatedSignalType>(JOB_CREATED_SIGNAL);
-    m_sigJobFailed    = newSignal<JobFailedSignalType>(JOB_FAILED_SIGNAL);
-    m_sigJobSucceeded = newSignal<JobSucceededSignalType>(JOB_SUCCEEDED_SIGNAL);
-
-    m_slotForwardJob = newSlot(FORWARD_JOB_SLOT, &SSelector::forwardJob, this);
 }
 
 //------------------------------------------------------------------------------
 
-SSelector::~SSelector() noexcept
-{
-}
+SSelector::~SSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SSelector::configuring()
 {
-    const ConfigType srvConfig = this->getConfigTree();
+    const ConfigType srvConfig = this->getConfiguration();
 
     const std::string mode = srvConfig.get<std::string>("type.<xmlattr>.mode", "reader");
     SIGHT_ASSERT(
@@ -104,29 +95,27 @@ void SSelector::configuring()
     m_servicesAreExcluded = (selectionMode == "exclude");
     SIGHT_DEBUG("selection mode => " + selectionMode);
 
-    const auto selectionCfg = srvConfig.equal_range("addSelection");
-    for(auto itSelection = selectionCfg.first ; itSelection != selectionCfg.second ; ++itSelection)
+    for(const auto& itSelection : boost::make_iterator_range(srvConfig.equal_range("addSelection")))
     {
-        const std::string service = itSelection->second.get<std::string>("<xmlattr>.service");
+        const auto service = itSelection.second.get<std::string>("<xmlattr>.service");
         m_selectedServices.push_back(service);
         SIGHT_DEBUG("add selection => " + service);
 
-        const std::string configId = itSelection->second.get<std::string>("<xmlattr>.config", "");
+        const std::string configId = itSelection.second.get<std::string>("<xmlattr>.config", "");
         if(!configId.empty())
         {
             m_serviceToConfig[service] = configId;
-            SIGHT_DEBUG("add config '" + configId + "' for service '" + service + "'");
+            SIGHT_DEBUG(std::string("add config '") + configId + "' for service '" + service + "'");
         }
     }
 
-    const auto configCfg = srvConfig.equal_range("config");
-    for(auto itCfg = configCfg.first ; itCfg != configCfg.second ; ++itCfg)
+    for(const auto& itCfg : boost::make_iterator_range(srvConfig.equal_range("config")))
     {
-        const std::string service  = itCfg->second.get<std::string>("<xmlattr>.service");
-        const std::string configId = itCfg->second.get<std::string>("<xmlattr>.id");
+        const auto service  = itCfg.second.get<std::string>("<xmlattr>.service");
+        const auto configId = itCfg.second.get<std::string>("<xmlattr>.id");
 
         m_serviceToConfig[service] = configId;
-        SIGHT_DEBUG("add config '" + configId + "' for service '" + service + "'");
+        SIGHT_DEBUG(std::string("add config '") + configId + "' for service '" + service + "'");
     }
 }
 
@@ -198,20 +187,20 @@ void SSelector::updating()
             std::string infoUser =
                 service::extension::Factory::getDefault()->getServiceDescription(serviceId);
 
-            std::map<std::string, std::string>::const_iterator iter = m_serviceToConfig.find(serviceId);
+            auto iter = m_serviceToConfig.find(serviceId);
             if(iter != m_serviceToConfig.end())
             {
                 infoUser = service::extension::Config::getDefault()->getConfigDesc(iter->second);
             }
 
-            if(infoUser != "")
+            if(!infoUser.empty())
             {
-                availableExtensionsMap.push_back(std::pair<std::string, std::string>(serviceId, infoUser));
+                availableExtensionsMap.emplace_back(serviceId, infoUser);
                 availableExtensionsSelector.push_back(infoUser);
             }
             else
             {
-                availableExtensionsMap.push_back(std::pair<std::string, std::string>(serviceId, serviceId));
+                availableExtensionsMap.emplace_back(serviceId, serviceId);
                 availableExtensionsSelector.push_back(serviceId);
             }
         }
@@ -246,8 +235,8 @@ void SSelector::updating()
             {
                 bool extensionIdFound = false;
 
-                typedef std::pair<std::string, std::string> PairType;
-                for(PairType pair : availableExtensionsMap)
+                using PairType = std::pair<std::string, std::string>;
+                for(const PairType& pair : availableExtensionsMap)
                 {
                     if(pair.second == selection)
                     {
@@ -273,7 +262,7 @@ void SSelector::updating()
         {
             // Get Config
             bool hasConfigForService = false;
-            core::runtime::ConfigurationElement::csptr srvCfg;
+            IService::ConfigType srvCfg;
             if(m_serviceToConfig.find(extensionId) != m_serviceToConfig.end())
             {
                 hasConfigForService = true;
@@ -283,7 +272,7 @@ void SSelector::updating()
                 );
                 SIGHT_ASSERT(
                     "No service configuration of type service::extension::Config was found",
-                    srvCfg
+                    !srvCfg.empty()
                 );
             }
 
@@ -296,11 +285,11 @@ void SSelector::updating()
                     reader->setInOut(obj.get_shared(), io::base::service::s_DATA_KEY);
                 }
 
-                reader->setWorker(m_associatedWorker);
+                reader->setWorker(this->worker());
 
                 if(hasConfigForService)
                 {
-                    reader->setConfiguration(core::runtime::ConfigurationElement::constCast(srvCfg));
+                    reader->setConfiguration(srvCfg);
                     reader->configure();
                 }
 
@@ -321,7 +310,7 @@ void SSelector::updating()
                     cursor.setDefaultCursor();
 
                     reader->stop();
-                    service::OSR::unregisterService(reader);
+                    service::unregisterService(reader);
                 }
                 catch(std::exception& e)
                 {
@@ -346,11 +335,11 @@ void SSelector::updating()
                     writer->setInput(obj.get_shared(), io::base::service::s_DATA_KEY);
                 }
 
-                writer->setWorker(m_associatedWorker);
+                writer->setWorker(this->worker());
 
                 if(hasConfigForService)
                 {
-                    writer->setConfiguration(core::runtime::ConfigurationElement::constCast(srvCfg));
+                    writer->setConfiguration(srvCfg);
                     writer->configure();
                 }
 
@@ -371,7 +360,7 @@ void SSelector::updating()
                     cursor.setDefaultCursor();
 
                     writer->stop();
-                    service::OSR::unregisterService(writer);
+                    service::unregisterService(writer);
                 }
                 catch(std::exception& e)
                 {
@@ -445,6 +434,4 @@ void SSelector::forwardJob(core::jobs::IJob::sptr iJob)
 
 //------------------------------------------------------------------------------
 
-} // namespace io
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::io
