@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -49,9 +49,8 @@ SRemoveDistance::SRemoveDistance() noexcept
 
 //------------------------------------------------------------------------------
 
-SRemoveDistance::~SRemoveDistance() noexcept
-{
-}
+SRemoveDistance::~SRemoveDistance() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -73,25 +72,25 @@ void SRemoveDistance::updating()
 {
     const auto image = m_image.lock();
 
-    data::Vector::sptr vectDist = data::helper::MedicalImage::getDistances(*image);
+    auto vectDist = data::helper::MedicalImage::getDistances(*image);
 
     if(data::helper::MedicalImage::checkImageValidity(image.get_shared())
        && vectDist)
     {
-        bool requestAll;
+        bool requestAll                    = false;
         data::PointList::sptr distToRemove = getDistanceToRemove(image.get_shared(), requestAll);
 
         if(distToRemove)
         {
             SIGHT_ASSERT("No field image distances id", vectDist);
-            const data::Vector::ConstIteratorType newEnd = std::remove(
+            const auto newEnd = std::remove(
                 vectDist->begin(),
                 vectDist->end(),
                 distToRemove
             );
-            vectDist->getContainer().erase(newEnd, vectDist->end());
+            vectDist->erase(newEnd, vectDist->end());
 
-            this->notifyDeleteDistance(image.get_shared(), distToRemove);
+            sight::module::ui::base::metrics::SRemoveDistance::notifyDeleteDistance(image.get_shared(), distToRemove);
         }
 
         if(requestAll)
@@ -99,8 +98,8 @@ void SRemoveDistance::updating()
             data::PointList::sptr backupDistance = image->getField<data::PointList>("m_imageDistancesId");
 
             image->removeField("m_imageDistancesId");
-            const auto sig = image->signal<data::Image::DistanceAddedSignalType>(
-                data::Image::s_DISTANCE_ADDED_SIG
+            const auto sig = image->signal<data::Image::DistanceRemovedSignalType>(
+                data::Image::s_DISTANCE_REMOVED_SIG
             );
             sig->asyncEmit(backupDistance);
         }
@@ -135,7 +134,7 @@ data::PointList::sptr SRemoveDistance::getDistanceToRemove(const data::Image::cs
     if(vectDist)
     {
         std::vector<std::string> selections;
-        selections.push_back("ALL");
+        selections.emplace_back("ALL");
         std::map<std::string, data::PointList::sptr> correspondence;
 
         for(const data::Object::sptr& obj : *vectDist)
@@ -190,7 +189,7 @@ data::PointList::sptr SRemoveDistance::getDistanceToRemove(const data::Image::cs
 void SRemoveDistance::notifyDeleteDistance(
     const data::Image::csptr& _image,
     const data::PointList::csptr& _distance
-) const
+)
 {
     const auto sig =
         _image->signal<data::Image::DistanceRemovedSignalType>(data::Image::s_DISTANCE_REMOVED_SIG);
@@ -212,8 +211,8 @@ void SRemoveDistance::removeLastDistance()
 
         if(distToRemove)
         {
-            data::Vector::IteratorType newEnd = std::remove(vectDist->begin(), vectDist->end(), distToRemove);
-            vectDist->getContainer().erase(newEnd, vectDist->end());
+            auto newEnd = std::remove(vectDist->begin(), vectDist->end(), distToRemove);
+            vectDist->erase(newEnd, vectDist->end());
             this->notifyDeleteDistance(image.get_shared(), distToRemove);
         }
     }
