@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,8 +27,8 @@
 #include <core/com/Slots.hxx>
 #include <core/jobs/IJob.hpp>
 
-#include <data/helper/SeriesDB.hpp>
 #include <data/Series.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <io/base/service/ioTypes.hpp>
 
@@ -37,10 +37,7 @@
 
 #include <ui/base/Cursor.hpp>
 
-namespace sight::module::ui::base
-{
-
-namespace series
+namespace sight::module::ui::base::series
 {
 
 static const core::com::Signals::SignalKeyType JOB_CREATED_SIGNAL = "jobCreated";
@@ -49,23 +46,22 @@ static const core::com::Slots::SlotKeyType FORWARD_JOB_SLOT       = "forwardJob"
 //------------------------------------------------------------------------------
 
 SDBMerger::SDBMerger() noexcept :
-    m_ioSelectorSrvConfig("IOSelectorServiceConfigVRRenderReader")
+    m_ioSelectorSrvConfig("IOSelectorServiceConfigVRRenderReader"),
+    m_sigJobCreated(newSignal<JobCreatedSignalType>(JOB_CREATED_SIGNAL)),
+    m_slotForwardJob(newSlot(FORWARD_JOB_SLOT, &SDBMerger::forwardJob, this))
 {
-    m_sigJobCreated  = newSignal<JobCreatedSignalType>(JOB_CREATED_SIGNAL);
-    m_slotForwardJob = newSlot(FORWARD_JOB_SLOT, &SDBMerger::forwardJob, this);
 }
 
 //------------------------------------------------------------------------------
 
-SDBMerger::~SDBMerger() noexcept
-{
-}
+SDBMerger::~SDBMerger() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SDBMerger::info(std::ostream& _sstream)
 {
-    _sstream << "Action for add SeriesDB" << std::endl;
+    _sstream << "Action for add SeriesSet" << std::endl;
 }
 
 //------------------------------------------------------------------------------
@@ -73,13 +69,9 @@ void SDBMerger::info(std::ostream& _sstream)
 void SDBMerger::configuring()
 {
     this->sight::ui::base::IAction::initialize();
-    std::vector<ConfigurationType> vectConfig = m_configuration->find("IOSelectorSrvConfig");
-    if(!vectConfig.empty())
-    {
-        ConfigurationType selectorConfig = vectConfig.at(0);
-        SIGHT_ASSERT("Missing 'name' attribute", selectorConfig->hasAttribute("name"));
-        m_ioSelectorSrvConfig = selectorConfig->getAttributeValue("name");
-    }
+
+    const auto& config = this->getConfiguration();
+    m_ioSelectorSrvConfig = config.get<std::string>("IOSelectorSrvConfig.<xmlattr>.name", m_ioSelectorSrvConfig);
 }
 
 //------------------------------------------------------------------------------
@@ -88,14 +80,13 @@ void SDBMerger::updating()
 {
     sight::ui::base::LockAction lock(this->getSptr());
 
-    // Create a new SeriesDB
-    data::SeriesDB::sptr localSeriesDB = data::SeriesDB::New();
+    // Create a new SeriesSet
+    auto local_series_set = data::SeriesSet::New();
 
-    /// Create IOSelectorService on the new SeriesDB and execute it.
+    /// Create IOSelectorService on the new SeriesSet and execute it.
 
     // Get the config
-    core::runtime::ConfigurationElement::csptr ioCfg;
-    ioCfg = service::extension::Config::getDefault()->getServiceConfig(
+    const auto ioCfg = service::extension::Config::getDefault()->getServiceConfig(
         m_ioSelectorSrvConfig,
         "sight::module::ui::base::io::SSelector"
     );
@@ -103,14 +94,14 @@ void SDBMerger::updating()
         "There is no service configuration "
         << m_ioSelectorSrvConfig
         << " for module::ui::base::editor::SSelector",
-        ioCfg
+        !ioCfg.empty()
     );
 
     // Init and execute the service
     service::IService::sptr ioSelectorSrv;
     ioSelectorSrv = service::add("sight::module::ui::base::io::SSelector");
-    ioSelectorSrv->setInOut(localSeriesDB, io::base::service::s_DATA_KEY);
-    ioSelectorSrv->setWorker(m_associatedWorker);
+    ioSelectorSrv->setInOut(local_series_set, io::base::service::s_DATA_KEY);
+    ioSelectorSrv->setWorker(this->worker());
 
     auto jobCreatedSignal = ioSelectorSrv->signal("jobCreated");
     if(jobCreatedSignal)
@@ -118,7 +109,7 @@ void SDBMerger::updating()
         jobCreatedSignal->connect(m_slotForwardJob);
     }
 
-    ioSelectorSrv->setConfiguration(core::runtime::ConfigurationElement::constCast(ioCfg));
+    ioSelectorSrv->setConfiguration(ioCfg);
     ioSelectorSrv->configure();
     ioSelectorSrv->start();
     ioSelectorSrv->update();
@@ -126,12 +117,11 @@ void SDBMerger::updating()
     service::remove(ioSelectorSrv);
 
     // Lock only when needed.
-    auto seriesDB = m_seriesDB.lock();
-    SIGHT_ASSERT("The inout key '" << s_SERIESDB << "' is not correctly set.", seriesDB);
+    auto series_set = m_series_set.lock();
+    SIGHT_ASSERT("The inout key '" << s_SERIES_SET << "' is not correctly set.", series_set);
 
-    data::helper::SeriesDB sDBhelper(*seriesDB);
-    sDBhelper.merge(localSeriesDB);
-    sDBhelper.notify();
+    const auto scoped_emitter = series_set->scoped_emit();
+    std::copy(local_series_set->cbegin(), local_series_set->cend(), data::inserter(*series_set));
 }
 
 //------------------------------------------------------------------------------
@@ -158,6 +148,4 @@ void SDBMerger::forwardJob(core::jobs::IJob::sptr iJob)
 //------------------------------------------------------------------------------
 //
 
-} // namespace series
-
-} // namespace sight::module::ui::base
+} // namespace sight::module::ui::base::series
