@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,6 @@
 
 #include "modules/ui/base/config.hpp"
 
-#include <core/com/Signal.hpp>
-#include <core/com/Signals.hpp>
-#include <core/tools/Failed.hpp>
-
 #include <ui/base/IAction.hpp>
 
 #include <map>
@@ -49,12 +45,10 @@ public:
     MODULE_UI_BASE_API CrossTypeAction() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_BASE_API virtual ~CrossTypeAction() noexcept;
+    MODULE_UI_BASE_API ~CrossTypeAction() noexcept override = default;
 
 protected:
 
-    typedef core::runtime::ConfigurationElement::sptr Configuration;
-
     /// Starts action
     void starting() override;
 
@@ -86,4 +80,4 @@ private:
     CrossTypeModifiedSignalType::sptr m_sigCrossTypeModified; ///< Signal emitted when cross type is modified
 };
 
-} // uiVisu
+} // namespace sight::module::ui::base::viz
