@@ -35,15 +35,14 @@ SIGHT_REGISTER_PLUGIN("sight::module::ui::console::Plugin");
 
 //-----------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
 void Plugin::start()
 {
-    core::runtime::getCurrentProfile()->setRunCallback(std::bind(&Plugin::run, this));
+    core::runtime::getCurrentProfile()->setRunCallback(run);
 }
 
 //-----------------------------------------------------------------------------
@@ -57,10 +56,8 @@ void Plugin::stop() noexcept
 int Plugin::run() noexcept
 {
     auto worker = core::thread::getDefaultWorker();
-    worker->post([](){core::runtime::getCurrentProfile()->setup();});
     worker->getFuture().wait(); // This is required to start WorkerAsio loop
 
-    core::runtime::getCurrentProfile()->cleanup();
     const int result = std::any_cast<int>(worker->getFuture().get());
 
     return result;
