@@ -29,10 +29,6 @@
 #include <core/memory/ByteSize.hpp>
 #include <core/memory/IPolicy.hpp>
 #include <core/memory/tools/MemoryMonitorTools.hpp>
-#include <core/tools/fwID.hpp>
-#include <core/tools/Stringizer.hpp>
-
-#include <service/macros.hpp>
 
 #include <ui/base/Cursor.hpp>
 #include <ui/base/dialog/IMessageDialog.hpp>
@@ -70,28 +66,32 @@ class PolicyComboBoxDelegate : public QItemDelegate
 {
 public:
 
-    PolicyComboBoxDelegate(QObject* parent = 0) :
+    explicit PolicyComboBoxDelegate(QObject* parent = nullptr) :
         QItemDelegate(parent)
     {
     }
 
-    QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    QWidget* createEditor(QWidget* parent, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 
-    void setEditorData(QWidget* editor, const QModelIndex& index) const;
-    void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const;
+    void setEditorData(QWidget* editor, const QModelIndex& index) const override;
+    void setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const override;
 
-    void updateEditorGeometry(QWidget* editor, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    void updateEditorGeometry(
+        QWidget* editor,
+        const QStyleOptionViewItem& option,
+        const QModelIndex& index
+    ) const override;
 };
 
 //------------------------------------------------------------------------------
 
 QWidget* PolicyComboBoxDelegate::createEditor(
     QWidget* parent,
-    const QStyleOptionViewItem&,
+    const QStyleOptionViewItem& /*option*/,
     const QModelIndex& index
 ) const
 {
-    QComboBox* policyComboBox = new QComboBox(parent);
+    auto* policyComboBox = new QComboBox(parent);
 
     const std::string value = index.model()->data(index, Qt::DisplayRole).toString().toStdString();
 
@@ -116,7 +116,7 @@ void PolicyComboBoxDelegate::setEditorData(QWidget* editor, const QModelIndex& i
 {
     QString value = index.model()->data(index, Qt::DisplayRole).toString();
 
-    QComboBox* policyComboBox = static_cast<QComboBox*>(editor);
+    auto* policyComboBox = static_cast<QComboBox*>(editor);
 
     int idx = policyComboBox->findText(value);
     if(idx != -1)
@@ -129,8 +129,8 @@ void PolicyComboBoxDelegate::setEditorData(QWidget* editor, const QModelIndex& i
 
 void PolicyComboBoxDelegate::setModelData(QWidget* editor, QAbstractItemModel* model, const QModelIndex& index) const
 {
-    QComboBox* policyComboBox = static_cast<QComboBox*>(editor);
-    QString value             = policyComboBox->currentText();
+    auto* policyComboBox = static_cast<QComboBox*>(editor);
+    QString value        = policyComboBox->currentText();
 
     model->setData(index, value, Qt::EditRole);
 }
@@ -141,6 +141,7 @@ void PolicyComboBoxDelegate::updateEditorGeometry(
     QWidget* editor,
     const QStyleOptionViewItem& option,
     const QModelIndex&
+    /*index*/
 ) const
 {
     editor->setGeometry(option.rect);
@@ -150,14 +151,14 @@ class PolicyTableModel : public QAbstractTableModel
 {
 public:
 
-    PolicyTableModel(QObject* parent = 0);
+    explicit PolicyTableModel(QObject* parent = nullptr);
 
-    int rowCount(const QModelIndex& parent) const;
-    int columnCount(const QModelIndex& parent) const;
-    QVariant data(const QModelIndex& index, int role) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const;
-    Qt::ItemFlags flags(const QModelIndex& index) const;
-    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole);
+    [[nodiscard]] int rowCount(const QModelIndex& parent) const override;
+    [[nodiscard]] int columnCount(const QModelIndex& parent) const override;
+    [[nodiscard]] QVariant data(const QModelIndex& index, int role) const override;
+    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    [[nodiscard]] Qt::ItemFlags flags(const QModelIndex& index) const override;
+    bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::EditRole) override;
 
     static const int s_EXTRA_INFO_NB;
 
@@ -169,9 +170,9 @@ private:
 const int PolicyTableModel::s_EXTRA_INFO_NB = 1;
 
 PolicyTableModel::PolicyTableModel(QObject* parent) :
-    QAbstractTableModel(parent)
+    QAbstractTableModel(parent),
+    m_buffManager(core::memory::BufferManager::getDefault())
 {
-    m_buffManager = core::memory::BufferManager::getDefault();
 }
 
 //------------------------------------------------------------------------------
@@ -204,7 +205,7 @@ QVariant PolicyTableModel::data(const QModelIndex& index, int role) const
 {
     if(!m_buffManager && !index.isValid())
     {
-        return QVariant();
+        return {};
     }
 
     core::mt::ReadLock lock(m_buffManager->getMutex());
@@ -212,7 +213,7 @@ QVariant PolicyTableModel::data(const QModelIndex& index, int role) const
 
     if(index.row() > int((s_EXTRA_INFO_NB + currentPolicy->getParamNames().size())) || index.row() < 0)
     {
-        return QVariant();
+        return {};
     }
 
     if(role == Qt::DisplayRole)
@@ -224,16 +225,17 @@ QVariant PolicyTableModel::data(const QModelIndex& index, int role) const
             {
                 return QString::fromStdString(currentPolicy->getLeafClassname());
             }
-            else if((unsigned int) index.row() <= names.size())
+
+            if((unsigned int) index.row() <= names.size())
             {
-                const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(index.row() - 1);
+                const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(std::size_t(index.row() - 1));
 
                 return QString::fromStdString(currentPolicy->getParam(name));
             }
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 //------------------------------------------------------------------------------
@@ -242,7 +244,7 @@ QVariant PolicyTableModel::headerData(int section, Qt::Orientation orientation,
 {
     if(role != Qt::DisplayRole)
     {
-        return QVariant();
+        return {};
     }
 
     if(m_buffManager && orientation == Qt::Vertical)
@@ -254,14 +256,15 @@ QVariant PolicyTableModel::headerData(int section, Qt::Orientation orientation,
         {
             return QString("Current policy");
         }
-        else if((unsigned int) section <= names.size())
+
+        if((unsigned int) section <= names.size())
         {
-            const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(section - 1);
+            const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(std::size_t(section - 1));
             return QString::fromStdString(name);
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 //------------------------------------------------------------------------------
@@ -281,28 +284,26 @@ bool PolicyTableModel::setData(const QModelIndex& index, const QVariant& value,
         if(col == 0 && (unsigned int) row <= names.size())
         {
             core::memory::IPolicy::sptr dumpPolicy;
-            switch(row)
+            if(row == 0)
             {
-                case 0:
-                    if(strvalue != currentPolicy->getLeafClassname())
+                if(strvalue != currentPolicy->getLeafClassname())
+                {
+                    dumpPolicy = core::memory::policy::registry::get()->create(strvalue);
+                    if(dumpPolicy)
                     {
-                        dumpPolicy = core::memory::policy::registry::get()->create(strvalue);
-                        if(dumpPolicy)
-                        {
-                            core::mt::ReadToWriteLock lock(m_buffManager->getMutex());
-                            m_buffManager->setDumpPolicy(dumpPolicy);
-                        }
-
-                        this->beginResetModel();
-                        this->endResetModel();
+                        core::mt::ReadToWriteLock anotherLock(m_buffManager->getMutex());
+                        m_buffManager->setDumpPolicy(dumpPolicy);
                     }
 
-                    break;
-
-                default:
-                    const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(row - 1);
+                    this->beginResetModel();
+                    this->endResetModel();
+                }
+                else
+                {
+                    const core::memory::IPolicy::ParamNamesType::value_type& name = names.at(std::size_t(row - 1));
                     currentPolicy->setParam(name, strvalue);
                     return true;
+                }
             }
         }
     }
@@ -328,12 +329,12 @@ class InfoTableModel : public QAbstractTableModel
 {
 public:
 
-    InfoTableModel(QObject* parent = 0);
+    explicit InfoTableModel(QObject* parent = nullptr);
 
-    int rowCount(const QModelIndex& parent) const;
-    int columnCount(const QModelIndex& parent) const;
-    QVariant data(const QModelIndex& index, int role) const;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const;
+    [[nodiscard]] int rowCount(const QModelIndex& parent) const override;
+    [[nodiscard]] int columnCount(const QModelIndex& parent) const override;
+    [[nodiscard]] QVariant data(const QModelIndex& index, int role) const override;
+    [[nodiscard]] QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
 
 private:
 
@@ -341,9 +342,9 @@ private:
 };
 
 InfoTableModel::InfoTableModel(QObject* parent) :
-    QAbstractTableModel(parent)
+    QAbstractTableModel(parent),
+    m_buffManager(core::memory::BufferManager::getDefault())
 {
-    m_buffManager = core::memory::BufferManager::getDefault();
 }
 
 //------------------------------------------------------------------------------
@@ -368,20 +369,20 @@ QVariant InfoTableModel::data(const QModelIndex& index, int role) const
 {
     if(!m_buffManager || !index.isValid())
     {
-        return QVariant();
+        return {};
     }
 
     if(index.row() > this->rowCount(index))
     {
-        return QVariant();
+        return {};
     }
 
     if(role == Qt::DisplayRole)
     {
         if(index.column() == 0)
         {
-            std::uint64_t sysMem;
-            core::memory::BufferManager::SizeType bufferManagerMem;
+            std::uint64_t sysMem                                   = 0;
+            core::memory::BufferManager::SizeType bufferManagerMem = 0;
             switch(index.row())
             {
                 case 0:
@@ -411,7 +412,7 @@ QVariant InfoTableModel::data(const QModelIndex& index, int role) const
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 //------------------------------------------------------------------------------
@@ -441,23 +442,24 @@ QVariant InfoTableModel::headerData(int section, Qt::Orientation orientation, in
                 return QString("Dumped");
 
                 break;
+
+            default:
+                return {};
         }
     }
 
-    return QVariant();
+    return {};
 }
 
 //------------------------------------------------------------------------------
 
-DumpEditor::DumpEditor() noexcept
-{
-}
+DumpEditor::DumpEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-DumpEditor::~DumpEditor() noexcept
-{
-}
+DumpEditor::~DumpEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -483,13 +485,13 @@ void DumpEditor::starting()
     m_list->setHorizontalHeaderLabels(header);
 
     m_refresh = new QPushButton(tr("Refresh"));
-    QVBoxLayout* sizer = new QVBoxLayout();
+    auto* sizer = new QVBoxLayout();
 
-    QHBoxLayout* sizerButton = new QHBoxLayout();
+    auto* sizerButton = new QHBoxLayout();
     sizerButton->addWidget(m_refresh);
 
     sizerButton->addItem(new QSpacerItem(10, 0, QSizePolicy::Expanding, QSizePolicy::Minimum));
-    QFrame* verticalLine = new QFrame();
+    auto* verticalLine = new QFrame();
     verticalLine->setFrameShape(QFrame::VLine);
     verticalLine->setFrameShadow(QFrame::Sunken);
     sizerButton->addWidget(verticalLine);
@@ -498,19 +500,19 @@ void DumpEditor::starting()
     sizer->addWidget(m_list, 2);
 
     m_policyEditor = new QTableView();
-    PolicyComboBoxDelegate* policyComboBoxDelegate = new PolicyComboBoxDelegate(m_policyEditor);
-    PolicyTableModel* policyTableModel             = new PolicyTableModel(m_policyEditor);
+    auto* policyComboBoxDelegate = new PolicyComboBoxDelegate(m_policyEditor);
+    auto* policyTableModel       = new PolicyTableModel(m_policyEditor);
     m_policyEditor->setModel(policyTableModel);
     m_policyEditor->setItemDelegateForRow(0, policyComboBoxDelegate);
     m_policyEditor->setSortingEnabled(false);
     m_policyEditor->horizontalHeader()->hide();
 
-    InfoTableModel* infoTableModel = new InfoTableModel();
+    auto* infoTableModel = new InfoTableModel();
     m_infoEditor = new QTableView();
     m_infoEditor->setModel(infoTableModel);
     m_infoEditor->horizontalHeader()->hide();
 
-    QHBoxLayout* tablesLayout = new QHBoxLayout();
+    auto* tablesLayout = new QHBoxLayout();
     tablesLayout->addWidget(m_infoEditor);
     tablesLayout->addWidget(m_policyEditor);
 
@@ -561,21 +563,17 @@ class SizeTableWidgetItem : public QTableWidgetItem
 {
 public:
 
-    SizeTableWidgetItem(const QString& text) :
+    explicit SizeTableWidgetItem(const QString& text) :
         QTableWidgetItem(text)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    virtual bool operator<(const QTableWidgetItem& other) const
+    bool operator<(const QTableWidgetItem& other) const override
     {
         return data(Qt::UserRole).toULongLong() < other.data(Qt::UserRole).toULongLong();
     }
-
-protected:
-
-    std::size_t m_size;
 };
 
 //------------------------------------------------------------------------------
@@ -644,14 +642,14 @@ void DumpEditor::onBufferInfo()
         bool isLock = dumpBuffInfo.lockCount() > 0;
         if(isLock)
         {
-            lockStatus = "locked(" + core::tools::getString(dumpBuffInfo.lockCount()) + ")";
+            lockStatus = "locked(" + std::to_string(dumpBuffInfo.lockCount()) + ")";
         }
         else
         {
             lockStatus = "unlocked";
         }
 
-        date = core::tools::getString(dumpBuffInfo.lastAccess.getLogicStamp());
+        date = std::to_string(dumpBuffInfo.lastAccess.getLogicStamp());
 
         QTableWidgetItem* currentSizeItem = new SizeTableWidgetItem(getHumanReadableSize(dumpBuffInfo.size));
         currentSizeItem->setData(Qt::UserRole, (qulonglong) dumpBuffInfo.size);
@@ -659,22 +657,22 @@ void DumpEditor::onBufferInfo()
         currentSizeItem->setBackground(backColor);
         m_list->setItem(itemCount, 0, currentSizeItem);
 
-        QTableWidgetItem* statusItem = new QTableWidgetItem(QString::fromStdString(status));
+        auto* statusItem = new QTableWidgetItem(QString::fromStdString(status));
         statusItem->setFlags(Qt::ItemIsEnabled);
         statusItem->setBackground(backColor);
         m_list->setItem(itemCount, 1, statusItem);
 
-        QTableWidgetItem* dateItem = new QTableWidgetItem(QString::fromStdString(date));
+        auto* dateItem = new QTableWidgetItem(QString::fromStdString(date));
         dateItem->setFlags(Qt::ItemIsEnabled);
         dateItem->setBackground(backColor);
         m_list->setItem(itemCount, 2, dateItem);
 
-        QTableWidgetItem* lockStatusItem = new QTableWidgetItem(QString::fromStdString(lockStatus));
+        auto* lockStatusItem = new QTableWidgetItem(QString::fromStdString(lockStatus));
         lockStatusItem->setFlags(Qt::ItemIsEnabled);
         lockStatusItem->setBackground(backColor);
         m_list->setItem(itemCount, 3, lockStatusItem);
 
-        QPushButton* actionItem = new QPushButton(QString::fromStdString((loaded) ? "Dump" : "Restore"), m_list);
+        auto* actionItem = new QPushButton(QString::fromStdString((loaded) ? "Dump" : "Restore"), m_list);
         actionItem->setEnabled(!isLock && (dumpBuffInfo.size > 0));
         m_list->setCellWidget(itemCount, 4, actionItem);
 
@@ -717,7 +715,7 @@ void DumpEditor::changeStatus(int index)
     if(buffManager)
     {
         const core::memory::BufferManager::BufferInfoMapType buffInfoMap = m_bufferInfos;
-        core::memory::BufferManager::ConstBufferPtrType selectedBuffer   = m_objectsUID[index];
+        core::memory::BufferManager::ConstBufferPtrType selectedBuffer   = m_objectsUID[std::size_t(index)];
 
         core::memory::BufferManager::BufferInfoMapType::const_iterator iter;
         iter = buffInfoMap.find(selectedBuffer);
@@ -767,4 +765,4 @@ void DumpEditor::changeStatus(int index)
 
 //------------------------------------------------------------------------------
 
-} // namespace sight::module
+} // namespace sight::module::ui::debug
