@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,23 +24,23 @@
 
 #include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
+#include <core/os/TempPath.hpp>
 #include <core/thread/Timer.hpp>
-#include <core/tools/System.hpp>
 
 #include <data/Array.hpp>
 #include <data/Composite.hpp>
-#include <data/helper/Composite.hpp>
 #include <data/helper/MedicalImage.hpp>
-#include <data/helper/SeriesDB.hpp>
 #include <data/ImageSeries.hpp>
 #include <data/Integer.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/SeriesSet.hpp>
 
 #include <service/base.hpp>
 
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/qt/container/QtContainer.hpp>
 
+#include <boost/lexical_cast.hpp>
+
 #include <QApplication>
 #include <QComboBox>
 #include <QHBoxLayout>
@@ -58,18 +58,16 @@ const core::com::Slots::SlotKeyType SSliceIndexDicomEditor::s_DISPLAY_MESSAGE_SL
 
 //------------------------------------------------------------------------------
 
-SSliceIndexDicomEditor::SSliceIndexDicomEditor() noexcept :
-    m_delay(500)
+SSliceIndexDicomEditor::SSliceIndexDicomEditor() noexcept
 {
     m_slotReadImage = newSlot(s_READ_IMAGE_SLOT, &SSliceIndexDicomEditor::readImage, this);
-    newSlot(s_DISPLAY_MESSAGE_SLOT, &SSliceIndexDicomEditor::displayErrorMessage, this);
+    newSlot(s_DISPLAY_MESSAGE_SLOT, &SSliceIndexDicomEditor::displayErrorMessage);
 }
 
 //------------------------------------------------------------------------------
 
-SSliceIndexDicomEditor::~SSliceIndexDicomEditor() noexcept
-{
-}
+SSliceIndexDicomEditor::~SSliceIndexDicomEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -77,34 +75,14 @@ void SSliceIndexDicomEditor::configuring()
 {
     sight::ui::base::IGuiContainer::initialize();
 
-    core::runtime::ConfigurationElement::sptr config = m_configuration->findConfigurationElement("config");
-    SIGHT_ASSERT(
-        "The service module::ui::dicom::SSliceIndexDicomEditor must have "
-        "a \"config\" element.",
-        config
-    );
+    const auto& config = this->getConfiguration();
 
-    bool success;
+    m_dicomReaderType = config.get<std::string>("config.<xmlattr>.dicomReader", m_dicomReaderType);
+    m_delay           = config.get<std::size_t>("config.<xmlattr>.delay", m_delay);
 
-    // Reader
-    std::tie(success, m_dicomReaderType) = config->getSafeAttributeValue("dicomReader");
-    SIGHT_ASSERT(
-        "It should be a \"dicomReader\" tag in the module::ui::dicom::SSliceIndexDicomEditor "
-        "config element.",
-        success
-    );
-
-    // Reader configuration
-    core::runtime::ConfigurationElement::sptr readerConfig = config->findConfigurationElement("readerConfig");
-    m_readerConfig =
-        (readerConfig && readerConfig->size() == 1) ? readerConfig->getElements()[0] : nullptr;
-
-    // Delay
-    std::string delayStr;
-    std::tie(success, delayStr) = config->getSafeAttributeValue("delay");
-    if(success)
+    if(const auto readerConfig = config.get_child_optional("readerConfig"); readerConfig.has_value())
     {
-        m_delay = boost::lexical_cast<std::size_t>(delayStr);
+        m_readerConfig = readerConfig.value();
     }
 }
 
@@ -112,12 +90,12 @@ void SSliceIndexDicomEditor::configuring()
 
 void SSliceIndexDicomEditor::starting()
 {
-    m_delayTimer2 = m_associatedWorker->createTimer();
+    m_delayTimer2 = this->worker()->createTimer();
 
     sight::ui::base::IGuiContainer::create();
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* layout = new QHBoxLayout();
 
     const auto dicomSeries = m_dicomSeries.lock();
     SIGHT_ASSERT("DicomSeries should not be null !", dicomSeries);
@@ -144,8 +122,8 @@ void SSliceIndexDicomEditor::starting()
     // Connect the signals
     QObject::connect(m_sliceIndexSlider, SIGNAL(valueChanged(int)), this, SLOT(changeSliceIndex(int)));
 
-    // Create temporary SeriesDB
-    m_tempSeriesDB = data::SeriesDB::New();
+    // Create temporary SeriesSet
+    m_tmp_series_set = data::SeriesSet::New();
 
     // Create reader
     auto dicomReader = service::add<sight::io::base::service::IReader>(m_dicomReaderType);
@@ -154,13 +132,8 @@ void SSliceIndexDicomEditor::starting()
                                                                       "sight::module::ui::dicom::SSliceIndexDicomEditor.",
         dicomReader
     );
-    dicomReader->setInOut(m_tempSeriesDB, sight::io::base::service::s_DATA_KEY);
-
-    if(m_readerConfig)
-    {
-        dicomReader->setConfiguration(m_readerConfig);
-    }
-
+    dicomReader->setInOut(m_tmp_series_set, sight::io::base::service::s_DATA_KEY);
+    dicomReader->setConfiguration(m_readerConfig);
     dicomReader->configure();
     dicomReader->start();
 
@@ -172,9 +145,9 @@ void SSliceIndexDicomEditor::starting()
     m_sagittalIndex = data::Integer::New(0);
 
     // Load a slice
-    std::chrono::milliseconds duration = std::chrono::milliseconds(m_delay);
+    auto duration = std::chrono::milliseconds(m_delay);
     m_delayTimer2->setFunction(
-        [ = ]()
+        [ =, this]()
         {
             this->triggerNewSlice();
         });
@@ -216,7 +189,7 @@ void SSliceIndexDicomEditor::info(std::ostream& _sstream)
 
 //------------------------------------------------------------------------------
 
-void SSliceIndexDicomEditor::changeSliceIndex(int)
+void SSliceIndexDicomEditor::changeSliceIndex(int /*unused*/)
 {
     // Update text
     std::stringstream ss;
@@ -270,13 +243,13 @@ void SSliceIndexDicomEditor::readImage(std::size_t selectedSliceIndex)
         return;
     }
 
-    // Clear temporary seriesDB
-    data::helper::SeriesDB sDBTempohelper(*m_tempSeriesDB);
-    sDBTempohelper.clear();
+    // Clear temporary series_set
+    const auto scoped_emitter = m_tmp_series_set->scoped_emit();
+    m_tmp_series_set->clear();
 
-    // Creates unique temporary folder, no need to check if exists before (see core::tools::System::getTemporaryFolder)
-    std::filesystem::path path    = core::tools::System::getTemporaryFolder("dicom");
-    std::filesystem::path tmpPath = path / "tmp";
+    // Creates unique temporary folder
+    core::os::TempDir tmpDir;
+    std::filesystem::path tmpPath = tmpDir / "tmp";
 
     SIGHT_INFO("Create " + tmpPath.string());
     std::filesystem::create_directories(tmpPath);
@@ -294,7 +267,7 @@ void SSliceIndexDicomEditor::readImage(std::size_t selectedSliceIndex)
     std::ofstream fs(dest, std::ios::binary | std::ios::trunc);
     SIGHT_THROW_IF("Can't open '" << tmpPath << "' for write.", !fs.good());
 
-    fs.write(buffer, static_cast<long>(size));
+    fs.write(buffer, static_cast<std::int64_t>(size));
     fs.close();
 
     // Read image
@@ -316,9 +289,9 @@ void SSliceIndexDicomEditor::readImage(std::size_t selectedSliceIndex)
     //Copy image
     data::ImageSeries::sptr imageSeries;
 
-    if(m_tempSeriesDB->getContainer().size() > 0)
+    if(!m_tmp_series_set->empty())
     {
-        auto series = *(m_tempSeriesDB->getContainer().begin());
+        auto series = m_tmp_series_set->front();
         if(isModalitySupported(*series))
         {
             imageSeries = data::ImageSeries::dynamicCast(series);
@@ -327,39 +300,34 @@ void SSliceIndexDicomEditor::readImage(std::size_t selectedSliceIndex)
 
     if(imageSeries)
     {
-        data::Image::sptr newImage      = imageSeries->getImage();
-        const data::Image::Size newSize = newImage->getSize();
+        const data::Image::Size newSize = imageSeries->getSize();
 
         m_frontalIndex->setValue(static_cast<int>(newSize[0] / 2));
         m_sagittalIndex->setValue(static_cast<int>(newSize[1] / 2));
 
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::AXIAL,
             m_axialIndex->value()
         );
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::FRONTAL,
             m_frontalIndex->value()
         );
         data::helper::MedicalImage::setSliceIndex(
-            *newImage,
+            *imageSeries,
             data::helper::MedicalImage::orientation_t::SAGITTAL,
             m_sagittalIndex->value()
         );
 
-        this->setOutput(s_IMAGE, newImage);
+        this->setOutput(s_IMAGE, imageSeries);
     }
-
-    std::error_code ec;
-    std::filesystem::remove_all(path, ec);
-    SIGHT_ERROR_IF("remove_all error for path " + path.string() + ": " + ec.message(), ec.value());
 }
 
 //------------------------------------------------------------------------------
 
-void SSliceIndexDicomEditor::displayErrorMessage(const std::string& message) const
+void SSliceIndexDicomEditor::displayErrorMessage(const std::string& message)
 {
     SIGHT_WARN("Error: " + message);
     sight::ui::base::dialog::MessageDialog messageBox;
