@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,7 +26,8 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
 #include <data/Composite.hpp>
 
@@ -39,31 +40,35 @@ namespace sight::module::ui::qml::activity
 
 static const core::com::Signals::SignalKeyType s_ACTIVITY_LAUNCHED_SIG = "activityLaunched";
 
-static const core::com::Slots::SlotKeyType s_LAUNCH_ACTIVITY_SLOT        = "launchActivity";
-static const core::com::Slots::SlotKeyType s_LAUNCH_ACTIVITY_SERIES_SLOT = "launchActivitySeries";
+static const core::com::Slots::SlotKeyType s_LAUNCH_ACTIVITY_SLOT = "launchActivity";
 
 //------------------------------------------------------------------------------
 
-SView::SView()
+SView::SView() :
+    m_sigActivityLaunched(newSignal<ActivityLaunchedSignalType>(s_ACTIVITY_LAUNCHED_SIG))
 {
-    m_sigActivityLaunched = newSignal<ActivityLaunchedSignalType>(s_ACTIVITY_LAUNCHED_SIG);
     newSlot(s_LAUNCH_ACTIVITY_SLOT, &SView::launchActivity, this);
-    newSlot(s_LAUNCH_ACTIVITY_SERIES_SLOT, &SView::launchActivitySeries, this);
-}
-
-//------------------------------------------------------------------------------
-
-SView::~SView()
-{
 }
 
 //------------------------------------------------------------------------------
 
 void SView::configuring()
 {
-    const ConfigType config = this->getConfigTree();
+    const ConfigType config = this->getConfiguration();
 
-    this->parseConfiguration(config, this->getInOuts());
+    sight::activity::IActivityLauncher::InOutMapType inoutMap;
+    std::for_each(
+        m_data.begin(),
+        m_data.end(),
+        [&inoutMap](const auto& p)
+        {
+            const auto obj = p.second->lock();
+            if(obj != nullptr)
+            {
+                inoutMap.push_back(obj->getID());
+            }
+        });
+    this->parseConfiguration(config, inoutMap);
 }
 
 //------------------------------------------------------------------------------
@@ -93,33 +98,22 @@ void SView::notifyActivityCreation()
 
 //------------------------------------------------------------------------------
 
-void SView::launchActivity(data::ActivitySeries::sptr activitySeries)
+void SView::launchActivity(data::Activity::sptr activity)
 {
-    bool isValid;
+    bool isValid = false;
     std::string message;
 
     // check if the activity can be launched
-    std::tie(isValid, message) = this->validateActivity(activitySeries);
+    std::tie(isValid, message) = sight::module::ui::qml::activity::SView::validateActivity(activity);
 
     if(isValid)
     {
         auto [info, replacementMap] = sight::activity::extension::Activity::getDefault()->getInfoAndReplacementMap(
-            *activitySeries,
+            *activity,
             m_parameters
         );
 
-        auto module = core::runtime::findModule(info.bundleId);
-
-        if(module->isStarted())
-        {
-            SIGHT_INFO(
-                "Module '" + module->getIdentifier() + "' (used for '" + info.appConfig.id + "') is already started !"
-            );
-        }
-        else
-        {
-            module->start();
-        }
+        core::runtime::startModule(info.bundleId);
 
         // get Activity path, it allows to retrieve the associated Qml file
         const auto path = core::runtime::getModuleResourceFilePath(info.bundleId, info.appConfig.id + ".qml");
@@ -149,15 +143,4 @@ void SView::launchActivity(data::ActivitySeries::sptr activitySeries)
 
 //------------------------------------------------------------------------------
 
-void SView::launchActivitySeries(data::Series::sptr series)
-{
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::dynamicCast(series);
-    if(activitySeries)
-    {
-        this->launchActivity(activitySeries);
-    }
-}
-
-//------------------------------------------------------------------------------
-
 } // namespace sight::module::ui::qml::activity
