@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,7 +26,7 @@
 
 #include <activity/IActivityLauncher.hpp>
 
-#include <data/ActivitySeries.hpp>
+#include <data/Activity.hpp>
 
 #include <ui/qml/IQmlEditor.hpp>
 
@@ -40,16 +40,13 @@ namespace sight::module::ui::qml::activity
  * @brief   This editor displays activities in a single view (when a new activity is launched, it replaces the previous
  * one).
  *
- * This service should receive signals containing ActivitySeries connected to the slot \b launchActivity.
+ * This service should receive signals containing Activity connected to the slot \b launchActivity.
  *
  * @section Signals Signals
  * - \b activityLaunched(): signal emitted when the activity is launched
  *
  * @section Slots Slots
- * - \b launchActivity( data::ActivitySeries::sptr ): This slot allows to create a view for the given activity
- *   series.
- * - \b launchActivitySeries( data::Series::sptr ): This slot allows to create a view for the given activity
- *   series.
+ * - \b launchActivity( data::Activity::sptr ): This slot allows to create a view for the given activity.
  *
  * @section Config Configuration
  *
@@ -112,7 +109,7 @@ public:
 
     /// Destructor. Do nothing.
 
-    MODULE_UI_QML_API ~SView() override;
+    MODULE_UI_QML_API ~SView() override = default;
 
     /// Signal emited when the activity is launched
     typedef core::com::Signal<void ()> ActivityLaunchedSignalType;
@@ -143,12 +140,12 @@ protected:
 private:
 
     /// Slot: Launch the given activity in the stackView.
-    void launchActivity(data::ActivitySeries::sptr activitySeries);
-
-    /// Slot: Launch the given activity in the stackView.
-    void launchActivitySeries(data::Series::sptr series);
+    void launchActivity(data::Activity::sptr activity);
 
     ActivityLaunchedSignalType::sptr m_sigActivityLaunched;
+
+    /// Input data to pass to the configuration
+    data::ptr_vector<data::Object, data::Access::inout> m_data {this, "data"};
 };
 
-} // uiActivitiesQml
+} // namespace sight::module::ui::qml::activity
