@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -51,9 +51,8 @@ SSliceIndexPositionEditor::SSliceIndexPositionEditor() noexcept
 
 //------------------------------------------------------------------------------
 
-SSliceIndexPositionEditor::~SSliceIndexPositionEditor() noexcept
-{
-}
+SSliceIndexPositionEditor::~SSliceIndexPositionEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -209,7 +208,7 @@ void SSliceIndexPositionEditor::onSliceIndex(int index)
 
 void SSliceIndexPositionEditor::onSliceType(int _type)
 {
-    orientation_t type = static_cast<orientation_t>(_type);
+    auto type = static_cast<orientation_t>(_type);
     SIGHT_ASSERT(
         "Bad slice type " << type,
         type == orientation_t::X_AXIS
@@ -239,14 +238,14 @@ service::IService::KeyConnectionsMap SSliceIndexPositionEditor::getAutoConnectio
 {
     KeyConnectionsMap connections;
 
-    connections.push(s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE);
     connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_INDEX_MODIFIED_SIG, s_UPDATE_SLICE_INDEX_SLOT);
     connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_UPDATE_SLICE_TYPE_SLOT);
-    connections.push(s_IMAGE_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace sight::module
+} // namespace sight::module::ui::qml::image
