@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -96,7 +96,7 @@ public:
     MODULE_UI_QML_API SSliceIndexPositionEditor() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_QML_API virtual ~SSliceIndexPositionEditor() noexcept;
+    MODULE_UI_QML_API ~SSliceIndexPositionEditor() noexcept override;
 
     /// To handle orientation of slices.
     using orientation_t = data::helper::MedicalImage::orientation_t;
@@ -133,7 +133,7 @@ protected:
      * @brief Returns proposals to connect service slots to associated object signals,
      * this method is used for obj/srv auto connection
      *
-     * Connect Image::s_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect Image::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
      * Connect Image::s_SLICE_INDEX_MODIFIED_SIG to this::s_UPDATE_SLICE_INDEX_SLOT
      * Connect Image::s_SLICE_TYPE_MODIFIED_SIG to this::s_UPDATE_SLICE_TYPE_SLOT
      * Connect Image::s_BUFFER_MODIFIED_SIG to this::s_UPDATE_BUFFER_SLOT
@@ -176,4 +176,4 @@ private:
     orientation_t m_orientation {orientation_t::Z_AXIS};
 };
 
-} // uiImageQml
+} // namespace sight::module::ui::qml::image
