@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -29,15 +29,13 @@ namespace sight::module::ui::qml::reconstruction
 
 //------------------------------------------------------------------------------
 
-SOrganMaterialEditor::SOrganMaterialEditor() noexcept
-{
-}
+SOrganMaterialEditor::SOrganMaterialEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SOrganMaterialEditor::~SOrganMaterialEditor() noexcept
-{
-}
+SOrganMaterialEditor::~SOrganMaterialEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -97,7 +95,7 @@ void SOrganMaterialEditor::onOpacitySlider(int value)
     SIGHT_ASSERT("'" << s_RECONSTRUCTION_INOUT << "' must be set as 'inout'", reconstruction);
 
     data::Material::sptr material = reconstruction->getMaterial();
-    material->diffuse()->alpha() = static_cast<float>(value) / 100.0f;
+    material->diffuse()->alpha() = static_cast<float>(value) / 100.0F;
     this->materialNotification();
 }
 
@@ -120,10 +118,10 @@ void SOrganMaterialEditor::materialNotification()
 service::IService::KeyConnectionsMap SOrganMaterialEditor::getAutoConnections() const
 {
     KeyConnectionsMap connections;
-    connections.push(s_RECONSTRUCTION_INOUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_RECONSTRUCTION_INOUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE);
     return connections;
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace sight::module
+} // namespace sight::module::ui::qml::reconstruction
