@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -82,7 +82,7 @@ public:
     MODULE_UI_QML_API SOrganMaterialEditor() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_QML_API virtual ~SOrganMaterialEditor() noexcept;
+    MODULE_UI_QML_API ~SOrganMaterialEditor() noexcept override;
 
 Q_SIGNALS:
 
@@ -90,8 +90,6 @@ Q_SIGNALS:
 
 protected:
 
-    typedef core::runtime::ConfigurationElement::sptr Configuration;
-
     /// Call IQmlEditor::starting
     void starting() override;
 
@@ -108,7 +106,7 @@ protected:
      * @brief Returns proposals to connect service slots to associated object signals,
      * this method is used for obj/srv auto connection
      *
-     * Connect Reconstruction::s_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect Reconstruction::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
      */
     KeyConnectionsMap getAutoConnections() const override;
 
@@ -129,4 +127,4 @@ private:
     data::ptr<data::Reconstruction, data::Access::inout> m_rec {this, s_RECONSTRUCTION_INOUT, true};
 };
 
-} // uiReconstructionQml
+} // namespace sight::module::ui::qml::reconstruction
