@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,7 +23,7 @@
 #include "modules/ui/qt/Plugin.hpp"
 
 #include <core/base.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 #include <core/runtime/profile/Profile.hpp>
 
 #include <service/macros.hpp>
@@ -52,15 +52,15 @@
 // Register all dialog implementation when we do use qt
 namespace base_dialog = sight::ui::base::dialog;
 
-fwGuiRegisterMacro(sight::ui::qt::dialog::InputDialog, base_dialog::IInputDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::LocationDialog, base_dialog::ILocationDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::LoggerDialog, base_dialog::ILoggerDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::MessageDialog, base_dialog::IMessageDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::MultiSelectorDialog, base_dialog::IMultiSelectorDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::NotificationDialog, base_dialog::INotificationDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::ProgressDialog, base_dialog::IProgressDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::PulseProgressDialog, base_dialog::IPulseProgressDialog::REGISTRY_KEY);
-fwGuiRegisterMacro(sight::ui::qt::dialog::SelectorDialog, base_dialog::ISelectorDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::InputDialog, base_dialog::IInputDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::LocationDialog, base_dialog::ILocationDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::LoggerDialog, base_dialog::ILoggerDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::MessageDialog, base_dialog::IMessageDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::MultiSelectorDialog, base_dialog::IMultiSelectorDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::NotificationDialog, base_dialog::INotificationDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::ProgressDialog, base_dialog::IProgressDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::PulseProgressDialog, base_dialog::IPulseProgressDialog::REGISTRY_KEY);
+SIGHT_REGISTER_GUI(sight::ui::qt::dialog::SelectorDialog, base_dialog::ISelectorDialog::REGISTRY_KEY);
 
 namespace sight::module::ui::qt
 {
@@ -71,9 +71,8 @@ SIGHT_REGISTER_PLUGIN("sight::module::ui::qt::Plugin");
 
 //-----------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -93,9 +92,9 @@ void Plugin::start()
     auto workerQt = sight::ui::qt::getQtWorker(argc, argv, callback, profile->getName(), profile->getVersion());
     core::thread::setDefaultWorker(workerQt);
 
-    workerQt->post(std::bind(&Plugin::loadStyleSheet, this));
+    workerQt->post([this](auto&& ...){loadStyleSheet();});
 
-    core::runtime::getCurrentProfile()->setRunCallback(std::bind(&Plugin::run, this));
+    core::runtime::getCurrentProfile()->setRunCallback(run);
 }
 
 //-----------------------------------------------------------------------------
@@ -107,20 +106,11 @@ void Plugin::stop() noexcept
 
 //-----------------------------------------------------------------------------
 
-void setup()
-{
-    core::runtime::getCurrentProfile()->setup();
-}
-
-//-----------------------------------------------------------------------------
-
 int Plugin::run() noexcept
 {
     auto workerQt = core::thread::getDefaultWorker();
-    workerQt->post(std::bind(&setup));
     workerQt->getFuture().wait(); // This is required to start WorkerQt loop
 
-    core::runtime::getCurrentProfile()->cleanup();
     int result = std::any_cast<int>(workerQt->getFuture().get());
 
     return result;
@@ -130,34 +120,56 @@ int Plugin::run() noexcept
 
 void Plugin::loadStyleSheet()
 {
-    if(this->getModule()->hasParameter("resource"))
+    if(QCoreApplication::instance() != nullptr)
     {
-        const std::string resourceFile = this->getModule()->getParameterValue("resource");
-        const auto path                = core::runtime::getModuleResourceFilePath(resourceFile);
-
-        const bool resourceLoaded = QResource::registerResource(path.string().c_str());
-        SIGHT_ASSERT("Cannot load resources '" + resourceFile + "'.", resourceLoaded);
-    }
-
-    if(this->getModule()->hasParameter("style"))
-    {
-        const std::string style = this->getModule()->getParameterValue("style");
-        qApp->setStyle(QStyleFactory::create(QString::fromStdString(style)));
-    }
-
-    if(this->getModule()->hasParameter("stylesheet"))
-    {
-        const std::string stylesheetFile = this->getModule()->getParameterValue("stylesheet");
-        const auto path                  = core::runtime::getModuleResourceFilePath(stylesheetFile);
-
-        QFile data(QString::fromStdString(path.string()));
-        QString style;
-        if(data.open(QFile::ReadOnly))
+        if(this->getModule()->hasParameter("resource"))
         {
-            QTextStream styleIn(&data);
-            style = styleIn.readAll();
-            data.close();
-            qApp->setStyleSheet(style);
+            const std::string resourceFile = this->getModule()->getParameterValue("resource");
+            const auto path                = core::runtime::getModuleResourceFilePath(resourceFile);
+
+            [[maybe_unused]] const bool resourceLoaded = QResource::registerResource(path.string().c_str());
+            SIGHT_ASSERT("Cannot load resources '" + resourceFile + "'.", resourceLoaded);
+        }
+
+        if(this->getModule()->hasParameter("style"))
+        {
+            const std::string style = this->getModule()->getParameterValue("style");
+            qApp->setStyle(QStyleFactory::create(QString::fromStdString(style)));
+        }
+
+        QString touchFriendlyStyle;
+        if(this->getModule()->getParameterValue("touch_friendly") == "true")
+        {
+            const std::filesystem::path touchFriendlyStylePath = core::runtime::getModuleResourceFilePath(
+                "sight::module::ui::qt/touch-friendly.qss"
+            );
+            {
+                QFile data(QString::fromStdString(touchFriendlyStylePath.string()));
+                if(data.open(QFile::ReadOnly))
+                {
+                    touchFriendlyStyle = QTextStream(&data).readAll();
+                }
+            }
+        }
+
+        QString appStyle;
+        if(this->getModule()->hasParameter("stylesheet"))
+        {
+            const std::string stylesheetValue = this->getModule()->getParameterValue("stylesheet");
+            const std::filesystem::path path  = core::runtime::getModuleResourceFilePath(stylesheetValue);
+            {
+                QFile data(QString::fromStdString(path.string()));
+                if(data.open(QFile::ReadOnly))
+                {
+                    appStyle = QTextStream(&data).readAll();
+                }
+            }
+        }
+
+        QString styleResult = appStyle + touchFriendlyStyle;
+        if(!styleResult.isEmpty())
+        {
+            qApp->setStyleSheet(styleResult);
         }
     }
 }
