@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,15 +26,10 @@
 #include <core/location/SingleFile.hpp>
 #include <core/location/SingleFolder.hpp>
 
-#include <data/Composite.hpp>
-#include <data/Integer.hpp>
-
-#include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
-
 #include <ui/base/dialog/LocationDialog.hpp>
 #include <ui/base/Preferences.hpp>
 
+#include <boost/algorithm/string.hpp>
 #include <boost/tokenizer.hpp>
 
 #include <QApplication>
@@ -50,19 +45,64 @@ namespace sight::module::ui::qt
 {
 
 const core::com::Signals::SignalKeyType SPreferencesConfiguration::s_PARAMETERS_MODIFIED_SIG = "parametersModified";
+const core::com::Signals::SignalKeyType SPreferencesConfiguration::s_PREFERENCE_CHANGED_SIG  = "preferenceChanged";
+
+//------------------------------------------------------------------------------
+
+sight::ui::base::parameter_t SPreferencesConfiguration::convertValue(const PreferenceElt& _elt)
+{
+    switch(_elt.m_type)
+    {
+        case PreferenceType::TEXT:
+        case PreferenceType::PATH:
+        case PreferenceType::COMBOBOX:
+        case PreferenceType::FILE:
+        {
+            return _elt.m_preferenceValue;
+        }
+
+        case PreferenceType::U_INT:
+        {
+            return std::stoi(_elt.m_preferenceValue);
+        }
+
+        case PreferenceType::DOUBLE:
+        {
+            return std::stod(_elt.m_preferenceValue);
+        }
+
+        case PreferenceType::CHECKBOX:
+        {
+            return _elt.m_preferenceValue == "true";
+        }
+
+        case PreferenceType::LIST:
+        {
+            std::vector<std::string> list;
+            boost::split(list, _elt.m_preferenceValue, boost::is_any_of(_elt.m_separator));
+            return list;
+        }
+
+        default:
+        {
+            SIGHT_ASSERT("Preference type not handled", false);
+            return {};
+        }
+    }
+}
 
 //-----------------------------------------------------------------------------
 
 SPreferencesConfiguration::SPreferencesConfiguration() noexcept
 {
     m_sigParametersModified = newSignal<ParametersModifiedSignalType>(s_PARAMETERS_MODIFIED_SIG);
+    m_sigPreferenceChanged  = newSignal<ChangedSignalType>(s_PREFERENCE_CHANGED_SIG);
 }
 
 //------------------------------------------------------------------------------
 
-SPreferencesConfiguration::~SPreferencesConfiguration() noexcept
-{
-}
+SPreferencesConfiguration::~SPreferencesConfiguration() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -70,112 +110,95 @@ void SPreferencesConfiguration::configuring()
 {
     this->initialize();
 
-    core::runtime::ConfigurationElementContainer config = m_configuration->findAllConfigurationElement("preference");
-    for(const auto& elt : config.getElements())
+    const auto configuration = this->getConfiguration();
+
+    for(const auto& cfg : boost::make_iterator_range(configuration.equal_range("preference")))
     {
         PreferenceElt pref;
 
-        ConfigurationType typeCfg = elt->findConfigurationElement("type");
-        SIGHT_ASSERT("element 'type' is missing.", typeCfg);
-        if(typeCfg->getValue() == "checkbox")
+        auto type = cfg.second.get<std::string>("type");
+        if(type == "checkbox")
         {
             pref.m_type = PreferenceType::CHECKBOX;
         }
-        else if(typeCfg->getValue() == "text")
+        else if(type == "text")
         {
             pref.m_type = PreferenceType::TEXT;
         }
-        else if(typeCfg->getValue() == "path")
+        else if(type == "path")
         {
             pref.m_type = PreferenceType::PATH;
         }
-        else if(typeCfg->getValue() == "file")
+        else if(type == "file")
         {
             pref.m_type = PreferenceType::FILE;
         }
-        else if(typeCfg->getValue() == "combobox")
+        else if(type == "combobox")
         {
             pref.m_type = PreferenceType::COMBOBOX;
         }
-        else if(typeCfg->getValue() == "double")
+        else if(type == "double")
         {
             pref.m_type = PreferenceType::DOUBLE;
 
-            ConfigurationType keyCfg = elt->findConfigurationElement("min");
-            if(keyCfg)
-            {
-                pref.m_dMinMax.first = std::stod(keyCfg->getValue());
-            }
-
-            keyCfg = elt->findConfigurationElement("max");
-            if(keyCfg)
-            {
-                pref.m_dMinMax.second = std::stod(keyCfg->getValue());
-            }
+            pref.m_dMinMax.first  = cfg.second.get<double>("min", pref.m_dMinMax.first);
+            pref.m_dMinMax.second = cfg.second.get<double>("max", pref.m_dMinMax.second);
         }
-        else if(typeCfg->getValue() == "int")
+        else if(type == "int")
         {
             pref.m_type = PreferenceType::U_INT;
 
-            ConfigurationType keyCfg = elt->findConfigurationElement("min");
-            if(keyCfg)
-            {
-                pref.m_iMinMax.first = std::stoi(keyCfg->getValue());
-            }
+            pref.m_iMinMax.first  = cfg.second.get<int>("min", pref.m_iMinMax.first);
+            pref.m_iMinMax.second = cfg.second.get<int>("max", pref.m_iMinMax.second);
+        }
+        else if(type == "list")
+        {
+            pref.m_type = PreferenceType::LIST;
 
-            keyCfg = elt->findConfigurationElement("max");
-            if(keyCfg)
-            {
-                pref.m_iMinMax.second = std::stoi(keyCfg->getValue());
-            }
+            pref.m_separator = cfg.second.get("separator", ",");
         }
         else
         {
-            SIGHT_ERROR("Preference type " << typeCfg->getValue() << " is not implemented");
+            SIGHT_ERROR("Preference type " << type << " is not implemented");
         }
 
-        ConfigurationType nameCfg = elt->findConfigurationElement("name");
-        SIGHT_ASSERT("element 'name' is missing.", nameCfg);
-        pref.m_name = nameCfg->getValue();
-
-        ConfigurationType keyCfg = elt->findConfigurationElement("key");
-        SIGHT_ASSERT("element 'key' is missing.", keyCfg);
-        pref.m_preferenceKey = keyCfg->getValue();
-
-        ConfigurationType defaultValueCfg = elt->findConfigurationElement("default_value");
-        SIGHT_ASSERT("element 'default_value' is missing.", defaultValueCfg);
-        pref.m_defaultValue = defaultValueCfg->getValue();
+        pref.m_name          = cfg.second.get<std::string>("name");
+        pref.m_preferenceKey = cfg.second.get<std::string>("key");
+        pref.m_defaultValue  = cfg.second.get<std::string>("default_value");
 
         if(pref.m_type == PreferenceType::TEXT || pref.m_type == PreferenceType::PATH
-           || pref.m_type == PreferenceType::FILE)
+           || pref.m_type == PreferenceType::FILE || pref.m_type == PreferenceType::LIST)
         {
             pref.m_lineEdit = new QLineEdit(QString::fromStdString(pref.m_defaultValue));
+            pref.m_lineEdit->setObjectName(pref.m_preferenceKey.c_str());
         }
         else if(pref.m_type == PreferenceType::CHECKBOX)
         {
             pref.m_checkBox = new QCheckBox();
             pref.m_checkBox->setChecked(pref.m_defaultValue == "true");
+            pref.m_checkBox->setObjectName(pref.m_preferenceKey.c_str());
         }
         else if(pref.m_type == PreferenceType::U_INT)
         {
             pref.m_lineEdit = new QLineEdit(QString::fromStdString(pref.m_defaultValue));
             pref.m_lineEdit->setValidator(new QIntValidator(pref.m_iMinMax.first, pref.m_iMinMax.second));
+            pref.m_lineEdit->setObjectName(pref.m_preferenceKey.c_str());
         }
         else if(pref.m_type == PreferenceType::DOUBLE)
         {
             pref.m_lineEdit = new QLineEdit(QString::fromStdString(pref.m_defaultValue));
             pref.m_lineEdit->setValidator(new QDoubleValidator(pref.m_dMinMax.first, pref.m_dMinMax.second, 6));
+            pref.m_lineEdit->setObjectName(pref.m_preferenceKey.c_str());
         }
         else if(pref.m_type == PreferenceType::COMBOBOX)
         {
-            ConfigurationType valuesCfg = elt->findConfigurationElement("values");
-            SIGHT_ASSERT("element 'values' is missing.", valuesCfg);
+            const auto valuesCfg = cfg.second.get<std::string>("values");
 
             const boost::char_separator<char> sep(", ;");
-            const std::string s = valuesCfg->getValue();
-            const boost::tokenizer<boost::char_separator<char> > tokens {s, sep};
+            const boost::tokenizer<boost::char_separator<char> > tokens {valuesCfg, sep};
 
             pref.m_comboBox = new QComboBox();
+            pref.m_comboBox->setObjectName(pref.m_preferenceKey.c_str());
             for(const std::string& value : tokens)
             {
                 pref.m_comboBox->addItem(QString::fromStdString(value));
@@ -209,7 +232,7 @@ void SPreferencesConfiguration::starting()
             }
         }
     }
-    catch(const sight::ui::base::PreferencesDisabled& e)
+    catch(const sight::ui::base::PreferencesDisabled& /*e*/)
     {
         // Nothing to do..
     }
@@ -219,7 +242,10 @@ void SPreferencesConfiguration::starting()
 
 void SPreferencesConfiguration::updating()
 {
-    QPointer<QDialog> dialog     = new QDialog();
+    const QString serviceID = QString::fromStdString(getID().substr(getID().find_last_of('_') + 1));
+
+    QPointer<QDialog> dialog = new QDialog();
+    dialog->setObjectName("SPreferencesConfiguration");
     QPointer<QGridLayout> layout = new QGridLayout();
 
     int index = 0;
@@ -228,7 +254,7 @@ void SPreferencesConfiguration::updating()
         QPointer<QLabel> label = new QLabel(QString::fromStdString(pref.m_name));
         layout->addWidget(label, index, 0);
 
-        if(pref.m_type == PreferenceType::TEXT)
+        if(pref.m_type == PreferenceType::TEXT || pref.m_type == PreferenceType::LIST)
         {
             pref.m_lineEdit->setText(QString::fromStdString(pref.m_preferenceValue));
             layout->addWidget(pref.m_lineEdit, index, 1);
@@ -278,9 +304,9 @@ void SPreferencesConfiguration::updating()
             QObject::connect(
                 directorySelector.data(),
                 &QPushButton::clicked,
-                [this, pref]()
+                [pref]()
                 {
-                    this->onSelectDir(pref.m_lineEdit);
+                    sight::module::ui::qt::SPreferencesConfiguration::onSelectDir(pref.m_lineEdit);
                 });
         }
         else if(pref.m_type == PreferenceType::FILE)
@@ -292,9 +318,9 @@ void SPreferencesConfiguration::updating()
             QObject::connect(
                 directorySelector.data(),
                 &QPushButton::clicked,
-                [this, pref]()
+                [pref]()
                 {
-                    this->onSelectFile(pref.m_lineEdit);
+                    sight::module::ui::qt::SPreferencesConfiguration::onSelectFile(pref.m_lineEdit);
                 });
         }
         else if(pref.m_type == PreferenceType::COMBOBOX)
@@ -320,7 +346,9 @@ void SPreferencesConfiguration::updating()
     }
 
     QPointer<QPushButton> cancelButton = new QPushButton("Cancel");
-    QPointer<QPushButton> okButton     = new QPushButton("OK");
+    cancelButton->setObjectName(cancelButton->text());
+    QPointer<QPushButton> okButton = new QPushButton("OK");
+    okButton->setObjectName(okButton->text());
     okButton->setDefault(true);
 
     QPointer<QHBoxLayout> buttonLayout = new QHBoxLayout();
@@ -340,14 +368,21 @@ void SPreferencesConfiguration::updating()
 
         for(PreferenceElt& pref : m_preferences)
         {
+            bool preferenceUpdate = false; // only emit signal for preference that has changed.
+
             if((pref.m_type == PreferenceType::TEXT || pref.m_type == PreferenceType::PATH
-                || pref.m_type == PreferenceType::FILE) && !pref.m_lineEdit->text().isEmpty())
+                || pref.m_type == PreferenceType::FILE || pref.m_type == PreferenceType::LIST)
+               && !pref.m_lineEdit->text().isEmpty())
             {
+                preferenceUpdate =
+                    pref.m_preferenceValue != pref.m_lineEdit->text().toStdString();
                 pref.m_preferenceValue = pref.m_lineEdit->text().toStdString();
             }
             else if(pref.m_type == PreferenceType::CHECKBOX)
             {
-                pref.m_preferenceValue = pref.m_checkBox->isChecked() ? "true" : "false";
+                const std::string checked = pref.m_checkBox->isChecked() ? "true" : "false";
+                preferenceUpdate       = pref.m_preferenceValue != checked;
+                pref.m_preferenceValue = checked;
             }
             else if(pref.m_type == PreferenceType::U_INT || pref.m_type == PreferenceType::DOUBLE)
             {
@@ -358,6 +393,8 @@ void SPreferencesConfiguration::updating()
 
                 if(isValid)
                 {
+                    preferenceUpdate =
+                        pref.m_preferenceValue != pref.m_lineEdit->text().toStdString();
                     pref.m_preferenceValue = pref.m_lineEdit->text().toStdString();
                 }
 
@@ -377,10 +414,19 @@ void SPreferencesConfiguration::updating()
             }
             else if(pref.m_type == PreferenceType::COMBOBOX)
             {
+                preferenceUpdate =
+                    pref.m_preferenceValue != pref.m_comboBox->currentText().toStdString();
                 pref.m_preferenceValue = pref.m_comboBox->currentText().toStdString();
             }
 
             preferences.put(pref.m_preferenceKey, pref.m_preferenceValue);
+
+            // Emit preferenceChanged signal with new value and preference key.
+            if(preferenceUpdate)
+            {
+                const auto value = this->convertValue(pref);
+                m_sigPreferenceChanged->asyncEmit(value, pref.m_preferenceKey);
+            }
         }
 
         m_sigParametersModified->asyncEmit();
