@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,6 +30,7 @@
 #include <data/String.hpp>
 
 #include <ui/base/IAction.hpp>
+#include <ui/base/parameter.hpp>
 
 #include <QCheckBox>
 #include <QComboBox>
@@ -44,7 +45,7 @@ namespace sight::data
 
 class String;
 
-}
+} // namespace sight::data
 
 namespace sight::module::ui::qt
 {
@@ -102,6 +103,13 @@ namespace sight::module::ui::qt
             <key>DEVICE_PORT</key>
             <default_value>104</default_value>
         </preference>
+        <preference>
+            <type>list</type>
+            <name>Values for Nonlinear</name>
+            <key>nonlin</key>
+            <separator>,</separator>
+            <default_value>25,50,90,120,150</default_value>
+        </preference>
     </service>
    @endcode
  *
@@ -114,6 +122,7 @@ namespace sight::module::ui::qt
  *                         'combobox' type).
  * - \b min (optional, int/double, default=0/-1000000.0): minimum value allowed in the field.
  * - \b max (optional, int/double, default=999999/1000000.0): maximum value allowed in the field.
+ * - \b separator (optional, list, default=','): the separator for the list type
  */
 class MODULE_UI_QT_CLASS_API SPreferencesConfiguration final : public QObject,
                                                                public sight::ui::base::IAction
@@ -149,7 +158,11 @@ private:
 
     /// Type of signal when parameters are updated.
     typedef core::com::Signal<void ()> ParametersModifiedSignalType;
-    MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_PARAMETERS_MODIFIED_SIG;
+    static const core::com::Signals::SignalKeyType s_PARAMETERS_MODIFIED_SIG;
+
+    /// Generic changed signal type
+    typedef core::com::Signal<void (sight::ui::base::parameter_t, std::string)> ChangedSignalType;
+    static const core::com::Signals::SignalKeyType s_PREFERENCE_CHANGED_SIG;
 
     enum class PreferenceType : std::int8_t
     {
@@ -159,12 +172,13 @@ private:
         PATH,
         FILE,
         COMBOBOX,
-        DOUBLE
+        DOUBLE,
+        LIST
     };
 
     struct PreferenceElt
     {
-        PreferenceType m_type;
+        PreferenceType m_type {PreferenceType::TEXT};
         QPointer<QLineEdit> m_lineEdit;
         QPointer<QCheckBox> m_checkBox;
         QPointer<QComboBox> m_comboBox;
@@ -174,13 +188,20 @@ private:
         std::string m_defaultValue;
         std::pair<int, int> m_iMinMax {0, 999999};
         std::pair<double, double> m_dMinMax {-1000000.0, 1000000.0};
+        std::string m_separator;
     };
 
-    void onSelectDir(QPointer<QLineEdit> _lineEdit);
+    /// @brief Converts string value from PreferenceElt.m_preferenceValue to real type regarding PreferenceElt.m_type.
+    /// @param _elt The preference element
+    /// @return std::variant as defined by parameter_t.
+    static sight::ui::base::parameter_t convertValue(const PreferenceElt& _elt);
 
-    void onSelectFile(QPointer<QLineEdit> _lineEdit);
+    static void onSelectDir(QPointer<QLineEdit> _lineEdit);
+
+    static void onSelectFile(QPointer<QLineEdit> _lineEdit);
 
     ParametersModifiedSignalType::sptr m_sigParametersModified;
+    ChangedSignalType::sptr m_sigPreferenceChanged;
 
     std::vector<PreferenceElt> m_preferences;
 };
