@@ -37,7 +37,7 @@
 #include <filesystem>
 #include <core/base.hpp>
 #include <service/macros.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include "SShowAbout.hpp"
 
@@ -47,7 +47,7 @@ namespace sight::module::ui::qt
 //------------------------------------------------------------------------------
 
 SShowAbout::SShowAbout() noexcept :
-    m_bServiceIsConfigured(false),
+
     m_fsAboutPath(""),
     m_title("About"),
     m_size(500, 300)
@@ -56,9 +56,8 @@ SShowAbout::SShowAbout() noexcept :
 
 //------------------------------------------------------------------------------
 
-SShowAbout::~SShowAbout() noexcept
-{
-}
+SShowAbout::~SShowAbout() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -73,35 +72,19 @@ void SShowAbout::configuring()
 {
     this->sight::ui::base::IAction::initialize();
 
-    typedef SPTR(core::runtime::ConfigurationElement) ConfigurationElement;
+    const auto& config = this->getConfiguration();
 
-    ConfigurationElement cfgFilename = m_configuration->findConfigurationElement("filename");
-    ConfigurationElement cfgTitle    = m_configuration->findConfigurationElement("title");
-    ConfigurationElement cfgSize     = m_configuration->findConfigurationElement("size");
+    const auto filename = config.get<std::string>("filename.<xmlattr>.id");
+    // Convert the path from a module location
+    m_fsAboutPath = core::runtime::getModuleResourceFilePath(filename);
 
-    if(cfgFilename)
-    {
-        const std::string& filename = cfgFilename->getExistingAttributeValue("id");
-        // Convert the path from a module location
-        m_fsAboutPath = core::runtime::getModuleResourceFilePath(filename);
+    m_bServiceIsConfigured = std::filesystem::exists(m_fsAboutPath);
+    SIGHT_WARN_IF("About file " + filename + " doesn't exist", !m_bServiceIsConfigured);
 
-        m_bServiceIsConfigured = std::filesystem::exists(m_fsAboutPath);
-        SIGHT_WARN_IF("About file " + filename + " doesn't exist", !m_bServiceIsConfigured);
-    }
+    m_title = config.get<std::string>("title", m_title);
 
-    if(cfgTitle)
-    {
-        m_title = cfgTitle->getValue();
-    }
-
-    if(cfgSize)
-    {
-        const std::string& w = cfgSize->getExistingAttributeValue("width");
-        const std::string& h = cfgSize->getExistingAttributeValue("height");
-
-        m_size.setWidth(std::stoi(w));
-        m_size.setHeight(std::stoi(h));
-    }
+    m_size.setWidth(config.get<int>("size.<xmlattr>.width", m_size.width()));
+    m_size.setHeight(config.get<int>("size.<xmlattr>.height", m_size.height()));
 }
 
 //------------------------------------------------------------------------------
@@ -110,7 +93,7 @@ void SShowAbout::updating()
 {
     SIGHT_ASSERT("The service 'SShowAbout' isn't configured properly.", m_bServiceIsConfigured);
 
-    QDialog* dialog = new QDialog(qApp->activeWindow());
+    auto* dialog = new QDialog(qApp->activeWindow());
     dialog->setWindowTitle(QString::fromStdString(m_title));
     QUrl url = QUrl::fromLocalFile(QString::fromStdString(m_fsAboutPath.string()));
 #if defined(QT_WEBKIT)
@@ -119,7 +102,7 @@ void SShowAbout::updating()
     htmlView->load(url);
     QObject::connect(htmlView, SIGNAL(linkClicked(const QUrl&)), this, SLOT(onUrlClicked(const QUrl&)));
 #else
-    QTextBrowser* htmlView = new QTextBrowser(dialog);
+    auto* htmlView = new QTextBrowser(dialog);
     htmlView->setSource(url);
     htmlView->setOpenExternalLinks(true);
     htmlView->setMinimumSize(m_size);
@@ -127,17 +110,17 @@ void SShowAbout::updating()
     searchPaths.append(QString::fromStdString(m_fsAboutPath.parent_path().string()));
     htmlView->setSearchPaths(searchPaths);
 #endif
-    QPushButton* okButton = new QPushButton(QObject::tr("Ok"));
-    QHBoxLayout* h_layout = new QHBoxLayout();
+    auto* okButton = new QPushButton(QObject::tr("Ok"));
+    auto* h_layout = new QHBoxLayout();
     h_layout->addStretch();
     h_layout->addWidget(okButton);
     h_layout->setContentsMargins(5, 5, 5, 5);
 
-    QFrame* line = new QFrame(dialog);
+    auto* line = new QFrame(dialog);
     line->setFrameShape(QFrame::HLine);
     line->setFrameShadow(QFrame::Sunken);
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     layout->addWidget(htmlView, 0);
     layout->addWidget(line, 0);
     layout->addLayout(h_layout, 0);
