@@ -24,8 +24,6 @@
 
 #include <core/base.hpp>
 
-#include <service/macros.hpp>
-
 #include <ui/base/Cursor.hpp>
 #include <ui/base/dialog/MessageDialog.hpp>
 
@@ -49,48 +47,30 @@ class HelpBrowser : public QTextBrowser
 {
 public:
 
-    HelpBrowser(QHelpEngine* helpEngine, QWidget* parent = 0) :
+    explicit HelpBrowser(QHelpEngine* helpEngine, QWidget* parent = nullptr) :
         QTextBrowser(parent),
-        helpEngine(helpEngine)
+        m_helpEngine(helpEngine)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    QVariant loadResource(int type, const QUrl& url)
+    QVariant loadResource(int type, const QUrl& url) override
     {
         if(url.scheme() == "qthelp")
         {
-            return QVariant(helpEngine->fileData(url));
-        }
-        else
-        {
-            return QTextBrowser::loadResource(type, url);
+            return {m_helpEngine->fileData(url)};
         }
+
+        return QTextBrowser::loadResource(type, url);
     }
 
 private:
 
-    QHelpEngine* helpEngine;
+    QHelpEngine* m_helpEngine;
 };
 //------------------------------------------------------------------------------
 
-//------------------------------------------------------------------------------
-
-SShowHelp::SShowHelp() noexcept :
-    m_bServiceIsConfigured(false),
-    m_fsHelpPath("")
-{
-}
-
-//------------------------------------------------------------------------------
-
-SShowHelp::~SShowHelp() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void SShowHelp::info(std::ostream& _sstream)
 {
     _sstream << "Action for show help contents" << std::endl;
@@ -107,13 +87,12 @@ void SShowHelp::configuring()
      *                             the appearance and available features of Qt Assistant.
      */
     this->sight::ui::base::IAction::initialize();
-    if(m_configuration->findConfigurationElement("filename"))
-    {
-        std::string filename = m_configuration->findConfigurationElement("filename")->getExistingAttributeValue("id");
-        m_fsHelpPath           = std::filesystem::path(filename);
-        m_bServiceIsConfigured = std::filesystem::exists(m_fsHelpPath);
-        SIGHT_WARN_IF("Help file " << filename << " doesn't exist", !m_bServiceIsConfigured);
-    }
+
+    const auto configuration = this->getConfiguration();
+    const auto filename      = configuration.get<std::string>("filename.<xmlattr>.id");
+    m_fsHelpPath           = std::filesystem::path(filename);
+    m_bServiceIsConfigured = std::filesystem::exists(m_fsHelpPath);
+    SIGHT_WARN_IF("Help file " << filename << " doesn't exist", !m_bServiceIsConfigured);
 }
 
 //------------------------------------------------------------------------------
@@ -122,9 +101,9 @@ void SShowHelp::updating()
 {
     SIGHT_ASSERT("The Help service isn't configured properly.", m_bServiceIsConfigured);
 
-    QDialog* dialog = new QDialog(qApp->activeWindow());
+    auto* dialog = new QDialog(qApp->activeWindow());
     dialog->setWindowTitle(QString("Help"));
-    QHelpEngine* helpEngine = new QHelpEngine(QString::fromStdString(m_fsHelpPath.string()), dialog);
+    auto* helpEngine = new QHelpEngine(QString::fromStdString(m_fsHelpPath.string()), dialog);
     if(!helpEngine->setupData())
     {
         SIGHT_ERROR("HelpEngine error: " << helpEngine->error().toStdString());
@@ -139,13 +118,13 @@ void SShowHelp::updating()
     }
     else
     {
-        QSplitter* helpPanel     = new QSplitter(Qt::Horizontal);
-        HelpBrowser* helpBrowser = new HelpBrowser(helpEngine, dialog);
+        auto* helpPanel   = new QSplitter(Qt::Horizontal);
+        auto* helpBrowser = new HelpBrowser(helpEngine, dialog);
         helpPanel->insertWidget(0, helpEngine->contentWidget());
         helpPanel->insertWidget(1, helpBrowser);
         helpPanel->setStretchFactor(1, 1);
 
-        QHBoxLayout* h_layout = new QHBoxLayout();
+        auto* h_layout = new QHBoxLayout();
         h_layout->addWidget(helpPanel);
         dialog->setLayout(h_layout);
         QObject::connect(
