@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,13 +20,14 @@
  *
  ***********************************************************************/
 
+// cspell:ignore NOLINTNEXTLINE
+
 #include "SStatus.hpp"
 
 #include <core/base.hpp>
 #include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <service/IService.hpp>
 #include <service/macros.hpp>
@@ -56,11 +57,7 @@ const core::com::Slots::SlotKeyType SStatus::s_TOGGLE_NTH_GREEN_RED_SLOT = "togg
 
 //-----------------------------------------------------------------------------
 
-SStatus::SStatus() noexcept :
-    m_count(1),
-    m_isCircular(false),
-    m_width(20),
-    m_height(20)
+SStatus::SStatus() noexcept
 {
     newSlot(s_CHANGE_TO_GREEN_SLOT, &SStatus::changeToGreen, this);
     newSlot(s_CHANGE_TO_RED_SLOT, &SStatus::changeToRed, this);
@@ -74,9 +71,8 @@ SStatus::SStatus() noexcept :
 
 //------------------------------------------------------------------------------
 
-SStatus::~SStatus() noexcept
-{
-}
+SStatus::~SStatus() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -84,8 +80,8 @@ void SStatus::starting()
 {
     this->create();
 
-    auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
-    QBoxLayout* layout;
+    auto qtContainer   = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
+    QBoxLayout* layout = nullptr;
     if(m_layout == "horizontal")
     {
         layout = new QHBoxLayout();
@@ -95,9 +91,12 @@ void SStatus::starting()
         layout = new QVBoxLayout();
     }
 
+    const QString serviceID = QString::fromStdString(getID().substr(getID().find_last_of('_') + 1));
+
     for(std::size_t i = 0 ; i < m_count ; ++i)
     {
         QPointer<QLabel> indicator = new QLabel();
+        indicator->setObjectName(serviceID + "/" + QString::number(i));
         indicator->setFixedWidth(static_cast<int>(m_width));
         indicator->setFixedHeight(static_cast<int>(m_height));
         m_indicator.push_back(indicator);
@@ -124,7 +123,7 @@ void SStatus::configuring()
 {
     this->initialize();
 
-    const auto config = this->getConfigTree();
+    const auto config = this->getConfiguration();
 
     m_greenTooltip  = config.get<std::string>("green", "");
     m_redTooltip    = config.get<std::string>("red", "");
@@ -142,6 +141,8 @@ void SStatus::configuring()
     m_width  = config.get<std::size_t>("size.width", 20);
     m_height = config.get<std::size_t>("size.height", 20);
 
+    m_borderRadius = m_isCircular ? QString::number(std::min(m_width, m_height) / 2) + "px" : "0";
+
     m_count = config.get<std::size_t>("count", 1);
 
     if(m_count == 1)
@@ -170,10 +171,11 @@ void SStatus::configuring()
 
             const auto labelStatusConfig = configLabels.get().equal_range("labelStatus");
             // Fill the labelStatus vector
+            // NOLINTNEXTLINE(bugprone-branch-clone)
             BOOST_FOREACH(const service::IService::ConfigType::value_type& v, labelStatusConfig)
             {
-                const std::string label = v.second.get<std::string>("");
-                QPointer<QLabel> qLab   = new QLabel();
+                const auto label      = v.second.get<std::string>("");
+                QPointer<QLabel> qLab = new QLabel();
                 qLab->setText(QString::fromStdString(label));
 
                 m_labelStatus.push_back(qLab);
@@ -211,7 +213,7 @@ void SStatus::updating()
 
 //------------------------------------------------------------------------------
 
-void SStatus::info(std::ostream& _sstream)
+void SStatus::info(std::ostream& /*_sstream*/)
 {
 }
 
@@ -219,14 +221,10 @@ void SStatus::info(std::ostream& _sstream)
 
 void SStatus::changeToGreen()
 {
-    for(QVector<QPointer<QLabel> >::Iterator it = m_indicator.begin() ; it != m_indicator.end() ; ++it)
+    for(auto& it : m_indicator)
     {
-        (*it)->setStyleSheet(
-            "background-color: green; border-radius: " + QString(
-                m_isCircular ? "10px;" : "0"
-            ) + ";"
-        );
-        (*it)->setToolTip(QString::fromStdString(m_greenTooltip));
+        it->setStyleSheet("background-color: green; border-radius: " + m_borderRadius + ";");
+        it->setToolTip(QString::fromStdString(m_greenTooltip));
     }
 }
 
@@ -234,13 +232,10 @@ void SStatus::changeToGreen()
 
 void SStatus::changeToRed()
 {
-    for(QVector<QPointer<QLabel> >::Iterator it = m_indicator.begin() ; it != m_indicator.end() ; ++it)
+    for(auto& it : m_indicator)
     {
-        (*it)->setStyleSheet(
-            "background-color: red; border-radius: " + QString(m_isCircular ? "10px;" : "0")
-            + ";"
-        );
-        (*it)->setToolTip(QString::fromStdString(m_redTooltip));
+        it->setStyleSheet("background-color: red; border-radius: " + m_borderRadius + ";");
+        it->setToolTip(QString::fromStdString(m_redTooltip));
     }
 }
 
@@ -248,14 +243,10 @@ void SStatus::changeToRed()
 
 void SStatus::changeToOrange()
 {
-    for(QVector<QPointer<QLabel> >::Iterator it = m_indicator.begin() ; it != m_indicator.end() ; ++it)
+    for(auto& it : m_indicator)
     {
-        (*it)->setStyleSheet(
-            "background-color: orange; border-radius: " + QString(
-                m_isCircular ? "10px;" : "0"
-            ) + ";"
-        );
-        (*it)->setToolTip(QString::fromStdString(m_orangeTooltip));
+        it->setStyleSheet("background-color: orange; border-radius: " + m_borderRadius + ";");
+        it->setToolTip(QString::fromStdString(m_orangeTooltip));
     }
 }
 
@@ -263,13 +254,12 @@ void SStatus::changeToOrange()
 
 void SStatus::toggleGreenRed(const bool green)
 {
-    for(QVector<QPointer<QLabel> >::Iterator it = m_indicator.begin() ; it != m_indicator.end() ; ++it)
+    for(auto& it : m_indicator)
     {
-        (*it)->setStyleSheet(
-            "background-color:" + QString(green ? "green" : "red") + "; border-radius: "
-            + QString(m_isCircular ? "10px;" : "0") + ";"
+        it->setStyleSheet(
+            "background-color:" + QString(green ? "green" : "red") + "; border-radius: " + m_borderRadius + ";"
         );
-        (*it)->setToolTip(green ? QString::fromStdString(m_greenTooltip) : QString::fromStdString(m_redTooltip));
+        it->setToolTip(green ? QString::fromStdString(m_greenTooltip) : QString::fromStdString(m_redTooltip));
     }
 }
 
@@ -277,17 +267,14 @@ void SStatus::toggleGreenRed(const bool green)
 
 void SStatus::changeNthToGreen(const int index)
 {
-    SIGHT_INFO_IF(
+    SIGHT_DEBUG_IF(
         "Index(" << index << ") must be in vector range [0:" << m_indicator.size() - 1 << "]",
-        index < 0 || index >= m_count
+        index < 0 || index >= int(m_count)
     );
 
-    if(index >= 0 && index < m_count)
+    if(index >= 0 && index < int(m_count))
     {
-        m_indicator.at(index)->setStyleSheet(
-            "background-color: green; border-radius: "
-            + QString(m_isCircular ? "10px;" : "0") + ";"
-        );
+        m_indicator.at(index)->setStyleSheet("background-color: green; border-radius: " + m_borderRadius + ";");
         m_indicator.at(index)->setToolTip(QString::fromStdString(m_greenTooltip));
     }
 }
@@ -296,17 +283,14 @@ void SStatus::changeNthToGreen(const int index)
 
 void SStatus::changeNthToRed(const int index)
 {
-    SIGHT_INFO_IF(
+    SIGHT_DEBUG_IF(
         "Index(" << index << ") must be in vector range [0:" << m_indicator.size() - 1 << "]",
-        index < 0 || index >= m_count
+        index < 0 || index >= int(m_count)
     );
 
-    if(index >= 0 && index < m_count)
+    if(index >= 0 && index < int(m_count))
     {
-        m_indicator.at(index)->setStyleSheet(
-            "background-color: red; border-radius: "
-            + QString(m_isCircular ? "10px;" : "0") + ";"
-        );
+        m_indicator.at(index)->setStyleSheet("background-color: red; border-radius: " + m_borderRadius + ";");
         m_indicator.at(index)->setToolTip(QString::fromStdString(m_redTooltip));
     }
 }
@@ -315,17 +299,14 @@ void SStatus::changeNthToRed(const int index)
 
 void SStatus::changeNthToOrange(const int index)
 {
-    SIGHT_INFO_IF(
+    SIGHT_DEBUG_IF(
         "Index(" << index << ") must be in vector range [0:" << m_indicator.size() - 1 << "]",
-        index < 0 || index >= m_count
+        index < 0 || index >= int(m_count)
     );
 
-    if(index >= 0 && index < m_count)
+    if(index >= 0 && index < int(m_count))
     {
-        m_indicator.at(index)->setStyleSheet(
-            "background-color: orange; border-radius: "
-            + QString(m_isCircular ? "10px;" : "0") + ";"
-        );
+        m_indicator.at(index)->setStyleSheet("background-color: orange; border-radius: " + m_borderRadius + ";");
         m_indicator.at(index)->setToolTip(QString::fromStdString(m_orangeTooltip));
     }
 }
@@ -334,16 +315,16 @@ void SStatus::changeNthToOrange(const int index)
 
 void SStatus::toggleNthGreenRed(const int index, const bool green)
 {
-    SIGHT_INFO_IF(
+    SIGHT_DEBUG_IF(
         "Index(" << index << ") must be in vector range [0:" << m_indicator.size() - 1 << "]",
-        index < 0 || index >= m_count
+        index < 0 || index >= int(m_count)
     );
 
-    if(index >= 0 && index < m_count)
+    if(index >= 0 && index < int(m_count))
     {
         m_indicator.at(index)->setStyleSheet(
             "background-color:" + QString(green ? "green" : "red")
-            + "; border-radius: " + QString(m_isCircular ? "10px;" : "0") + ";"
+            + "; border-radius: " + m_borderRadius + ";"
         );
         m_indicator.at(index)->setToolTip(
             green ? QString::fromStdString(m_greenTooltip)
