@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,8 +24,7 @@
 
 #include <core/com/Signal.hxx>
 #include <core/com/Slots.hxx>
-#include <core/runtime/operations.hpp>
-#include <core/runtime/Runtime.hpp>
+#include <core/runtime/path.hpp>
 #include <core/tools/Os.hpp>
 
 #include <ui/base/dialog/MessageDialog.hpp>
@@ -38,25 +37,11 @@
 #include <QQuickItem>
 #include <QVBoxLayout>
 
-namespace sight::module::ui::qt
-{
-
-namespace activity
+namespace sight::module::ui::qt::activity
 {
 
 //------------------------------------------------------------------------------
 
-const core::com::Signals::SignalKeyType s_ACTIVITY_CREATED_SIG = "activityCreated";
-const core::com::Signals::SignalKeyType s_DATA_REQUIRED_SIG    = "dataRequired";
-const core::com::Signals::SignalKeyType s_ENABLED_PREVIOUS_SIG = "enabledPrevious";
-const core::com::Signals::SignalKeyType s_ENABLED_NEXT_SIG     = "enabledNext";
-
-const core::com::Slots::SlotKeyType s_GO_TO_SLOT      = "goTo";
-const core::com::Slots::SlotKeyType s_CHECK_NEXT_SLOT = "checkNext";
-const core::com::Slots::SlotKeyType s_NEXT_SLOT       = "next";
-const core::com::Slots::SlotKeyType s_PREVIOUS_SLOT   = "previous";
-const core::com::Slots::SlotKeyType s_SEND_INFO_SLOT  = "sendInfo";
-
 static const std::string s_CLEAR_ACTIVITIES_CONFIG = "clearActivities";
 static const std::string s_THEME_CONFIG            = "theme";
 static const std::string s_CLEAR_CONFIG            = "clear";
@@ -65,26 +50,19 @@ static const std::string s_FOREGROUND_CONFIG       = "foreground";
 static const std::string s_BACKGROUND_CONFIG       = "background";
 static const std::string s_PRIMARY_CONFIG          = "primary";
 static const std::string s_ELEVATION_CONFIG        = "elevation";
+static const std::string s_BUTTON_WIDTH            = "buttonWidth";
+static const std::string s_FONT_SIZE               = "fontSize";
 
 //------------------------------------------------------------------------------
 
 SSequencer::SSequencer() noexcept
 {
-    m_sigActivityCreated = newSignal<ActivityCreatedSignalType>(s_ACTIVITY_CREATED_SIG);
-    m_sigDataRequired    = newSignal<DataRequiredSignalType>(s_DATA_REQUIRED_SIG);
-    m_sigEnabledPrevious = newSignal<EnabledPreviousSignalType>(s_ENABLED_PREVIOUS_SIG);
-    m_sigEnabledNext     = newSignal<EnabledNextSignalType>(s_ENABLED_NEXT_SIG);
-    newSlot(s_GO_TO_SLOT, &SSequencer::goTo, this);
-    newSlot(s_CHECK_NEXT_SLOT, &SSequencer::checkNext, this);
-    newSlot(s_NEXT_SLOT, &SSequencer::next, this);
-    newSlot(s_PREVIOUS_SLOT, &SSequencer::previous, this);
-    newSlot(s_SEND_INFO_SLOT, &SSequencer::sendInfo, this);
-}
-
-//------------------------------------------------------------------------------
-
-SSequencer::~SSequencer() noexcept
-{
+    newSlot(Slots::GO_TO, &SSequencer::goTo, this);
+    newSlot(Slots::CHECK_NEXT, &SSequencer::checkNext, this);
+    newSlot(Slots::VALIDATE_NEXT, &SSequencer::validateNext, this);
+    newSlot(Slots::NEXT, &SSequencer::next, this);
+    newSlot(Slots::PREVIOUS, &SSequencer::previous, this);
+    newSlot(Slots::SEND_INFO, &SSequencer::sendInfo, this);
 }
 
 //------------------------------------------------------------------------------
@@ -93,7 +71,7 @@ void SSequencer::configuring()
 {
     this->sight::ui::base::IGuiContainer::initialize();
 
-    const service::IService::ConfigType config = this->getConfigTree();
+    const service::IService::ConfigType config = this->getConfiguration();
 
     auto pair = config.equal_range("activity");
     auto it   = pair.first;
@@ -105,13 +83,15 @@ void SSequencer::configuring()
 
     m_clearActivities = config.get<bool>(s_CLEAR_ACTIVITIES_CONFIG, m_clearActivities);
 
-    m_theme      = config.get<std::string>(s_THEME_CONFIG, m_theme);
-    m_clear      = config.get<std::string>(s_CLEAR_CONFIG, m_clear);
-    m_accent     = config.get<std::string>(s_ACCENT_CONFIG, m_accent);
-    m_foreground = config.get<std::string>(s_FOREGROUND_CONFIG, m_foreground);
-    m_background = config.get<std::string>(s_BACKGROUND_CONFIG, m_background);
-    m_primary    = config.get<std::string>(s_PRIMARY_CONFIG, m_primary);
-    m_elevation  = config.get<std::string>(s_ELEVATION_CONFIG, m_elevation);
+    m_theme       = config.get<std::string>(s_THEME_CONFIG, m_theme);
+    m_clear       = config.get<std::string>(s_CLEAR_CONFIG, m_clear);
+    m_accent      = config.get<std::string>(s_ACCENT_CONFIG, m_accent);
+    m_foreground  = config.get<std::string>(s_FOREGROUND_CONFIG, m_foreground);
+    m_background  = config.get<std::string>(s_BACKGROUND_CONFIG, m_background);
+    m_primary     = config.get<std::string>(s_PRIMARY_CONFIG, m_primary);
+    m_elevation   = config.get<std::string>(s_ELEVATION_CONFIG, m_elevation);
+    m_buttonWidth = config.get<std::string>(s_BUTTON_WIDTH, m_buttonWidth);
+    m_fontSize    = config.get<double>(s_FONT_SIZE, m_fontSize);
 }
 
 //------------------------------------------------------------------------------
@@ -122,7 +102,7 @@ void SSequencer::starting()
 
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
-    QVBoxLayout* mainLayout = new QVBoxLayout();
+    auto* mainLayout = new QVBoxLayout();
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
     m_widget = new QQuickWidget();
@@ -131,13 +111,13 @@ void SSequencer::starting()
     const auto path =
         core::runtime::getModuleResourceFilePath("sight::module::ui::qt", "ActivitySequencer.qml");
     QWidget* parent = qtContainer->getQtContainer();
-    auto engine     = m_widget->engine();
+    auto* engine    = m_widget->engine();
     m_widget->setResizeMode(QQuickWidget::SizeRootObjectToView);
 
     QColor clear;
     if(m_clear.empty())
     {
-        clear = parent->palette().color(QPalette::Background);
+        clear = parent->palette().color(QPalette::Window);
 
         // styleSheet override QPalette
         // we assume that styleSheet is the dark style
@@ -227,6 +207,11 @@ void SSequencer::starting()
         QString::fromStdString(s_ELEVATION_CONFIG),
         QString::fromStdString(m_elevation)
     );
+    engine->rootContext()->setContextProperty(
+        QString::fromStdString(s_BUTTON_WIDTH),
+        QString::fromStdString(m_buttonWidth)
+    );
+    engine->rootContext()->setContextProperty(QString::fromStdString(s_FONT_SIZE), m_fontSize);
 
     m_widget->setSource(QUrl::fromLocalFile(QString::fromStdString(path.string())));
 
@@ -247,10 +232,10 @@ void SSequencer::stopping()
 void SSequencer::updating()
 {
     {
-        auto seriesDB = m_seriesDB.lock();
-        SIGHT_ASSERT("Missing '" << s_SERIESDB_INOUT << "' seriesDB", seriesDB);
+        auto activity_set = m_activity_set.lock();
+        SIGHT_ASSERT("Missing '" << s_ACTIVITY_SET_INOUT << "' activity_set", activity_set);
 
-        m_currentActivity = this->parseActivities(*seriesDB);
+        m_currentActivity = this->parseActivities(*activity_set);
     }
     if(m_currentActivity >= 0)
     {
@@ -259,7 +244,7 @@ void SSequencer::updating()
             this->enableActivity(i);
         }
 
-        // launch the last series
+        // launch the last activity
         this->goTo(m_currentActivity);
     }
     else
@@ -280,8 +265,8 @@ void SSequencer::goTo(int index)
         return;
     }
 
-    auto seriesDB = m_seriesDB.lock();
-    SIGHT_ASSERT("Missing '" << s_SERIESDB_INOUT << "' seriesDB", seriesDB);
+    auto activity_set = m_activity_set.lock();
+    SIGHT_ASSERT("Missing '" << s_ACTIVITY_SET_INOUT << "' activity_set", activity_set);
 
     // Clear activities if go backward.
     if(m_clearActivities && m_currentActivity > index)
@@ -300,31 +285,31 @@ void SSequencer::goTo(int index)
         }
 
         // Disable all next activities (including current)
-        for(std::size_t i = index + 1 ; i < seriesDB->size() ; ++i)
+        for(int i = index + 1, end = int(activity_set->size()) ; i < end ; ++i)
         {
             this->disableActivity(i);
         }
 
         // Remove all last activities.
-        this->removeLastActivities(*seriesDB, index);
+        this->removeLastActivities(*activity_set, std::size_t(index));
     }
     // Store data otherwise.
     else if(m_currentActivity >= 0)
     {
-        this->storeActivityData(*seriesDB, m_currentActivity);
+        this->storeActivityData(*activity_set, std::size_t(m_currentActivity));
     }
 
-    const std::size_t newIdx = static_cast<std::size_t>(index);
+    const auto newIdx = static_cast<std::size_t>(index);
 
-    data::ActivitySeries::sptr activity = this->getActivity(*seriesDB, newIdx, m_slotUpdate);
+    data::Activity::sptr activity = this->getActivity(*activity_set, newIdx, slot(IService::slots::s_UPDATE));
 
     bool ok = true;
     std::string errorMsg;
 
-    std::tie(ok, errorMsg) = this->validateActivity(activity);
+    std::tie(ok, errorMsg) = sight::module::ui::qt::activity::SSequencer::validateActivity(activity);
     if(ok)
     {
-        m_sigActivityCreated->asyncEmit(activity);
+        m_activity_created->asyncEmit(activity);
 
         m_currentActivity = index;
         QObject* object = m_widget->rootObject();
@@ -334,7 +319,7 @@ void SSequencer::goTo(int index)
     else
     {
         sight::ui::base::dialog::MessageDialog::show("Activity not valid", errorMsg);
-        m_sigDataRequired->asyncEmit(activity);
+        m_data_required->asyncEmit(activity);
     }
 }
 
@@ -342,28 +327,130 @@ void SSequencer::goTo(int index)
 
 void SSequencer::checkNext()
 {
-    auto seriesDB = m_seriesDB.lock();
-    SIGHT_ASSERT("Missing '" << s_SERIESDB_INOUT << "' seriesDB", seriesDB);
+    auto activity_set = m_activity_set.lock();
+    SIGHT_ASSERT("Missing '" << s_ACTIVITY_SET_INOUT << "' activity_set", activity_set);
 
     // Store current activity data before checking the next one,
     // new data can be added in the current activity during the process.
     if(m_currentActivity >= 0)
     {
-        this->storeActivityData(*seriesDB, m_currentActivity);
+        storeActivityData(*activity_set, std::size_t(m_currentActivity));
     }
 
-    const std::size_t nextIdx = static_cast<std::size_t>(m_currentActivity + 1);
-    if(nextIdx < m_activityIds.size())
+    // Check if the next activity is valid (creates the activity if needed)
+    // NOLINTNEXTLINE(bugprone-misplaced-widening-cast)
+    const auto next_index = std::size_t(m_currentActivity + 1);
+    if(next_index < m_activityIds.size())
     {
-        data::ActivitySeries::sptr nextActivity = this->getActivity(*seriesDB, nextIdx, m_slotUpdate);
+        const auto& next_activity = this->getActivity(*activity_set, next_index, slot(IService::slots::s_UPDATE));
+        const auto& [ok, error] = SSequencer::validateActivity(next_activity);
 
-        bool ok = true;
-        std::string errorMsg;
-
-        std::tie(ok, errorMsg) = this->validateActivity(nextActivity);
         if(ok)
         {
-            this->enableActivity(m_currentActivity + 1);
+            enableActivity(int(next_index));
+        }
+        else
+        {
+            disableActivity(int(next_index));
+            SIGHT_DEBUG(error);
+        }
+
+        m_next_enabled->asyncEmit(ok);
+
+        // Refresh next activities validity
+        std::size_t last_valid = next_index;
+
+        if(ok)
+        {
+            // Find the last valid activity
+            while(++last_valid < activity_set->size())
+            {
+                const auto& activity = activity_set->at(last_valid);
+                const auto& [next_ok, next_error] = SSequencer::validateActivity(activity);
+
+                if(next_ok)
+                {
+                    enableActivity(int(last_valid));
+                }
+                else
+                {
+                    disableActivity(int(last_valid));
+                    SIGHT_DEBUG(next_error);
+
+                    break;
+                }
+            }
+        }
+
+        // Disable all next activities
+        while(++last_valid < activity_set->size())
+        {
+            disableActivity(int(last_valid));
+        }
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SSequencer::validateNext()
+{
+    auto activity_set = m_activity_set.lock();
+    SIGHT_ASSERT("Missing '" << s_ACTIVITY_SET_INOUT << "' activity_set", activity_set);
+
+    // Store current activity data before checking the next one,
+    // new data can be added in the current activity during the process.
+    if(m_currentActivity >= 0)
+    {
+        storeActivityData(*activity_set, std::size_t(m_currentActivity));
+    }
+
+    // Check if the next activity is valid (creates the activity if needed)
+    // NOLINTNEXTLINE(bugprone-misplaced-widening-cast)
+    const auto next_index = std::size_t(m_currentActivity + 1);
+    if(next_index < m_activityIds.size())
+    {
+        const auto& next_activity = this->getActivity(*activity_set, next_index, slot(IService::slots::s_UPDATE));
+        const auto& [ok, error] = sight::module::ui::qt::activity::SSequencer::validateActivity(next_activity);
+
+        if(ok)
+        {
+            m_next_valid->asyncEmit();
+        }
+        else
+        {
+            disableActivity(int(next_index));
+            SIGHT_DEBUG(error);
+
+            m_next_invalid->asyncEmit();
+        }
+
+        m_next_validated->asyncEmit(ok);
+
+        // Refresh next activities validity
+        std::size_t last_valid = next_index;
+
+        if(ok)
+        {
+            // Find the last valid activity
+            while(++last_valid < activity_set->size())
+            {
+                const auto& activity = activity_set->at(last_valid);
+                const auto& [next_ok, next_error] = SSequencer::validateActivity(activity);
+
+                if(!next_ok)
+                {
+                    disableActivity(int(last_valid));
+                    SIGHT_DEBUG(next_error);
+
+                    break;
+                }
+            }
+        }
+
+        // Disable all next activities
+        while(++last_valid < activity_set->size())
+        {
+            disableActivity(int(last_valid));
         }
     }
 }
@@ -372,7 +459,12 @@ void SSequencer::checkNext()
 
 void SSequencer::next()
 {
-    this->goTo(m_currentActivity + 1);
+    const auto next_index = m_currentActivity + 1;
+
+    // Reset requirements created by next activities
+    cleanRequirements(std::size_t(next_index));
+
+    goTo(next_index);
 }
 
 //------------------------------------------------------------------------------
@@ -387,10 +479,10 @@ void SSequencer::previous()
 void SSequencer::sendInfo() const
 {
     const bool previousEnabled = (m_currentActivity > 0);
-    m_sigEnabledPrevious->asyncEmit(previousEnabled);
+    m_has_previous->asyncEmit(previousEnabled);
 
     const bool nextEnabled = (m_currentActivity < static_cast<int>(m_activityIds.size()) - 1);
-    m_sigEnabledNext->asyncEmit(nextEnabled);
+    m_has_next->asyncEmit(nextEnabled);
 }
 
 //------------------------------------------------------------------------------
@@ -414,14 +506,11 @@ void SSequencer::disableActivity(int index)
 service::IService::KeyConnectionsMap SSequencer::getAutoConnections() const
 {
     KeyConnectionsMap connections;
-    connections.push(s_SERIESDB_INOUT, data::SeriesDB::s_ADDED_SERIES_SIG, s_UPDATE_SLOT);
-    connections.push(s_SERIESDB_INOUT, data::SeriesDB::s_MODIFIED_SIG, s_UPDATE_SLOT);
-
+    connections.push(s_ACTIVITY_SET_INOUT, data::ActivitySet::s_ADDED_OBJECTS_SIG, IService::slots::s_UPDATE);
+    connections.push(s_ACTIVITY_SET_INOUT, data::ActivitySet::s_MODIFIED_SIG, IService::slots::s_UPDATE);
     return connections;
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace activity
-
-} // namespace activity
+} // namespace sight::module::ui::qt::activity
