@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,16 +26,15 @@
 
 #include <activity/IActivitySequencer.hpp>
 
+#include <data/ActivitySet.hpp>
+
 #include <ui/base/IEditor.hpp>
 
 #include <QObject>
 #include <QPointer>
 #include <QQuickWidget>
 
-namespace sight::module::ui::qt
-{
-
-namespace activity
+namespace sight::module::ui::qt::activity
 {
 
 /**
@@ -44,38 +43,37 @@ namespace activity
  *
  * The order of the activities is given in the configuration.
  *
- * ActivitySeries are created for each activity using the data produced by the previous activities. This activities are
- * stored in the current SeriesDB. By default all the data are stored, you can to backward and forward as you want in
+ * Activity are created for each activity using the data produced by the previous activities. This activities are
+ * stored in the current ActivitySet. By default all the data are stored, you can to backward and forward as you want in
  * the existing activities. Using the tag 'clearActivities', you can remove the last activities when going backward to
  * force the user to re-generate the data.
  *
  * @warning If an activity can not be launched with the existing parameters, the signal 'dataRequired' is emitted. It
  * can be connected to an activity wizard to add the missing data, or you can supplied 'requirementOverrides' composite.
  *
- * @note If the inout SeriesDB already contains activities, their are parsed and the sequencer open on the last
+ * @note If the inout ActivitySet already contains activities, their are parsed and the sequencer open on the last
  * activities. Be careful to store them in the right order.
  *
- * @warning If the SeriesDB contains other series (or unknown activities), they are removed with a simple log error.
- *
  * @section Signal Signal
- * - \b activityCreated(data::ActivitySeries::sptr) : This signal is emitted when an activity is created (using
+ * - \b activityCreated(data::Activity::sptr) : This signal is emitted when an activity is created (using
  *   next() or previous().
  * - \b dataRequired() : This signal is emitted when the activity can not be launch because it requires data.
- * - \b enabledNext(bool): This signal is emitted when the next button is enabled (when the activity is not the last
- *   one)
- * - \b enabledPrevious(bool): This signal is emitted when the previous button is enabled (when the activity is not the
- *   first one)
+ * - \b hasNext(bool): This signal is emitted on sendInfo() slot, with the information if an activity is present after
+ * the current one.
+ * - \b hasPrevious(bool): This signal is emitted on sendInfo() slot, with the information if an activity is present
+ * before the current one.
+ * - \b nextEnabled(bool): This signal is emitted when the next button is enabled and can be launched.
  *
  * @section Slots Slots
- * - \b next() : Create the next activity series
- * - \b previous() : Create the next activity series
- * - \b goTo(int) : Create the activity series at the given index
- * - \b sendInfo() : Send the 'enabledNext' and 'enablePrevious' signals for the current activity
+ * - \b next() : Create the next activity
+ * - \b previous() : Create the next activity
+ * - \b goTo(int) : Create the activity at the given index
+ * - \b sendInfo() : Send the 'hasNext' and 'hasPrevious' signals for the current activity
  *
  * @section XML XML Configuration
  * @code{.xml}
     <service  type="sight::module::ui::qt::activity::SSequencer">
-        <inout key="seriesDB" uid=""  autoConnect="true" />
+        <inout key="activitySet" uid=""  autoConnect="true" />
         <activity id="..." name="..." />
         <activity id="..." name="..." />
         <activity id="..." name="..." />
@@ -87,6 +85,8 @@ namespace activity
         <background>#FF00FF</background>
         <primary>#FF00FF</primary>
         <elevation>#FF00FF</elevation>
+        <buttonWidth>200</buttonWidth>
+        <fontSize>12</fontSize>
     </service>
    @endcode
  * @subsection In In
@@ -95,7 +95,7 @@ namespace activity
  *   data that would normally be passed from an activity to the next.
  *
  * @subsection In-Out In-Out
- * - \b seriesDB [sight::data::SeriesDB]: used to store the ActivitySeries of the managed activities
+ * - \b activity_set [sight::data::ActivitySet]: used to store the Activity of the managed activities
  *
  * @subsection Configuration Configuration
  * - \b activity :
@@ -111,6 +111,8 @@ namespace activity
  * - \b background (optional): the background color used by the sequencer.
  * - \b primary (optional): the primary color used by the sequencer.
  * - \b elevation (optional): the elevation color used by the sequencer.
+ * - \b buttonWidth (optional): the width of the buttons of the sequencer.
+ * - \b fontSize (optional): the size of the font used in the buttons of the sequencer.
  *
  * @todo listen the current activity data to notify when the next activity can be created
  */
@@ -128,24 +130,58 @@ public:
     MODULE_UI_QT_API SSequencer() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_QT_API ~SSequencer() noexcept override;
+    MODULE_UI_QT_API ~SSequencer() noexcept override = default;
 
-    /**
-     * @name Signals API
-     * @{
-     */
-    typedef core::com::Signal<void (data::ActivitySeries::sptr)> ActivityCreatedSignalType;
-    typedef core::com::Signal<void (data::ActivitySeries::sptr)> DataRequiredSignalType;
-    typedef core::com::Signal<void (bool)> EnabledPreviousSignalType;
-    typedef core::com::Signal<void (bool)> EnabledNextSignalType;
-/**
- * @}
- */
+    struct MODULE_UI_QT_CLASS_API Slots final
+    {
+        using key_t = sight::core::com::Slots::SlotKeyType;
+
+        inline static const key_t GO_TO         = "goTo";
+        inline static const key_t CHECK_NEXT    = "checkNext";
+        inline static const key_t VALIDATE_NEXT = "validateNext";
+        inline static const key_t NEXT          = "next";
+        inline static const key_t PREVIOUS      = "previous";
+        inline static const key_t SEND_INFO     = "sendInfo";
+    };
+
+    struct MODULE_UI_QT_CLASS_API Signals final
+    {
+        using key_t = sight::core::com::Signals::SignalKeyType;
+
+        inline static const key_t ACTIVITY_CREATED = "activityCreated";
+        inline static const key_t DATA_REQUIRED    = "dataRequired";
+        inline static const key_t HAS_PREVIOUS     = "hasPrevious";
+        inline static const key_t HAS_NEXT         = "hasNext";
+        inline static const key_t NEXT_ENABLED     = "nextEnabled";
+
+        inline static const key_t NEXT_VALIDATED = "nextValidated";
+        inline static const key_t NEXT_VALID     = "nextValid";
+        inline static const key_t NEXT_INVALID   = "nextInvalid";
+
+        using void_signal_t     = core::com::Signal<void ()>;
+        using bool_signal_t     = core::com::Signal<void (bool)>;
+        using activity_signal_t = core::com::Signal<void (data::Activity::sptr)>;
+    };
+
+    /// Slot: Check if the next activities can be enabled
+    MODULE_UI_QT_API void checkNext();
+
+    /// Slot: Validate the next activities without enabling it. Emits nextValidated(true/false), next(In)Valid signals
+    MODULE_UI_QT_API void validateNext();
+
+    /// Slot: Create the next activity, emit 'dataRequired' signal if the activity require additional data
+    MODULE_UI_QT_API void next();
+
+    /// Slot: Create the previous activity, emit 'dataRequired' signal if the activity require additional data
+    MODULE_UI_QT_API void previous();
+
+    /// Slot: Send the 'hasNext' and 'enablePrevious' signals for the current activity
+    MODULE_UI_QT_API void sendInfo() const;
 
 public Q_SLOTS:
 
     /// Slot: create the activity at the given index, emit 'dataRequired' signal if the activity require additional data
-    void goTo(int index);
+    MODULE_UI_QT_API void goTo(int index);
 
 protected:
 
@@ -159,42 +195,25 @@ protected:
     void stopping() override;
 
     /**
-     * @brief Analyse the series contained in the current seriesDB.
+     * @brief Analyse the contained in the current activity_set.
      *
-     * - if the series is not an activity or if it is an unknown activity, it is removed
+     * - if the is an unknown activity, it is removed
      * - else, the activity data is stored in m_requirements
      * - the last activity is launched
      */
     void updating() override;
 
-    /// Connect the service to the SeriesDB signals
+    /// Connect the service to the ActivitySet signals
     KeyConnectionsMap getAutoConnections() const override;
 
 private:
 
-    /// Slot: Check if the next activities can be enabled
-    void checkNext();
-
-    /// Slot: Create the next activity series, emit 'dataRequired' signal if the activity require additional data
-    void next();
-
-    /// Slot: Create the previous activity series, emit 'dataRequired' signal if the activity require additional data
-    void previous();
-
-    /// Slot: Send the 'enabledNext' and 'enablePrevious' signals for the current activity
-    void sendInfo() const;
-
     /// Invoke 'enableActivity' method in Qml file
     void enableActivity(int index);
 
     /// Invokes 'disableActivity' method in Qml file
     void disableActivity(int index);
 
-    ActivityCreatedSignalType::sptr m_sigActivityCreated;
-    DataRequiredSignalType::sptr m_sigDataRequired;
-    EnabledPreviousSignalType::sptr m_sigEnabledPrevious;
-    EnabledNextSignalType::sptr m_sigEnabledNext;
-
     /// List of the activities
     std::vector<std::string> m_activityNames;
 
@@ -211,11 +230,43 @@ private:
     std::string m_background;
     std::string m_primary;
     std::string m_elevation;
+    std::string m_buttonWidth {"200"};
+    double m_fontSize {12.0};
 
-    static constexpr std::string_view s_SERIESDB_INOUT = "seriesDB";
-    data::ptr<data::SeriesDB, data::Access::inout> m_seriesDB {this, "seriesDB", true};
+    const Signals::activity_signal_t::sptr m_activity_created {
+        newSignal<Signals::activity_signal_t>(Signals::ACTIVITY_CREATED)
+    };
+
+    const Signals::activity_signal_t::sptr m_data_required {
+        newSignal<Signals::activity_signal_t>(Signals::DATA_REQUIRED)
+    };
+
+    const Signals::bool_signal_t::sptr m_has_previous {
+        newSignal<Signals::bool_signal_t>(Signals::HAS_PREVIOUS)
+    };
+
+    const Signals::bool_signal_t::sptr m_has_next {
+        newSignal<Signals::bool_signal_t>(Signals::HAS_NEXT)
+    };
+
+    const Signals::bool_signal_t::sptr m_next_enabled {
+        newSignal<Signals::bool_signal_t>(Signals::NEXT_ENABLED)
+    };
+
+    const Signals::bool_signal_t::sptr m_next_validated {
+        newSignal<Signals::bool_signal_t>(Signals::NEXT_VALIDATED)
+    };
+
+    const Signals::void_signal_t::sptr m_next_valid {
+        newSignal<Signals::void_signal_t>(Signals::NEXT_VALID)
+    };
+
+    const Signals::void_signal_t::sptr m_next_invalid {
+        newSignal<Signals::void_signal_t>(Signals::NEXT_INVALID)
+    };
+
+    static constexpr std::string_view s_ACTIVITY_SET_INOUT = "activitySet";
+    data::ptr<data::ActivitySet, data::Access::inout> m_activity_set {this, s_ACTIVITY_SET_INOUT, true};
 };
 
-} // namespace activity
-
-} // namespace sight::module::ui::qt
+} // namespace sight::module::ui::qt::activity
