@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,27 +22,17 @@
 
 #include "SWizard.hpp"
 
+#include <activity/builder/data.hpp>
 #include <activity/IValidator.hpp>
 
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
-#include <core/com/Signals.hpp>
-#include <core/com/Slot.hpp>
-#include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
-#include <core/tools/dateAndTime.hpp>
-#include <core/tools/UUID.hpp>
+#include <core/runtime/path.hpp>
+#include <core/runtime/runtime.hpp>
 
+#include <data/ActivitySet.hpp>
 #include <data/Composite.hpp>
-#include <data/Equipment.hpp>
-#include <data/helper/SeriesDB.hpp>
-#include <data/Patient.hpp>
 #include <data/Series.hpp>
-#include <data/Study.hpp>
-
-#include <service/macros.hpp>
 
 #include <ui/base/dialog/InputDialog.hpp>
 #include <ui/qt/container/QtContainer.hpp>
@@ -54,20 +44,16 @@
 #include <QObject>
 #include <QVBoxLayout>
 
-namespace sight::module::ui::qt
-{
-
-namespace activity
+namespace sight::module::ui::qt::activity
 {
 
 //------------------------------------------------------------------------------
 
-const core::com::Slots::SlotKeyType SWizard::s_CREATE_ACTIVITY_SLOT        = "createActivity";
-const core::com::Slots::SlotKeyType SWizard::s_UPDATE_ACTIVITY_SLOT        = "updateActivity";
-const core::com::Slots::SlotKeyType SWizard::s_UPDATE_ACTIVITY_SERIES_SLOT = "updateActivitySeries";
-const core::com::Signals::SignalKeyType SWizard::s_ACTIVITY_CREATED_SIG    = "activityCreated";
-const core::com::Signals::SignalKeyType SWizard::s_ACTIVITY_UPDATED_SIG    = "activityUpdated";
-const core::com::Signals::SignalKeyType SWizard::s_CANCELED_SIG            = "canceled";
+const core::com::Slots::SlotKeyType SWizard::s_CREATE_ACTIVITY_SLOT     = "createActivity";
+const core::com::Slots::SlotKeyType SWizard::s_UPDATE_ACTIVITY_SLOT     = "updateActivity";
+const core::com::Signals::SignalKeyType SWizard::s_ACTIVITY_CREATED_SIG = "activityCreated";
+const core::com::Signals::SignalKeyType SWizard::s_ACTIVITY_UPDATED_SIG = "activityUpdated";
+const core::com::Signals::SignalKeyType SWizard::s_CANCELED_SIG         = "canceled";
 
 using sight::activity::extension::ActivityInfo;
 using sight::activity::extension::Activity;
@@ -76,14 +62,10 @@ using sight::activity::extension::Activity;
 
 //------------------------------------------------------------------------------
 
-SWizard::SWizard() noexcept :
-    m_mode(Mode::CREATE),
-    m_confirmUpdate(true),
-    m_isCancelable(true)
+SWizard::SWizard() noexcept
 {
     newSlot(s_CREATE_ACTIVITY_SLOT, &SWizard::createActivity, this);
     newSlot(s_UPDATE_ACTIVITY_SLOT, &SWizard::updateActivity, this);
-    newSlot(s_UPDATE_ACTIVITY_SERIES_SLOT, &SWizard::updateActivitySeries, this);
 
     m_sigActivityCreated = newSignal<ActivityCreatedSignalType>(s_ACTIVITY_CREATED_SIG);
     m_sigActivityUpdated = newSignal<ActivityUpdatedSignalType>(s_ACTIVITY_UPDATED_SIG);
@@ -92,9 +74,8 @@ SWizard::SWizard() noexcept :
 
 //------------------------------------------------------------------------------
 
-SWizard::~SWizard() noexcept
-{
-}
+SWizard::~SWizard() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -102,7 +83,7 @@ void SWizard::configuring()
 {
     sight::ui::base::IGuiContainer::initialize();
 
-    const auto config = this->getConfigTree();
+    const auto config = this->getConfiguration();
 
     m_ioSelectorConfig = config.get("ioSelectorConfig", "");
     SIGHT_ASSERT("ioSelector Configuration must not be empty", !m_ioSelectorConfig.empty());
@@ -120,11 +101,11 @@ void SWizard::configuring()
     const auto iconCfg  = iconsCfg.equal_range("icon");
     for(auto itIcon = iconCfg.first ; itIcon != iconCfg.second ; ++itIcon)
     {
-        const auto iconCfg = itIcon->second.get_child("<xmlattr>");
+        const auto anotherIconCfg = itIcon->second.get_child("<xmlattr>");
 
-        const std::string type = iconCfg.get<std::string>("type");
+        const auto type = anotherIconCfg.get<std::string>("type");
         SIGHT_ASSERT("'type' attribute must not be empty", !type.empty());
-        const std::string icon = iconCfg.get<std::string>("icon");
+        const auto icon = anotherIconCfg.get<std::string>("icon");
         SIGHT_ASSERT("'icon' attribute must not be empty", !icon.empty());
 
         const auto file = core::runtime::getResourceFilePath(icon);
@@ -144,7 +125,7 @@ void SWizard::starting()
 
     QWidget* const container = qtContainer->getQtContainer();
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     layout->setContentsMargins(0, 0, 0, 0);
 
     m_title = new QLabel("");
@@ -173,7 +154,7 @@ void SWizard::starting()
 
     layout->addWidget(m_DataView, 1);
 
-    QHBoxLayout* buttonLayout = new QHBoxLayout();
+    auto* buttonLayout = new QHBoxLayout();
     layout->addLayout(buttonLayout);
 
     if(m_isCancelable)
@@ -233,13 +214,15 @@ void SWizard::stopping()
 
 void SWizard::updating()
 {
-    auto as = m_activitySeries.lock();
+    auto as = m_activity.lock();
     if(as)
     {
         this->updateActivity(as.get_shared());
     }
-
-    SIGHT_DEBUG_IF("activity series is not defined, it cannot be updated", !as);
+    else
+    {
+        SIGHT_DEBUG("activity is not defined, it cannot be updated");
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -251,22 +234,10 @@ void SWizard::createActivity(std::string activityID)
     info = Activity::getDefault()->getInfo(activityID);
 
     // load activity module
-    std::shared_ptr<core::runtime::Module> module = core::runtime::findModule(info.bundleId);
-    if(!module->isStarted())
-    {
-        module->start();
-    }
+    core::runtime::startModule(info.bundleId);
 
-    m_actSeries = data::ActivitySeries::New();
-
-    m_actSeries->setModality("OT");
-    m_actSeries->setInstanceUID("fwActivities." + core::tools::UUID::generateUUID());
-
-    boost::posix_time::ptime now = boost::posix_time::second_clock::local_time();
-    m_actSeries->setDate(core::tools::getDate(now));
-    m_actSeries->setTime(core::tools::getTime(now));
-
-    m_actSeries->setActivityConfigId(info.id);
+    m_new_activity = data::Activity::New();
+    m_new_activity->setActivityConfigId(info.id);
 
     m_title->setText(QString("<h1>%1</h1>").arg(QString::fromStdString(info.title)));
     m_description->setText(QString::fromStdString(info.description));
@@ -291,7 +262,7 @@ void SWizard::createActivity(std::string activityID)
             m_okButton->setText("Next");
         }
 
-        this->slot(s_SHOW_SLOT)->asyncRun();
+        this->slot(slots::s_SHOW)->asyncRun();
     }
     else
     {
@@ -299,39 +270,34 @@ void SWizard::createActivity(std::string activityID)
         for(const auto& req : info.requirements)
         {
             SIGHT_ASSERT("minOccurs and maxOccurs should be 0", req.minOccurs == 0 && req.maxOccurs == 0);
-            data::Composite::sptr data = m_actSeries->getData();
-            (*data)[req.name] = data::factory::New(req.type);
+            (*m_new_activity)[req.name] = sight::activity::detail::data::create(req.type, req.objectConfig);
         }
 
-        const auto seriesDB = m_seriesDB.lock();
-        SIGHT_ASSERT("The inout key '" << s_SERIESDB << "' is not defined.", seriesDB);
+        const auto activity_set = m_activity_set.lock();
+        SIGHT_ASSERT("The inout key '" << s_ACTIVITY_SET << "' is not defined.", activity_set);
 
-        data::helper::SeriesDB helper(*seriesDB);
-        helper.add(m_actSeries);
-        helper.notify();
-        m_sigActivityCreated->asyncEmit(m_actSeries);
+        const auto scoped_emitter = activity_set->scoped_emit();
+        activity_set->push_back(m_new_activity);
+
+        m_sigActivityCreated->asyncEmit(m_new_activity);
     }
 }
 
 //------------------------------------------------------------------------------
 
-void SWizard::updateActivity(data::ActivitySeries::sptr activitySeries)
+void SWizard::updateActivity(data::Activity::sptr activity)
 {
     ActivityInfo info;
-    info = Activity::getDefault()->getInfo(activitySeries->getActivityConfigId());
+    info = Activity::getDefault()->getInfo(activity->getActivityConfigId());
 
     // load activity module
-    std::shared_ptr<core::runtime::Module> module = core::runtime::findModule(info.bundleId);
-    if(!module->isStarted())
-    {
-        module->start();
-    }
+    core::runtime::startModule(info.bundleId);
 
     m_title->setText(QString("<h1>%1</h1>").arg(QString::fromStdString(info.title)));
     m_description->setText(QString::fromStdString(info.description));
 
-    m_mode      = Mode::UPDATE;
-    m_actSeries = activitySeries;
+    m_mode         = Mode::UPDATE;
+    m_new_activity = activity;
 
     bool needConfig = false;
 
@@ -347,7 +313,7 @@ void SWizard::updateActivity(data::ActivitySeries::sptr activitySeries)
 
     if(needConfig)
     {
-        m_DataView->fillInformation(m_actSeries);
+        m_DataView->fillInformation(m_new_activity);
         if(m_DataView->count() > 1)
         {
             m_okButton->setText("Next");
@@ -357,20 +323,9 @@ void SWizard::updateActivity(data::ActivitySeries::sptr activitySeries)
     {
         // Start immediately without popping any configuration UI
         data::Object::ModifiedSignalType::sptr sig;
-        sig = m_actSeries->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
+        sig = m_new_activity->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
         sig->asyncEmit();
-        m_sigActivityUpdated->asyncEmit(m_actSeries);
-    }
-}
-
-//------------------------------------------------------------------------------
-
-void SWizard::updateActivitySeries(data::Series::sptr series)
-{
-    data::ActivitySeries::sptr activitySeries = data::ActivitySeries::dynamicCast(series);
-    if(activitySeries)
-    {
-        this->updateActivity(activitySeries);
+        m_sigActivityUpdated->asyncEmit(m_new_activity);
     }
 }
 
@@ -392,10 +347,10 @@ void SWizard::onTabChanged(int index)
 
 void SWizard::onReset()
 {
-    if(m_actSeries)
+    if(m_new_activity)
     {
         ActivityInfo info;
-        info = Activity::getDefault()->getInfo(m_actSeries->getActivityConfigId());
+        info = Activity::getDefault()->getInfo(m_new_activity->getActivityConfigId());
         m_DataView->fillInformation(info);
 
         if(m_DataView->count() > 1)
@@ -453,66 +408,49 @@ void SWizard::onBuildActivity()
                 {
                     return;
                 }
-                else if(button == QMessageBox::Yes)
+
+                if(button == QMessageBox::Yes)
                 {
-                    m_actSeries = data::Object::copy(m_actSeries);
-                    m_mode      = Mode::CREATE; // The new activity should be added in the seriesDB
+                    m_new_activity = data::Object::copy(m_new_activity);
+                    m_mode         = Mode::CREATE; // The new activity should be added in the activity_set
                 }
             }
 
             // check all data and create/update the activity
-            bool ok = m_DataView->checkAndComputeData(m_actSeries, errorMsg);
+            bool ok = m_DataView->checkAndComputeData(m_new_activity, errorMsg);
             if(ok)
             {
-                data::Composite::sptr data = m_actSeries->getData();
-
-                // Copy the patient/study information of a series
-                data::Series::sptr series;
-                for(const auto& elt : (*data))
-                {
-                    series = data::Series::dynamicCast(elt.second);
-                    if(series)
-                    {
-                        m_actSeries->setPatient(data::Object::copy(series->getPatient()));
-                        m_actSeries->setStudy(data::Object::copy(series->getStudy()));
-                        m_actSeries->setEquipment(data::Object::copy(series->getEquipment()));
-                        break;
-                    }
-                }
-
                 if(m_mode == Mode::CREATE)
                 {
-                    // Add the new activity series in seriesDB
-                    ActivityInfo info;
-                    info = Activity::getDefault()->getInfo(
-                        m_actSeries->getActivityConfigId()
-                    );
+                    // Add the new activity in activity_set
+                    ActivityInfo info = Activity::getDefault()->getInfo(m_new_activity->getActivityConfigId());
 
-                    std::string description = sight::ui::base::dialog::InputDialog::showInputDialog(
+                    const auto& [description, input_ok] = sight::ui::base::dialog::InputDialog::showInputDialog(
                         "Activity creation",
                         "Please, give a description of the activity.",
                         info.title
                     );
-                    if(description.empty())
+
+                    if(!input_ok && description.empty())
                     {
                         return;
                     }
 
-                    m_actSeries->setDescription(description);
-                    const auto seriesDB = m_seriesDB.lock();
-                    SIGHT_ASSERT("The inout key '" << s_SERIESDB << "' is not defined.", seriesDB);
+                    m_new_activity->setDescription(description);
+                    const auto activity_set = m_activity_set.lock();
+                    SIGHT_ASSERT("The inout key '" << s_ACTIVITY_SET << "' is not defined.", activity_set);
 
-                    data::helper::SeriesDB helper(*seriesDB);
-                    helper.add(m_actSeries);
-                    helper.notify();
-                    m_sigActivityCreated->asyncEmit(m_actSeries);
+                    const auto scoped_emitter = activity_set->scoped_emit();
+                    activity_set->push_back(m_new_activity);
+
+                    m_sigActivityCreated->asyncEmit(m_new_activity);
                 }
                 else // m_mode == Mode::UPDATE
                 {
                     data::Object::ModifiedSignalType::sptr sig;
-                    sig = m_actSeries->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
+                    sig = m_new_activity->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
                     sig->asyncEmit();
-                    m_sigActivityUpdated->asyncEmit(m_actSeries);
+                    m_sigActivityUpdated->asyncEmit(m_new_activity);
                 }
             }
             else
@@ -532,6 +470,4 @@ void SWizard::onBuildActivity()
 
 //------------------------------------------------------------------------------
 
-} //namespace activity
-
-} //namespace sight::module::ui::qt
+} // namespace sight::module::ui::qt::activity
