@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2021 IRCAD France
+ * Copyright (C) 2016-2022 IRCAD France
  * Copyright (C) 2016-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,15 +27,8 @@
 
 #include <activity/extension/Activity.hpp>
 
-#include <core/com/Signal.hpp>
-#include <core/com/Signals.hpp>
-#include <core/com/Slot.hpp>
-#include <core/com/Slots.hpp>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/EConfigurationElement.hpp>
-
-#include <data/ActivitySeries.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/Activity.hpp>
+#include <data/ActivitySet.hpp>
 #include <data/Vector.hpp>
 
 #include <ui/base/IEditor.hpp>
@@ -44,41 +37,35 @@
 #include <QPointer>
 #include <QPushButton>
 
-namespace sight::module::ui::qt
-{
-
-namespace activity
+namespace sight::module::ui::qt::activity
 {
 
 /**
- * @brief This editor allows to select the data required by an activity in order to create the ActivitySeries.
+ * @brief This editor allows to select the data required by an activity in order to create the Activity.
  *
  * This editor displays a tab widget (one tab by data).
- * It works on a data::SeriesDB and adds the created activity series into the seriesDB.
+ * It works on a data::ActivitySet and adds the created activity into the activity_set.
  *
  * @section Slots Slots
- * - \b createActivity(std::string) : This slot displays the gui allowing to create a data::ActivitySeries with
+ * - \b createActivity(std::string) : This slot displays the gui allowing to create a data::Activity with
  *      the required data for the given activity.
- * - \b updateActivity(data::ActivitySeries::sptr) : This slot displays the gui allowing to update the required
+ * - \b updateActivity(data::Activity::sptr) : This slot displays the gui allowing to update the required
  *      data for the given activity.
- * - \b updateActivitySeries(data::Series::sptr) : This slot receives a data::Series, but works only if
- *   the series is an ActivitySeries, else it does nothing. It displays the gui allowing to update the required data for
- *   the given activity.
  *
  * @section Signals Signals
- * - \b activityCreated(data::ActivitySeries::sptr) : This signal is emitted when the activitySeries is built.
- * - \b activityUpdated(data::ActivitySeries::sptr) : This signal is emitted when the activitySeries is updated.
+ * - \b activityCreated(data::Activity::sptr) : This signal is emitted when the activity is built.
+ * - \b activityUpdated(data::Activity::sptr) : This signal is emitted when the activity is updated.
  * - \b canceled() : This signal is emitted when the cancel button is clicked.
  *
  * @section XML XML Configuration
  *
  * @code{.xml}
    <service impl="sight::module::ui::qt::activity::SWizard">
-     <inout key="seriesDB" uid="..." />
-     <inout key="activitySeries" uid="..." />
+     <inout key="activitySet" uid="..." />
+     <inout key="activity" uid="..." />
      <ioSelectorConfig>config</ioSelectorConfig>
      <sdbIoSelectorConfig>config</sdbIoSelectorConfig>
-     <activitySeries>seriesUid</activitySeries>
+     <activity>activityUid</activity>
      <confirm>true</confirm>
      <cancel>true</cancel>
      <icons>
@@ -88,13 +75,13 @@ namespace activity
    </service>
    @endcode
  * @subsection In-Out In-Out
- * - \b seriesDB [sight::data::SeriesDB]: seriesDB to store the create activity series
- * - \b seriesDB [sight::data::ActivitySeries] (optional): uid of the activity series to update. It is only used when
+ * - \b activity_set [sight::data::ActivitySet]: activity_set to store the create activity
+ * - \b activity [sight::data::Activity] (optional): uid of the activity to update. It is only used when
  * the update() method is called.
  * @subsection Configuration Configuration
  * - \b ioSelectorConfig : configuration for the SSelector service used to import data in this editor.
  * - \b sdbIoSelectorConfig(optional, default: ioSelectorConfig): configuration for the SSelector service used to
- * import data in this editor from a SeriesDB.
+ * import data in this editor from a ActivitySet.
  * - \b icons : defines the icons displayed for a type of data
  *    - \b type : type of data
  *    - \b icon : path of the icon to display
@@ -115,7 +102,7 @@ public:
     MODULE_UI_QT_API SWizard() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_QT_API virtual ~SWizard() noexcept;
+    MODULE_UI_QT_API ~SWizard() noexcept override;
 
     /**
      * @name Slot API
@@ -123,7 +110,6 @@ public:
      */
     MODULE_UI_QT_API static const core::com::Slots::SlotKeyType s_CREATE_ACTIVITY_SLOT;
     MODULE_UI_QT_API static const core::com::Slots::SlotKeyType s_UPDATE_ACTIVITY_SLOT;
-    MODULE_UI_QT_API static const core::com::Slots::SlotKeyType s_UPDATE_ACTIVITY_SERIES_SLOT;
     /// @}
 
     /**
@@ -131,10 +117,10 @@ public:
      * @{
      */
     MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_ACTIVITY_CREATED_SIG;
-    typedef core::com::Signal<void (data::ActivitySeries::sptr)> ActivityCreatedSignalType;
+    typedef core::com::Signal<void (data::Activity::sptr)> ActivityCreatedSignalType;
 
     MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_ACTIVITY_UPDATED_SIG;
-    typedef core::com::Signal<void (data::ActivitySeries::sptr)> ActivityUpdatedSignalType;
+    typedef core::com::Signal<void (data::Activity::sptr)> ActivityUpdatedSignalType;
 
     MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_CANCELED_SIG;
     typedef core::com::Signal<void ()> CanceledSignalType;
@@ -166,21 +152,13 @@ private:
     void createActivity(std::string activityID);
 
     /// SLOT: Displays the gui allowing to update the required data for the activity.
-    void updateActivity(data::ActivitySeries::sptr activitySeries);
-
-    /// SLOT: Displays the gui allowing to update the required data for the activity.
-    /**
-     * @brief SLOT: It displays the gui allowing to update the required data for the given activity.
-     * @note This slot receives a data::Series, but works only if the series is an ActivitySeries, else it does
-     *       nothing.
-     */
-    void updateActivitySeries(data::Series::sptr series);
+    void updateActivity(data::Activity::sptr activity);
 
     /**
      * @brief Called when the user click on the 'apply' Button.
      *
-     * if mode == CREATE : It creates the activitySeries and add it to the seriesDB.
-     * else, it update the current activity series.
+     * if mode == CREATE : It creates the activity and add it to the activity_set.
+     * else, it update the current activity.
      */
     void onBuildActivity();
 
@@ -193,7 +171,7 @@ private:
     /// Called when the user click on the 'cancel' Button.
     void onCancel();
 
-    data::ActivitySeries::sptr m_actSeries; ///< Activity series builded
+    data::Activity::sptr m_new_activity; ///< Activity builded
 
     QPointer<DataView> m_DataView;        ///< view used to select required data for activity
     QPointer<QPushButton> m_okButton;     ///<  Button 'Apply' or 'Next' to validate the activity creation
@@ -203,24 +181,22 @@ private:
     QPointer<QLabel> m_description;       ///< Label to show activity description
 
     std::string m_ioSelectorConfig;    ///< configuration used to import data
-    std::string m_sdbIoSelectorConfig; ///< configuration used to import data from e SeriesDB
+    std::string m_sdbIoSelectorConfig; ///< configuration used to import data from e ActivitySet
 
     DataView::ObjectIconMapType m_objectIcons; ///< Map defining the icon associated to an object.
 
-    Mode m_mode; ///< editor mode (CREATE or UPDATE)
+    Mode m_mode {Mode::CREATE}; ///< editor mode (CREATE or UPDATE)
 
-    bool m_confirmUpdate; ///< if true, the editor proposes a confirmation dialog when the activity is updated.
-    bool m_isCancelable;  /// true if the cancel button is proposed
+    bool m_confirmUpdate {true}; ///< if true, the editor proposes a confirmation dialog when the activity is updated.
+    bool m_isCancelable {true};  /// true if the cancel button is proposed
 
-    ActivityCreatedSignalType::sptr m_sigActivityCreated; ///< Signal emitted when the activitySeries is created
-    ActivityCreatedSignalType::sptr m_sigActivityUpdated; ///< Signal emitted when the activitySeries is updated
+    ActivityCreatedSignalType::sptr m_sigActivityCreated; ///< Signal emitted when the activity is created
+    ActivityCreatedSignalType::sptr m_sigActivityUpdated; ///< Signal emitted when the activity is updated
     CanceledSignalType::sptr m_sigCanceled;               /// Signal emitted when the creation is canceled.
 
-    static constexpr std::string_view s_SERIESDB = "seriesDB";
-    data::ptr<data::SeriesDB, data::Access::inout> m_seriesDB {this, s_SERIESDB};
-    data::ptr<data::ActivitySeries, data::Access::inout> m_activitySeries {this, "activitySeries"};
+    static constexpr std::string_view s_ACTIVITY_SET = "activitySet";
+    data::ptr<data::ActivitySet, data::Access::inout> m_activity_set {this, s_ACTIVITY_SET};
+    data::ptr<data::Activity, data::Access::inout> m_activity {this, "activity"};
 };
 
-} // editor
-
-} // sight::module::ui::qt
+} // namespace sight::module::ui::qt::activity
