@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,29 +22,26 @@
 
 #include "modules/ui/qt/calibration/SCameraConfigLauncher.hpp"
 
-#include <core/base.hpp>
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
-#include <core/com/Signals.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <data/CalibrationInfo.hpp>
 #include <data/Camera.hpp>
 #include <data/Composite.hpp>
-#include <data/SeriesDB.hpp>
+#include <data/Vector.hpp>
 
 #include <io/base/service/ioTypes.hpp>
 #include <io/base/service/IReader.hpp>
 
-#include <service/macros.hpp>
-#include <service/op/Add.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/base.hpp>
 
 #include <ui/base/dialog/InputDialog.hpp>
 #include <ui/base/dialog/LocationDialog.hpp>
 #include <ui/base/dialog/MessageDialog.hpp>
 #include <ui/qt/container/QtContainer.hpp>
 
+#include <boost/lexical_cast.hpp>
+
 #include <QHBoxLayout>
 #include <QInputDialog>
 #include <QStringList>
@@ -52,22 +49,20 @@
 namespace sight::module::ui::qt::calibration
 {
 
-SCameraConfigLauncher::SCameraConfigLauncher() noexcept
-{
-}
+SCameraConfigLauncher::SCameraConfigLauncher() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SCameraConfigLauncher::~SCameraConfigLauncher() noexcept
-{
-}
+SCameraConfigLauncher::~SCameraConfigLauncher() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SCameraConfigLauncher::configuring()
 {
     this->initialize();
-    service::IService::ConfigType configuration = this->getConfigTree();
+    service::IService::ConfigType configuration = this->getConfiguration();
 
     SIGHT_ASSERT(
         "There must be one (and only one) <config/> element.",
@@ -91,7 +86,7 @@ void SCameraConfigLauncher::starting()
 
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
 
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* layout = new QHBoxLayout();
 
     m_cameraComboBox = new QComboBox();
     layout->addWidget(m_cameraComboBox);
@@ -100,7 +95,8 @@ void SCameraConfigLauncher::starting()
                       core::runtime::getModuleResourceFilePath(
                           "sight::module::ui::icons",
                           "Import.svg"
-                      ).string()
+                      )
+                      .string()
     ));
     m_addButton = new QPushButton(addIcon, "");
     m_addButton->setToolTip("Add a new camera.");
@@ -110,7 +106,8 @@ void SCameraConfigLauncher::starting()
                          core::runtime::getModuleResourceFilePath(
                              "sight::module::ui::icons",
                              "CameraSeries.svg"
-                         ).string()
+                         )
+                         .string()
     ));
     m_importButton = new QPushButton(importIcon, "");
     m_importButton->setToolTip("Import an intrinsic calibration.");
@@ -120,7 +117,8 @@ void SCameraConfigLauncher::starting()
                          core::runtime::getModuleResourceFilePath(
                              "sight::module::ui::icons",
                              "remove.svg"
-                         ).string()
+                         )
+                         .string()
     ));
     m_removeButton = new QPushButton(removeIcon, "");
     m_removeButton->setToolTip("Remove the camera.");
@@ -132,11 +130,11 @@ void SCameraConfigLauncher::starting()
 
     qtContainer->setLayout(layout);
 
-    std::size_t nbCam;
+    std::size_t nbCam = 0;
     {
-        const auto cameraSeries = m_cameraSeries.lock();
-        SIGHT_ASSERT("Missing cameraSeries.", cameraSeries);
-        nbCam = cameraSeries->numCameras();
+        const auto camera_set = m_camera_set.lock();
+        SIGHT_ASSERT("Missing cameraSet.", camera_set);
+        nbCam = camera_set->size();
     }
     if(nbCam == 0)
     {
@@ -188,10 +186,10 @@ void SCameraConfigLauncher::updating()
 void SCameraConfigLauncher::onCameraChanged(int index)
 {
     {
-        const auto cameraSeries = m_cameraSeries.lock();
+        const auto cameraSet = m_camera_set.lock();
         SIGHT_ASSERT(
             "Bad index: " << index,
-            index >= 0 && static_cast<std::size_t>(index) < cameraSeries->numCameras()
+            index >= 0 && static_cast<std::size_t>(index) < cameraSet->size()
         );
     }
 
@@ -229,9 +227,9 @@ void SCameraConfigLauncher::onAddClicked()
 
 void SCameraConfigLauncher::onImportClicked()
 {
-    auto sdb    = data::SeriesDB::New();
+    auto vector = data::Vector::New();
     auto reader = service::add<io::base::service::IReader>("sight::module::io::session::SReader");
-    reader->setInOut(sdb, io::base::service::s_DATA_KEY);
+    reader->setInOut(vector, io::base::service::s_DATA_KEY);
 
     try
     {
@@ -256,79 +254,75 @@ void SCameraConfigLauncher::onImportClicked()
 
         throw;
     }
-    service::OSR::unregisterService(reader);
 
-    auto series             = sdb->getContainer();
-    auto cameraSeriesVector = std::vector<data::CameraSeries::sptr>();
+    service::remove(reader);
 
-    for(auto& series_ : series)
+    QStringList cameras;
+    std::map<std::string, data::Camera::csptr> camera_map;
+    std::size_t n_set = 0;
+
+    for(const auto& object : *vector)
     {
-        auto cameraSeries_ = data::CameraSeries::dynamicCast(series_);
-        if(cameraSeries_ != nullptr)
+        const auto& camera_set = data::CameraSet::dynamicCast(object);
+
+        if(camera_set)
         {
-            cameraSeriesVector.push_back(cameraSeries_);
+            for(std::size_t n_camera = 0, end = camera_set->size() ; n_camera != end ; ++n_camera)
+            {
+                const auto& camera   = camera_set->get_camera(n_camera);
+                const auto& cameraID =
+                    camera->getCameraID() + " [" + std::to_string(n_set) + ", " + std::to_string(n_camera) + "]";
+
+                camera_map.insert(std::make_pair(cameraID, camera));
+                cameras << QString::fromStdString(cameraID);
+            }
+
+            ++n_set;
         }
     }
 
-    if(cameraSeriesVector.size() == 0)
+    if(n_set == 0)
     {
         sight::ui::base::dialog::MessageDialog::show(
-            "No CameraSeries in SDB",
-            "There are no CameraSeries present in the loaded SeriesDB",
+            "No CameraSet in file",
+            "There are no CameraSet present in the loaded file.",
+            sight::ui::base::dialog::IMessageDialog::CRITICAL
+        );
+    }
+    else if(cameras.empty())
+    {
+        sight::ui::base::dialog::MessageDialog::show(
+            "No Cameras in file",
+            "There are CameraSet present in the loaded CameraSet, but no Cameras were found",
             sight::ui::base::dialog::IMessageDialog::CRITICAL
         );
     }
     else
     {
-        QStringList cameras;
-        std::map<std::string, data::Camera::csptr> map;
-        for(auto nSeries = 0 ; nSeries != cameraSeriesVector.size() ; ++nSeries)
-        {
-            auto cameraSeries_ = cameraSeriesVector[nSeries];
-            for(auto nCam = 0 ; nCam != cameraSeries_->numCameras() ; ++nCam)
-            {
-                auto cam      = cameraSeries_->getCamera(nCam);
-                auto cameraID =
-                    cam->getCameraID() + " [" + std::to_string(nSeries) + ", " + std::to_string(nCam) + "]";
-                map.insert(std::make_pair(cameraID, cam));
-                cameras << QString(cameraID.data());
-            }
-        }
+        auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
+        bool ok          = false;
+        auto selected    = QInputDialog::getItem(
+            qtContainer->getQtContainer(),
+            "Please select a camera",
+            "Camera",
+            cameras,
+            0,
+            false,
+            &ok
+        );
 
-        if(cameras.size() == 0)
+        if(ok)
         {
-            sight::ui::base::dialog::MessageDialog::show(
-                "No Cameras in SDB",
-                "There are CameraSeries present in the loaded SeriesDB, but no Cameras were found",
-                sight::ui::base::dialog::IMessageDialog::CRITICAL
-            );
-        }
-        else
-        {
-            auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
-            bool ok          = false;
-            auto selected    = QInputDialog::getItem(
-                qtContainer->getQtContainer(),
-                "Please select a camera",
-                "Camera",
-                cameras,
-                0,
-                false,
-                &ok
-            );
-            if(ok)
-            {
-                const auto selectedStd    = selected.toStdString();
-                const auto selectedCamera = map[selectedStd];
-                const auto camIdx         = m_cameraComboBox->currentIndex();
-                const auto cameraSeries   = m_cameraSeries.lock();
-                auto camera               = cameraSeries->getCamera(camIdx);
-                camera->deepCopy(selectedCamera);
-                camera->signal<data::Camera::IntrinsicCalibratedSignalType>(
-                    data::Camera::s_INTRINSIC_CALIBRATED_SIG
-                )
-                ->asyncEmit();
-            }
+            const auto selectedStd    = selected.toStdString();
+            const auto selectedCamera = camera_map[selectedStd];
+            const auto camIdx         = m_cameraComboBox->currentIndex();
+            const auto camera_set     = m_camera_set.lock();
+            auto camera               = camera_set->get_camera(std::size_t(camIdx));
+            camera->deepCopy(selectedCamera);
+            camera->signal<data::Camera::IntrinsicCalibratedSignalType>(
+                data::Camera::s_INTRINSIC_CALIBRATED_SIG
+            )
+            ->asyncEmit();
         }
     }
 }
@@ -337,28 +331,28 @@ void SCameraConfigLauncher::onImportClicked()
 
 void SCameraConfigLauncher::onRemoveClicked()
 {
-    const std::size_t index = static_cast<std::size_t>(m_cameraComboBox->currentIndex());
+    const auto index = static_cast<std::size_t>(m_cameraComboBox->currentIndex());
     if(index > 0)
     {
         m_cameraComboBox->blockSignals(true);
 
         {
-            const auto cameraSeries = m_cameraSeries.lock();
+            const auto camera_set = m_camera_set.lock();
             // Remove camera
-            data::Camera::sptr camera = cameraSeries->getCamera(index);
-            cameraSeries->removeCamera(camera);
-            data::CameraSeries::RemovedCameraSignalType::sptr sig;
-            sig = cameraSeries->signal<data::CameraSeries::RemovedCameraSignalType>(
-                data::CameraSeries::s_REMOVED_CAMERA_SIG
+            data::Camera::sptr camera = camera_set->get_camera(index);
+            camera_set->remove_camera(camera);
+
+            auto sig = camera_set->signal<data::CameraSet::removed_camera_signal_t>(
+                data::CameraSet::s_REMOVED_CAMERA_SIG
             );
             sig->asyncEmit(camera);
 
             // Remove calibrationInfo
             std::string calibrationInfoKey = "calibrationInfo_" + std::to_string(index);
-            const auto activitySeries      = m_activitySeries.lock();
-            activitySeries->getData()->getContainer().erase(calibrationInfoKey);
+            const auto activity            = m_activity.lock();
+            activity->erase(calibrationInfoKey);
 
-            const std::size_t nbCam = cameraSeries->numCameras();
+            const std::size_t nbCam = camera_set->size();
             if(nbCam == 1)
             {
                 m_extrinsicButton->setEnabled(false);
@@ -388,11 +382,11 @@ void SCameraConfigLauncher::onRemoveClicked()
 
 void SCameraConfigLauncher::onExtrinsicToggled(bool checked)
 {
-    std::size_t index;
+    std::size_t index = 0;
     {
-        const auto cameraSeries = m_cameraSeries.lock();
+        const auto camera_set = m_camera_set.lock();
         index = static_cast<std::size_t>(m_cameraComboBox->currentIndex());
-        SIGHT_ASSERT("Bad index: " << index, index < cameraSeries->numCameras());
+        SIGHT_ASSERT("Bad index: " << index, index < camera_set->size());
     }
     if(checked)
     {
@@ -410,15 +404,13 @@ void SCameraConfigLauncher::startIntrinsicConfig(std::size_t index)
 {
     service::FieldAdaptorType replaceMap;
     {
-        const auto cameraSeries   = m_cameraSeries.lock();
-        data::Camera::sptr camera = cameraSeries->getCamera(index);
+        const auto camera_set     = m_camera_set.lock();
+        data::Camera::sptr camera = camera_set->get_camera(index);
 
         std::string calibrationInfoKey = "calibrationInfo_" + std::to_string(index);
 
-        const auto activitySeries             = m_activitySeries.lock();
-        data::Composite::sptr data            = activitySeries->getData();
-        data::CalibrationInfo::sptr calibInfo =
-            data::CalibrationInfo::dynamicCast(data->getContainer()[calibrationInfoKey]);
+        const auto activity = m_activity.lock();
+        auto calibInfo      = data::CalibrationInfo::dynamicCast((*activity)[calibrationInfoKey]);
 
         replaceMap["camera"]          = camera->getID();
         replaceMap["calibrationInfo"] = calibInfo->getID();
@@ -437,10 +429,10 @@ void SCameraConfigLauncher::startExtrinsicConfig(std::size_t index)
     {
         const std::size_t cameraIdx = std::max(index, std::size_t(1));
 
-        const auto cameraSeries = m_cameraSeries.lock();
+        const auto camera_set = m_camera_set.lock();
 
-        data::Camera::sptr camera1 = cameraSeries->getCamera(0);
-        data::Camera::sptr camera2 = cameraSeries->getCamera(cameraIdx);
+        data::Camera::sptr camera1 = camera_set->get_camera(0);
+        data::Camera::sptr camera2 = camera_set->get_camera(cameraIdx);
 
         // Check if the two cameras are calibrated
         if(!camera1->getIsCalibrated() || !camera2->getIsCalibrated())
@@ -451,26 +443,26 @@ void SCameraConfigLauncher::startExtrinsicConfig(std::size_t index)
         }
 
         // cspell: ignore Extr
-        // Add 2 calibration info in ActivitySeries if not exist
-        std::string calibrationInfo1Key = "calibrationInfoExtr0_" + boost::lexical_cast<std::string>(cameraIdx);
-        std::string calibrationInfo2Key = "calibrationInfoExtr1_" + boost::lexical_cast<std::string>(cameraIdx);
-        const auto activitySeries       = m_activitySeries.lock();
-        data::Composite::sptr data      = activitySeries->getData();
+        // Add 2 calibration info in Activity if not exist
+        std::string calibrationInfo1Key = "calibrationInfoExtr0_" + std::to_string(cameraIdx);
+        std::string calibrationInfo2Key = "calibrationInfoExtr1_" + std::to_string(cameraIdx);
+        const auto activity             = m_activity.lock();
         data::CalibrationInfo::sptr calibInfo1;
         data::CalibrationInfo::sptr calibInfo2;
-        // Get the calibrationInfo from the activity series if it exists or create it.
-        if(data->find(calibrationInfo1Key) == data->end() || data->find(calibrationInfo2Key) == data->end())
+        // Get the calibrationInfo from the activity if it exists or create it.
+        if(activity->find(calibrationInfo1Key) == activity->end()
+           || activity->find(calibrationInfo2Key) == activity->end())
         {
             calibInfo1 = data::CalibrationInfo::New();
             calibInfo2 = data::CalibrationInfo::New();
 
-            data->getContainer()[calibrationInfo1Key] = calibInfo1;
-            data->getContainer()[calibrationInfo2Key] = calibInfo2;
+            (*activity)[calibrationInfo1Key] = calibInfo1;
+            (*activity)[calibrationInfo2Key] = calibInfo2;
         }
         else
         {
-            calibInfo1 = data::CalibrationInfo::dynamicCast(data->getContainer()[calibrationInfo1Key]);
-            calibInfo2 = data::CalibrationInfo::dynamicCast(data->getContainer()[calibrationInfo2Key]);
+            calibInfo1 = data::CalibrationInfo::dynamicCast((*activity)[calibrationInfo1Key]);
+            calibInfo2 = data::CalibrationInfo::dynamicCast((*activity)[calibrationInfo2Key]);
         }
 
         replaceMap["camera1"]          = camera1->getID();
@@ -489,25 +481,24 @@ void SCameraConfigLauncher::startExtrinsicConfig(std::size_t index)
 
 void SCameraConfigLauncher::addCamera()
 {
-    std::size_t nbCam;
+    std::size_t nbCam = 0;
     {
-        const auto cameraSeries = m_cameraSeries.lock();
-        nbCam = cameraSeries->numCameras();
+        const auto camera_set = m_camera_set.lock();
+        nbCam = camera_set->size();
 
         data::Camera::sptr camera = data::Camera::New();
 
-        // Add the CalibrationInfo in activitySeries to be saved in activity
+        // Add the CalibrationInfo in activity to be saved in activity
         std::string calibrationInfoKey        = "calibrationInfo_" + std::to_string(nbCam);
         data::CalibrationInfo::sptr calibInfo = data::CalibrationInfo::New();
 
-        const auto activitySeries = m_activitySeries.lock();
-        activitySeries->getData()->getContainer()[calibrationInfoKey] = calibInfo;
+        const auto activity = m_activity.lock();
+        (*activity)[calibrationInfoKey] = calibInfo;
 
         // Add the camera
-        cameraSeries->addCamera(camera);
-        data::CameraSeries::AddedCameraSignalType::sptr sig;
-        sig = cameraSeries->signal<data::CameraSeries::AddedCameraSignalType>(
-            data::CameraSeries::s_ADDED_CAMERA_SIG
+        camera_set->add_camera(camera);
+        auto sig = camera_set->signal<data::CameraSet::added_camera_signal_t>(
+            data::CameraSet::s_ADDED_CAMERA_SIG
         );
         sig->asyncEmit(camera);
     }
