@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,16 +22,13 @@
 
 #include "modules/ui/qt/calibration/SDisplayCalibrationInfo.hpp"
 
+#include <core/com/Proxy.hpp>
 #include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/EConfigurationElement.hpp>
 
 #include <data/String.hpp>
 
 #include <service/extension/AppConfig.hpp>
-#include <service/macros.hpp>
-#include <service/registry/Proxy.hpp>
 
 #include <sstream>
 
@@ -44,7 +41,6 @@ static const core::com::Slots::SlotKeyType s_DISPLAY_IMAGE_SLOT = "displayImage"
 static const core::com::Slots::SlotKeyType s_STOP_CONFIG_SLOT   = "stopConfig";
 
 static const std::string s_SINGLE_IMAGE_CONFIG = "singleImageConfig";
-static const std::string s_TWO_IMAGE_CONFIG    = "twoImageConfig";
 
 static const std::string s_CLOSE_CONFIG_CHANNEL_ID = "CLOSE_CONFIG_CHANNEL";
 
@@ -58,9 +54,8 @@ SDisplayCalibrationInfo::SDisplayCalibrationInfo() noexcept
 
 //------------------------------------------------------------------------------
 
-SDisplayCalibrationInfo::~SDisplayCalibrationInfo() noexcept
-{
-}
+SDisplayCalibrationInfo::~SDisplayCalibrationInfo() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -75,7 +70,7 @@ void SDisplayCalibrationInfo::stopping()
 {
     if(m_configMgr)
     {
-        service::registry::Proxy::sptr proxies = service::registry::Proxy::getDefault();
+        core::com::Proxy::sptr proxies = core::com::Proxy::get();
         proxies->disconnect(m_proxychannel, this->slot(s_STOP_CONFIG_SLOT));
         m_configMgr->stopAndDestroy();
         m_configMgr.reset();
@@ -127,7 +122,6 @@ void SDisplayCalibrationInfo::displayImage(std::size_t idx)
         data::PointList::csptr pointList1 = calInfo1->getPointList(img1);
         replaceMap["pointListId1"] = pointList1->getID();
 
-        core::runtime::ConfigurationElement::csptr config;
         if(calInfo2)
         {
             strConfig = std::string(s_TWO_IMAGES_CONFIG);
@@ -140,20 +134,23 @@ void SDisplayCalibrationInfo::displayImage(std::size_t idx)
 
         replaceMap[s_CLOSE_CONFIG_CHANNEL_ID] = m_proxychannel;
 
-        config =
-            service::extension::AppConfig::getDefault()->getAdaptedTemplateConfig(strConfig, replaceMap, true);
+        const auto config = service::extension::AppConfig::getDefault()->getAdaptedTemplateConfig(
+            strConfig,
+            replaceMap,
+            true
+        );
 
         // Launch configuration
         m_configMgr = service::IAppConfigManager::New();
-        m_configMgr->service::IAppConfigManager::setConfig(config);
+        m_configMgr->setConfig(config);
         m_configMgr->launch();
 
         // Proxy to be notified of the window closure
-        service::registry::Proxy::sptr proxies = service::registry::Proxy::getDefault();
+        core::com::Proxy::sptr proxies = core::com::Proxy::get();
         proxies->connect(m_proxychannel, this->slot(s_STOP_CONFIG_SLOT));
     }
 }
 
 //------------------------------------------------------------------------------
 
-} // uiCalibration
+} // namespace sight::module::ui::qt::calibration
