@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,13 +24,12 @@
 
 #include "modules/ui/qt/config.hpp"
 
-#include <core/com/helper/SigSlotConnection.hpp>
 #include <core/com/Slot.hpp>
 #include <core/com/Slots.hpp>
 
 #include <data/CalibrationInfo.hpp>
 
-#include <service/AppConfigManager.hpp>
+#include <service/IAppConfigManager.hpp>
 #include <service/IController.hpp>
 
 namespace sight::module::ui::qt::calibration
@@ -78,7 +77,7 @@ public:
     MODULE_UI_QT_API SDisplayCalibrationInfo() noexcept;
 
     /// Destructor. Does nothing.
-    MODULE_UI_QT_API virtual ~SDisplayCalibrationInfo() noexcept;
+    MODULE_UI_QT_API ~SDisplayCalibrationInfo() noexcept override;
 
 protected:
 
@@ -123,4 +122,4 @@ private:
     data::ptr<data::CalibrationInfo, data::Access::in> m_calibrationInfo2 {this, s_CALIBRATION_INFO_2, false, true};
 };
 
-} // uiCalibration
+} // namespace sight::module::ui::qt::calibration
