@@ -28,7 +28,6 @@
 #include <core/com/Slots.hxx>
 #include <core/tools/fwID.hpp>
 
-#include <data/helper/Vector.hpp>
 #include <data/Image.hpp>
 
 #include <ui/qt/container/QtContainer.hpp>
@@ -45,8 +44,7 @@ const core::com::Slots::SlotKeyType SImagesSelector::s_REMOVE_SLOT = "remove";
 const core::com::Slots::SlotKeyType SImagesSelector::s_RESET_SLOT  = "reset";
 
 //------------------------------------------------------------------------------
-SImagesSelector::SImagesSelector() noexcept :
-    m_captureIdx(0)
+SImagesSelector::SImagesSelector() noexcept
 {
     newSlot(s_ADD_SLOT, &SImagesSelector::add, this);
     newSlot(s_REMOVE_SLOT, &SImagesSelector::remove, this);
@@ -55,9 +53,8 @@ SImagesSelector::SImagesSelector() noexcept :
 
 //------------------------------------------------------------------------------
 
-SImagesSelector::~SImagesSelector() noexcept
-{
-}
+SImagesSelector::~SImagesSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -77,13 +74,13 @@ void SImagesSelector::starting()
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(getContainer());
 
     // Main container, VBox
-    QVBoxLayout* vLayout = new QVBoxLayout();
+    auto* vLayout = new QVBoxLayout();
 
     //   First HBox, displays number of items and the remove button
-    QHBoxLayout* nbItemsHBox = new QHBoxLayout();
+    auto* nbItemsHBox = new QHBoxLayout();
 
     //     Fill the nbItemsHBox
-    QLabel* label = new QLabel("nb captures:");
+    auto* label = new QLabel("nb captures:");
     nbItemsHBox->addWidget(label);
 
     m_nbCapturesLabel = new QLabel("0");
@@ -117,7 +114,7 @@ void SImagesSelector::updating()
 
     m_capturesListWidget->clear();
     unsigned int captureIdx = 0;
-    for(data::Object::sptr obj : vector->getContainer())
+    for(const data::Object::sptr& obj : *vector)
     {
         data::Image::sptr image = data::Image::dynamicCast(obj);
         if(image)
@@ -142,11 +139,10 @@ void SImagesSelector::remove()
     if(idx >= 0)
     {
         const auto vector      = m_selected_image.lock();
-        data::Object::sptr obj = vector->getContainer()[idx];
+        data::Object::sptr obj = (*vector)[std::size_t(idx)];
 
-        data::helper::Vector vectorHelper(vector.get_shared());
-        vectorHelper.remove(obj);
-        vectorHelper.notify();
+        const auto scoped_emitter = vector->scoped_emit();
+        vector->remove(obj);
 
         this->updating();
     }
@@ -158,9 +154,8 @@ void SImagesSelector::reset()
 {
     const auto vector = m_selected_image.lock();
 
-    data::helper::Vector vectorHelper(vector.get_shared());
-    vectorHelper.clear();
-    vectorHelper.notify();
+    const auto scoped_emitter = vector->scoped_emit();
+    vector->clear();
 
     m_capturesListWidget->clear();
     m_nbCapturesLabel->setText(QString("0"));
@@ -186,7 +181,7 @@ void SImagesSelector::add(core::HiResClock::HiResClockType timestamp)
     size[1] = frameTL->getHeight();
     size[2] = 1;
 
-    data::Image::PixelFormat format;
+    data::Image::PixelFormat format {data::Image::PixelFormat::UNDEFINED};
     // FIXME since frameTL does not have format information, we assume that image are Grayscale, RGB or RGBA according
     // to the number of components.
     switch(frameTL->numComponents())
@@ -212,20 +207,19 @@ void SImagesSelector::add(core::HiResClock::HiResClockType timestamp)
     image->setOrigin(origin);
     const data::Image::Spacing spacing = {1., 1., 1.};
     image->setSpacing(spacing);
-    image->setWindowWidth(100);
-    image->setWindowCenter(0);
+    image->setWindowWidth({100});
+    image->setWindowCenter({0});
 
     const auto dumpLock = image->dump_lock();
 
     const std::uint8_t* frameBuff = &buffer->getElement(0);
-    std::uint8_t* imgBuffer       = static_cast<std::uint8_t*>(image->getBuffer());
+    auto* imgBuffer               = static_cast<std::uint8_t*>(image->getBuffer());
     std::copy(frameBuff, frameBuff + buffer->getSize(), imgBuffer);
 
     const auto vector = m_selected_image.lock();
 
-    sight::data::helper::Vector vectorHelper(vector.get_shared());
-    vectorHelper.add(image);
-    vectorHelper.notify();
+    const auto scoped_emitter = vector->scoped_emit();
+    vector->push_back(image);
 
     this->updating();
 }
