@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2015-2022 IRCAD France
+ * Copyright (C) 2015-2023 IRCAD France
  * Copyright (C) 2015-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,58 +22,45 @@
 
 #include "SSignalButton.hpp"
 
-#include <core/base.hpp>
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
-#include <core/com/Signals.hpp>
-#include <core/com/Slot.hpp>
 #include <core/com/Slot.hxx>
-#include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
-#include <core/tools/fwID.hpp>
-
-#include <service/macros.hpp>
+#include <core/runtime/path.hpp>
 
 #include <ui/qt/container/QtContainer.hpp>
 
+#include <QVariant>
 #include <QVBoxLayout>
 
-#include <string>
-
-namespace sight::module::ui::qt
-{
-
-namespace com
+namespace sight::module::ui::qt::com
 {
 
 static const core::com::Signals::SignalKeyType s_CLICKED_SIG = "clicked";
 static const core::com::Signals::SignalKeyType s_TOGGLED_SIG = "toggled";
 
-static const core::com::Slots::SlotKeyType s_SET_CHECKED_SLOT       = "setChecked";
-static const core::com::Slots::SlotKeyType s_CHECK_SLOT             = "check";
-static const core::com::Slots::SlotKeyType s_UNCHECK_SLOT           = "uncheck";
-static const core::com::Slots::SlotKeyType s_SET_IS_EXECUTABLE_SLOT = "setIsExecutable";
-static const core::com::Slots::SlotKeyType s_SET_EXECUTABLE_SLOT    = "setExecutable";
-static const core::com::Slots::SlotKeyType s_SET_INEXECUTABLE_SLOT  = "setInexecutable";
-static const core::com::Slots::SlotKeyType s_SET_VISIBLE_SLOT       = "setVisible";
-static const core::com::Slots::SlotKeyType s_SHOW_SLOT              = "show";
-static const core::com::Slots::SlotKeyType s_HIDE_SLOT              = "hide";
+static const core::com::Slots::SlotKeyType s_SET_CHECKED_SLOT = "setChecked";
+static const core::com::Slots::SlotKeyType s_CHECK_SLOT       = "check";
+static const core::com::Slots::SlotKeyType s_UNCHECK_SLOT     = "uncheck";
+
+static const core::com::Slots::SlotKeyType s_SET_ENABLED_SLOT = "setEnabled";
+static const core::com::Slots::SlotKeyType s_ENABLE_SLOT      = "enable";
+static const core::com::Slots::SlotKeyType s_DISABLE_SLOT     = "disable";
+static const core::com::Slots::SlotKeyType s_SET_VISIBLE_SLOT = "setVisible";
+static const core::com::Slots::SlotKeyType s_SHOW_SLOT        = "show";
+static const core::com::Slots::SlotKeyType s_HIDE_SLOT        = "hide";
 
 //-----------------------------------------------------------------------------
 
-SSignalButton::SSignalButton() noexcept
+SSignalButton::SSignalButton() noexcept :
+    m_sigClicked(newSignal<ClickedSignalType>(s_CLICKED_SIG)),
+    m_sigToggled(newSignal<ToggledSignalType>(s_TOGGLED_SIG))
 {
-    m_sigClicked = newSignal<ClickedSignalType>(s_CLICKED_SIG);
-    m_sigToggled = newSignal<ToggledSignalType>(s_TOGGLED_SIG);
-
     newSlot(s_SET_CHECKED_SLOT, &SSignalButton::setChecked, this);
     newSlot(s_CHECK_SLOT, &SSignalButton::check, this);
     newSlot(s_UNCHECK_SLOT, &SSignalButton::uncheck, this);
-    newSlot(s_SET_IS_EXECUTABLE_SLOT, &SSignalButton::setIsExecutable, this);
-    newSlot(s_SET_EXECUTABLE_SLOT, &SSignalButton::setExecutable, this);
-    newSlot(s_SET_INEXECUTABLE_SLOT, &SSignalButton::setInexecutable, this);
+    newSlot(s_SET_ENABLED_SLOT, &SSignalButton::setEnabled, this);
+    newSlot(s_ENABLE_SLOT, &SSignalButton::enable, this);
+    newSlot(s_DISABLE_SLOT, &SSignalButton::disable, this);
     newSlot(s_SET_VISIBLE_SLOT, &SSignalButton::setVisible, this);
     newSlot(s_SHOW_SLOT, &SSignalButton::show, this);
     newSlot(s_HIDE_SLOT, &SSignalButton::hide, this);
@@ -81,9 +68,8 @@ SSignalButton::SSignalButton() noexcept
 
 //-----------------------------------------------------------------------------
 
-SSignalButton::~SSignalButton() noexcept
-{
-}
+SSignalButton::~SSignalButton() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -91,86 +77,32 @@ void SSignalButton::configuring()
 {
     this->initialize();
 
-    core::runtime::ConfigurationElement::sptr config = m_configuration->findConfigurationElement("config");
+    const auto configuration = this->getConfiguration();
 
-    if(config)
+    const auto config = configuration.get_child_optional("config");
+
+    if(config.has_value())
     {
-        core::runtime::ConfigurationElement::sptr checkableCfg = config->findConfigurationElement("checkable");
-        if(checkableCfg)
+        m_checkable    = config->get<bool>("checkable", m_checkable);
+        m_checkAtStart = config->get<bool>("checked", m_checkAtStart);
+        m_enable       = config->get<bool>("enable", m_enable);
+
+        m_text    = config->get<std::string>("text", m_text);
+        m_text2   = config->get<std::string>("text2", m_text2);
+        m_toolTip = config->get<std::string>("toolTip", m_toolTip);
+
+        if(const auto icon = config->get_optional<std::string>("icon"); icon.has_value())
         {
-            SIGHT_ASSERT(
-                "'checkable' value must be 'true' or 'false'",
-                checkableCfg->getValue() == "true" || checkableCfg->getValue() == "false"
-            );
-            m_checkable = (checkableCfg->getValue() == "true");
+            m_icon = core::runtime::getModuleResourceFilePath(icon.value());
         }
 
-        core::runtime::ConfigurationElement::sptr executableCfg = config->findConfigurationElement("executable");
-        if(executableCfg)
+        if(const auto icon = config->get_optional<std::string>("icon2"); icon.has_value())
         {
-            SIGHT_ASSERT(
-                "'executable' value must be 'true' or 'false'",
-                executableCfg->getValue() == "true" || executableCfg->getValue() == "false"
-            );
-            m_executable = (executableCfg->getValue() == "true");
+            m_icon2 = core::runtime::getModuleResourceFilePath(icon.value());
         }
 
-        core::runtime::ConfigurationElement::sptr txtCfg = config->findConfigurationElement("text");
-        if(txtCfg)
-        {
-            m_text = txtCfg->getValue();
-        }
-
-        core::runtime::ConfigurationElement::sptr iconCfg = config->findConfigurationElement("icon");
-        if(iconCfg)
-        {
-            m_icon = core::runtime::getModuleResourceFilePath(iconCfg->getValue());
-        }
-
-        core::runtime::ConfigurationElement::sptr txt2Cfg = config->findConfigurationElement("text2");
-        if(txt2Cfg)
-        {
-            SIGHT_ASSERT("Button must be 'checkable' in order to defined 'text2'", m_checkable);
-            SIGHT_ASSERT("'text' tag must be defined in order to specify 'text2'", !m_text.empty());
-            m_text2 = txt2Cfg->getValue();
-        }
-
-        core::runtime::ConfigurationElement::sptr icon2Cfg = config->findConfigurationElement("icon2");
-        if(icon2Cfg)
-        {
-            SIGHT_ASSERT("Button must be 'checkable' in order to defined 'icon2'", m_checkable);
-            SIGHT_ASSERT("'icon' tag must be defined in order to specify 'icon2'", iconCfg);
-            m_icon2 = core::runtime::getModuleResourceFilePath(icon2Cfg->getValue());
-        }
-
-        core::runtime::ConfigurationElement::sptr checkedCfg = config->findConfigurationElement("checked");
-        if(checkedCfg)
-        {
-            SIGHT_ASSERT("Button must be 'checkable' in order to defined 'checked'", m_checkable);
-            SIGHT_ASSERT(
-                "'checked' value must be 'true' or 'false'",
-                checkedCfg->getValue() == "true" || checkedCfg->getValue() == "false"
-            );
-            m_checkAtStart = (checkedCfg->getValue() == "true");
-        }
-
-        core::runtime::ConfigurationElement::sptr widthCfg = config->findConfigurationElement("iconWidth");
-        if(widthCfg)
-        {
-            m_iconWidth = std::stoi(widthCfg->getValue());
-        }
-
-        core::runtime::ConfigurationElement::sptr heightCfg = config->findConfigurationElement("iconHeight");
-        if(heightCfg)
-        {
-            m_iconHeight = std::stoi(heightCfg->getValue());
-        }
-
-        core::runtime::ConfigurationElement::sptr tooltipCfg = config->findConfigurationElement("toolTip");
-        if(tooltipCfg)
-        {
-            m_toolTip = tooltipCfg->getValue();
-        }
+        m_iconWidth  = config->get<unsigned int>("iconWidth", m_iconWidth);
+        m_iconHeight = config->get<unsigned int>("iconHeight", m_iconHeight);
     }
 }
 
@@ -182,9 +114,10 @@ void SSignalButton::starting()
 
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     m_button = new QPushButton(QString::fromStdString(m_text));
-    m_button->setEnabled(m_executable);
+    m_button->setEnabled(m_enable);
+    m_button->setProperty("class", "signal-button");
     layout->addWidget(m_button);
     qtContainer->setLayout(layout);
 
@@ -200,7 +133,7 @@ void SSignalButton::starting()
 
     if(m_iconWidth > 0 && m_iconHeight > 0)
     {
-        m_button->setIconSize(QSize(m_iconWidth, m_iconHeight));
+        m_button->setIconSize(QSize(int(m_iconWidth), int(m_iconHeight)));
     }
 
     if(m_checkable)
@@ -305,29 +238,33 @@ void SSignalButton::uncheck()
 
 //-----------------------------------------------------------------------------
 
-void SSignalButton::setIsExecutable(bool _isExecutable)
+void SSignalButton::setEnabled(bool _isEnabled)
 {
-    m_button->setEnabled(_isExecutable);
+    IEditor::setEnabled(_isEnabled);
+    // Keep this in case of SSignalButton is used outside a view container
+    m_button->setEnabled(_isEnabled);
 }
 
 //-----------------------------------------------------------------------------
 
-void SSignalButton::setExecutable()
+void SSignalButton::enable()
 {
-    m_button->setEnabled(true);
+    this->setEnabled(true);
 }
 
 //-----------------------------------------------------------------------------
 
-void SSignalButton::setInexecutable()
+void SSignalButton::disable()
 {
-    m_button->setEnabled(false);
+    this->setEnabled(false);
 }
 
 //-----------------------------------------------------------------------------
 
 void SSignalButton::setVisible(bool _isVisible)
 {
+    IEditor::setVisible(_isVisible);
+    // Keep this in case of SSignalButton is used outside a view container
     m_button->setVisible(_isVisible);
 }
 
@@ -335,18 +272,16 @@ void SSignalButton::setVisible(bool _isVisible)
 
 void SSignalButton::show()
 {
-    m_button->show();
+    this->setVisible(true);
 }
 
 //-----------------------------------------------------------------------------
 
 void SSignalButton::hide()
 {
-    m_button->hide();
+    this->setVisible(false);
 }
 
 //-----------------------------------------------------------------------------
 
-} // namespace com.
-
-} // namespace sight::module::ui::base.
+} // namespace sight::module::ui::qt::com
