@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2015-2021 IRCAD France
+ * Copyright (C) 2015-2023 IRCAD France
  * Copyright (C) 2015-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,10 +33,7 @@
 
 #include <filesystem>
 
-namespace sight::module::ui::qt
-{
-
-namespace com
+namespace sight::module::ui::qt::com
 {
 
 /**
@@ -52,9 +49,9 @@ namespace com
  * - \b setChecked(bool): allows to check/uncheck the button.
  * - \b check(): allows to check the button.
  * - \b uncheck(): allows to uncheck the button.
- * - \b setIsExecutable(bool): sets the button executability.
- * - \b setExecutable(): sets the button executable.
- * - \b setInexecutable(): sets the button inexecutable.
+ * - \b setEnabled(bool): sets the button executability.
+ * - \b enable(): sets the button executable.
+ * - \b disable(): sets the button inexecutable.
  * - \b setVisible(bool):s ets the button visibility.
  * - \b show(): shows the button.
  * - \b hide(): hides the button.
@@ -79,7 +76,7 @@ namespace com
  * - \b text (optional, string, default=""): text displayed on the button.
  * - \b icon (optional, string, default=""): icon displayed on the button.
  * - \b checkable (optional, bool, default=false): if true, the button is checkable.
- * - \b executable (optional, bool, default=true): if true, the button is executable.
+ * - \b enable (optional, bool, default=true): if true, the button is executable.
  * - \b text2 (optional, string, default=""): text displayed if the button is checked.
  * - \b icon2 (optional, string, default=""): icon displayed if the button is checked.
  * - \b checked (optional, bool, default=false): if true, the button is checked at start.
@@ -100,7 +97,7 @@ public:
     MODULE_UI_QT_API SSignalButton() noexcept;
 
     /// Destroys the service.
-    MODULE_UI_QT_API virtual ~SSignalButton() noexcept;
+    MODULE_UI_QT_API ~SSignalButton() noexcept override;
 
 protected:
 
@@ -120,7 +117,7 @@ private Q_SLOTS:
 
     void onClicked();
 
-    void onToggled(bool);
+    void onToggled(bool /*toggled*/);
 
 private:
 
@@ -134,22 +131,22 @@ private:
     void uncheck();
 
     /// SLOT: sets the button executability.
-    void setIsExecutable(bool _isExecutable);
+    void setEnabled(bool _isEnabled) override;
 
     /// SLOT: sets the button executable.
-    void setExecutable();
+    void enable() override;
 
     /// SLOT: sets the button inexecutable.
-    void setInexecutable();
+    void disable() override;
 
     /// SLOT: sets the button visibility.
-    void setVisible(bool _isVisible);
+    void setVisible(bool _isVisible) override;
 
     /// SLOT: shows the button.
-    void show();
+    void show() override;
 
     /// SLOT: hides he button.
-    void hide();
+    void hide() override;
 
     typedef core::com::Signal<void ()> ClickedSignalType;
     /// Contains the signal emitted when button is clicked.
@@ -163,10 +160,10 @@ private:
     QPointer<QPushButton> m_button {nullptr};
 
     /// Defines the button's text.
-    std::string m_text {""};
+    std::string m_text;
 
     /// Defines the button's text when it is checked.
-    std::string m_text2 {""};
+    std::string m_text2;
 
     /// Defines the path of the button's icon.
     std::filesystem::path m_icon;
@@ -178,7 +175,7 @@ private:
     bool m_checkable {false};
 
     /// Defines if the button is executable.
-    bool m_executable {true};
+    bool m_enable {true};
 
     /// Defines if the button is checked at start.
     bool m_checkAtStart {false};
@@ -190,9 +187,7 @@ private:
     unsigned m_iconHeight {0};
 
     /// Defines the button tooltip.
-    std::string m_toolTip {""};
+    std::string m_toolTip;
 };
 
-} // namespace com.
-
-} // namespace sight::module::ui::base.
+} // namespace sight::module::ui::qt::com
