@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -69,7 +69,7 @@ public:
 
     MODULE_UI_QT_API ImageInfo() noexcept;
 
-    MODULE_UI_QT_API virtual ~ImageInfo() noexcept;
+    MODULE_UI_QT_API ~ImageInfo() noexcept override;
 
 protected:
 
@@ -91,8 +91,8 @@ protected:
      * @brief Returns proposals to connect service slots to associated object signals,
      * this method is used for obj/srv auto connection
      *
-     * Connect Image::s_MODIFIED_SIG to this::s_UPDATE_SLOT
-     * Connect Image::s_BUFFER_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect Image::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
+     * Connect Image::s_BUFFER_MODIFIED_SIG to this::IService::slots::s_UPDATE
      */
     KeyConnectionsMap getAutoConnections() const override;
 
@@ -109,4 +109,4 @@ private:
     data::ptr<data::Image, data::Access::in> m_image {this, s_IMAGE, true};
 };
 
-} // uiImageQt
+} // namespace sight::module::ui::qt::image
