@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,28 +23,18 @@
 #include "modules/ui/qt/image/SliceIndexPositionEditor.hpp"
 
 #include <core/base.hpp>
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
-#include <core/com/Signals.hpp>
-#include <core/com/Slot.hpp>
 #include <core/com/Slot.hxx>
-#include <core/com/Slots.hpp>
 #include <core/com/Slots.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
 
-#include <data/Composite.hpp>
 #include <data/helper/MedicalImage.hpp>
 #include <data/Image.hpp>
 #include <data/Integer.hpp>
 
-#include <service/macros.hpp>
-
 #include <ui/qt/container/QtContainer.hpp>
 
 #include <boost/algorithm/string/case_conv.hpp>
 #include <boost/algorithm/string/trim.hpp>
-#include <boost/lexical_cast.hpp>
 
 #include <QVBoxLayout>
 #include <QWidget>
@@ -71,9 +61,8 @@ SliceIndexPositionEditor::SliceIndexPositionEditor() noexcept
 
 //------------------------------------------------------------------------------
 
-SliceIndexPositionEditor::~SliceIndexPositionEditor() noexcept
-{
-}
+SliceIndexPositionEditor::~SliceIndexPositionEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -85,18 +74,23 @@ void SliceIndexPositionEditor::starting()
         this->getContainer()
     );
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    const QString serviceID = QString::fromStdString(getID().substr(getID().find_last_of('_') + 1));
 
-    m_sliceSelectorPanel = new sight::ui::qt::SliceSelector();
+    auto* layout = new QVBoxLayout();
+
+    m_sliceSelectorPanel = new sight::ui::qt::SliceSelector(m_displayAxisSelector, m_displayStepButtons);
     m_sliceSelectorPanel->setEnable(false);
+    m_sliceSelectorPanel->setObjectName(serviceID);
 
     sight::ui::qt::SliceSelector::ChangeIndexCallback changeIndexCallback;
-    changeIndexCallback = std::bind(&SliceIndexPositionEditor::sliceIndexNotification, this, std::placeholders::_1);
+    changeIndexCallback = [this](unsigned&& PH1, auto&& ...){sliceIndexNotification(std::forward<decltype(PH1)>(PH1));};
     m_sliceSelectorPanel->setChangeIndexCallback(changeIndexCallback);
 
     sight::ui::qt::SliceSelector::ChangeIndexCallback changeTypeCallback;
-    changeTypeCallback = std::bind(&SliceIndexPositionEditor::sliceTypeNotification, this, std::placeholders::_1);
+    changeTypeCallback = [this](auto&& PH1, auto&& ...){sliceTypeNotification(std::forward<decltype(PH1)>(PH1));};
     m_sliceSelectorPanel->setChangeTypeCallback(changeTypeCallback);
+    m_sliceSelectorPanel->setTypeSelection(m_orientation);
+
     layout->addWidget(m_sliceSelectorPanel);
     layout->setContentsMargins(0, 0, 0, 0);
 
@@ -119,39 +113,40 @@ void SliceIndexPositionEditor::configuring()
 {
     this->initialize();
 
-    if(this->m_configuration->size() > 0)
-    {
-        std::vector<core::runtime::ConfigurationElement::sptr> slideIndexCfg = m_configuration->find("sliceIndex");
-        SIGHT_ASSERT("Only one xml element \"sliceIndex\" is accepted.", slideIndexCfg.size() == 1);
-        SIGHT_ASSERT("The xml element \"sliceIndex\" is empty.", !(*slideIndexCfg.begin())->getValue().empty());
-        std::string orientation = (*slideIndexCfg.begin())->getValue();
-        boost::algorithm::trim(orientation);
-        boost::algorithm::to_lower(orientation);
+    const auto config = this->getConfiguration();
 
-        if(orientation == "axial")
-        {
-            m_orientation = orientation_t::AXIAL; // Z
-        }
-        else if(orientation == "frontal")
-        {
-            m_orientation = orientation_t::FRONTAL; // Y
-        }
-        else if(orientation == "sagittal")
-        {
-            m_orientation = orientation_t::SAGITTAL; // X
-        }
-        else
-        {
-            SIGHT_FATAL("The value for the xml element \"sliceIndex\" can only be axial, frontal or sagittal.");
-        }
+    auto orientation = config.get<std::string>("sliceIndex");
+
+    boost::algorithm::trim(orientation);
+    boost::algorithm::to_lower(orientation);
+
+    if(orientation == "axial")
+    {
+        m_orientation = orientation_t::AXIAL; // Z
     }
+    else if(orientation == "frontal")
+    {
+        m_orientation = orientation_t::FRONTAL; // Y
+    }
+    else if(orientation == "sagittal")
+    {
+        m_orientation = orientation_t::SAGITTAL; // X
+    }
+    else
+    {
+        SIGHT_FATAL("The value for the xml element \"sliceIndex\" can only be axial, frontal or sagittal.");
+    }
+
+    m_displayAxisSelector = config.get<bool>("displayAxisSelector", m_displayAxisSelector);
+
+    m_displayStepButtons = config.get<bool>("displayStepButtons", m_displayStepButtons);
 }
 
 //------------------------------------------------------------------------------
 
 void SliceIndexPositionEditor::updating()
 {
-    const auto image = m_image.lock();
+    const auto image = m_image.const_lock();
 
     const bool imageIsValid = imHelper::checkImageValidity(image.get_shared());
     m_sliceSelectorPanel->setEnable(imageIsValid);
@@ -214,13 +209,13 @@ void SliceIndexPositionEditor::updateSliceType(int from, int to)
 
 //------------------------------------------------------------------------------
 
-void SliceIndexPositionEditor::info(std::ostream&)
+void SliceIndexPositionEditor::info(std::ostream& /*_sstream*/)
 {
 }
 
 //------------------------------------------------------------------------------
 
-void SliceIndexPositionEditor::updateSliceIndexFromImg(sight::data::Image& _image)
+void SliceIndexPositionEditor::updateSliceIndexFromImg(const sight::data::Image& _image)
 {
     if(imHelper::checkImageValidity(_image))
     {
@@ -247,7 +242,7 @@ void SliceIndexPositionEditor::updateSliceTypeFromImg(const orientation_t& type)
     // Update Type Choice
     m_sliceSelectorPanel->setTypeSelection(static_cast<int>(type));
 
-    const auto image = m_image.lock();
+    const auto image = m_image.const_lock();
     SIGHT_ASSERT("The inout key '" + s_IMAGE_INOUT + "' is not defined.", image);
 
     this->updateSliceIndexFromImg(*image);
@@ -261,7 +256,7 @@ void SliceIndexPositionEditor::sliceIndexNotification(unsigned int index)
 
     imHelper::setSliceIndex(*image, m_orientation, index);
 
-    int idx[3] = {
+    std::array idx {
         static_cast<int>(imHelper::getSliceIndex(
                              *image,
                              imHelper::orientation_t::SAGITTAL
@@ -287,7 +282,7 @@ void SliceIndexPositionEditor::sliceIndexNotification(unsigned int index)
 
 void SliceIndexPositionEditor::sliceTypeNotification(int _type)
 {
-    orientation_t type = static_cast<orientation_t>(_type);
+    auto type = static_cast<orientation_t>(_type);
     SIGHT_ASSERT(
         "Bad slice type " << type,
         type == orientation_t::X_AXIS
@@ -301,7 +296,7 @@ void SliceIndexPositionEditor::sliceTypeNotification(int _type)
 
     // Fire the signal
     {
-        const auto image = m_image.lock();
+        const auto image = m_image.const_lock();
 
         auto sig = image->signal<data::Image::SliceTypeModifiedSignalType>(
             data::Image::s_SLICE_TYPE_MODIFIED_SIG
@@ -320,14 +315,14 @@ service::IService::KeyConnectionsMap SliceIndexPositionEditor::getAutoConnection
 {
     KeyConnectionsMap connections;
 
-    connections.push(s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE);
     connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_INDEX_MODIFIED_SIG, s_UPDATE_SLICE_INDEX_SLOT);
     connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_UPDATE_SLICE_TYPE_SLOT);
-    connections.push(s_IMAGE_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INOUT, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace sight::module
+} // namespace sight::module::ui::qt::image
