@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -47,6 +47,7 @@ namespace sight::module::ui::qt::image
    <service uid="..." type="sight::module::ui::qt::image::SliceIndexPositionEditor" autoConnect="true">
       <inout key="image" uid="..."/>
       <sliceIndex>${orientationValue}</sliceIndex>
+      <displayAxisSelector>true</displayAxisSelector>
    </service>
    @endcode
  * @subsection In-Out In-Out
@@ -54,6 +55,8 @@ namespace sight::module::ui::qt::image
  *
  * @subsection Configuration Configuration
  * - \b sliceIndex : Axis on which the index will be changed, must be "axial", "frontal" or "sagittal".
+ * - \b displayAxisSelector : Allows to change the axis.
+ * - \b displayStepButtons : Allows to change the slice index with step buttons.
  */
 class MODULE_UI_QT_CLASS_API SliceIndexPositionEditor : public sight::ui::base::IEditor
 {
@@ -65,7 +68,7 @@ public:
     MODULE_UI_QT_API SliceIndexPositionEditor() noexcept;
 
     /// Destructor. Do nothing.
-    MODULE_UI_QT_API virtual ~SliceIndexPositionEditor() noexcept;
+    MODULE_UI_QT_API ~SliceIndexPositionEditor() noexcept override;
 
 protected:
 
@@ -104,7 +107,7 @@ protected:
      * @brief Returns proposals to connect service slots to associated object signals,
      * this method is used for obj/srv auto connection
      *
-     * Connect Image::s_MODIFIED_SIG to this::s_UPDATE_SLOT
+     * Connect Image::s_MODIFIED_SIG to this::IService::slots::s_UPDATE
      * Connect Image::s_SLICE_INDEX_MODIFIED_SIG to this::s_UPDATE_SLICE_INDEX_SLOT
      * Connect Image::s_SLICE_TYPE_MODIFIED_SIG to this::s_UPDATE_SLICE_TYPE_SLOT
      * Connect Image::s_BUFFER_MODIFIED_SIG to this::s_UPDATE_BUFFER_SLOT
@@ -115,7 +118,7 @@ protected:
     MODULE_UI_QT_API void info(std::ostream& _sstream) override;
 
     /// Update the editor slider from the image slice index.
-    MODULE_UI_QT_API void updateSliceIndexFromImg(sight::data::Image& _image);
+    MODULE_UI_QT_API void updateSliceIndexFromImg(const sight::data::Image& _image);
 
     /// Update the editor slice type choice from the image slice type.
     MODULE_UI_QT_API void updateSliceTypeFromImg(const orientation_t& type);
@@ -145,7 +148,7 @@ private:
      * @}
      */
 
-    sight::ui::qt::SliceSelector* m_sliceSelectorPanel;
+    sight::ui::qt::SliceSelector* m_sliceSelectorPanel {};
 
     data::ptr<data::Image, data::Access::inout> m_image {this, "image", true};
 
@@ -154,6 +157,10 @@ private:
     std::int64_t m_sagittalIndex {-1};
 
     orientation_t m_orientation {orientation_t::Z_AXIS};
+
+    bool m_displayAxisSelector {true};
+
+    bool m_displayStepButtons {false};
 };
 
-} // uiImageQt
+} // namespace sight::module::ui::qt::image
