@@ -22,27 +22,16 @@
 
 #include "modules/ui/qt/metrics/Distance.hpp"
 
-#include <core/base.hpp>
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
-#include <core/runtime/ConfigurationElement.hpp>
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
-#include <data/Boolean.hpp>
-#include <data/Composite.hpp>
 #include <data/helper/MedicalImage.hpp>
-#include <data/String.hpp>
-
-#include <service/IService.hpp>
-#include <service/macros.hpp>
 
 #include <ui/qt/container/QtContainer.hpp>
 
 #include <QIcon>
 #include <QVBoxLayout>
 
-#include <filesystem>
-
 namespace sight::module::ui::qt::metrics
 {
 
@@ -59,9 +48,8 @@ Distance::Distance() noexcept
 
 //------------------------------------------------------------------------------
 
-Distance::~Distance() noexcept
-{
-}
+Distance::~Distance() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -82,7 +70,7 @@ void Distance::starting()
     m_distButton = new QPushButton(imageDist, tr(""));
     m_distButton->setToolTip(tr("Distance"));
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     layout->addWidget(m_distButton, 1);
     layout->setContentsMargins(0, 0, 0, 0);
     QObject::connect(m_distButton, SIGNAL(clicked()), this, SLOT(onDistanceButton()));
