@@ -85,8 +85,6 @@ public:
 
 protected:
 
-    typedef core::runtime::ConfigurationElement::sptr Configuration;
-
     /**
      * @brief Install the layout.
      *
@@ -123,4 +121,4 @@ private:
     data::ptr<data::Image, data::Access::inout> m_image {this, "image"};
 };
 
-} // uiMeasurementQt
+} // namespace sight::module::ui::qt::metrics
