@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,8 +24,11 @@
 
 #include "modules/ui/qt/config.hpp"
 
+#include <data/ImageSeries.hpp>
 #include <data/Landmarks.hpp>
 #include <data/Matrix4.hpp>
+#include <data/mt/locked_ptr.hpp>
+#include <data/Point.hpp>
 #include <data/tools/PickingInfo.hpp>
 
 #include <ui/base/IEditor.hpp>
@@ -43,14 +46,90 @@
 namespace sight::module::ui::qt::metrics
 {
 
+struct LandmarksOrImageSeriesConstPtr
+{
+    data::Landmarks::csptr landmarks;
+    data::ImageSeries::csptr imageSeries;
+};
+
+struct LandmarksOrImageSeriesConstLock
+{
+    data::mt::locked_ptr<const data::Landmarks> landmarks;
+    data::mt::locked_ptr<const data::ImageSeries> imageSeries;
+
+    operator LandmarksOrImageSeriesConstPtr() const {
+        return {.landmarks = landmarks.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+};
+
+struct LandmarksOrImageSeriesPtr
+{
+    data::Landmarks::sptr landmarks;
+    data::ImageSeries::sptr imageSeries;
+
+    operator LandmarksOrImageSeriesConstPtr() const {
+        return {.landmarks = landmarks, .imageSeries = imageSeries};
+    }
+};
+
+struct LandmarksOrImageSeriesLock
+{
+    data::mt::locked_ptr<data::Landmarks> landmarks;
+    data::mt::locked_ptr<data::ImageSeries> imageSeries;
+
+    operator LandmarksOrImageSeriesPtr() const {
+        return {.landmarks = landmarks.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+
+    operator LandmarksOrImageSeriesConstPtr() const {
+        return {.landmarks = landmarks.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+};
+
+struct ImageOrImageSeriesConstPtr
+{
+    data::Image::csptr image;
+    data::ImageSeries::csptr imageSeries;
+};
+
+struct ImageOrImageSeriesConstLock
+{
+    data::mt::locked_ptr<const data::Image> image;
+    data::mt::locked_ptr<const data::ImageSeries> imageSeries;
+
+    operator ImageOrImageSeriesConstPtr() const {
+        return {.image = image.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+};
+
+struct ImageOrImageSeriesPtr
+{
+    data::Image::csptr image;
+    data::ImageSeries::sptr imageSeries;
+
+    operator ImageOrImageSeriesConstPtr() const {
+        return {.image = image, .imageSeries = imageSeries};
+    }
+};
+
+struct ImageOrImageSeriesLock
+{
+    data::mt::locked_ptr<const data::Image> image;
+    data::mt::locked_ptr<data::ImageSeries> imageSeries;
+
+    operator ImageOrImageSeriesPtr() const {
+        return {.image = image.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+
+    operator ImageOrImageSeriesConstPtr() const {
+        return {.image = image.get_shared(), .imageSeries = imageSeries.get_shared()};
+    }
+};
+
 /**
  * @brief This service defines a graphical editor to edit landmarks.
  *
  * @section Slots Slots
- * - @deprecated \b addPickedPoint(data::tools::PickingInfo): adds or removes picked landmark. call \b
- * pick(data::tools::PickingInfo) instead.
- *
- * - \b pick(data::tools::PickingInfo): adds or removes picked landmark.
  * - \b addPoint(std::string): adds a point to editor.
  * - \b modifyPoint(std::string, std::size_t): updates the editor when a point has moved.
  * - \b selectPoint(std::string, std::size_t): selects a point in the editor.
@@ -61,11 +140,15 @@ namespace sight::module::ui::qt::metrics
  * - \b modifyGroup(std::string): updates a group attributes.
  * - \b renameGroup(std::string, std::string): renames a group in the editor.
  *
+ * @section Signals Signals
+ * - \b groupSelected(std::string groupName): triggered when a new group is selected from the editor
+ *
  * @section XML XML Configuration
  *
  * @code{.xml}
         <service uid="..." type="sight::module::ui::qt::metrics::SLandmarks" >
            <inout key="landmarks" uid="..." />
+           <inout key="currentLandmark" uid="..." />
            <in key="matrix" uid="..." />
            <text>Use 'Ctrl+Left Click' to add new landmarks</text>
            <size>10.0</size>
@@ -80,6 +163,10 @@ namespace sight::module::ui::qt::metrics
  *
  *  @subsection In-Out In-Out
  * - \b landmarks [sight::data::Landmarks]: the landmarks structure on which this editor is working.
+ * - \b imageSeries [sight::data::ImageSeries]: the imageSeries structure on which this editor is working.
+ *  Either landmarks or imageSeries parameter must be set.
+ * - \b currentLandmark [sight::data::Point]: (optional) the coordinates of the currently selected landmark.
+ *  It is updated when a new landmark is created, or when a double click is made on an existing landmark.
  *
  * @subsection Configuration Configuration
  * - \b text (optional): text displayed at the top of this editor.
@@ -114,7 +201,7 @@ public:
      * @return A map of each proposed connection.
      *
      * Connect data::Landmarks::s_MODIFIED_SIG of s_LANDMARKS_INOUT to
-     * module::ui::qt::metrics::SLandmarks::s_UPDATE_SLOT
+     * module::ui::qt::metrics::SLandmarks::IService::slots::s_UPDATE
      * Connect data::Landmarks::s_POINT_ADDED_SIG of s_LANDMARKS_INOUT to
      * module::ui::qt::metrics::SLandmarks::s_ADD_POINT_SLOT
      * Connect data::Landmarks::s_POINT_MODIFIED_SIG of s_LANDMARKS_INOUT to
@@ -139,6 +226,8 @@ public:
     /// Signal send when double clicked on a landmark, send its world coordinates;
     MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_SEND_WORLD_COORD;
     typedef core::com::Signal<void (double, double, double)> world_coordinates_signal_t;
+    MODULE_UI_QT_API static const core::com::Signals::SignalKeyType s_GROUP_SELECTED;
+    using GroupSelectedSignal = core::com::Signal<void (std::string)>;
 
     /// Resets the interface content and create connections between widgets and this service.
     void updating() override;
@@ -173,6 +262,13 @@ public:
      */
     void onLandmarkDoubleClicked(QTreeWidgetItem* _item, int _column) const;
 
+    /**
+     * @brief Called when a new landmark is set as current one (double click or pick)
+     *
+     * @param world_coord coordinate of the current landmark
+     */
+    void updateCurrentLandmark(data::Landmarks::PointType& world_coord) const;
+
     /**
      * @brief Called when a group's point size is modified.
      * @param _newSize the new size of the group.
@@ -205,84 +301,60 @@ public:
     /// Called when the remove button is pressed, deletes selected group or point.
     void onRemoveSelection();
 
-    /**
-     * @brief SLOT: adds or removes a landmark from picking information.
-     *
-     * Interactions will take place while holding down the button. The following actions are available:
-     * - CTRL + left mouse click: adds a new landmarks in the current selected group or create a new group to add it.
-     * - CTRL + right mouse click: removes the landmark at the closest picking position.
-     *
-     * @deprecated Uses pick(data::tools::PickingInfo _info) instead.
-     *
-     * @param _pickingInfo Picking information.
-     */
-    void addPickedPoint(data::tools::PickingInfo _pickingInfo);
-
-    /**
-     * @brief SLOT: adds or removes a landmark from picking information.
-     *
-     * Interactions will take place while holding down the button. The following actions are available:
-     * - CTRL + left mouse click: adds a new landmarks in the current selected group or create a new group to add it.
-     * - CTRL + right mouse click: removes the landmark at the closest picking position.
-     *
-     * @param _info contains picking information.
-     */
-    void pick(data::tools::PickingInfo _info);
-
     /**
      * @brief SLOT: adds a point to the editor.
      * @param _groupName the group name where the point is added.
      */
-    void addPoint(std::string _groupName);
+    void addPoint(std::string _groupName) const;
 
     /**
      * @brief Slot: updates a point coordinates in the editor.
      * @param _groupName the group name of the updated point.
      * @param _index the index of the point to update.
      */
-    void modifyPoint(std::string _groupName, std::size_t _index);
+    void modifyPoint(std::string _groupName, std::size_t _index) const;
 
     /**
      * @brief SLOT: selects the point's corresponding item in the editor.
      * @param _groupName the group name of the selected point.
      * @param _index the index of the point to select.
      */
-    void selectPoint(std::string _groupName, std::size_t _index);
+    void selectPoint(std::string _groupName, std::size_t _index) const;
 
     /// Slot: deselects the currently selected item.
-    void deselectPoint(std::string, std::size_t);
+    void deselectPoint(std::string /*unused*/, std::size_t /*unused*/) const;
 
     /**
      * @brief Slot: adds a landmark group to the editor.
      * @param _name Name of the new group.
      */
-    void addGroup(std::string _name);
+    void addGroup(std::string _name) const;
 
     /**
      * @brief SLOT: removes a group from the editor.
      * @param _name The group name to remove.
      */
-    void removeGroup(std::string _name);
+    void removeGroup(std::string _name) const;
 
     /**
      * @brief SLOT: removes point from editor
      * @param _groupName the group name of the point the remove.
      * @param _index the index of the point to remove.
      */
-    void removePoint(std::string _groupName, std::size_t _index);
+    void removePoint(std::string _groupName, std::size_t _index) const;
 
     /**
      * @brief SLOT: renames a group in the editor.
      * @param _oldName the old name of the group.
      * @param _newName the new name of the group.
      */
-    void renameGroup(std::string _oldName, std::string _newName);
+    void renameGroup(std::string _oldName, std::string _newName) const;
 
     /**
      * @brief SLOT: updates a group properties in the editor.
      * @param _name The group name to updates.
      */
-    void modifyGroup(std::string _name);
+    void modifyGroup(std::string _name) const;
 
     /**
      * @brief Gets the name of the currently selected group.
@@ -324,6 +396,10 @@ public:
      */
     static void setColorButtonIcon(QPushButton* button, const QColor& _color);
 
+    LandmarksOrImageSeriesLock lock();
+
+    LandmarksOrImageSeriesConstLock constLock() const;
+
     /// Contains a tree representing landmarks sorted by their groups.
     QPointer<QTreeWidget> m_treeWidget;
 
@@ -358,22 +434,26 @@ public:
     bool m_advancedMode {false};
 
     /// Sets the default landmark size.
-    float m_defaultLandmarkSize {10.f};
+    float m_defaultLandmarkSize {10.F};
 
     /// Sets the default landmark opacity.
-    float m_defaultLandmarkOpacity {1.f};
+    float m_defaultLandmarkOpacity {1.F};
 
     /// Sets the text displayed at the top of this editor.
-    std::string m_text {"Use 'Ctrl+Left Click' to add new landmarks"};
+    std::string m_text;
 
-    static constexpr std::string_view s_LANDMARKS_INOUT = "landmarks";
-    static constexpr std::string_view s_MATRIX_IN       = "matrix";
+    static constexpr std::string_view s_LANDMARKS_INOUT        = "landmarks";
+    static constexpr std::string_view s_IMAGE_SERIES_INOUT     = "imageSeries";
+    static constexpr std::string_view s_MATRIX_IN              = "matrix";
+    static constexpr std::string_view s_CURRENT_LANDMARK_INOUT = "currentLandmark";
     data::ptr<data::Matrix4, sight::data::Access::in> m_matrix {this, s_MATRIX_IN, false, true};
     data::ptr<data::Landmarks, sight::data::Access::inout> m_landmarks {this, s_LANDMARKS_INOUT, true};
+    data::ptr<data::ImageSeries, sight::data::Access::inout> m_imageSeries {this, s_IMAGE_SERIES_INOUT, true};
+    data::ptr<data::Point, sight::data::Access::inout> m_currentLandmark {this, s_CURRENT_LANDMARK_INOUT, false, true};
 
     /// Used to generate random color
     std::uniform_real_distribution<float> m_distributor {0.0F, 1.0F};
-    std::mt19937 m_generator {static_cast<std::uint32_t>(std::time(nullptr))};
+    std::mt19937 m_generator {std::random_device {}()};
 };
 
-} // sight::module::ui::qt::metrics
+} // namespace sight::module::ui::qt::metrics
