@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -44,10 +44,7 @@ class QCheckBox;
 class QListWidgetItem;
 class QTreeWidgetItem;
 
-namespace sight::module::ui::qt
-{
-
-namespace model
+namespace sight::module::ui::qt::model
 {
 
 /**
@@ -123,9 +120,9 @@ protected:
      * @brief Proposals to connect service slots to associated object signals.
      * @return A map of each proposed connection.
      *
-     * Connect data::ModelSeries::s_MODIFIED_SIG of s_MODEL_SERIES_INOUT to s_UPDATE_SLOT.
-     * Connect data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG of s_MODEL_SERIES_INOUT to s_UPDATE_SLOT.
-     * Connect data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG of s_MODEL_SERIES_INOUT to s_UPDATE_SLOT.
+     * Connect data::ModelSeries::s_MODIFIED_SIG of s_MODEL_SERIES_INOUT to IService::slots::s_UPDATE.
+     * Connect data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG of s_MODEL_SERIES_INOUT to IService::slots::s_UPDATE.
+     * Connect data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG of s_MODEL_SERIES_INOUT to IService::slots::s_UPDATE.
      */
     KeyConnectionsMap getAutoConnections() const final;
 
@@ -164,16 +161,16 @@ private:
 private Q_SLOTS:
 
     /// Changes the current item, called when new current item is setted in m_organChoice.
-    void onCurrentItemChanged(QTreeWidgetItem* _current, QTreeWidgetItem*);
+    void onCurrentItemChanged(QTreeWidgetItem* _current, QTreeWidgetItem* /*unused*/);
 
     /// Changes the current item, called when new current item is setted in m_organChoice.
-    void onCurrentItemChanged(QTreeWidgetItem* _current, int _column);
+    static void onCurrentItemChanged(QTreeWidgetItem* _current, int _column);
 
     /// Shows reconstructions, called when m_showCheckBox is clicked.
     void onShowReconstructions(int state);
 
     /// Shows a reconstruction, called when new current item is setted in m_organChoice.
-    void onOrganChoiceVisibility(QTreeWidgetItem* _item, int);
+    static void onOrganChoiceVisibility(QTreeWidgetItem* _item, int /*unused*/);
 
     /// Shows reconstructions, called when m_checkAllButton is clicked.
     void onCheckAllCheckBox();
@@ -229,6 +226,4 @@ private:
     data::ptr<data::ModelSeries, data::Access::inout> m_modelSeries {this, "modelSeries", true};
 };
 
-} // namespace model.
-
-} // namespace sight::module::ui::qt.
+} // namespace sight::module::ui::qt::model
