@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,7 +26,6 @@
 #include <core/com/Slot.hxx>
 #include <core/tools/fwID.hpp>
 
-#include <data/helper/Composite.hpp>
 #include <data/helper/Field.hpp>
 #include <data/Material.hpp>
 #include <data/Mesh.hpp>
@@ -50,28 +49,23 @@
 
 #include <map>
 
-namespace sight::module::ui::qt
-{
-
-namespace model
+namespace sight::module::ui::qt::model
 {
 
 static const std::string s_MATRIX_FIELD_NAME = "TransformMatrix";
 
 SOrganTransformation::SOrganTransformation() noexcept :
-    m_saveButton(0),
-    m_loadButton(0),
-    m_resetButton(0),
-    m_reconstructionListBox(0),
-    m_saveCount(0)
+    m_saveButton(nullptr),
+    m_loadButton(nullptr),
+    m_resetButton(nullptr),
+    m_reconstructionListBox(nullptr)
 {
 }
 
 //------------------------------------------------------------------------------
 
-SOrganTransformation::~SOrganTransformation() noexcept
-{
-}
+SOrganTransformation::~SOrganTransformation() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -87,12 +81,12 @@ void SOrganTransformation::starting()
     this->create();
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
 
-    QGroupBox* groupBox = new QGroupBox(tr("Organs"));
+    auto* groupBox = new QGroupBox(tr("Organs"));
     layout->addWidget(groupBox);
 
-    QVBoxLayout* layoutGroupBox = new QVBoxLayout();
+    auto* layoutGroupBox = new QVBoxLayout();
     groupBox->setLayout(layoutGroupBox);
 
     m_selectAllCheckBox     = new QCheckBox(tr("Select All"));
@@ -153,7 +147,7 @@ void SOrganTransformation::updating()
 
 //------------------------------------------------------------------------------
 
-void SOrganTransformation::info(std::ostream& sstream)
+void SOrganTransformation::info(std::ostream& /*sstream*/)
 {
 }
 
@@ -177,15 +171,15 @@ void SOrganTransformation::refresh()
     {
         const auto pComposite = m_composite.lock();
 
-        for(data::Reconstruction::sptr rec : series->getReconstructionDB())
+        for(const data::Reconstruction::sptr& rec : series->getReconstructionDB())
         {
             m_reconstructionMap[rec->getOrganName()] = rec;
         }
 
-        for(ReconstructionMapType::iterator it = m_reconstructionMap.begin() ; it != m_reconstructionMap.end() ; ++it)
+        for(auto& it : m_reconstructionMap)
         {
-            std::string organName = it->first;
-            QListWidgetItem* item = new QListWidgetItem(QString::fromStdString(organName), m_reconstructionListBox);
+            std::string organName = it.first;
+            auto* item            = new QListWidgetItem(QString::fromStdString(organName), m_reconstructionListBox);
             if(pComposite && pComposite->find(organName) != pComposite->end())
             {
                 item->setCheckState(Qt::Checked);
@@ -219,27 +213,15 @@ void SOrganTransformation::onReconstructionCheck(QListWidgetItem* currentItem)
         data::Reconstruction::sptr pReconstruction = m_reconstructionMap[item_name];
         data::Mesh::sptr pMesh                     = pReconstruction->getMesh();
 
-        data::helper::Composite aCompositeHelper(pComposite.get_shared());
+        const auto scoped_emitter = pComposite->scoped_emit();
         if((currentItem->checkState()) == Qt::Checked)
         {
-            if(pComposite->find(item_name) == pComposite->end())
-            {
-                aCompositeHelper.add(item_name, pMesh);
-            }
-            else
-            {
-                aCompositeHelper.swap(item_name, pMesh);
-            }
+            pComposite->insert_or_assign(item_name, pMesh);
         }
         else
         {
-            if(pComposite->find(item_name) != pComposite->end())
-            {
-                aCompositeHelper.remove(item_name);
-            }
+            pComposite->erase(item_name);
         }
-
-        aCompositeHelper.notify();
     }
 }
 
@@ -250,7 +232,7 @@ void SOrganTransformation::onResetClick()
     const auto series = m_modelSeries.lock();
 
     //search the corresponding triangular mesh
-    for(data::Reconstruction::sptr rec : series->getReconstructionDB())
+    for(const data::Reconstruction::sptr& rec : series->getReconstructionDB())
     {
         data::Mesh::sptr pTmpTrMesh = rec->getMesh();
 
@@ -274,7 +256,7 @@ void SOrganTransformation::onSaveClick()
 
     if(!series->getReconstructionDB().empty())
     {
-        for(data::Reconstruction::sptr rec : series->getReconstructionDB())
+        for(const data::Reconstruction::sptr& rec : series->getReconstructionDB())
         {
             data::Mesh::sptr pTmpTrMesh = rec->getMesh();
             data::Matrix4::sptr pTmpMat =
@@ -306,7 +288,7 @@ void SOrganTransformation::onLoadClick()
         const auto series = m_modelSeries.lock();
 
         //search the corresponding triangular mesh
-        for(data::Reconstruction::sptr rec : series->getReconstructionDB())
+        for(const data::Reconstruction::sptr& rec : series->getReconstructionDB())
         {
             data::Mesh::sptr pTmpTrMesh = rec->getMesh();
             if(matMap.find(pTmpTrMesh->getID()) != matMap.end())
@@ -327,8 +309,8 @@ void SOrganTransformation::onLoadClick()
 
 void SOrganTransformation::onSelectAllChanged(int state)
 {
-    const auto pComposite = m_composite.lock();
-    data::helper::Composite compositeHelper(pComposite.get_shared());
+    const auto pComposite     = m_composite.lock();
+    const auto scoped_emitter = pComposite->scoped_emit();
 
     if(state == Qt::Checked)
     {
@@ -336,12 +318,9 @@ void SOrganTransformation::onSelectAllChanged(int state)
 
         const auto series = m_modelSeries.lock();
 
-        for(data::Reconstruction::sptr rec : series->getReconstructionDB())
+        for(const data::Reconstruction::sptr& rec : series->getReconstructionDB())
         {
-            if(pComposite->find(rec->getOrganName()) == pComposite->end())
-            {
-                compositeHelper.add(rec->getOrganName(), rec->getMesh());
-            }
+            pComposite->insert({rec->getOrganName(), rec->getMesh()});
         }
     }
     else if(state == Qt::Unchecked)
@@ -353,14 +332,12 @@ void SOrganTransformation::onSelectAllChanged(int state)
         {
             if(item->checkState() == Qt::Unchecked)
             {
-                compositeHelper.remove(item->text().toStdString());
+                pComposite->erase(item->text().toStdString());
             }
         }
 
         this->refresh();
     }
-
-    compositeHelper.notify();
 }
 
 //------------------------------------------------------------------------------
@@ -387,19 +364,17 @@ void SOrganTransformation::addMeshTransform()
 service::IService::KeyConnectionsMap SOrganTransformation::getAutoConnections() const
 {
     KeyConnectionsMap connections;
-    connections.push(s_MODEL_SERIES, data::ModelSeries::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_MODEL_SERIES, data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG, s_UPDATE_SLOT);
-    connections.push(s_MODEL_SERIES, data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG, s_UPDATE_SLOT);
-    connections.push(s_COMPOSITE, data::Composite::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_COMPOSITE, data::Composite::s_ADDED_OBJECTS_SIG, s_UPDATE_SLOT);
-    connections.push(s_COMPOSITE, data::Composite::s_CHANGED_OBJECTS_SIG, s_UPDATE_SLOT);
-    connections.push(s_COMPOSITE, data::Composite::s_REMOVED_OBJECTS_SIG, s_UPDATE_SLOT);
+    connections.push(s_MODEL_SERIES, data::ModelSeries::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_MODEL_SERIES, data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_MODEL_SERIES, data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_COMPOSITE, data::Composite::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_COMPOSITE, data::Composite::s_ADDED_OBJECTS_SIG, IService::slots::s_UPDATE);
+    connections.push(s_COMPOSITE, data::Composite::s_CHANGED_OBJECTS_SIG, IService::slots::s_UPDATE);
+    connections.push(s_COMPOSITE, data::Composite::s_REMOVED_OBJECTS_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
 
 //------------------------------------------------------------------------------
 
-} // namespace model
-
-} // namespace sight::module::ui::qt
+} // namespace sight::module::ui::qt::model
