@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2021 IRCAD France
+ * Copyright (C) 2009-2022 IRCAD France
  * Copyright (C) 2012-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,10 +24,7 @@
 
 #include <cppunit/extensions/HelperMacros.h>
 
-namespace sight::module::ui::qt
-{
-
-namespace ut
+namespace sight::module::ui::qt::ut
 {
 
 /**
@@ -42,12 +39,10 @@ CPPUNIT_TEST_SUITE_END();
 public:
 
     // interface
-    void setUp();
-    void tearDown();
+    void setUp() override;
+    void tearDown() override;
 
-    void testDefaultFrame();
+    static void testDefaultFrame();
 };
 
-} //namespace ut
-
-} //namespace sight::module::ui::qt
+} // namespace sight::module::ui::qt::ut
