@@ -28,7 +28,7 @@
 #include <core/tools/Failed.hpp>
 
 #include <data/Camera.hpp>
-#include <data/CameraSeries.hpp>
+#include <data/CameraSet.hpp>
 
 #include <ui/base/IEditor.hpp>
 
@@ -36,10 +36,7 @@
 #include <QObject>
 #include <QPointer>
 
-namespace sight::module::ui::qt
-{
-
-namespace video
+namespace sight::module::ui::qt::video
 {
 
 /**
@@ -74,17 +71,18 @@ namespace video
  *
  * @code{.xml}
     <service uid="..." type="sight::module::ui::qt::video::SCamera" >
-        <inout key="cameraSeries" uid="..."/>
+        <inout key="cameraSet" uid="..."/>
         <createCameraNumber>2</createCameraNumber>
         <videoSupport>true</videoSupport>
         <useAbsolutePath>false</useAbsolutePath>
         <label>Video source: </label>
+        <resolution>min/max/preferences/prompt/640x480</resolution>
     </service>
    @endcode
  *
  * @subsection In-Out In-Out
  * - \b camera [sight::data::Camera]: camera data.
- * - \b cameraSeries [sight::data::CameraSeries]: camera series thus containing several camera.
+ * - \b cameraSet [sight::data::CameraSet]: camera series thus containing several camera.
  *
  * @subsection Configuration Configuration
  * - \b videoSupport (optional, default="false"): if we can open a video file in addition with cameras.
@@ -93,7 +91,16 @@ namespace video
  * - \b createCameraNumber (optional, default="0"): number of cameras to create. If the parameter is set and the
  * camera series already contains camera data, an assertion will be raised.
  * - \b label (optional, default="Video source: "): label of the selector.
+ * - \b resolution (optional, default="preferences"): Camera resolution. If 'preferences' is set, the camera resolution
+ * will
+ * be extracted from the preferences, otherwise, `min`, `max` or a specific value (eg: 640x480) are computed from the
+ * camera's supported resolutions. When `prompt` option is set, the camera selection dialog will be always displayed.
+ *
+ * @section remarks remarks
+ * In order to launch directly the video after selecting and configuring the device, remember to connect the
+ *`configuredDevice()` signal with your grabber's `startCamera` slot.
  */
+
 class MODULE_UI_QT_CLASS_API SCamera final : public QObject,
                                              public sight::ui::base::IEditor
 {
@@ -107,7 +114,10 @@ public:
     MODULE_UI_QT_API SCamera();
 
     /// Destroys the service.
-    MODULE_UI_QT_API virtual ~SCamera() noexcept;
+    MODULE_UI_QT_API ~SCamera() noexcept override = default;
+
+    // Key saved in the preference file
+    static const std::string s_RESOLUTION_PREF_KEY;
 
 protected Q_SLOTS:
 
@@ -117,22 +127,31 @@ protected Q_SLOTS:
      */
     void onApply(int _index);
 
+    /**
+     * @brief Calls when user select another device.
+     * @param _index the index of the selected device.
+     */
+    void onActivated(int _index);
+
+    /// Allows setting the camera resolution preference.
+    void setPreference();
+
 private:
 
     /// Type of the 'configured' signal.
     typedef core::com::Signal<void ()> ConfiguredSignalType;
 
     /// Configures the service.
-    virtual void configuring() final;
+    void configuring() final;
 
     /// Installs the layout.
-    virtual void starting() final;
+    void starting() final;
 
     /// Destroys the layout.
-    virtual void stopping() final;
+    void stopping() final;
 
     /// Does nothing.
-    virtual void updating() final;
+    void updating() final;
 
     /// Calls when user select a file.
     void onChooseFile();
@@ -158,19 +177,27 @@ private:
     // Sets the file path as absolute ones
     bool m_useAbsolutePath {false};
 
-    /// Signal emitted when the cameraSeries has been configured.
+    /// Signal emitted when the cameraSet has been configured.
     ConfiguredSignalType::sptr m_sigConfiguredCameras;
 
     /// Label of the selector.
     std::string m_label {"Video source: "};
 
-    static constexpr std::string_view s_CAMERA        = "camera";
-    static constexpr std::string_view s_CAMERA_SERIES = "cameraSeries";
+    /// Requested resolution in xml configuration of the service
+    std::string m_resolution;
+
+    /// Value extracted from the preferences
+    std::string m_cameraResolutionPreference;
+
+    bool m_preferenceMode {false};
+
+    static constexpr std::string_view s_CAMERA     = "camera";
+    static constexpr std::string_view s_CAMERA_SET = "cameraSet";
 
     data::ptr<data::Camera, data::Access::inout> m_camera {this, s_CAMERA, false, true};
-    data::ptr<data::CameraSeries, data::Access::inout> m_cameraSeries {this, s_CAMERA_SERIES, false, true};
+    data::ptr<data::CameraSet, data::Access::inout> m_camera_set {this, s_CAMERA_SET, false, true};
+
+    int oldIndex {};
 };
 
-} // video
-
-} // sight::module::ui::qt
+} // namespace sight::module::ui::qt::video
