@@ -30,10 +30,7 @@
 
 #include <QVideoFrame>
 
-namespace sight::module::ui::qt
-{
-
-namespace video
+namespace sight::module::ui::qt::video
 {
 
 //-----------------------------------------------------------------------------
@@ -41,6 +38,4 @@ namespace video
 typedef boost::bimaps::bimap<QVideoFrame::PixelFormat, data::Camera::PixelFormat> PixelFormatTranslatorType;
 extern MODULE_UI_QT_API PixelFormatTranslatorType pixelFormatTranslator;
 
-} // video
-
-} // sight::module::ui::qt
+} // namespace sight::module::ui::qt::video
