@@ -23,14 +23,11 @@
 #include "modules/ui/qt/viz/SnapshotEditor.hpp"
 
 #include <core/base.hpp>
-#include <core/com/Signal.hpp>
 #include <core/com/Signal.hxx>
 #include <core/com/Signals.hpp>
 #include <core/location/SingleFile.hpp>
 #include <core/location/SingleFolder.hpp>
-#include <core/runtime/operations.hpp>
-
-#include <service/macros.hpp>
+#include <core/runtime/path.hpp>
 
 #include <ui/base/dialog/LocationDialog.hpp>
 #include <ui/base/dialog/MessageDialog.hpp>
@@ -42,8 +39,6 @@
 #include <QString>
 #include <QWidget>
 
-#include <filesystem>
-
 namespace sight::module::ui::qt::viz
 {
 
@@ -60,9 +55,8 @@ SnapshotEditor::SnapshotEditor() noexcept
 
 //------------------------------------------------------------------------------
 
-SnapshotEditor::~SnapshotEditor() noexcept
-{
-}
+SnapshotEditor::~SnapshotEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -77,7 +71,7 @@ void SnapshotEditor::starting()
     m_snapButton = new QPushButton(icon, "");
     m_snapButton->setToolTip(QObject::tr("Snapshot"));
 
-    QHBoxLayout* h_layout = new QHBoxLayout();
+    auto* h_layout = new QHBoxLayout();
     h_layout->addWidget(m_snapButton);
     h_layout->setContentsMargins(0, 0, 0, 0);
 
@@ -108,7 +102,7 @@ void SnapshotEditor::updating()
 
 //------------------------------------------------------------------------------
 
-void SnapshotEditor::info(std::ostream& _sstream)
+void SnapshotEditor::info(std::ostream& /*_sstream*/)
 {
 }
 
@@ -123,7 +117,7 @@ void SnapshotEditor::onSnapButton()
     SIGHT_ASSERT("container not instanced", container);
     if(container->isVisible())
     {
-        std::string filename = this->requestFileName();
+        std::string filename = sight::module::ui::qt::viz::SnapshotEditor::requestFileName();
 
         if(!filename.empty())
         {
@@ -147,7 +141,7 @@ void SnapshotEditor::onSnapButton()
 std::string SnapshotEditor::requestFileName()
 {
     static auto defaultDirectory = std::make_shared<core::location::SingleFolder>();
-    std::string fileName         = "";
+    std::string fileName;
 
     sight::ui::base::dialog::LocationDialog dialogFile;
     dialogFile.setTitle("Save snapshot as");
