@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2018 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,9 +22,6 @@
 
 #include "SCompositorParameterEditor.hpp"
 
-#include <viz/scene3d/IAdaptor.hpp>
-#include <viz/scene3d/SRender.hpp>
-
 #include <core/com/Slots.hxx>
 
 #include <data/Boolean.hpp>
@@ -37,6 +34,9 @@
 #include <ui/base/GuiRegistry.hpp>
 #include <ui/qt/container/QtContainer.hpp>
 
+#include <viz/scene3d/IAdaptor.hpp>
+#include <viz/scene3d/SRender.hpp>
+
 #include <modules/ui/viz/helper/ParameterEditor.hpp>
 
 #include <QWidget>
@@ -54,9 +54,8 @@ SCompositorParameterEditor::SCompositorParameterEditor() noexcept
 
 //------------------------------------------------------------------------------
 
-SCompositorParameterEditor::~SCompositorParameterEditor() noexcept
-{
-}
+SCompositorParameterEditor::~SCompositorParameterEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -64,7 +63,7 @@ void SCompositorParameterEditor::configuring()
 {
     this->initialize();
 
-    auto config = this->getConfigTree();
+    auto config = this->getConfiguration();
 
     m_layerID = config.get<std::string>("layer.<xmlattr>.id", "");
 }
@@ -123,7 +122,7 @@ void SCompositorParameterEditor::updateCompositor(
             {
                 /// Filter object types
                 const auto shaderObj =
-                    adaptor->getInOut<data::Object>(sight::viz::scene3d::IParameter::s_PARAMETER_INOUT).lock();
+                    adaptor->getInOut(sight::viz::scene3d::IParameter::s_PARAMETER_INOUT).lock();
                 const auto& objType = shaderObj->getClassname();
 
                 if(objType == "sight::data::Boolean" || objType == "sight::data::Float"
@@ -144,7 +143,7 @@ void SCompositorParameterEditor::updateCompositor(
         auto qtContainer   = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
         QWidget* container = qtContainer->getQtContainer();
 
-        QWidget* p2 = new QWidget(container);
+        auto* p2 = new QWidget(container);
         m_editorInfo.editorPanel = sight::ui::qt::container::QtContainer::New();
         m_editorInfo.editorPanel->setQtContainer(p2);
 
@@ -199,7 +198,7 @@ void SCompositorParameterEditor::clear()
 
         sight::ui::base::GuiRegistry::unregisterSIDContainer(m_editorInfo.uuid);
 
-        service::OSR::unregisterService(objService);
+        service::unregisterService(objService);
 
         m_sizer->removeWidget(m_editorInfo.editorPanel->getQtContainer());
         m_editorInfo.editorPanel->destroyContainer();
