@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,7 +27,7 @@
 #include <data/Composite.hpp>
 
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/qt/container/QtContainer.hpp>
 
@@ -58,9 +58,8 @@ SCompositorSelector::SCompositorSelector() noexcept
 
 //------------------------------------------------------------------------------
 
-SCompositorSelector::~SCompositorSelector() noexcept
-{
-}
+SCompositorSelector::~SCompositorSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -75,7 +74,7 @@ void SCompositorSelector::starting()
     m_layersBox       = new QComboBox();
     m_compositorChain = new QListWidget();
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     layout->addWidget(m_layersBox);
     layout->addWidget(m_compositorChain);
 
@@ -134,7 +133,7 @@ void SCompositorSelector::onSelectedLayerItem(int index)
 
         // We need the ogre's viewport in order to add the compositors,
         // this is why we have to check the viewport's existence
-        if(layer->getViewport())
+        if(layer->getViewport() != nullptr)
         {
             // Fill the list widget
             this->updateCompositorList();
@@ -178,17 +177,16 @@ void SCompositorSelector::refreshRenderers()
     m_layersBox->clear();
 
     // Fill layer box with all enabled layers
-    service::registry::ObjectService::ServiceVectorType renderers =
-        service::OSR::getServices("sight::viz::scene3d::SRender");
+    const auto renderers = service::getServices("sight::viz::scene3d::SRender");
 
-    for(auto srv : renderers)
+    for(const auto& srv : renderers)
     {
         auto render = sight::viz::scene3d::SRender::dynamicCast(srv);
 
         for(auto& layerMap : render->getLayers())
         {
-            const std::string id       = layerMap.first;
-            const std::string renderID = render->getID();
+            const std::string id = layerMap.first;
+            std::string renderID = render->getID();
             m_layersBox->addItem(QString::fromStdString(renderID + " : " + id));
             m_layers.push_back(layerMap.second);
 
@@ -228,7 +226,7 @@ void SCompositorSelector::updateCompositorList()
                 QString compositorName = compositor.get()->getName().c_str();
                 layer->addAvailableCompositor(compositorName.toStdString());
 
-                QListWidgetItem* newCompositor = new QListWidgetItem(compositorName, m_compositorChain);
+                auto* newCompositor = new QListWidgetItem(compositorName, m_compositorChain);
                 newCompositor->setFlags(newCompositor->flags() | Qt::ItemIsUserCheckable);
                 newCompositor->setCheckState(Qt::Unchecked);
             }
@@ -256,10 +254,10 @@ void SCompositorSelector::checkEnabledCompositors()
                 auto layerCompositor = std::find_if(
                     m_layerCompositorChain.begin(),
                     m_layerCompositorChain.end(),
-                    sight::viz::scene3d::compositor::ChainManager::FindCompositorByName(
-                        currentCompositorName
-                    )
-                );
+                    [&currentCompositorName](const auto& _compositor)
+                    {
+                        return _compositor.first == currentCompositorName;
+                    });
 
                 if(layerCompositor != m_layerCompositorChain.end())
                 {
@@ -292,10 +290,10 @@ bool SCompositorSelector::isEnabledCompositor(const std::string& compositorName)
     auto layerCompositor = std::find_if(
         m_layerCompositorChain.begin(),
         m_layerCompositorChain.end(),
-        sight::viz::scene3d::compositor::ChainManager::FindCompositorByName(
-            compositorName
-        )
-    );
+        [&compositorName](const auto& _compositor)
+        {
+            return _compositor.first == compositorName;
+        });
 
     if(layerCompositor != m_layerCompositorChain.end())
     {
