@@ -62,9 +62,8 @@ SMaterialSelector::SMaterialSelector() noexcept
 
 //------------------------------------------------------------------------------
 
-SMaterialSelector::~SMaterialSelector() noexcept
-{
-}
+SMaterialSelector::~SMaterialSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -72,13 +71,17 @@ void SMaterialSelector::starting()
 {
     this->create();
 
+    const QString serviceID = QString::fromStdString(getID().substr(getID().find_last_of('_') + 1));
+
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
+    qtContainer->getQtContainer()->setObjectName(serviceID);
 
     // Selection
-    QLabel* currentMaterial = new QLabel();
+    auto* currentMaterial = new QLabel();
     currentMaterial->setText("Current material : ");
 
     m_materialBox = new QComboBox();
+    m_materialBox->setObjectName(serviceID + "/materialBox");
 
     std::pair<std::string, std::string> elt;
     Ogre::ResourceManager::ResourceMapIterator iter = Ogre::MaterialManager::getSingleton().getResourceIterator();
@@ -93,14 +96,15 @@ void SMaterialSelector::starting()
 
     m_materialBox->setCurrentIndex(0);
 
-    QHBoxLayout* labelLayout = new QHBoxLayout();
+    auto* labelLayout = new QHBoxLayout();
     labelLayout->addWidget(currentMaterial);
     labelLayout->addWidget(m_materialBox);
 
     // Reload
     m_reloadButton = new QPushButton("Reload");
+    m_reloadButton->setObjectName(serviceID + "/" + m_reloadButton->text());
 
-    QVBoxLayout* layout = new QVBoxLayout();
+    auto* layout = new QVBoxLayout();
     layout->addLayout(labelLayout);
     layout->addWidget(m_reloadButton);
 
@@ -188,13 +192,13 @@ void SMaterialSelector::onReloadMaterial()
 
     const Ogre::Material::Techniques& techniques = material->getTechniques();
 
-    for(const auto tech : techniques)
+    for(auto* const tech : techniques)
     {
         SIGHT_ASSERT("Technique is not set", tech);
 
         const Ogre::Technique::Passes& passes = tech->getPasses();
 
-        for(const auto pass : passes)
+        for(auto* const pass : passes)
         {
             SIGHT_ASSERT("No pass found", pass);
 
