@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,8 +22,6 @@
 
 #include "SShaderParameterEditor.hpp"
 
-#include <viz/scene3d/IAdaptor.hpp>
-
 #include <data/Material.hpp>
 #include <data/Mesh.hpp>
 #include <data/Reconstruction.hpp>
@@ -32,6 +30,8 @@
 
 #include <ui/base/GuiRegistry.hpp>
 
+#include <viz/scene3d/IAdaptor.hpp>
+
 #include <modules/ui/viz/helper/ParameterEditor.hpp>
 
 #include <QWidget>
@@ -40,15 +40,13 @@ namespace sight::module::ui::viz
 {
 
 //------------------------------------------------------------------------------
-SShaderParameterEditor::SShaderParameterEditor() noexcept
-{
-}
+SShaderParameterEditor::SShaderParameterEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SShaderParameterEditor::~SShaderParameterEditor() noexcept
-{
-}
+SShaderParameterEditor::~SShaderParameterEditor() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -57,12 +55,15 @@ void SShaderParameterEditor::starting()
     {
         const auto rec                = m_reconstruction.lock();
         data::Material::sptr material = rec->getMaterial();
-        m_connections.connect(material, data::Material::s_MODIFIED_SIG, this->getSptr(), s_UPDATE_SLOT);
+        m_connections.connect(material, data::Material::s_MODIFIED_SIG, this->getSptr(), IService::slots::s_UPDATE);
     }
 
     this->create();
 
+    const QString serviceID = QString::fromStdString(getID().substr(getID().find_last_of('_') + 1));
+
     auto qtContainer = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
+    qtContainer->getQtContainer()->setObjectName(serviceID);
 
     m_sizer = new QVBoxLayout();
     m_sizer->setContentsMargins(0, 0, 0, 0);
@@ -110,7 +111,7 @@ void SShaderParameterEditor::clear()
 
         sight::ui::base::GuiRegistry::unregisterSIDContainer(m_editorInfo.uuid);
 
-        service::OSR::unregisterService(objService);
+        service::unregisterService(objService);
 
         m_sizer->removeWidget(m_editorInfo.editorPanel->getQtContainer());
         m_editorInfo.editorPanel->destroyContainer();
@@ -125,9 +126,7 @@ void SShaderParameterEditor::updateGuiInfo()
     /// Getting all Material adaptors
     const auto reconstruction = m_reconstruction.lock();
 
-    service::registry::ObjectService::ServiceVectorType srvVec = service::OSR::getServices(
-        "sight::module::viz::scene3d::adaptor::SMaterial"
-    );
+    const auto srvVec = service::getServices("sight::module::viz::scene3d::adaptor::SMaterial");
 
     /// Stop if no Material adaptors have been find
     if(srvVec.empty())
@@ -139,9 +138,9 @@ void SShaderParameterEditor::updateGuiInfo()
     /// Try to find the material adaptor working with the same data::Material
     /// as the one contained by the current reconstruction
     sight::viz::scene3d::IAdaptor::sptr matService;
-    for(auto srv : srvVec)
+    for(const auto& srv : srvVec)
     {
-        if(srv->getInOut<data::Object>("material").lock()->getID() == reconstruction->getMaterial()->getID())
+        if(srv->getInOut("material").lock()->getID() == reconstruction->getMaterial()->getID())
         {
             matService = sight::viz::scene3d::IAdaptor::dynamicCast(srv);
             break;
@@ -160,7 +159,7 @@ void SShaderParameterEditor::updateGuiInfo()
         {
             /// Filter object types
             const auto shaderObj =
-                paramSrv->getInOut<data::Object>(sight::viz::scene3d::IParameter::s_PARAMETER_INOUT).lock();
+                paramSrv->getInOut(sight::viz::scene3d::IParameter::s_PARAMETER_INOUT).lock();
             const ObjectClassnameType objType = shaderObj->getClassname();
 
             if(objType == "sight::data::Boolean" || objType == "sight::data::Float"
@@ -181,7 +180,7 @@ void SShaderParameterEditor::updateGuiInfo()
     auto qtContainer   = sight::ui::qt::container::QtContainer::dynamicCast(this->getContainer());
     QWidget* container = qtContainer->getQtContainer();
 
-    QWidget* p2 = new QWidget(container);
+    auto* p2 = new QWidget(container);
     m_editorInfo.editorPanel = sight::ui::qt::container::QtContainer::New();
     m_editorInfo.editorPanel->setQtContainer(p2);
 
@@ -196,7 +195,7 @@ void SShaderParameterEditor::updateGuiInfo()
     service::IService::ConfigType editorConfig;
 
     // Get all ShaderParameter subservices from the corresponding Material adaptor
-    for(auto wAdaptor : matService->getRegisteredServices())
+    for(const auto& wAdaptor : matService->getRegisteredServices())
     {
         const auto adaptor = wAdaptor.lock();
         if(adaptor->getClassname() == "sight::module::viz::scene3d::adaptor::SShaderParameter")
