@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -27,7 +27,7 @@
 #include <data/Composite.hpp>
 
 #include <service/macros.hpp>
-#include <service/registry/ObjectService.hpp>
+#include <service/registry.hpp>
 
 #include <ui/qt/container/QtContainer.hpp>
 
@@ -45,15 +45,13 @@ namespace sight::module::ui::viz
 
 //------------------------------------------------------------------------------
 
-SStereoSelector::SStereoSelector() noexcept
-{
-}
+SStereoSelector::SStereoSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SStereoSelector::~SStereoSelector() noexcept
-{
-}
+SStereoSelector::~SStereoSelector() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -68,7 +66,7 @@ void SStereoSelector::starting()
     m_layersBox = new QComboBox();
     m_modeBox   = new QComboBox();
 
-    QHBoxLayout* layout = new QHBoxLayout();
+    auto* layout = new QHBoxLayout();
     layout->addWidget(m_layersBox);
     layout->addWidget(m_modeBox);
 
@@ -137,10 +135,9 @@ void SStereoSelector::refreshRenderers()
     m_layersBox->clear();
 
     // Fill layer box with all enabled layers
-    service::registry::ObjectService::ServiceVectorType renderers =
-        service::OSR::getServices("sight::viz::scene3d::SRender");
+    const auto renderers = service::getServices("sight::viz::scene3d::SRender");
 
-    for(auto srv : renderers)
+    for(const auto& srv : renderers)
     {
         auto render = sight::viz::scene3d::SRender::dynamicCast(srv);
 
