@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2019 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -32,16 +32,15 @@ static const core::com::Signals::SignalKeyType s_STEREO_ACTIVE_SIG = "stereoActi
 
 //------------------------------------------------------------------------------
 
-SStereoToggler::SStereoToggler()
+SStereoToggler::SStereoToggler() :
+    m_stereoActiveSig(newSignal<StereoActiveSigType>(s_STEREO_ACTIVE_SIG))
 {
-    m_stereoActiveSig = newSignal<StereoActiveSigType>(s_STEREO_ACTIVE_SIG);
 }
 
 //------------------------------------------------------------------------------
 
 SStereoToggler::~SStereoToggler()
-{
-}
+= default;
 
 //------------------------------------------------------------------------------
 
@@ -49,7 +48,7 @@ void SStereoToggler::configuring()
 {
     this->initialize();
 
-    const ConfigType config = this->getConfigTree().get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration().get_child("config.<xmlattr>");
 
     m_layerId = config.get<std::string>("layer");
     SIGHT_ASSERT("Empty layer ID.", !m_layerId.empty());
@@ -87,13 +86,12 @@ void SStereoToggler::updating()
 {
     if(this->confirmAction())
     {
-        service::registry::ObjectService::ServiceVectorType renderers =
-            service::OSR::getServices("sight::viz::scene3d::SRender");
+        const auto renderers = service::getServices("sight::viz::scene3d::SRender");
 
-        const bool enableStereo = this->getIsActive() && this->getIsExecutable();
+        const bool enableStereo = this->checked() && this->enabled();
         const auto stereoMode   = enableStereo ? m_stereoMode : StereoModeType::NONE;
 
-        for(auto srv : renderers)
+        for(const auto& srv : renderers)
         {
             auto renderSrv = sight::viz::scene3d::SRender::dynamicCast(srv);
             auto layerMap  = renderSrv->getLayers();
@@ -125,4 +123,4 @@ void SStereoToggler::stopping()
 
 //------------------------------------------------------------------------------
 
-} // uiVisuOgre
+} // namespace sight::module::ui::viz
