@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2022 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,7 +22,7 @@
 
 #include "modules/viz/sample/Plugin.hpp"
 
-#include <core/runtime/operations.hpp>
+#include <core/runtime/runtime.hpp>
 
 namespace sight::module::viz::sample
 {
@@ -33,9 +33,8 @@ SIGHT_REGISTER_PLUGIN("sight::module::viz::sample::Plugin");
 
 //------------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
