@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2021 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,15 +34,13 @@ static const std::string s_IMAGE_INPUT = "image";
 
 //------------------------------------------------------------------------------
 
-SImage::SImage() noexcept
-{
-}
+SImage::SImage() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-SImage::~SImage() noexcept
-{
-}
+SImage::~SImage() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -68,14 +66,15 @@ void SImage::starting()
     renderConfig.put("scene.background.<xmlattr>.color", "#36393E");
     renderConfig.put("scene.layer.<xmlattr>.id", "default");
     renderConfig.put("scene.layer.<xmlattr>.order", "1");
+    renderConfig.put("scene.layer.<xmlattr>.transparency", "");
 
     service::IService::ConfigType interactorCfg;
     interactorCfg.put("<xmlattr>.uid", this->getID() + "interactorAdaptor");
     service::IService::ConfigType negatoCfg;
     negatoCfg.put("<xmlattr>.uid", this->getID() + "negato3DAdaptor");
 
-    renderConfig.add_child("scene.adaptor", interactorCfg);
-    renderConfig.add_child("scene.adaptor", negatoCfg);
+    renderConfig.add_child("scene.layer.adaptor", interactorCfg);
+    renderConfig.add_child("scene.layer.adaptor", negatoCfg);
 
     m_renderSrv = service::add("sight::viz::scene3d::SRender");
     m_renderSrv->setConfiguration(renderConfig);
@@ -83,26 +82,26 @@ void SImage::starting()
 
     m_renderSrv->configure();
 
-    service::IService::ConfigType interactorConfig;
-    interactorConfig.put("config.<xmlattr>.layer", "default");
     m_interactorSrv = service::add("sight::module::viz::scene3d::adaptor::STrackballCamera");
-    m_interactorSrv->setConfiguration(interactorConfig);
     m_interactorSrv->setID(this->getID() + "interactorAdaptor");
     m_interactorSrv->configure();
 
+    // Create default transfer function
+    m_tf = data::TransferFunction::createDefaultTF();
+
     auto image = m_image.lock();
     service::IService::ConfigType negatoConfig;
-    negatoConfig.put("config.<xmlattr>.layer", "default");
     negatoConfig.put("config.<xmlattr>.interactive", "true");
     m_negatoSrv = service::add("sight::module::viz::scene3d::adaptor::SNegato3D");
     m_negatoSrv->setConfiguration(negatoConfig);
-    m_negatoSrv->setInOut(std::const_pointer_cast<data::Image>(image->getConstSptr()), "image", true);
+    m_negatoSrv->setInput(image.get_shared(), "image", true);
+    m_negatoSrv->setInOut(m_tf, "tf", true);
     m_negatoSrv->setID(this->getID() + "negato3DAdaptor");
     m_negatoSrv->configure();
 
-    m_renderSrv->slot("start")->asyncRun();
-    m_interactorSrv->slot("start")->asyncRun();
-    m_negatoSrv->slot("start")->asyncRun();
+    m_renderSrv->start().wait();
+    m_interactorSrv->start().wait();
+    m_negatoSrv->start().wait();
 }
 
 //------------------------------------------------------------------------------
@@ -112,7 +111,7 @@ service::IService::KeyConnectionsMap SImage::getAutoConnections() const
     // This is actually useless since the sub-service already listens to the data,
     // but this prevents a warning in fwServices from being raised.
     KeyConnectionsMap connections;
-    connections.push(s_IMAGE_INPUT, data::Object::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INPUT, data::Object::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -133,13 +132,14 @@ void SImage::stopping()
 
     sight::ui::base::GuiRegistry::unregisterSIDContainer(this->getID() + "-genericScene");
 
-    service::OSR::unregisterService(m_negatoSrv);
-    service::OSR::unregisterService(m_interactorSrv);
-    service::OSR::unregisterService(m_renderSrv);
+    service::unregisterService(m_negatoSrv);
+    service::unregisterService(m_interactorSrv);
+    service::unregisterService(m_renderSrv);
 
     m_negatoSrv.reset();
     m_interactorSrv.reset();
     m_renderSrv.reset();
+    m_tf.reset();
 
     this->destroy();
 }
