@@ -26,10 +26,7 @@
 
 #include <viz/scene2d/IAdaptor.hpp>
 
-namespace sight::module::viz::scene2d
-{
-
-namespace adaptor
+namespace sight::module::viz::scene2d::adaptor
 {
 
 /**
@@ -67,7 +64,7 @@ public:
     SIGHT_DECLARE_SERVICE(SAxis, sight::viz::scene2d::IAdaptor);
 
     MODULE_VIZ_SCENE2D_API SAxis() noexcept;
-    MODULE_VIZ_SCENE2D_API virtual ~SAxis() noexcept;
+    MODULE_VIZ_SCENE2D_API ~SAxis() noexcept override;
 
 protected:
 
@@ -86,47 +83,94 @@ private:
     /// Builds axis graphic items.
     void buildAxis();
 
-    ///
-    double getStartVal();
+    /// Builds labels graphic items.
+    void buildLabels();
 
     ///
-    double getEndVal();
+    double getStartVal() const;
+
+    ///
+    double getEndVal() const;
+
+    /// Displays axis graphic items.
+    void updateAxis();
+
+    /// Displays labels graphic items.
+    void updateLabels();
 
     // Specify where the axis must be aligned: left, right, top or bottom.
     // Left and right side axis are aligned/floating relatively to the view.
     std::string m_align;
 
-    /// The required interval between two consecutive values of the axis.
-    float m_interval {1.f};
-
-    /// Minimal value of the axis.
-    float m_min {0.f};
-
-    /// Maximal value of the axis.
-    float m_max {0.f};
-
-    /// Size of a tick.
-    float m_tickSize {1.0f};
-
-    /// Color.
-    QPen m_color {Qt::white};
-
-    /// Tells if the line of the axis must be displayed in addition to ticks.
-    bool m_showLine {true};
-
     /// A layer that gathers all the graphic items.
     QGraphicsItemGroup* m_layer {nullptr};
 
-    /// The line of the axis.
-    QGraphicsLineItem* m_line {nullptr};
+    /// Minimal value of the axis.
+    double m_min {0.};
 
-    /// The graphic items that refer to ticks of the axis.
-    std::vector<QGraphicsLineItem*> m_ticks;
+    /// Maximal value of the axis.
+    double m_max {0.};
+
+    /// The required interval between two consecutive values of the axis.
+    double m_interval {1.};
+    struct Line
+    {
+        /// Size of a tick.
+        double tickSize {1.0};
+
+        /// Color.
+        QPen color {Qt::white};
+
+        /// The line of the axis.
+        QGraphicsLineItem* line {nullptr};
+
+        /// The graphic items that refer to ticks of the axis.
+        std::vector<QGraphicsLineItem*> ticks;
+    };
+    Line m_line;
+
+    struct Labels
+    {
+        /// The unit of this values as text.
+        QGraphicsSimpleTextItem* unit {nullptr};
+
+        /// Tells if the unit of the axis must be displayed.
+        bool showUnit {true};
+
+        /// The unit  of the axis (as text) that will be displayed.
+        std::string displayedUnit;
+
+        /// Specify where the axis must be aligned: left, right, top or bottom.
+        /// Left and right side axis are aligned/floating relatively to the view.
+        std::string align;
+
+        /// A vector containing QGraphicsItem-s representing the scale values of the axis.
+        std::vector<QGraphicsItem*> values;
+
+        /// The font applied to grid's values.
+        QFont font;
+
+        /// The color applied to grid's values.
+        QBrush brush;
+
+        /// The pen.
+        QPen pen {Qt::white};
+
+        /// The step which defines when a value of the axis should be displayed if there is not
+        /// enough space to display all the values.
+        int step {1};
+
+        /// Size of the font used for rendering grid values.
+        int fontSize {8};
+
+        /// Extra scale factor to force a minimum size of the font - platform dependent (set in the constructor)
+        double extraScale {10.};
+    };
+
+    Labels m_labels;
 
     static constexpr std::string_view s_VIEWPORT_INPUT = "viewport";
     data::ptr<sight::viz::scene2d::data::Viewport, sight::data::Access::in> m_viewport {this, s_VIEWPORT_INPUT};
 };
 
-} // namespace adaptor
-
-} // namespace sight::module::viz::scene2d
+} // namespace sight::module::viz::scene2d::adaptor
