@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,6 +22,13 @@
 
 #include "modules/viz/scene3d/Plugin.hpp"
 
+#include "viz/scene3d/Utils.hpp"
+
+#include <core/runtime/Profile.hpp>
+#include <core/tools/Os.hpp>
+
+#include <boost/tokenizer.hpp>
+
 #include <OgreLogManager.h>
 
 /**
@@ -38,20 +45,45 @@ SIGHT_REGISTER_PLUGIN("sight::module::viz::scene3d::Plugin");
 
 //------------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void Plugin::start()
 {
-    // Redirect Ogre Log to Sight Log.
+    // Find log dir
+    const auto& current_profile = core::runtime::getCurrentProfile();
+    const auto& profile_name    = current_profile ? current_profile->getName() : std::string();
+    const auto& ogre_log        = core::tools::os::getUserCacheDir(profile_name) / "Ogre.log";
+
+    // Start Ogre Log
     m_logManager = new Ogre::LogManager();
-    m_log        = m_logManager->createLog("Ogre.log", true, false, false);
+    m_log        = m_logManager->createLog(ogre_log.string(), true, false, true);
     m_listener   = new SightOgreListener();
     m_log->addListener(m_listener);
     m_log->setLogDetail(Ogre::LL_BOREME);
+
+    // Ogre plugins to load
+    if(this->getModule()->hasParameter("plugins"))
+    {
+        const std::string pluginsStr = this->getModule()->getParameterValue("plugins");
+        const std::size_t count      = std::size_t(std::count(pluginsStr.begin(), pluginsStr.end(), ' '));
+
+        std::vector<std::string> plugins;
+        plugins.reserve(count);
+
+        // Split the string into individual ones (one per plugin)
+        {
+            using separator = boost::char_separator<std::string::value_type>;
+            using tokenizer = boost::tokenizer<separator>;
+
+            const tokenizer t(pluginsStr, separator {" ", "", boost::drop_empty_tokens});
+            plugins.assign(t.begin(), t.end());
+        }
+
+        sight::viz::scene3d::Utils::addPlugins(plugins);
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -68,8 +100,8 @@ void Plugin::stop() noexcept
 void SightOgreListener::messageLogged(
     const Ogre::String& _message,
     Ogre::LogMessageLevel _lml,
-    bool,
-    const Ogre::String&,
+    bool /*maskDebug*/,
+    const Ogre::String& /*logName*/,
     bool& _skipThisMessage
 )
 {
@@ -78,11 +110,11 @@ void SightOgreListener::messageLogged(
         switch(_lml)
         {
             case Ogre::LML_TRIVIAL:
-                SIGHT_INFO(_message);
+                SIGHT_DEBUG(_message);
                 break;
 
             case Ogre::LML_NORMAL:
-                SIGHT_DEBUG(_message);
+                SIGHT_INFO(_message);
                 break;
 
             case Ogre::LML_WARNING:
