@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2017-2022 IRCAD France
+ * Copyright (C) 2017-2023 IRCAD France
  * Copyright (C) 2017-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -28,8 +28,8 @@
 #include <core/com/Slot.hpp>
 
 #include <viz/scene3d/IAdaptor.hpp>
+#include <viz/scene3d/IText.hpp>
 #include <viz/scene3d/ITransformable.hpp>
-#include <viz/scene3d/Text.hpp>
 
 #include <Ogre.h>
 
@@ -38,7 +38,7 @@ namespace sight::data
 
 class Material;
 
-}
+} // namespace sight::data
 
 namespace sight::module::viz::scene3d::adaptor
 {
@@ -51,16 +51,16 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b toggleVisibility(): toggle whether the axis is shown or not.
  * - \b show(): shows the axis.
  * - \b hide(): hides the axis.
+ * - \b updateOriginColor(data::Color::sptr): update origin sphere with provided color.
  *
  * @section XML XML Configuration
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SAxis">
-        <config layer="default" transform="transformUID" length="30" label="true" name="A1" />
+        <config transform="transformUID" length="30" label="true" name="A1" />
     </service>
    @endcode
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the mesh's layer.
  * - \b transform (optional, string, default=""): the name of the Ogre transform node where to attach the mesh, as it
  *      was specified in the STransform adaptor.
  * - \b visible (optional, bool, default=true): the visibility of the axis.
@@ -84,7 +84,7 @@ public:
     MODULE_VIZ_SCENE3D_API SAxis() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SAxis() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SAxis() noexcept override = default;
 
 protected:
 
@@ -108,11 +108,17 @@ protected:
 
 private:
 
+    /// SLOT: internal function to update origin color using provided data::Color.
+    void updateOriginColor(sight::data::Color::sptr _newColor);
+
     /// Contains the material data.
     data::Material::sptr m_material {nullptr};
 
+    /// Contains the material for the origin (to change its color dynamically).
+    data::Material::sptr m_originMaterial {nullptr};
+
     /// Defines the axis length in scene units.
-    float m_length {50.f};
+    float m_length {50.F};
 
     /// Enables the visibility of axis labels.
     bool m_enableLabel {true};
@@ -123,6 +129,9 @@ private:
     /// Enables the origin visibility.
     bool m_originVisibility {false};
 
+    /// Enables the axes visibility.
+    bool m_axisVisibility {true};
+
     /// Defines the origin color.
     std::string m_originColor {"#FFFFFF"};
 
@@ -148,15 +157,12 @@ private:
     Ogre::SceneNode* m_sceneNode {nullptr};
 
     /// Stores labels attached to each axis.
-    std::array<sight::viz::scene3d::Text*, 3> m_axisLabels {{nullptr, nullptr, nullptr}};
+    std::array<sight::viz::scene3d::IText::sptr, 3> m_axisLabels {{nullptr, nullptr, nullptr}};
 
-    sight::viz::scene3d::Text* m_axisNameTxt {nullptr};
+    sight::viz::scene3d::IText::sptr m_axisNameTxt {nullptr};
 
     /// Defines labels font size in points.
-    std::size_t m_fontSize {16};
-
-    /// Defines the TrueType font source file.
-    std::string m_fontSource {"DejaVuSans.ttf"};
+    std::size_t m_fontSize {12};
 
     /// Axis name, default empty.
     std::string m_axisName;
