@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -48,14 +48,14 @@ struct SCamera::CameraNodeListener : public Ogre::MovableObject::Listener
 
     //------------------------------------------------------------------------------
 
-    CameraNodeListener(SCamera* _renderer) :
+    explicit CameraNodeListener(SCamera* _renderer) :
         m_layer(_renderer)
     {
     }
 
     //------------------------------------------------------------------------------
 
-    void objectMoved(Ogre::MovableObject*) override
+    void objectMoved(Ogre::MovableObject* /*unused*/) override
     {
         m_layer->updateTF3D();
     }
@@ -71,15 +71,33 @@ SCamera::SCamera() noexcept
 
 //------------------------------------------------------------------------------
 
-SCamera::~SCamera() noexcept
-{
-}
+SCamera::~SCamera() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void SCamera::configuring()
 {
     this->configureParams();
+
+    const ConfigType config   = this->getConfiguration();
+    const auto projectionType = config.get<std::string>("config.<xmlattr>.projection", "perspective");
+
+    if(projectionType == "orthographic")
+    {
+        m_useOrthographicProjection = true;
+    }
+    else if(projectionType == "perspective")
+    {
+        m_useOrthographicProjection = false;
+    }
+    else
+    {
+        SIGHT_ERROR(
+            "Projection type '" + projectionType
+            + "' is not managed use either 'perspective'(default) or 'orthographic'"
+        );
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -90,6 +108,13 @@ void SCamera::starting()
 
     m_camera = this->getLayer()->getDefaultCamera();
 
+    if(m_useOrthographicProjection)
+    {
+        m_camera->setProjectionType(Ogre::ProjectionType::PT_ORTHOGRAPHIC);
+        // inform layer since some computations are a bit different from perspective.
+        this->getLayer()->setOrthographicCamera(true);
+    }
+
     m_cameraNodeListener = new CameraNodeListener(this);
     m_camera->setListener(m_cameraNodeListener);
 
@@ -106,7 +131,6 @@ void SCamera::starting()
         s_CALIBRATE_SLOT
     );
 
-    this->calibrate();
     this->updating();
 }
 
@@ -115,10 +139,11 @@ void SCamera::starting()
 service::IService::KeyConnectionsMap SCamera::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_TRANSFORM_INOUT, data::Matrix4::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_TRANSFORM_INOUT, data::Matrix4::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_CALIBRATION_INPUT, data::Camera::s_MODIFIED_SIG, s_CALIBRATE_SLOT);
     connections.push(s_CALIBRATION_INPUT, data::Camera::s_INTRINSIC_CALIBRATED_SIG, s_CALIBRATE_SLOT);
-    connections.push(s_CAMERA_SERIES_INPUT, data::CameraSeries::s_MODIFIED_SIG, s_CALIBRATE_SLOT);
-    connections.push(s_CAMERA_SERIES_INPUT, data::CameraSeries::s_EXTRINSIC_CALIBRATED_SIG, s_CALIBRATE_SLOT);
+    connections.push(s_CAMERA_SET_INPUT, data::CameraSet::s_MODIFIED_SIG, s_CALIBRATE_SLOT);
+    connections.push(s_CAMERA_SET_INPUT, data::CameraSet::s_EXTRINSIC_CALIBRATED_SIG, s_CALIBRATE_SLOT);
 
     return connections;
 }
@@ -127,45 +152,48 @@ service::IService::KeyConnectionsMap SCamera::getAutoConnections() const
 
 void SCamera::updating()
 {
-    Ogre::Affine3 ogreMatrix;
+    if(m_calibrationDone || this->calibrate())
     {
-        const auto transform = m_transform.lock();
-
-        // Received input line and column data from Sight transformation matrix
-        for(std::size_t lt = 0 ; lt < 4 ; lt++)
+        Ogre::Affine3 ogreMatrix;
         {
-            for(std::size_t ct = 0 ; ct < 4 ; ct++)
+            const auto transform = m_transform.lock();
+
+            // Received input line and column data from Sight transformation matrix
+            for(std::size_t lt = 0 ; lt < 4 ; lt++)
             {
-                ogreMatrix[ct][lt] = static_cast<Ogre::Real>(transform->getCoefficient(ct, lt));
+                for(std::size_t ct = 0 ; ct < 4 ; ct++)
+                {
+                    ogreMatrix[ct][lt] = static_cast<Ogre::Real>((*transform)(ct, lt));
+                }
             }
         }
+
+        // Decompose the camera matrix
+        Ogre::Vector3 position;
+        Ogre::Vector3 scale;
+        Ogre::Quaternion orientation;
+        ogreMatrix.decomposition(position, scale, orientation);
+
+        // Reverse view-up and direction for AR
+        const Ogre::Quaternion rotateY(Ogre::Degree(180), Ogre::Vector3(0, 1, 0));
+        const Ogre::Quaternion rotateZ(Ogre::Degree(180), Ogre::Vector3(0, 0, 1));
+        orientation = orientation * rotateZ * rotateY;
+
+        // Flag to skip updateTF3D() when called from the camera listener
+        m_skipUpdate = true;
+
+        Ogre::Node* parent = m_camera->getParentNode();
+
+        // Reset the camera position
+        parent->setPosition(0, 0, 0);
+        parent->setOrientation(Ogre::Quaternion::IDENTITY);
+
+        // Update the camera position
+        parent->rotate(orientation);
+        parent->translate(position);
+
+        this->requestRender();
     }
-
-    // Decompose the camera matrix
-    Ogre::Vector3 position;
-    Ogre::Vector3 scale;
-    Ogre::Quaternion orientation;
-    ogreMatrix.decomposition(position, scale, orientation);
-
-    // Reverse view-up and direction for AR
-    const Ogre::Quaternion rotateY(Ogre::Degree(180), Ogre::Vector3(0, 1, 0));
-    const Ogre::Quaternion rotateZ(Ogre::Degree(180), Ogre::Vector3(0, 0, 1));
-    orientation = orientation * rotateZ * rotateY;
-
-    // Flag to skip updateTF3D() when called from the camera listener
-    m_skipUpdate = true;
-
-    Ogre::Node* parent = m_camera->getParentNode();
-
-    // Reset the camera position
-    parent->setPosition(0, 0, 0);
-    parent->setOrientation(Ogre::Quaternion::IDENTITY);
-
-    // Update the camera position
-    parent->rotate(orientation);
-    parent->translate(position);
-
-    this->requestRender();
 }
 
 //------------------------------------------------------------------------------
@@ -174,7 +202,7 @@ void SCamera::stopping()
 {
     m_layerConnection.disconnect();
 
-    if(m_cameraNodeListener)
+    if(m_cameraNodeListener != nullptr)
     {
         m_camera->setListener(nullptr);
         delete m_cameraNodeListener;
@@ -240,13 +268,13 @@ void SCamera::updateTF3D()
     {
         for(std::size_t ct = 0 ; ct < 4 ; ct++)
         {
-            transform->setCoefficient(ct, lt, static_cast<double>(newTransMat[ct][lt]));
+            (*transform)(ct, lt) = static_cast<double>(newTransMat[ct][lt]);
         }
     }
 
     auto sig = transform->signal<data::Object::ModifiedSignalType>(data::Object::s_MODIFIED_SIG);
     {
-        core::com::Connection::Blocker blocker(sig->getConnection(m_slotUpdate));
+        core::com::Connection::Blocker blocker(sig->getConnection(slot(IService::slots::s_UPDATE)));
         sig->asyncEmit();
     }
 }
@@ -276,25 +304,26 @@ void SCamera::setAspectRatio(Ogre::Real _ratio)
     SIGHT_ASSERT("The associated camera doesn't exist.", m_camera);
 
     m_aspectRatio = _ratio;
+    SIGHT_ASSERT("Width and height should be strictly positive", !std::isnan(_ratio));
     m_camera->setAspectRatio(m_aspectRatio);
 }
 
 //-----------------------------------------------------------------------------
 
-void SCamera::calibrate()
+bool SCamera::calibrate()
 {
-    const auto cameraSeries      = m_cameraSeries.lock();
+    const auto camera_set        = m_camera_set.lock();
     const auto cameraCalibration = m_cameraCalibration.lock();
 
     SIGHT_WARN_IF(
         "A '" << s_CALIBRATION_INPUT << "' input was set but will not be used because a '"
-        << s_CAMERA_SERIES_INPUT << "' was defined as well",
-        cameraSeries && cameraCalibration
+        << s_CAMERA_SET_INPUT << "' was defined as well",
+        camera_set && cameraCalibration
     );
 
-    if(cameraSeries)
+    if(camera_set)
     {
-        this->calibrateCameraSeries(*cameraSeries);
+        this->calibrateCameraSet(*camera_set);
     }
     else if(cameraCalibration)
     {
@@ -302,22 +331,30 @@ void SCamera::calibrate()
     }
     else
     {
-        const float width  = static_cast<float>(m_camera->getViewport()->getActualWidth());
-        const float height = static_cast<float>(m_camera->getViewport()->getActualHeight());
+        const auto width  = static_cast<float>(m_camera->getViewport()->getActualWidth());
+        const auto height = static_cast<float>(m_camera->getViewport()->getActualHeight());
+        if(width <= 0 || height <= 0)
+        {
+            SIGHT_ERROR("Width and height should be strictly positive");
+            return false;
+        }
 
         const float aspectRatio = width / height;
         m_camera->setAspectRatio(aspectRatio);
     }
+
+    m_calibrationDone = true;
+    return true;
 }
 
 //------------------------------------------------------------------------------
 
 void SCamera::calibrateMonoCamera(const data::Camera& _cam)
 {
-    const float width    = static_cast<float>(m_camera->getViewport()->getActualWidth());
-    const float height   = static_cast<float>(m_camera->getViewport()->getActualHeight());
-    const float nearClip = static_cast<float>(m_camera->getNearClipDistance());
-    const float farClip  = static_cast<float>(m_camera->getFarClipDistance());
+    const auto width    = static_cast<float>(m_camera->getViewport()->getActualWidth());
+    const auto height   = static_cast<float>(m_camera->getViewport()->getActualHeight());
+    const auto nearClip = static_cast<float>(m_camera->getNearClipDistance());
+    const auto farClip  = static_cast<float>(m_camera->getFarClipDistance());
 
     if(_cam.getIsCalibrated())
     {
@@ -337,17 +374,17 @@ void SCamera::calibrateMonoCamera(const data::Camera& _cam)
 
 //------------------------------------------------------------------------------
 
-void SCamera::calibrateCameraSeries(const data::CameraSeries& _cs)
+void SCamera::calibrateCameraSet(const data::CameraSet& _cs)
 {
-    const float width        = static_cast<float>(m_camera->getViewport()->getActualWidth());
-    const float height       = static_cast<float>(m_camera->getViewport()->getActualHeight());
-    const float nearClip     = static_cast<float>(m_camera->getNearClipDistance());
-    const float farClip      = static_cast<float>(m_camera->getFarClipDistance());
-    const std::size_t nbCams = _cs.numCameras();
+    const auto width         = static_cast<float>(m_camera->getViewport()->getActualWidth());
+    const auto height        = static_cast<float>(m_camera->getViewport()->getActualHeight());
+    const auto nearClip      = static_cast<float>(m_camera->getNearClipDistance());
+    const auto farClip       = static_cast<float>(m_camera->getFarClipDistance());
+    const std::size_t nbCams = _cs.size();
 
     SIGHT_WARN_IF(
-        "There are no cameras in the '" << s_CAMERA_SERIES_INPUT << "', the default projection transform"
-                                                                    "will be used.",
+        "There are no cameras in the '" << s_CAMERA_SET_INPUT << "', the default projection transform"
+                                                                 "will be used.",
         nbCams == 0
     );
 
@@ -356,7 +393,7 @@ void SCamera::calibrateCameraSeries(const data::CameraSeries& _cs)
     // Calibrate only the first camera when stereo is not enabled.
     if(layer->getStereoMode() == sight::viz::scene3d::compositor::Core::StereoModeType::NONE && nbCams > 0)
     {
-        this->calibrateMonoCamera(*_cs.getCamera(0));
+        this->calibrateMonoCamera(*_cs.get_camera(0));
     }
     else
     {
@@ -365,7 +402,7 @@ void SCamera::calibrateCameraSeries(const data::CameraSeries& _cs)
 
         for(std::size_t i = 0 ; i < nbCams ; ++i)
         {
-            const data::Camera::csptr camera = _cs.getCamera(i);
+            const data::Camera::csptr camera = _cs.get_camera(i);
 
             if(camera->getIsCalibrated())
             {
@@ -389,12 +426,12 @@ void SCamera::calibrateCameraSeries(const data::CameraSeries& _cs)
             // first camera to the current one.
             if(i < nbCams - 1)
             {
-                const data::Matrix4::csptr extrinsic = _cs.getExtrinsicMatrix(i + 1);
+                const data::Matrix4::csptr extrinsic = _cs.get_extrinsic_matrix(i + 1);
                 extrinsicMx = sight::viz::scene3d::Utils::convertTM3DToOgreMx(extrinsic) * extrinsicMx;
             }
         }
 
-        if(calibrations.size() > 0)
+        if(!calibrations.empty())
         {
             layer->setCameraCalibrations(calibrations);
             this->updating();
