@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -53,7 +53,7 @@ class CompositorListener;
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SCompositorParameter">
         <inout key="parameter" uid="collimation" />
-        <config layer="..." compositorName="compositor" parameter="u_value" shaderType="fragment" />
+        <config compositorName="compositor" parameter="u_value" shaderType="fragment" />
     </service>
    @endcode
  *
@@ -61,7 +61,6 @@ class CompositorListener;
  * - \b parameter [sight::data::Object]: parameter containing the data to upload.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the compositor's layer.
  * - \b visible (optional, bool, default=true): defines if the compositor is enabled or not.
  * - \b compositorName (mandatory, string): the name of the associated Ogre compositor.
  * - \b parameter (mandatory, string): name of the shader parameter to set.
@@ -80,7 +79,7 @@ public:
     MODULE_VIZ_SCENE3D_API SCompositorParameter() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SCompositorParameter() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SCompositorParameter() noexcept override = default;
 
 protected:
 
@@ -107,14 +106,17 @@ private:
     /// Updates parameter according to the attached data::Object.
     void updateValue(Ogre::MaterialPtr& _mat);
 
+    /// Adds the listener
+    void addListener();
+
     /// Defines the material name.
     std::string m_compositorName;
 
     /// Contains the Ogre compositor listener, we need to keep a pointer to unregister it.
-    CompositorListener* m_listener;
+    CompositorListener* m_listener {nullptr};
 
-    /// Contains the compositor we work on.
-    Ogre::CompositorInstance* m_compositor;
+    /// Handles connection with the layer.
+    core::com::helper::SigSlotConnection m_resizeConnection;
 
     friend class CompositorListener;
 };
