@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -42,19 +42,19 @@ namespace sight::module::viz::scene3d::adaptor
 
 struct FragmentsInfoMaterialListener final : public Ogre::MaterialManager::Listener
 {
-    virtual ~FragmentsInfoMaterialListener()
-    {
-    }
+    ~FragmentsInfoMaterialListener() override
+    = default;
 
     //------------------------------------------------------------------------------
 
-    virtual Ogre::Technique* handleSchemeNotFound(
-        unsigned short,
+    Ogre::Technique* handleSchemeNotFound(
+        std::uint16_t /*schemeIndex*/,
         const Ogre::String& _schemeName,
         Ogre::Material* _originalMaterial,
-        unsigned short,
+        std::uint16_t /*lodIndex*/,
         const Ogre::Renderable*
-)
+        /*rend*/
+    ) override
     {
         Ogre::Technique* newTech = nullptr;
 
@@ -68,7 +68,7 @@ struct FragmentsInfoMaterialListener final : public Ogre::MaterialManager::Liste
             );
 
             const Ogre::Technique::Passes& passes = newTech->getPasses();
-            for(const auto pass : passes)
+            for(auto* const pass : passes)
             {
                 pass->setCullingMode(Ogre::CULL_NONE);
                 pass->setManualCullingMode(Ogre::MANUAL_CULL_NONE);
@@ -81,17 +81,13 @@ struct FragmentsInfoMaterialListener final : public Ogre::MaterialManager::Liste
 };
 
 static std::unique_ptr<FragmentsInfoMaterialListener> s_MATERIAL_LISTENER = nullptr;
+static const core::com::Slots::SlotKeyType s_RESIZE_VIEWPORT_SLOT         = "resizeViewport";
 
 //-----------------------------------------------------------------------------
 
 SFragmentsInfo::SFragmentsInfo() noexcept
 {
-}
-
-//-----------------------------------------------------------------------------
-
-SFragmentsInfo::~SFragmentsInfo() noexcept
-{
+    newSlot(s_RESIZE_VIEWPORT_SLOT, &SFragmentsInfo::resizeViewport, this);
 }
 
 //-----------------------------------------------------------------------------
@@ -101,10 +97,10 @@ void SFragmentsInfo::configuring()
     // IAdaptor handles the layerID.
     this->configureParams();
 
-    const ConfigType config = this->getConfigTree().get_child("config.<xmlattr>");
-    m_width     = config.get<int>("width", m_width);
-    m_height    = config.get<int>("height", m_height);
-    m_flipImage = config.get<bool>("flip", m_flipImage);
+    const ConfigType config = this->getConfiguration();
+    m_width     = config.get<int>(s_CONFIG + "width", m_width);
+    m_height    = config.get<int>(s_CONFIG + "height", m_height);
+    m_flipImage = config.get<bool>(s_CONFIG + "flip", m_flipImage);
 
     // If Both width & height are found we fix the size.
     if(m_width > 0 && m_height > 0)
@@ -124,7 +120,7 @@ void SFragmentsInfo::starting()
     m_targetPrimitiveIDName = this->getID() + "_primitiveID_RTT";
 
     const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
-    layer->getRenderService()->getInteractorManager()->getRenderTarget()->addListener(this);
+    layer->getRenderTarget()->addListener(this);
 
     if(!s_MATERIAL_LISTENER)
     {
@@ -147,8 +143,12 @@ void SFragmentsInfo::starting()
 
         this->createCompositor(w, h);
 
-        // Listen the viewport to catch the resize event.
-        viewport->addListener(this);
+        m_resizeConnection.connect(
+            this->getLayer(),
+            sight::viz::scene3d::Layer::s_RESIZE_LAYER_SIG,
+            this->getSptr(),
+            s_RESIZE_VIEWPORT_SLOT
+        );
     }
 }
 
@@ -200,17 +200,12 @@ void SFragmentsInfo::updating() noexcept
 
 void SFragmentsInfo::stopping()
 {
+    m_resizeConnection.disconnect();
+
     this->destroyCompositor();
 
     const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
-    layer->getRenderService()->getInteractorManager()->getRenderTarget()->removeListener(this);
-
-    // Removes the listener from the viewport.
-    if(!m_fixedSize)
-    {
-        Ogre::Viewport* const viewport = layer->getViewport();
-        viewport->removeListener(this);
-    }
+    layer->getRenderTarget()->removeListener(this);
 }
 
 //-----------------------------------------------------------------------------
@@ -271,7 +266,7 @@ void SFragmentsInfo::createCompositor(int _width, int _height)
 
     Ogre::CompositionTechnique* const technique = m_compositor->createTechnique();
 
-    Ogre::CompositionTechnique::TextureDefinition* globalTarget;
+    Ogre::CompositionTechnique::TextureDefinition* globalTarget = nullptr;
     globalTarget        = technique->createTextureDefinition(m_targetName);
     globalTarget->scope = Ogre::CompositionTechnique::TextureScope::TS_GLOBAL;
     globalTarget->formatList.push_back(Ogre::PixelFormat::PF_A8B8G8R8);
@@ -291,7 +286,7 @@ void SFragmentsInfo::createCompositor(int _width, int _height)
         globalTarget->formatList.push_back(Ogre::PixelFormat::PF_FLOAT32_R);
 
         const std::string localName("local_RTT");
-        Ogre::CompositionTechnique::TextureDefinition* localTarget;
+        Ogre::CompositionTechnique::TextureDefinition* localTarget = nullptr;
         localTarget        = technique->createTextureDefinition(localName);
         localTarget->scope = Ogre::CompositionTechnique::TextureScope::TS_LOCAL;
         localTarget->formatList.push_back(Ogre::PixelFormat::PF_DEPTH32);
@@ -318,7 +313,7 @@ void SFragmentsInfo::createCompositor(int _width, int _height)
 
     if(retrievePrimitiveID)
     {
-        Ogre::CompositionTechnique::TextureDefinition* globalTargetPrimitiveID;
+        Ogre::CompositionTechnique::TextureDefinition* globalTargetPrimitiveID = nullptr;
         globalTargetPrimitiveID        = technique->createTextureDefinition(m_targetPrimitiveIDName);
         globalTargetPrimitiveID->scope = Ogre::CompositionTechnique::TextureScope::TS_GLOBAL;
         globalTargetPrimitiveID->formatList.push_back(Ogre::PixelFormat::PF_R32_SINT);
@@ -364,22 +359,23 @@ void SFragmentsInfo::destroyCompositor()
 
 //-----------------------------------------------------------------------------
 
-void SFragmentsInfo::viewportDimensionsChanged(Ogre::Viewport* _viewport)
+void SFragmentsInfo::resizeViewport()
 {
-    int left, top, width, height;
-    _viewport->getActualDimensions(left, top, width, height);
+    const auto layer = this->getLayer();
+    auto rect        = layer->getViewport()->getActualDimensions();
 
     // Sometimes, the size can be null, we need to avoid resizing since a global texture needs absolute values.
-    if(width != 0 && height != 0)
+    if(rect.width() != 0 && rect.height() != 0)
     {
         this->destroyCompositor();
-        this->createCompositor(width, height);
+        this->createCompositor(static_cast<int>(rect.width()), static_cast<int>(rect.height()));
+        layer->getRenderTarget()->addListener(this);
     }
 }
 
 //-----------------------------------------------------------------------------
 
-void SFragmentsInfo::postRenderTargetUpdate(const Ogre::RenderTargetEvent&)
+void SFragmentsInfo::postRenderTargetUpdate(const Ogre::RenderTargetEvent& /*evt*/)
 {
     this->updating();
 }
