@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,6 +30,7 @@
 #include <service/macros.hpp>
 
 #include <viz/scene3d/helper/Camera.hpp>
+#include <viz/scene3d/helper/ManualObject.hpp>
 #include <viz/scene3d/helper/Scene.hpp>
 
 #include <OgreCamera.h>
@@ -40,21 +41,15 @@
 namespace sight::module::viz::scene3d::adaptor
 {
 
-static const std::string s_NEAR_CONFIG  = "near";
-static const std::string s_FAR_CONFIG   = "far";
-static const std::string s_COLOR_CONFIG = "color";
+//-----------------------------------------------------------------------------
+
+SFrustum::SFrustum() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
-SFrustum::SFrustum() noexcept
-{
-}
-
-//-----------------------------------------------------------------------------
-
-SFrustum::~SFrustum() noexcept
-{
-}
+SFrustum::~SFrustum() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
@@ -62,8 +57,7 @@ void SFrustum::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
     this->setTransformId(
         config.get<std::string>(
@@ -72,6 +66,10 @@ void SFrustum::configuring()
         )
     );
 
+    static const std::string s_NEAR_CONFIG  = s_CONFIG + "near";
+    static const std::string s_FAR_CONFIG   = s_CONFIG + "far";
+    static const std::string s_COLOR_CONFIG = s_CONFIG + "color";
+
     m_near  = config.get<float>(s_NEAR_CONFIG, m_near);
     m_far   = config.get<float>(s_FAR_CONFIG, m_far);
     m_color = config.get<std::string>(s_COLOR_CONFIG, m_color);
@@ -83,7 +81,34 @@ void SFrustum::starting()
 {
     this->initialize();
 
-    // Create material
+    // Create camera
+    m_ogreCamera = this->getSceneManager()->createCamera(Ogre::String(this->getID() + std::string(s_CAMERA_INPUT)));
+    m_ogreCamera->setVisible(m_isVisible);
+
+    // Clipping
+    if(m_near != 0.F)
+    {
+        m_ogreCamera->setNearClipDistance(m_near);
+    }
+
+    if(m_far != 0.F)
+    {
+        m_ogreCamera->setFarClipDistance(m_far);
+    }
+
+    // Set data to camera
+    this->setOgreCamFromData();
+
+    // Add camera to ogre scene
+    Ogre::SceneNode* rootSceneNode = this->getSceneManager()->getRootSceneNode();
+    Ogre::SceneNode* transNode     = this->getOrCreateTransformNode(rootSceneNode);
+    transNode->attachObject(m_ogreCamera);
+
+    // Set position
+    transNode->setPosition(Ogre::Vector3(0, 0, 0));
+    transNode->setDirection(Ogre::Vector3(Ogre::Real(0), Ogre::Real(0), Ogre::Real(1)));
+
+    // Create material for the frustum
     m_material = data::Material::New();
     m_material->diffuse()->setRGBA(m_color);
 
@@ -92,42 +117,23 @@ void SFrustum::starting()
             "sight::module::viz::scene3d::adaptor::SMaterial"
         );
     materialAdaptor->setInOut(m_material, module::viz::scene3d::adaptor::SMaterial::s_MATERIAL_INOUT, true);
-    materialAdaptor->setID(this->getID() + materialAdaptor->getID());
-    materialAdaptor->setMaterialName(this->getID() + materialAdaptor->getID());
-    materialAdaptor->setRenderService(this->getRenderService());
-    materialAdaptor->setLayerID(this->m_layerID);
-    materialAdaptor->setShadingMode("ambient");
-    materialAdaptor->setMaterialTemplateName(sight::viz::scene3d::Material::DEFAULT_MATERIAL_TEMPLATE_NAME);
+    materialAdaptor->configure(
+        this->getID() + materialAdaptor->getID(),
+        this->getID() + materialAdaptor->getID(),
+        this->getRenderService(),
+        m_layerID,
+        "ambient"
+    );
     materialAdaptor->start();
     materialAdaptor->update();
 
-    // Create camera
-    m_ogreCamera = this->getSceneManager()->createCamera(Ogre::String(this->getID() + std::string(s_CAMERA_INPUT)));
-    m_ogreCamera->setMaterial(materialAdaptor->getMaterial());
-    m_ogreCamera->setVisible(m_isVisible);
-
-    // Clipping
-    if(m_near != 0.f)
-    {
-        m_ogreCamera->setNearClipDistance(m_near);
-    }
-
-    if(m_far != 0.f)
-    {
-        m_ogreCamera->setFarClipDistance(m_far);
-    }
-
-    // Set data to camera
-    this->setOgreCamFromData();
-
-    // Set position
-    m_ogreCamera->setPosition(Ogre::Vector3(0, 0, 0));
-    m_ogreCamera->setDirection(Ogre::Vector3(Ogre::Real(0), Ogre::Real(0), Ogre::Real(1)));
-
-    // Add camera to ogre scene
-    Ogre::SceneNode* rootSceneNode = this->getSceneManager()->getRootSceneNode();
-    Ogre::SceneNode* transNode     = this->getOrCreateTransformNode(rootSceneNode);
-    transNode->attachObject(m_ogreCamera);
+    m_frustum = this->getSceneManager()->createManualObject(this->getID() + "_frustum");
+    sight::viz::scene3d::helper::ManualObject::createFrustum(
+        m_frustum,
+        materialAdaptor->getMaterialName(),
+        *m_ogreCamera
+    );
+    transNode->attachObject(m_frustum);
 
     this->requestRender();
 }
@@ -137,8 +143,8 @@ void SFrustum::starting()
 service::IService::KeyConnectionsMap SFrustum::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_CAMERA_INPUT, data::Camera::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_CAMERA_INPUT, data::Camera::s_INTRINSIC_CALIBRATED_SIG, s_UPDATE_SLOT);
+    connections.push(s_CAMERA_INPUT, data::Camera::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_CAMERA_INPUT, data::Camera::s_INTRINSIC_CALIBRATED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -148,7 +154,7 @@ service::IService::KeyConnectionsMap SFrustum::getAutoConnections() const
 void SFrustum::updating()
 {
     this->setOgreCamFromData();
-    m_ogreCamera->setDebugDisplayEnabled(m_isVisible);
+    m_frustum->setVisible(m_isVisible);
     this->requestRender();
 }
 
@@ -158,7 +164,9 @@ void SFrustum::stopping()
 {
     this->unregisterServices();
 
+    m_frustum->detachFromParent();
     m_ogreCamera->detachFromParent();
+    this->getSceneManager()->destroyManualObject(m_frustum);
     this->getSceneManager()->destroyCamera(m_ogreCamera);
 
     m_ogreCamera = nullptr;
@@ -173,8 +181,8 @@ void SFrustum::setOgreCamFromData()
 
     if(camera->getIsCalibrated())
     {
-        const float width  = static_cast<float>(camera->getWidth());
-        const float height = static_cast<float>(camera->getHeight());
+        const auto width  = static_cast<float>(camera->getWidth());
+        const auto height = static_cast<float>(camera->getHeight());
 
         Ogre::Matrix4 m =
             sight::viz::scene3d::helper::Camera::computeProjectionMatrix(*camera, width, height, m_near, m_far);
@@ -191,7 +199,7 @@ void SFrustum::setOgreCamFromData()
 
 void SFrustum::setVisible(bool _isVisible)
 {
-    m_ogreCamera->setDebugDisplayEnabled(_isVisible);
+    m_frustum->setVisible(_isVisible);
     this->requestRender();
 }
 
