@@ -50,7 +50,7 @@ namespace sight::module::viz::scene3d::adaptor
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SFrustum">
         <in key="camera" uid="..." />
-        <config layer="..." transform="..." near="..." far="..."/>
+        <config transform="..." near="..." far="..."/>
     </service>
    @endcode
  *
@@ -58,7 +58,6 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b camera [sight::data::Camera]:  camera containing calibration information.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the frustum's layer
  * - \b transform (optional, string, default=""): transform applied to the frustum's scene node
  * - \b near (optional, float, default=1.0): near clipping distance of the Ogre::Camera
  * - \b far (optional, float, default=20.0): far clipping distance of the Ogre::Camera
@@ -114,6 +113,9 @@ private:
     /// Sets Ogre::Camera from data::Camera parameters.
     void setOgreCamFromData();
 
+    /// Contains the manual object of the line.
+    Ogre::ManualObject* m_frustum {nullptr};
+
     /// Contains the Ogre's camera (frustum) representing data::Camera position and parameters.
     Ogre::Camera* m_ogreCamera {nullptr};
 
@@ -121,10 +123,10 @@ private:
     data::Material::sptr m_material {nullptr};
 
     /// Defines the near clipping distance.
-    float m_near {1.f};
+    float m_near {1.F};
 
     /// Defines the far clipping distance.
-    float m_far {20.f};
+    float m_far {20.F};
 
     /// Defines the color of frustum.
     std::string m_color {"#FF0000"};
