@@ -54,7 +54,7 @@ namespace sight::module::viz::scene3d::adaptor
         <service type="sight::module::viz::scene3d::adaptor::SFrustumList">
             <in key="camera" uid="..." />
             <in key="transform" uid="..." />
-            <config layer="default" near="0.1" far="300" color="#f8e119" transform="..." />
+            <config near="0.1" far="300" color="#f8e119" transform="..." />
        </service>
    @endcode
  *
@@ -63,7 +63,6 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b transform [sight::data::Matrix4]: each time this transform is modified, a frustum is created.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the frustum's layer
  * - \b near (optional, float, default=1.0): near clipping distance of the Ogre::Camera
  * - \b far (optional, float, default=20.0): far clipping distance of the Ogre::Camera
  * - \b color (optional, hexadecimal, default=0x0000FF): frustum's color
@@ -121,11 +120,14 @@ private:
     /// SLOT: adds a frustum in the list and displays it.
     void addFrustum();
 
+    /// Transform the data::Transform into position / oriention of the scene node.
+    void setTransfromToNode(Ogre::SceneNode* _node);
+
     /// Defines the near clipping distance.
-    float m_near {1.f};
+    float m_near {1.F};
 
     /// Defines the far clipping distance.
-    float m_far {20.f};
+    float m_far {20.F};
 
     /// Defines the color of frustum.
     std::string m_color {"#0000FF"};
@@ -133,8 +135,10 @@ private:
     /// Defines the maximum capacity of frustum list.
     unsigned int m_capacity {50};
 
+    using frustum_t = std::pair<Ogre::ManualObject*, Ogre::SceneNode*>;
+
     /// Stores a circular list of frustum adaptors.
-    boost::circular_buffer<Ogre::Camera*> m_frustumList {};
+    boost::circular_buffer<frustum_t> m_frustumList {};
 
     /// Uses to generate unique ID for each Ogre::Camera.
     std::size_t m_currentCamIndex {0};
@@ -145,9 +149,6 @@ private:
     /// Contains the material data.
     data::Material::sptr m_material {nullptr};
 
-    /// Contains the scene node where all frustums are attached.
-    Ogre::SceneNode* m_sceneNode {nullptr};
-
     static constexpr std::string_view s_TRANSFORM_INPUT = "transform";
 
     sight::data::ptr<sight::data::Camera, sight::data::Access::in> m_camera {this, "camera"};
