@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,10 +26,12 @@
 
 #include <data/PointList.hpp>
 
+#include <geometry/data/PointList.hpp>
+
 #include <viz/scene3d/IAdaptor.hpp>
 #include <viz/scene3d/interactor/IInteractor.hpp>
+#include <viz/scene3d/IText.hpp>
 #include <viz/scene3d/Material.hpp>
-#include <viz/scene3d/Text.hpp>
 
 #include <Ogre.h>
 
@@ -41,30 +43,20 @@ namespace sight::module::viz::scene3d::adaptor
 
 /**
  * @brief This adaptor displays distances retrieved from the image fields.
- *
- * @section Slots Slots
- * - \b addDistance(): adds distances contained in the image from the scene manager.
- * - \b removeDistance(): removes distances contained in the image from the scene manager.
- * - \b updateVisibilityFromField(): updates the visibility of distances from the field status.
- * - \b updateVisibility(bool): sets whether distances are shown or not.
- * - \b toggleVisibility(): toggles whether distances are shown or not.
- * - \b show(): shows distance.
- * - \b hide(): hides distance.
- *
+ * @deprecated Use sight::module::viz::scene3dQt::adaptor::SImageMultiDistances instead.
+
  * @section XML XML Configuration
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SImageMultiDistances" autoConnect="true" >
         <inout key="image" uid="..." />
-        <config layer="default" fontSource="DejaVuSans.ttf" fontSize="32" radius="4.5" priority="2" />
+        <config fontSource="DejaVuSans.ttf" fontSize="32" radius="4.5" priority="2" />
     </service>
    @endcode
  *
- * @subsection In-Out In-Out:
+ * @subsection Input Input:
  * - \b image [sight::data::Image]: image containing the distance field.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string) : defines distance's layer.
- * - \b fontSource (optional, string, default=DejaVuSans.ttf): TrueType font (*.ttf) source file.
  * - \b fontSize (optional, int, default=16): font size in points.
  * - \b radius (optional, float, default=4.5): size of the distances spheres.
  * - \b interactive (optional, bool, default=true): enables interactions with distances.
@@ -72,6 +64,20 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b queryMask (optional, uint32, default=0xFFFFFFFF): mask used to filter out entities when the distance is auto
  *      snapped.
  * - \b distanceQueryFlags (optional, uint32, default=0x40000000): mask apply to distances spheres.
+ *
+ * @section Slots Slots
+ * - \b removeDistance(): removes distances contained in the image from the scene manager.
+ * - \b updateVisibilityFromField(): updates the visibility of distances from the field status.
+ * - \b updateVisibility(bool): sets whether distances are shown or not.
+ * - \b updateModifiedDistance(data::PointList::sptr): renders distances in other negato2d and negato3d adaptors.
+ * - \b toggleVisibility(): toggles whether distances are shown or not.
+ * - \b show(): shows distance.
+ * - \b hide(): hides distance.
+ *
+ * @section Signals Signals
+ * - \b toolDeactivate(): signal set when the tool is deactivated.
+ *
+ *
  */
 class SImageMultiDistances final :
     public sight::viz::scene3d::IAdaptor,
@@ -79,6 +85,14 @@ class SImageMultiDistances final :
 {
 public:
 
+    struct signals
+    {
+        using key_t = sight::core::com::Signals::SignalKeyType;
+        static inline const key_t s_DEACTIVATE_DISTANCE_TOOL = "deactivateDistanceTool";
+
+        using void_signal_t = sight::core::com::Signal<void ()>;
+    };
+
     /// Generates default methods as New, dynamicCast, ...
     SIGHT_DECLARE_SERVICE(SImageMultiDistances, sight::viz::scene3d::IAdaptor);
 
@@ -86,7 +100,7 @@ public:
     MODULE_VIZ_SCENE3D_API SImageMultiDistances() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SImageMultiDistances() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SImageMultiDistances() noexcept override = default;
 
     /**
      * @brief Retrieves the picked distance and stores the result in m_pickedData.
@@ -101,10 +115,31 @@ public:
      * @param _x X screen coordinate.
      * @param _y Y screen coordinate.
      */
-    MODULE_VIZ_SCENE3D_API void mouseMoveEvent(MouseButton, Modifier _mod, int _x, int _y, int, int) override;
+    MODULE_VIZ_SCENE3D_API void mouseMoveEvent(
+        MouseButton /*_button*/,
+        Modifier _mod,
+        int _x,
+        int _y,
+        int /*_dx*/,
+        int /*_dy*/
+    ) override;
 
     /// Resets m_pickedData.
-    MODULE_VIZ_SCENE3D_API void buttonReleaseEvent(MouseButton, Modifier _mod, int, int) override;
+    MODULE_VIZ_SCENE3D_API void buttonReleaseEvent(
+        MouseButton _button,
+        Modifier _mod,
+        int _x,
+        int _y
+    ) override;
+
+    /// catch escape to go out of add distance mode
+    MODULE_VIZ_SCENE3D_API void keyPressEvent(int _key, Modifier /*_mods*/, int /*_mouseX*/, int /*_mouseY*/) final;
+
+    /// catch the mouse leaving the widget
+    MODULE_VIZ_SCENE3D_API void leaveEvent() final;
+
+    /// catch the mouse entering the widget
+    MODULE_VIZ_SCENE3D_API void enterEvent() final;
 
 protected:
 
@@ -117,10 +152,9 @@ protected:
     /**
      * @brief Proposals to connect service slots to associated object signals.
      *
-     * Connect data::Image::s_DISTANCE_ADDED_SIG to s_ADD_DISTANCE_SLOT
      * Connect data::Image::s_DISTANCE_REMOVED_SIG to s_REMOVE_DISTANCE_SLOT
      * Connect data::Image::s_DISTANCE_DISPLAYED_SIG to s_UPDATE_VISIBILITY_SLOT
-     * Connect data::Image::s_MODIFIED_SIG to s_UPDATE_SLOT
+     * Connect data::Image::s_MODIFIED_SIG to IService::slots::s_UPDATE
      */
     MODULE_VIZ_SCENE3D_API KeyConnectionsMap getAutoConnections() const override;
 
@@ -146,17 +180,17 @@ private:
     struct DistanceData
     {
         data::PointList::sptr m_pointList;
-        Ogre::SceneNode* m_node1;
-        Ogre::ManualObject* m_sphere1;
-        Ogre::SceneNode* m_node2;
-        Ogre::ManualObject* m_sphere2;
-        Ogre::ManualObject* m_line;
-        Ogre::ManualObject* m_dashedLine;
-        Ogre::SceneNode* m_labelNode;
-        sight::viz::scene3d::Text* m_label;
+        Ogre::SceneNode* m_node1 {};
+        Ogre::ManualObject* m_sphere1 {};
+        Ogre::SceneNode* m_node2 {};
+        Ogre::ManualObject* m_sphere2 {};
+        Ogre::ManualObject* m_line {};
+        Ogre::ManualObject* m_dashedLine {};
+        Ogre::SceneNode* m_labelNode {};
+        sight::viz::scene3d::IText::sptr m_label;
     };
 
-    /// Stores picking informations.
+    /// Stores picking information.
     struct PickedData
     {
         DistanceData* m_data;
@@ -164,14 +198,14 @@ private:
     };
 
     /// Map each distances to there related list ID.
-    typedef std::map<core::tools::fwID::IDType, DistanceData> DistanceMap;
+    using DistanceMap = std::map<core::tools::fwID::IDType, DistanceData>;
 
     /**
      * @brief Generates a color from a distance ID.
      * @param _id ID of the distance.
      * @return The generated color.
      */
-    static Ogre::ColourValue generateColor(core::tools::fwID::IDType _id);
+    Ogre::ColourValue generateColor();
 
     /**
      * @brief Generates a dashed line in a Ogre::ManualObject.
@@ -181,26 +215,26 @@ private:
      * @param _thickness Thickness of dash.
      */
     static void generateDashedLine(
-        Ogre::ManualObject* const _object,
+        Ogre::ManualObject* _object,
         const Ogre::Vector3& _begin,
         const Ogre::Vector3& _end,
         float _thickness
     );
 
     /**
-     * @brief Gets the formated string used to display the length of a distance.
-     * @return The formated string.
+     * @brief Gets the formatted string used to display the length of a distance.
+     * @return The formatted string.
      */
-    static std::string getLength(const Ogre::Vector3&, const Ogre::Vector3&);
+    static std::string getLength(const Ogre::Vector3& /*_begin*/, const Ogre::Vector3& /*_end*/);
 
     /**
      * @brief Gets the normalized camera direction vector.
      * @return A vector representing the camera direction
      */
-    static Ogre::Vector3 getCamDirection(const Ogre::Camera* const);
+    static Ogre::Vector3 getCamDirection(const Ogre::Camera* /*_cam*/);
 
-    /// Retrieves distances from the image and adds them to the scene.
-    void addDistances();
+    /// Saves the created distances to image's field
+    void updateImageDistanceField(data::PointList::sptr _pl);
 
     /// Retrieves distances from the image and remove them from the scene.
     void removeDistances();
@@ -208,6 +242,9 @@ private:
     /// Updates distances visibility from the image field.
     void updateVisibilityFromField();
 
+    /// Activates the distance tool by changing the cursor and updating a boolean
+    void activateDistanceTool(bool _activate);
+
     /**
      * @brief Gets the nearest picked position if there is one.
      * @param _x X screen coordinate.
@@ -220,7 +257,7 @@ private:
      * @brief Creates a distance and add it into m_distances.
      * @param _pl The point list used to create the distance.
      */
-    void createDistance(data::PointList::sptr _pl);
+    void createDistance(data::PointList::sptr& _pl);
 
     /**
      * @brief Updates a distance.
@@ -228,7 +265,7 @@ private:
      * @param _begin New begin position.
      * @param _end New end position
      */
-    void updateDistance(const DistanceData* const _data, Ogre::Vector3 _begin, Ogre::Vector3 _end);
+    void updateDistance(const DistanceData* _data, Ogre::Vector3 _begin, Ogre::Vector3 _end);
 
     /**
      * @brief Destroys a distance from its ID and remove it from m_distances.
@@ -236,21 +273,34 @@ private:
      */
     void destroyDistance(core::tools::fwID::IDType _id);
 
-    /// Defines the radius of distances spheres.
-    float m_distanceSphereRadius {3.5f};
+    /// Slot: Allows visualizing the creation and/or modification of distances field of an Image in multiple
+    /// adaptors(Negato2d/Negato3d) by displaying the distances synchronously.
+    void updateModifiedDistance(data::PointList::sptr _pl);
 
-    /// Defines the TrueType font source file.
-    std::string m_fontSource {"DejaVuSans.ttf"};
+    /// Defines the radius of distances spheres.
+    float m_distanceSphereRadius {3.5F};
 
     /// Defines the font size in points.
-    std::size_t m_fontSize {16};
+    std::size_t m_fontSize {12};
 
     /// Defines whether or not interactions are enabled with distances.
     bool m_interactive {true};
 
+    /// Defines whether to start using the distance creation tool or not.
+    bool m_toolActivated {false};
+
+    /// Defines whether a distance is in creation or not.
+    bool m_creationMode {false};
+
+    /// @brief  indicates if is over a distance
+    bool m_isOverDistance {false};
+
     /// Defines the priority of the interactor.
     int m_priority {2};
 
+    /// Counter to swap color at each new distance
+    int m_colorIndex {0};
+
     /// Defines the current picked data, reset by buttonReleaseEvent(MouseButton, int, int).
     PickedData m_pickedData {nullptr, true};
 
@@ -278,11 +328,12 @@ private:
     /// Contains the material with no depth check for dashed lines.
     sight::viz::scene3d::Material::uptr m_dashedLineMaterial {nullptr};
 
-    /// Stores all generatesd distances.
+    /// Stores all generated distances.
     DistanceMap m_distances;
+    std::vector<data::Point::sptr> m_points;
 
     static constexpr std::string_view s_IMAGE_INOUT = "image";
-    sight::data::ptr<sight::data::Image, sight::data::Access::inout> m_image {this, s_IMAGE_INOUT};
+    sight::data::ptr<sight::data::Image, sight::data::Access::inout> m_image {this, s_IMAGE_INOUT, true};
 };
 
 } // namespace sight::module::viz::scene3d::adaptor.
