@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -45,12 +45,7 @@ static const core::com::Slots::SlotKeyType s_SET_Y_OFFSET_SLOT = "setYOffset";
 static const service::IService::KeyType s_DIFFUSE_COLOR_INOUT  = "diffuseColor";
 static const service::IService::KeyType s_SPECULAR_COLOR_INOUT = "specularColor";
 
-static const std::string s_NAME_CONFIG         = "name";
-static const std::string s_SWITCHED_ON_CONFIG  = "switchedOn";
-static const std::string s_THETA_OFFSET_CONFIG = "thetaOffset";
-static const std::string s_PHI_OFFSET_CONFIG   = "phiOffset";
-
-fwRenderOgreRegisterLightMacro(
+SIGHT_REGISTER_SCENE3D_LIGHT(
     sight::module::viz::scene3d::adaptor::SLight,
     sight::viz::scene3d::ILight::REGISTRY_KEY
 )
@@ -73,20 +68,11 @@ SLight::SLight(sight::viz::scene3d::ILight::Key /*key*/)
 
 //------------------------------------------------------------------------------
 
-SLight::~SLight() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void SLight::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
-
-    m_lightName = config.get<std::string>("name");
+    const ConfigType config = this->getConfiguration();
 
     this->setTransformId(
         config.get<std::string>(
@@ -95,6 +81,12 @@ void SLight::configuring()
         )
     );
 
+    static const std::string s_NAME_CONFIG         = s_CONFIG + "name";
+    static const std::string s_SWITCHED_ON_CONFIG  = s_CONFIG + "switchedOn";
+    static const std::string s_THETA_OFFSET_CONFIG = s_CONFIG + "thetaOffset";
+    static const std::string s_PHI_OFFSET_CONFIG   = s_CONFIG + "phiOffset";
+
+    m_lightName   = config.get<std::string>(s_NAME_CONFIG);
     m_switchedOn  = config.get<bool>(s_SWITCHED_ON_CONFIG, m_switchedOn);
     m_thetaOffset = config.get<float>(s_THETA_OFFSET_CONFIG, m_thetaOffset);
     m_phiOffset   = config.get<float>(s_PHI_OFFSET_CONFIG, m_phiOffset);
@@ -112,7 +104,6 @@ void SLight::starting()
     m_light = sceneMgr->createLight(this->getID() + "_" + m_lightName);
 
     // Sets the default light direction to the camera's view direction,
-    m_light->setDirection(Ogre::Vector3::NEGATIVE_UNIT_Z);
     m_light->setType(m_lightType);
     m_light->setVisible(m_switchedOn);
 
@@ -121,7 +112,7 @@ void SLight::starting()
     m_lightNode = transNode->createChildSceneNode(this->getID() + "_light");
     m_lightNode->attachObject(m_light);
 
-    if(m_thetaOffset != 0.f || m_phiOffset != 0.f)
+    if(m_thetaOffset != 0.F || m_phiOffset != 0.F)
     {
         this->setThetaOffset(m_thetaOffset);
         this->setPhiOffset(m_phiOffset);
@@ -138,18 +129,19 @@ void SLight::starting()
                 "sight::module::viz::scene3d::adaptor::SMaterial"
             );
         materialAdaptor->setInOut(m_material, module::viz::scene3d::adaptor::SMaterial::s_MATERIAL_INOUT, true);
-        materialAdaptor->setID(this->getID() + materialAdaptor->getID());
-        materialAdaptor->setMaterialName(this->getID() + materialAdaptor->getID());
-        materialAdaptor->setRenderService(this->getRenderService());
-        materialAdaptor->setLayerID(m_layerID);
-        materialAdaptor->setMaterialTemplateName(sight::viz::scene3d::Material::DEFAULT_MATERIAL_TEMPLATE_NAME);
+        materialAdaptor->configure(
+            this->getID() + materialAdaptor->getID(),
+            this->getID() + materialAdaptor->getID(),
+            this->getRenderService(),
+            m_layerID
+        );
         materialAdaptor->start();
 
         materialAdaptor->getMaterialFw()->setHasVertexColor(true);
         materialAdaptor->update();
 
         // Size, these value allow to display light with good enough ratio.
-        const float originRadius   = m_length * 0.1f;
+        const float originRadius   = m_length * 0.1F;
         const float cylinderLength = m_length - m_length / 10;
         const float cylinderRadius = m_length / 80;
         const float coneLength     = m_length - cylinderLength;
@@ -161,7 +153,7 @@ void SLight::starting()
         sight::viz::scene3d::helper::ManualObject::createSphere(
             m_lightPosition,
             materialAdaptor->getMaterialName(),
-            Ogre::ColourValue(0.98f, 0.96f, 0.62f, 1.0f),
+            Ogre::ColourValue(0.98F, 0.96F, 0.62F, 1.0F),
             originRadius,
             sample
         );
@@ -175,7 +167,7 @@ void SLight::starting()
         sight::viz::scene3d::helper::ManualObject::createCylinder(
             m_directionalFeedback.first,
             materialAdaptor->getMaterialName(),
-            Ogre::ColourValue(0.f, 0.f, 1.f, 1.0f),
+            Ogre::ColourValue(0.F, 0.F, 1.F, 1.0F),
             cylinderRadius,
             cylinderLength,
             sample
@@ -187,7 +179,7 @@ void SLight::starting()
         sight::viz::scene3d::helper::ManualObject::createCone(
             m_directionalFeedback.second,
             materialAdaptor->getMaterialName(),
-            Ogre::ColourValue(0.f, 0.f, 1.f, 1.0f),
+            Ogre::ColourValue(0.F, 0.F, 1.F, 1.0F),
             coneRadius,
             coneLength,
             sample
@@ -195,7 +187,7 @@ void SLight::starting()
         Ogre::SceneNode* coneNode = m_lightNode->createChildSceneNode(this->getID() + "_coneNode");
 
         coneNode->attachObject(m_directionalFeedback.second);
-        coneNode->translate(0.f, 0.f, cylinderLength);
+        coneNode->translate(0.F, 0.F, cylinderLength);
         coneNode->yaw(Ogre::Degree(-90));
 
         m_directionalFeedback.first->setVisible(m_visualFeedback && m_lightType == Ogre::Light::LT_DIRECTIONAL);
@@ -210,8 +202,8 @@ void SLight::starting()
 service::IService::KeyConnectionsMap SLight::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_DIFFUSE_COLOR_INOUT, data::Color::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_SPECULAR_COLOR_INOUT, data::Color::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_DIFFUSE_COLOR_INOUT, data::Color::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_SPECULAR_COLOR_INOUT, data::Color::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -303,7 +295,7 @@ void SLight::switchOn(bool _on)
 {
     m_switchedOn = _on;
 
-    if(m_light)
+    if(m_light != nullptr)
     {
         m_light->setVisible(m_switchedOn);
         this->requestRender();
@@ -347,7 +339,7 @@ void SLight::setPhiOffset(float _phiOffset)
 void SLight::enableVisualFeedback(bool _enable)
 {
     m_visualFeedback = _enable;
-    if(m_lightPosition)
+    if(m_lightPosition != nullptr)
     {
         m_lightPosition->setVisible(m_visualFeedback);
         m_directionalFeedback.first->setVisible(m_visualFeedback && m_lightType == Ogre::Light::LT_DIRECTIONAL);
@@ -360,7 +352,7 @@ void SLight::enableVisualFeedback(bool _enable)
 void SLight::setType(Ogre::Light::LightTypes _type)
 {
     m_lightType = _type;
-    if(m_directionalFeedback.first)
+    if(m_directionalFeedback.first != nullptr)
     {
         m_directionalFeedback.first->setVisible(m_visualFeedback && m_lightType == Ogre::Light::LT_DIRECTIONAL);
         m_directionalFeedback.second->setVisible(m_visualFeedback && m_lightType == Ogre::Light::LT_DIRECTIONAL);
