@@ -35,7 +35,7 @@ namespace sight::data
 
 class Material;
 
-}
+} // namespace sight::data
 
 namespace sight::module::viz::scene3d::adaptor
 {
@@ -53,12 +53,11 @@ namespace sight::module::viz::scene3d::adaptor
  * @section XML XML Configuration
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SLine">
-        <config layer="default" transform="transformUID" length="30" dashLength="2.5" color="#0000FF" dashed="false" />
+        <config transform="transformUID" length="30" dashLength="2.5" color="#0000FF" dashed="false" />
     </service>
    @endcode
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the line's layer
  * - \b transform (optional, string, default=""): the name of the Ogre transform node where to attach the mesh, as it
  *      was specified in the STransform adaptor
  * - \b length (optional, float, default=50.0): length of the line in mm (default 50)
@@ -108,7 +107,7 @@ private:
      * @brief Attaches a node in the scene graph.
      * @param _node node to attach.
      */
-    void attachNode(Ogre::MovableObject* _node);
+    void attachNode(Ogre::MovableObject* object);
 
     /**
      * @brief Draws a line.
@@ -132,7 +131,7 @@ private:
     Ogre::ManualObject* m_line {nullptr};
 
     /// Defines the length of the line (in mm).
-    float m_length {50.f};
+    float m_length {50.F};
 
     /// Defines the color of the line.
     Ogre::ColourValue m_color;
@@ -141,7 +140,7 @@ private:
     bool m_dashed {false};
 
     /// Defines the length of one dash.
-    float m_dashLength {2.5f};
+    float m_dashLength {2.5F};
 };
 
 } // namespace sight::module::viz::scene3d::adaptor.
