@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -33,6 +33,7 @@
 #include <data/Mesh.hpp>
 
 #include <viz/scene3d/IAdaptor.hpp>
+#include <viz/scene3d/IMaterialAdaptor.hpp>
 #include <viz/scene3d/Material.hpp>
 #include <viz/scene3d/Mesh.hpp>
 #include <viz/scene3d/ogre.hpp>
@@ -48,7 +49,7 @@ namespace sight::data
 
 class Material;
 
-}
+} // namespace sight::data
 
 namespace sight::module::viz::scene3d::adaptor
 {
@@ -76,7 +77,6 @@ namespace sight::module::viz::scene3d::adaptor
  *      of the adaptor.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): defines the mesh's layer.
  * - \b materialTemplate (optional, string, default=""): name of the base Ogre material/
  * - \b materialName (optional, string, default=""): name of the Ogre material. This is necessary to bind a
  *      sight::module::viz::scene3d:SMesh or a sight::module::viz::scene3d:SModelSeries to this material;
@@ -88,12 +88,12 @@ namespace sight::module::viz::scene3d::adaptor
  *  - \b representationMode (optional, SURFACE/POINT/WIREFRAME/EDGE, default=SURFACE):
  *      representation mode as in data::Material.
  */
-class MODULE_VIZ_SCENE3D_CLASS_API SMaterial final : public sight::viz::scene3d::IAdaptor
+class MODULE_VIZ_SCENE3D_CLASS_API SMaterial final : public sight::viz::scene3d::IMaterialAdaptor
 {
 public:
 
     /// Generates default methods as New, dynamicCast, ...
-    SIGHT_DECLARE_SERVICE(SMaterial, sight::viz::scene3d::IAdaptor);
+    SIGHT_DECLARE_SERVICE(SMaterial, sight::viz::scene3d::IMaterialAdaptor);
 
     /**
      * @name Slots API
@@ -116,37 +116,47 @@ public:
     MODULE_VIZ_SCENE3D_API SMaterial() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SMaterial() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SMaterial() noexcept override = default;
+
+    /// Configures the adaptor without using the XML configuration.
+    MODULE_VIZ_SCENE3D_API void configure(
+        const std::string& _id,
+        const std::string& _name,
+        sight::viz::scene3d::SRender::sptr _service,
+        const std::string& _layer,
+        const std::string& _shadingMode = "",
+        const std::string& _template    = sight::viz::scene3d::Material::DEFAULT_MATERIAL_TEMPLATE_NAME
+    ) override;
 
     /// Gets Ogre associated material.
-    MODULE_VIZ_SCENE3D_API Ogre::MaterialPtr getMaterial();
+    MODULE_VIZ_SCENE3D_API Ogre::MaterialPtr getMaterial() override;
 
     /// Gets material name.
-    MODULE_VIZ_SCENE3D_API std::string getMaterialName() const;
+    MODULE_VIZ_SCENE3D_API std::string getMaterialName() const override;
 
     /// Retrieves the associated texture name.
-    MODULE_VIZ_SCENE3D_API void setTextureName(const std::string& _textureName);
+    MODULE_VIZ_SCENE3D_API void setTextureName(const std::string& _textureName) override;
 
     /// Sets material name.
-    MODULE_VIZ_SCENE3D_API void setMaterialName(const std::string& _materialName);
+    MODULE_VIZ_SCENE3D_API void setMaterialName(const std::string& _materialName) override;
 
     /// Sets material template name.
-    MODULE_VIZ_SCENE3D_API void setMaterialTemplateName(const std::string& _materialName);
+    MODULE_VIZ_SCENE3D_API void setMaterialTemplateName(const std::string& _materialName) override;
 
     /// Tells if there is a texture currently bound.
-    MODULE_VIZ_SCENE3D_API bool hasDiffuseTexture() const;
+    MODULE_VIZ_SCENE3D_API bool hasDiffuseTexture() const override;
 
     /// Gets the shading mode.
-    MODULE_VIZ_SCENE3D_API const std::string& getShadingMode() const;
+    MODULE_VIZ_SCENE3D_API const std::string& getShadingMode() const override;
 
     /// Sets the shading mode.
-    MODULE_VIZ_SCENE3D_API void setShadingMode(const std::string& _shadingMode);
+    MODULE_VIZ_SCENE3D_API void setShadingMode(const std::string& _shadingMode) override;
 
     /// Set the renderable object.
-    MODULE_VIZ_SCENE3D_API void setR2VBObject(sight::viz::scene3d::R2VBRenderable* _r2vbObject);
+    MODULE_VIZ_SCENE3D_API void setR2VBObject(sight::viz::scene3d::R2VBRenderable* _r2vbObject) override;
 
     /// Gets the internal material code.
-    MODULE_VIZ_SCENE3D_API sight::viz::scene3d::Material* getMaterialFw() const;
+    MODULE_VIZ_SCENE3D_API sight::viz::scene3d::Material* getMaterialFw() const override;
 
 protected:
 
@@ -160,7 +170,7 @@ protected:
      * @brief Proposals to connect service slots to associated object signals.
      * @return A map of each proposed connection.
      *
-     * Connect data::Material::s_MODIFIED_SIG of s_MATERIAL_INOUT to s_UPDATE_SLOT
+     * Connect data::Material::s_MODIFIED_SIG of s_MATERIAL_INOUT to IService::slots::s_UPDATE
      * Connect data::Material::s_ADDED_FIELDS_SIG of s_MATERIAL_INOUT to s_UPDATE_FIELD_SLOT
      * Connect data::Material::s_CHANGED_FIELDS_SIG of s_MATERIAL_INOUT to s_UPDATE_FIELD_SLOT
      * Connect data::Material::s_ADDED_TEXTURE_SIG of s_MATERIAL_INOUT to s_ADD_TEXTURE_SLOT
