@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -40,13 +40,13 @@ namespace sight::data
 
 class Material;
 
-}
+} // namespace sight::data
 namespace sight::data
 {
 
 class Mesh;
 
-}
+} // namespace sight::data
 
 namespace sight::module::viz::scene3d::adaptor
 {
@@ -81,7 +81,7 @@ namespace sight::module::viz::scene3d::adaptor
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SMesh" >
         <in key="mesh" uid="..." />
-        <config layer="..." transform="..." visible="true" materialName="..." shadingMode="phong" textureName="..."
+        <config transform="..." visible="true" materialName="..." shadingMode="phong" textureName="..."
         queryFlags="0x40000000" />
     </service>
    @endcode
@@ -90,7 +90,6 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b mesh [sight::data::Mesh]: adapted mesh.
  *
  * @subsection Configuration Configuration:
- *  - \b layer (mandatory, string): defines the mesh's layer
  *  - \b autoresetcamera (optional, true/false, default=true): reset the camera when this mesh is modified, "true" or
  *"false".
  *  - \b transform (optional, string, default=""): the name of the Ogre transform node where to attach the mesh, as it
@@ -210,7 +209,7 @@ protected:
      * Connect data::Mesh::s_POINT_COLORS_MODIFIED_SIG to s_MODIFY_COLORS_SLOT
      * Connect data::Mesh::s_CELL_COLORS_MODIFIED_SIG to s_MODIFY_COLORS_SLOT
      * Connect data::Mesh::s_POINT_TEX_COORDS_MODIFIED_SIG to s_MODIFY_POINT_TEX_COORDS_SLOT
-     * Connect data::Mesh::s_MODIFIED_SIG to s_UPDATE_SLOT
+     * Connect data::Mesh::s_MODIFIED_SIG to IService::slots::s_UPDATE
      */
     MODULE_VIZ_SCENE3D_API service::IService::KeyConnectionsMap getAutoConnections() const override;
 
@@ -352,7 +351,7 @@ inline Ogre::Entity* SMesh::getEntity() const
 
 inline bool SMesh::getVisibility() const
 {
-    return m_entity ? m_entity->getVisible() : m_isVisible;
+    return m_entity != nullptr ? m_entity->getVisible() : m_isVisible;
 }
 
 //------------------------------------------------------------------------------
