@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2021 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -43,12 +43,6 @@ namespace sight::module::viz::scene3d::adaptor
 
 static const core::com::Slots::SlotKeyType s_CHANGE_FIELD_SLOT = "changeField";
 
-static const std::string s_AUTORESET_CAMERA_CONFIG = "autoresetcamera";
-static const std::string s_MATERIAL_CONFIG         = "material";
-static const std::string s_DYNAMIC_CONFIG          = "dynamic";
-static const std::string s_DYNAMIC_VERTICES_CONFIG = "dynamicVertices";
-static const std::string s_QUERY_CONFIG            = "queryFlags";
-
 //------------------------------------------------------------------------------
 
 SModelSeries::SModelSeries() noexcept
@@ -58,18 +52,11 @@ SModelSeries::SModelSeries() noexcept
 
 //------------------------------------------------------------------------------
 
-SModelSeries::~SModelSeries() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void SModelSeries::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
     this->setTransformId(
         config.get<std::string>(
@@ -78,15 +65,21 @@ void SModelSeries::configuring()
         )
     );
 
+    static const std::string s_AUTORESET_CAMERA_CONFIG = s_CONFIG + "autoresetcamera";
+    static const std::string s_MATERIAL_CONFIG         = s_CONFIG + "material";
+    static const std::string s_DYNAMIC_CONFIG          = s_CONFIG + "dynamic";
+    static const std::string s_DYNAMIC_VERTICES_CONFIG = s_CONFIG + "dynamicVertices";
+    static const std::string s_QUERY_CONFIG            = s_CONFIG + "queryFlags";
+
     m_autoResetCamera = config.get<bool>(s_AUTORESET_CAMERA_CONFIG, true);
 
     m_materialTemplateName = config.get<std::string>(s_MATERIAL_CONFIG, m_materialTemplateName);
     m_isDynamic            = config.get<bool>(s_DYNAMIC_CONFIG, m_isDynamic);
     m_isDynamicVertices    = config.get<bool>(s_DYNAMIC_VERTICES_CONFIG, m_isDynamicVertices);
 
-    if(config.count(s_QUERY_CONFIG))
+    if(config.count(s_QUERY_CONFIG) != 0U)
     {
-        const std::string hexaMask = config.get<std::string>(s_QUERY_CONFIG);
+        const auto hexaMask = config.get<std::string>(s_QUERY_CONFIG);
         SIGHT_ASSERT(
             "Hexadecimal values should start with '0x'"
             "Given value : " + hexaMask,
@@ -116,9 +109,9 @@ void SModelSeries::starting()
 service::IService::KeyConnectionsMap SModelSeries::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_MODEL_INPUT, data::ModelSeries::s_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_MODEL_INPUT, data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG, s_UPDATE_SLOT);
-    connections.push(s_MODEL_INPUT, data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG, s_UPDATE_SLOT);
+    connections.push(s_MODEL_INPUT, data::ModelSeries::s_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_MODEL_INPUT, data::ModelSeries::s_RECONSTRUCTIONS_ADDED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_MODEL_INPUT, data::ModelSeries::s_RECONSTRUCTIONS_REMOVED_SIG, IService::slots::s_UPDATE);
     connections.push(s_MODEL_INPUT, data::ModelSeries::s_ADDED_FIELDS_SIG, s_CHANGE_FIELD_SLOT);
     connections.push(s_MODEL_INPUT, data::ModelSeries::s_REMOVED_FIELDS_SIG, s_CHANGE_FIELD_SLOT);
     connections.push(s_MODEL_INPUT, data::ModelSeries::s_CHANGED_FIELDS_SIG, s_CHANGE_FIELD_SLOT);
@@ -137,7 +130,7 @@ void SModelSeries::updating()
     // showRec indicates if we have to show the associated reconstructions or not
     const bool showRec = modelSeries->getField("ShowReconstructions", data::Boolean::New(true))->value();
 
-    for(auto reconstruction : modelSeries->getReconstructionDB())
+    for(const auto& reconstruction : modelSeries->getReconstructionDB())
     {
         auto adaptor = this->registerService<module::viz::scene3d::adaptor::SReconstruction>(
             "sight::module::viz::scene3d::adaptor::SReconstruction"
@@ -184,7 +177,7 @@ void SModelSeries::stopping()
 void SModelSeries::setVisible(bool _visible)
 {
     auto adaptors = this->getRegisteredServices();
-    for(auto adaptor : adaptors)
+    for(const auto& adaptor : adaptors)
     {
         auto recAdaptor = module::viz::scene3d::adaptor::SReconstruction::dynamicCast(adaptor.lock());
         recAdaptor->updateVisibility(!_visible);
@@ -200,7 +193,7 @@ void SModelSeries::showReconstructionsOnFieldChanged()
     const bool showRec = modelSeries->getField("ShowReconstructions", data::Boolean::New(true))->value();
 
     auto adaptors = this->getRegisteredServices();
-    for(auto adaptor : adaptors)
+    for(const auto& adaptor : adaptors)
     {
         auto recAdaptor = module::viz::scene3d::adaptor::SReconstruction::dynamicCast(adaptor.lock());
         recAdaptor->updateVisibility(!showRec);
