@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -36,28 +36,16 @@ namespace sight::module::viz::scene3d::adaptor
 {
 
 static const core::com::Slots::SlotKeyType s_RESET_CAMERA_SLOT       = "resetCamera";
+static const core::com::Slots::SlotKeyType s_RESIZE_VIEWPORT_SLOT    = "resizeViewport";
 static const core::com::Slots::SlotKeyType s_CHANGE_ORIENTATION_SLOT = "changeOrientation";
-static const core::com::Slots::SlotKeyType s_MOVE_BACK_SLOT          = "moveBack";
-
-static const std::string s_PRIORITY_CONFIG              = "priority";
-static const std::string s_LAYER_ORDER_DEPENDANT_CONFIG = "layerOrderDependant";
-static const std::string s_ORIENTATION_CONFIG           = "orientation";
 
 //-----------------------------------------------------------------------------
 
-SNegato2DCamera::SNegato2DCamera() noexcept :
-    // This connection is useless here but needed to create the TF helper.
-    m_helperTF(std::bind(&SNegato2DCamera::updating, this))
+SNegato2DCamera::SNegato2DCamera() noexcept
 {
     newSlot(s_RESET_CAMERA_SLOT, &SNegato2DCamera::resetCamera, this);
+    newSlot(s_RESIZE_VIEWPORT_SLOT, &SNegato2DCamera::resizeViewport, this);
     newSlot(s_CHANGE_ORIENTATION_SLOT, &SNegato2DCamera::changeOrientation, this);
-    newSlot(s_MOVE_BACK_SLOT, &SNegato2DCamera::moveBack, this);
-}
-
-//-----------------------------------------------------------------------------
-
-SNegato2DCamera::~SNegato2DCamera() noexcept
-{
 }
 
 //-----------------------------------------------------------------------------
@@ -66,13 +54,12 @@ void SNegato2DCamera::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
-    m_priority            = config.get<int>(s_PRIORITY_CONFIG, m_priority);
-    m_layerOrderDependant = config.get<bool>(s_LAYER_ORDER_DEPENDANT_CONFIG, m_layerOrderDependant);
+    m_priority            = config.get<int>(s_CONFIG + "priority", m_priority);
+    m_layerOrderDependant = config.get<bool>(s_CONFIG + "layerOrderDependant", m_layerOrderDependant);
 
-    const std::string orientation = config.get<std::string>(s_ORIENTATION_CONFIG, "sagittal");
+    const std::string orientation = config.get<std::string>(s_CONFIG + "orientation", "sagittal");
 
     SIGHT_ERROR_IF(
         "Unknown orientation: '" + orientation
@@ -92,6 +79,8 @@ void SNegato2DCamera::configuring()
     {
         m_currentNegatoOrientation = Orientation::X_AXIS;
     }
+
+    m_margin = config.get<float>(s_CONFIG + "margin", m_margin);
 }
 
 //-----------------------------------------------------------------------------
@@ -107,6 +96,13 @@ void SNegato2DCamera::starting()
     Ogre::Camera* const cam = this->getLayer()->getDefaultCamera();
     cam->setProjectionType(Ogre::ProjectionType::PT_ORTHOGRAPHIC);
 
+    m_layerConnection.connect(
+        this->getLayer(),
+        sight::viz::scene3d::Layer::s_RESIZE_LAYER_SIG,
+        this->getSptr(),
+        s_RESIZE_VIEWPORT_SLOT
+    );
+
     this->resetCamera();
 }
 
@@ -119,20 +115,9 @@ void SNegato2DCamera::updating() noexcept
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::swapping(std::string_view _key)
-{
-    if(_key == s_TF_INOUT)
-    {
-        const auto image = m_image.lock();
-        const auto tf    = m_tf.lock();
-        m_helperTF.setOrCreateTF(tf.get_shared(), image.get_shared());
-    }
-}
-
-//-----------------------------------------------------------------------------
-
 void SNegato2DCamera::stopping()
 {
+    m_layerConnection.disconnect();
     const auto layer = this->getLayer();
     auto interactor  = std::dynamic_pointer_cast<sight::viz::scene3d::interactor::IInteractor>(this->getSptr());
     layer->removeInteractor(interactor);
@@ -142,17 +127,15 @@ void SNegato2DCamera::stopping()
 
 service::IService::KeyConnectionsMap SNegato2DCamera::getAutoConnections() const
 {
-    KeyConnectionsMap connections;
-    connections.push(s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, s_RESET_CAMERA_SLOT);
-    connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_CHANGE_ORIENTATION_SLOT);
-    connections.push(s_IMAGE_INOUT, data::Image::s_SLICE_INDEX_MODIFIED_SIG, s_MOVE_BACK_SLOT);
-
-    return connections;
+    return {
+        {s_IMAGE_INOUT, data::Image::s_MODIFIED_SIG, s_RESET_CAMERA_SLOT},
+        {s_IMAGE_INOUT, data::Image::s_SLICE_TYPE_MODIFIED_SIG, s_CHANGE_ORIENTATION_SLOT}
+    };
 }
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
+void SNegato2DCamera::wheelEvent(Modifier _modifier, double _delta, int _x, int _y)
 {
     const auto layer = this->getLayer();
 
@@ -165,7 +148,7 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
             auto* const camera         = layer->getDefaultCamera();
             auto* const camNode        = camera->getParentNode();
 
-            constexpr float mouseWheelScale = 0.05f;
+            constexpr float mouseWheelScale = 0.05F;
             const float zoomAmount          = static_cast<float>(-_delta) * mouseWheelScale;
 
             // Compute the mouse's position in the camera's view.
@@ -178,12 +161,13 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
             // Zoom in.
             const float orthoHeight    = camera->getOrthoWindowHeight();
             const float newOrthoHeight = orthoHeight + (orthoHeight / zoomAmount);
-            const float clampedHeight  = std::max(newOrthoHeight, 1e-7f); // Make sure the height is strictly greater
+            const float clampedHeight  = std::max(newOrthoHeight, 1e-7F); // Make sure the height is strictly greater
                                                                           // than 0
 
-            const float vpWidth  = static_cast<float>(viewport->getActualWidth());
-            const float vpHeight = static_cast<float>(viewport->getActualHeight());
+            const auto vpWidth  = static_cast<float>(viewport->getActualWidth());
+            const auto vpHeight = static_cast<float>(viewport->getActualHeight());
 
+            SIGHT_ASSERT("Width and height should be strictly positive", vpWidth > 0 && vpHeight > 0);
             camera->setAspectRatio(vpWidth / vpHeight);
             camera->setOrthoWindowHeight(clampedHeight);
 
@@ -193,6 +177,9 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
 
             // Translate the camera back to the cursor's previous position.
             camNode->translate(mousePosView - newMousePosView);
+            m_hasMoved = true;
+
+            this->requestRender();
         }
         // Wheel alone or other modifier -> moving along slices (SHIFT to speed-up)
         else
@@ -206,7 +193,7 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
                 static_cast<int>(imHelper::getSliceIndex(*image, m_currentNegatoOrientation).value_or(0));
             const int max_slice = static_cast<int>(image->getSize()[m_currentNegatoOrientation] - 1);
 
-            if(max_slice < 0)
+            if(max_slice <= 0)
             {
                 // Do nothing, image doesn't have slices.
                 return;
@@ -221,12 +208,12 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
             // Here we assume that each 120 units of delta correspond to one increment of mouse wheel
             // So we move forward/backward of 1 slice each 120 units.
 
-            int slice_move = _delta / 120;
+            int slice_move = static_cast<int>(_delta) / 120;
 
             // Speed up SHIFT+ wheel: "scrolls" 5% of total slices at each wheel move.
             if(_modifier == Modifier::SHIFT)
             {
-                slice_move *= std::round(static_cast<float>(max_slice) * 5.f / 100.f);
+                slice_move *= int(std::round(static_cast<float>(max_slice) * 5.F / 100.F));
             }
 
             // TODO: We may test for finer-resolution wheels and wait for another event before moving.
@@ -246,25 +233,56 @@ void SNegato2DCamera::wheelEvent(Modifier _modifier, int _delta, int _x, int _y)
             imHelper::setSliceIndex(*image, m_currentNegatoOrientation, new_slice_index);
 
             // Get up-to-date index values.
-            const int idx[3] = {
+            const std::array<int, 3> idx {
                 static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::SAGITTAL).value_or(0)),
                 static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::FRONTAL).value_or(0)),
                 static_cast<int>(imHelper::getSliceIndex(*image, imHelper::orientation_t::AXIAL).value_or(0))
             };
+            m_hasMoved = true;
 
             // Send signal.
             auto sig = image->signal<data::Image::SliceIndexModifiedSignalType>(
                 data::Image::s_SLICE_INDEX_MODIFIED_SIG
             );
-            // this->moveBack() will be automatically called due to auto-connection.
             sig->asyncEmit(idx[2], idx[1], idx[0]);
         }
     }
 }
 
+//------------------------------------------------------------------------------
+
+void SNegato2DCamera::pinchGestureEvent(double _scaleFactor, int _centerX, int _centerY)
+{
+    // * 42 / 0.05 is a magic number to get a similar behavior as the mouse wheel
+    wheelEvent(Modifier::CONTROL, (_scaleFactor * 42) / 0.05, _centerX, _centerY);
+}
+
+//------------------------------------------------------------------------------
+
+void SNegato2DCamera::panGestureMoveEvent(int _x, int _y, int _dx, int _dy)
+{
+    m_isInteracting = true;
+
+    mouseMoveEvent(MouseButton::MIDDLE, {}, _x, _y, _dx, _dy);
+}
+
+//------------------------------------------------------------------------------
+
+void SNegato2DCamera::panGestureReleaseEvent(int /*_x*/, int /*_y*/, int /*_dx*/, int /*_dy*/)
+{
+    m_isInteracting = false;
+}
+
 // ----------------------------------------------------------------------------
 
-void SNegato2DCamera::mouseMoveEvent(IInteractor::MouseButton _button, Modifier, int _x, int _y, int _dx, int _dy)
+void SNegato2DCamera::mouseMoveEvent(
+    IInteractor::MouseButton _button,
+    Modifier /*_mods*/,
+    int _x,
+    int _y,
+    int _dx,
+    int _dy
+)
 {
     if(m_isInteracting && _button == MouseButton::MIDDLE)
     {
@@ -286,11 +304,13 @@ void SNegato2DCamera::mouseMoveEvent(IInteractor::MouseButton _button, Modifier,
             sight::viz::scene3d::helper::Camera::convertScreenSpaceToViewSpace(*camera, screenPos);
 
         camNode->translate(mousePosView - previousMousePosView);
+        m_hasMoved = true;
+        this->requestRender();
     }
     else if(m_isInteracting && _button == MouseButton::RIGHT)
     {
-        const double dx = static_cast<double>(_x - m_initialPos[0]);
-        const double dy = static_cast<double>(m_initialPos[1] - _y);
+        const auto dx = static_cast<double>(_x - m_initialPos[0]);
+        const auto dy = static_cast<double>(m_initialPos[1] - _y);
 
         this->updateWindowing(dx, dy);
     }
@@ -298,7 +318,7 @@ void SNegato2DCamera::mouseMoveEvent(IInteractor::MouseButton _button, Modifier,
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::buttonPressEvent(IInteractor::MouseButton _button, Modifier, int _x, int _y)
+void SNegato2DCamera::buttonPressEvent(IInteractor::MouseButton _button, Modifier /*_mods*/, int _x, int _y)
 {
     const auto layer = this->getLayer();
     if(_button == MouseButton::MIDDLE)
@@ -309,11 +329,10 @@ void SNegato2DCamera::buttonPressEvent(IInteractor::MouseButton _button, Modifie
     {
         m_isInteracting = true;
 
-        const data::TransferFunction::sptr tf = m_helperTF.getTransferFunction();
-        const data::mt::locked_ptr lock(tf);
+        const auto tf = m_tf.const_lock();
 
-        m_initialLevel  = tf->getLevel();
-        m_initialWindow = tf->getWindow();
+        m_initialLevel  = tf->level();
+        m_initialWindow = tf->window();
 
         m_initialPos = {_x, _y};
     }
@@ -321,14 +340,19 @@ void SNegato2DCamera::buttonPressEvent(IInteractor::MouseButton _button, Modifie
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::buttonReleaseEvent(IInteractor::MouseButton, Modifier, int, int)
+void SNegato2DCamera::buttonReleaseEvent(
+    IInteractor::MouseButton /*_button*/,
+    Modifier /*_mods*/,
+    int /*_x*/,
+    int /*_y*/
+)
 {
     m_isInteracting = false;
 }
 
 //-----------------------------------------------------------------------------
 
-void SNegato2DCamera::keyPressEvent(int _key, Modifier, int _x, int _y)
+void SNegato2DCamera::keyPressEvent(int _key, Modifier /*_mods*/, int _x, int _y)
 {
     const auto layer = this->getLayer();
     if(IInteractor::isInLayer(_x, _y, layer, m_layerOrderDependant) && (_key == 'R' || _key == 'r'))
@@ -343,26 +367,24 @@ void SNegato2DCamera::resetCamera()
 {
     // This method is called when the image buffer is modified,
     // we need to retrieve the TF here if it came from the image.
-    const auto image = m_image.lock();
-    const auto tf    = m_tf.lock();
-    m_helperTF.setOrCreateTF(tf.get_shared(), image.get_shared());
-
     const auto layer           = this->getLayer();
     const auto* const viewport = layer->getViewport();
     auto* const camera         = layer->getDefaultCamera();
     auto* const camNode        = camera->getParentNode();
 
-    const float vpWidth  = static_cast<float>(viewport->getActualWidth());
-    const float vpHeight = static_cast<float>(viewport->getActualHeight());
-    const float vpRatio  = vpWidth / vpHeight;
+    const auto vpWidth  = static_cast<float>(viewport->getActualWidth());
+    const auto vpHeight = static_cast<float>(viewport->getActualHeight());
+    SIGHT_ASSERT("Width and height should be strictly positive", vpWidth > 0 && vpHeight > 0);
+    const float vpRatio = vpWidth / vpHeight;
     camera->setAspectRatio(vpRatio);
 
     // HACK: Temporarily set the near clip distance here because the Layer doesn't handle orthographic cameras.
-    camera->setNearClipDistance(1e-3f);
+    camera->setNearClipDistance(1e-3F);
 
     camNode->setPosition(Ogre::Vector3::ZERO);
     camNode->resetOrientation();
 
+    const auto image   = m_image.const_lock();
     const auto origin  = image->getOrigin();
     const auto size    = image->getSize();
     const auto spacing = image->getSpacing();
@@ -375,43 +397,43 @@ void SNegato2DCamera::resetCamera()
         switch(m_currentNegatoOrientation)
         {
             case Orientation::X_AXIS:
-                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(-90.f));
-                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(-90.f));
+                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(-90.F));
+                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(-90.F));
                 width  = static_cast<double>(size[1]) * spacing[1];
                 height = static_cast<double>(size[2]) * spacing[2];
                 ratio  = static_cast<float>(width / height);
                 break;
 
             case Orientation::Y_AXIS:
-                camNode->rotate(Ogre::Vector3::UNIT_X, Ogre::Degree(90.f));
+                camNode->rotate(Ogre::Vector3::UNIT_X, Ogre::Degree(90.F));
                 width  = static_cast<double>(size[0]) * spacing[0];
                 height = static_cast<double>(size[2]) * spacing[2];
                 ratio  = static_cast<float>(width / height);
                 break;
 
             case Orientation::Z_AXIS:
-                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(180.f));
-                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(180.f));
-                height = static_cast<double>(size[0]) * spacing[0];
-                width  = static_cast<double>(size[1]) * spacing[1];
+                camNode->rotate(Ogre::Vector3::UNIT_Z, Ogre::Degree(180.F));
+                camNode->rotate(Ogre::Vector3::UNIT_Y, Ogre::Degree(180.F));
+                width  = static_cast<double>(size[0]) * spacing[0];
+                height = static_cast<double>(size[1]) * spacing[1];
                 ratio  = static_cast<float>(width / height);
                 break;
         }
 
         if(vpRatio > ratio)
         {
-            const Ogre::Real h = static_cast<Ogre::Real>(height);
-            // Zoom out the camera (add 10% of the height), allow the image to not be stuck on the viewport.
-            camera->setOrthoWindowHeight(h + h * 0.1f);
+            const auto h = static_cast<Ogre::Real>(height);
+            // Zoom out the camera with the margin, allow the image to not be stuck on the viewport.
+            camera->setOrthoWindowHeight(h + h * m_margin);
         }
         else
         {
-            const Ogre::Real w = static_cast<Ogre::Real>(width);
-            // Zoom out the camera (add 10% of the width), allow the image to not be stuck on the viewport.
-            camera->setOrthoWindowWidth(w + w * 0.1f);
+            const auto w = static_cast<Ogre::Real>(width);
+            // Zoom out the camera with the margin, allow the image to not be stuck on the viewport.
+            camera->setOrthoWindowWidth(w + w * m_margin);
         }
 
-        const std::size_t orientation = static_cast<std::size_t>(m_currentNegatoOrientation);
+        const auto orientation = static_cast<std::size_t>(m_currentNegatoOrientation);
         Ogre::Vector3 camPos(
             static_cast<Ogre::Real>(origin[0] + static_cast<double>(size[0]) * spacing[0] * 0.5),
             static_cast<Ogre::Real>(origin[1] + static_cast<double>(size[1]) * spacing[1] * 0.5),
@@ -423,16 +445,21 @@ void SNegato2DCamera::resetCamera()
                                     * spacing[orientation]);
         camNode->setPosition(camPos);
 
-        const auto worldBoundingBox = layer->computeWorldBoundingBox();
-        if(worldBoundingBox.isFinite())
-        {
-            layer->resetCameraClippingRange(worldBoundingBox);
-        }
-
+        m_hasMoved = false;
         this->requestRender();
     }
 }
 
+//------------------------------------------------------------------------------
+
+void SNegato2DCamera::resizeViewport()
+{
+    if(!m_hasMoved)
+    {
+        this->resetCamera();
+    }
+}
+
 //-----------------------------------------------------------------------------
 
 void SNegato2DCamera::changeOrientation(int _from, int _to)
@@ -452,31 +479,6 @@ void SNegato2DCamera::changeOrientation(int _from, int _to)
     }
 }
 
-//-----------------------------------------------------------------------------
-
-void SNegato2DCamera::moveBack()
-{
-    const auto layer    = this->getLayer();
-    auto* const camera  = layer->getDefaultCamera();
-    auto* const camNode = camera->getParentNode();
-
-    const auto worldBoundingBox = layer->computeWorldBoundingBox();
-
-    if(worldBoundingBox.isFinite())
-    {
-        const std::size_t orientation = static_cast<std::size_t>(m_currentNegatoOrientation);
-
-        auto camPos = camNode->getPosition();
-
-        const float backupPos = worldBoundingBox.getMinimum()[orientation] - 1.f;
-        camPos[orientation] = std::min(camPos[orientation], backupPos);
-
-        camNode->setPosition(camPos);
-
-        this->requestRender();
-    }
-}
-
 //------------------------------------------------------------------------------
 
 void SNegato2DCamera::updateWindowing(double _dw, double _dl)
@@ -484,13 +486,13 @@ void SNegato2DCamera::updateWindowing(double _dw, double _dl)
     const double newWindow = m_initialWindow + _dw;
     const double newLevel  = m_initialLevel - _dl;
 
-    const data::TransferFunction::sptr tf = m_helperTF.getTransferFunction();
     {
-        const data::mt::locked_ptr lock(tf);
+        const auto image = m_image.const_lock();
+        const auto tf    = m_tf.lock();
 
         tf->setWindow(newWindow);
         tf->setLevel(newLevel);
-        const auto sig = tf->signal<data::TransferFunction::WindowingModifiedSignalType>(
+        const auto sig = tf->template signal<data::TransferFunction::WindowingModifiedSignalType>(
             data::TransferFunction::s_WINDOWING_MODIFIED_SIG
         );
         {
