@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,7 +25,6 @@
 #include "modules/viz/scene3d/config.hpp"
 
 #include <data/helper/MedicalImage.hpp>
-#include <data/helper/TransferFunction.hpp>
 
 #include <viz/scene3d/IAdaptor.hpp>
 
@@ -49,14 +48,13 @@ namespace sight::module::viz::scene3d::adaptor
  * @section Slots Slots
  * - \b resetCamera(): zooms out the camera to see the whole scene.
  * - \b changeOrientation(int,int): sets the camera's orientation to one of the image's axes.
- * - \b moveBack(): moves the camera backwards outside the scene's bounding box.
  *
  * @section XML XML Configuration
  * @code{.xml}
     <service type="sight::module::viz::scene3d::adaptor::SNegato2DCamera" >
         <inout key="image" uid="..." autoConnect="true" />
         <inout key="tf" uid="..." />
-        <config layer="..." priority="0" layerOrderDependant="true" orientation="sagittal" />
+        <config priority="0" layerOrderDependant="true" orientation="sagittal" margin="0.1"/>
    </service>
    @endcode
  *
@@ -68,10 +66,11 @@ namespace sight::module::viz::scene3d::adaptor
  *      image's default transferFunction (CT-GreyLevel).
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): layer on which the negato camera interactions are added.
  * - \b priority (optional, int, default=0): interaction priority, higher priority interactions are performed first.
  * - \b layerOrderDependant (optional, bool, default=true): define if interaction must take into account above layers.
  * - \b orientation (optional, sagittal/frontal/axial, default=sagittal): the camera's orientation at start.
+ * - \b margin (optional, default=0.1): margin to the border of the viewport, in percentage of the highest of width
+ *  or height.
  */
 class MODULE_VIZ_SCENE3D_CLASS_API SNegato2DCamera final : public sight::viz::scene3d::IAdaptor,
                                                            public sight::viz::scene3d::interactor::IInteractor
@@ -85,15 +84,41 @@ public:
     MODULE_VIZ_SCENE3D_API SNegato2DCamera() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SNegato2DCamera() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SNegato2DCamera() noexcept override = default;
 
     /**
-     * @brief Zooms in the scene at the current cursor position.
+     * @brief Moving along slices (SHIFT to speed-up) or Zooms in the scene at the current cursor position.
      * @param _delta distance that the wheel is rotated.
      * @param _x current width coordinate of the mouse cursor.
      * @param _y current height coordinate of the mouse cursor.
      */
-    MODULE_VIZ_SCENE3D_API void wheelEvent(Modifier, int _delta, int _x, int _y) override;
+    MODULE_VIZ_SCENE3D_API void wheelEvent(Modifier /*_modifier*/, double _delta, int _x, int _y) final;
+
+    /**
+     * @brief Zooms in the scene at the current cursor position.
+     * @param _scalingFactor distance of the fingers
+     * @param _centerX the width coordinate of the center of the pinch
+     * @param _centerY the height coordinate of the center of the pinch
+     */
+    MODULE_VIZ_SCENE3D_API void pinchGestureEvent(double _scaleFactor, int _centerX, int _centerY) final;
+
+    /**
+     * @brief Moves the camera along the projection plane.
+     * @param _x the last width coordinate of the finger
+     * @param _y the last height coordinate of the finger
+     * @param _dx width displacement of the finger since the last event.
+     * @param _dy height displacement of the finger since the last event.
+     */
+    MODULE_VIZ_SCENE3D_API void panGestureMoveEvent(int _x, int _y, int _dx, int _dy) final;
+
+    /**
+     * @brief Ends Moving the camera along the projection plane.
+     * @param _x the last width coordinate of the finger
+     * @param _y the last height coordinate of the finger
+     * @param _dx width displacement of the finger since the last event.
+     * @param _dy height displacement of the finger since the last event.
+     */
+    MODULE_VIZ_SCENE3D_API void panGestureReleaseEvent(int _x, int _y, int _dx, int _dy) final;
 
     /**
      * @brief Interacts with the negato if it was picked by pressing any mouse button.
@@ -109,12 +134,12 @@ public:
      */
     MODULE_VIZ_SCENE3D_API void mouseMoveEvent(
         IInteractor::MouseButton _button,
-        Modifier,
+        Modifier /*_mods*/,
         int _x,
         int _y,
         int _dx,
         int _dy
-    ) override;
+    ) final;
 
     /**
      * @brief Verifies if the button is pressed within the camera's viewport and enables mouse movements if that is the
@@ -123,7 +148,12 @@ public:
      * @param _x current width coordinate of the mouse cursor.
      * @param _y current height coordinate of the mouse cursor.
      */
-    MODULE_VIZ_SCENE3D_API void buttonPressEvent(IInteractor::MouseButton _button, Modifier, int _x, int _y) override;
+    MODULE_VIZ_SCENE3D_API void buttonPressEvent(
+        IInteractor::MouseButton _button,
+        Modifier /*_mods*/,
+        int _x,
+        int _y
+    ) final;
 
     /**
      * @brief Disables mouse movements.
@@ -131,7 +161,12 @@ public:
      * @param _x current width coordinate of the mouse cursor.
      * @param _y current height coordinate of the mouse cursor.
      */
-    MODULE_VIZ_SCENE3D_API void buttonReleaseEvent(IInteractor::MouseButton _button, Modifier, int _x, int _y) override;
+    MODULE_VIZ_SCENE3D_API void buttonReleaseEvent(
+        IInteractor::MouseButton _button,
+        Modifier /*_mods*/,
+        int _x,
+        int _y
+    ) final;
 
     /**
      * @brief Resets the camera when the 'R' key is pressed.
@@ -139,15 +174,15 @@ public:
      * @param _x current width coordinate of the mouse cursor.
      * @param _y current height coordinate of the mouse cursor.
      */
-    MODULE_VIZ_SCENE3D_API void keyPressEvent(int _key, Modifier, int _x, int _y) override;
+    MODULE_VIZ_SCENE3D_API void keyPressEvent(int _key, Modifier /*_mods*/, int _x, int _y) final;
 
 protected:
 
     /// Configures the layer, interaction priority and camera orientation.
-    MODULE_VIZ_SCENE3D_API void configuring() override;
+    MODULE_VIZ_SCENE3D_API void configuring() final;
 
     /// Adds negato camera interactions to the layer.
-    MODULE_VIZ_SCENE3D_API void starting() override;
+    MODULE_VIZ_SCENE3D_API void starting() final;
 
     /**
      * @brief Proposals to connect service slots to associated object signals.
@@ -157,19 +192,13 @@ protected:
      * Connect data::Image::s_SLICE_TYPE_MODIFIED_SIG of s_IMAGE_INPUT to s_CHANGE_ORIENTATION_SLOT
      * Connect data::Image::s_SLICE_INDEX_MODIFIED_SIG of s_IMAGE_INPUT to s_MOVE_BACK_SLOT
      */
-    MODULE_VIZ_SCENE3D_API service::IService::KeyConnectionsMap getAutoConnections() const override;
+    MODULE_VIZ_SCENE3D_API service::IService::KeyConnectionsMap getAutoConnections() const final;
 
     /// Does nothing.
-    MODULE_VIZ_SCENE3D_API void updating() noexcept override;
-
-    /**
-     * @brief Retrieves the current transfer function.
-     * @param _key key of the swapped data.
-     */
-    MODULE_VIZ_SCENE3D_API void swapping(std::string_view _key) override;
+    MODULE_VIZ_SCENE3D_API void updating() noexcept final;
 
     /// Removes negato camera interactions from the layer.
-    MODULE_VIZ_SCENE3D_API void stopping() override;
+    MODULE_VIZ_SCENE3D_API void stopping() final;
 
 private:
 
@@ -178,6 +207,9 @@ private:
     /// SLOT: resets the camera's zoom.
     void resetCamera();
 
+    /// SLOT: resets the display when resizing.
+    void resizeViewport();
+
     /**
      * @brief SLOT: sets the camera's orientation to one of the image's axes.
      * @param _from origin of the orientation.
@@ -185,11 +217,8 @@ private:
      */
     void changeOrientation(int _from, int _to);
 
-    /// SLOT: moves the camera backwards outside the scene's bounding box.
-    void moveBack();
-
     /// Updates the transfer function window and level by adding the input values.
-    void updateWindowing(double _windowDelta, double _levelDelta);
+    void updateWindowing(double _dw, double _dl);
 
     /// Defines the current interaction status.
     bool m_isInteracting {false};
@@ -200,18 +229,24 @@ private:
     /// Defines the interaction priority.
     int m_priority {0};
 
-    /// Helps interfacing with the transfer function input.
-    data::helper::TransferFunction m_helperTF;
-
     /// Defines the transfer function window value at the time the interaction started.
-    double m_initialWindow {0.f};
+    double m_initialWindow {0.F};
 
     /// Defines the transfer function level value at the time the interaction started.
-    double m_initialLevel {0.f};
+    double m_initialLevel {0.F};
 
     /// Defines the mouse position at the time the windowing interaction started.
     Ogre::Vector2i m_initialPos {-1, -1};
 
+    /// Defines the margin to the border of the viewport.
+    float m_margin {0.1F};
+
+    /// This allows us to reset the camera when Qt refreshes the size of the viewport after the start of the adaptor
+    bool m_hasMoved {false};
+
+    /// Handles connection with the layer.
+    core::com::helper::SigSlotConnection m_layerConnection;
+
     static constexpr std::string_view s_IMAGE_INOUT = "image";
     static constexpr std::string_view s_TF_INOUT    = "tf";
 
