@@ -24,16 +24,12 @@
 
 #include "modules/viz/scene3d/config.hpp"
 
-#include <core/com/Slot.hpp>
-#include <core/com/Slots.hpp>
-
-#include <data/Float.hpp>
-#include <data/helper/TransferFunction.hpp>
-
 #include <viz/scene3d/IAdaptor.hpp>
 #include <viz/scene3d/interactor/IInteractor.hpp>
 #include <viz/scene3d/ITransformable.hpp>
+#include <viz/scene3d/PickingCross.hpp>
 #include <viz/scene3d/Plane.hpp>
+#include <viz/scene3d/Texture.hpp>
 #include <viz/scene3d/TransferFunction.hpp>
 
 #include <OGRE/OgreManualObject.h>
@@ -53,7 +49,7 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b newImage(): update the image display to show the new content.
  * - \b sliceType(int, int): update image slice index .
  * - \b sliceIndex(int, int, int): update image slice type.
- * - \b updateOpacity(): sets the planes's opacity.
+ * - \b setTransparency(double): sets the global transparency of the three image planes.
  * - \b updateVisibility(bool): sets whether the negato is shown or not.
  * - \b toggleVisibility(): toggle whether the negato is shown or not.
  * - \b show(): shows the negato.
@@ -64,19 +60,20 @@ namespace sight::module::viz::scene3d::adaptor
  * @section XML XML Configuration
  * @code{.xml}
     <service type="sight::module::viz::scene3d::adaptor::SNegato3D">
-        <inout key="image" uid="..." />
+        <in key="image" uid="..." />
         <inout key="tf" uid="..." />
-        <config layer="default" sliceIndex="axial" filtering="none" tfAlpha="true" />
+        <config sliceIndex="axial" filtering="none" tfAlpha="true" />
     </service>
    @endcode
  *
- * @subsection In-Out In-Out:
+ * @subsection Input Input:
  * - \b image [sight::data::Image]: image to display.
- * - \b tf [sight::data::TransferFunction] (optional): the current TransferFunction. If it is not defined, we use the
+ *
+ * @subsection In-Out In-Out:
+ * - \b tf [sight::data::TransferFunction]: the current TransferFunction. If it is not defined, we use the
  *      image's default transferFunction (CT-GreyLevel).
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): id of the layer where this adaptor applies.
  * - \b sliceIndex (optional, axial/frontal/sagittal, default=axial): orientation of the negato.
  * - \b filtering (optional, none/linear/anisotropic, default=none): texture filter type of the negato.
  * - \b tfAlpha (optional, bool, default=false): if true, the alpha channel of the transfer function is used.
@@ -122,20 +119,12 @@ protected:
      * Connect data::Image::s_MODIFIED_SIG of s_BUFFER_MODIFIED_SIG to s_NEWIMAGE_SLOT
      * Connect data::Image::s_MODIFIED_SIG of s_SLICE_TYPE_MODIFIED_SIG to s_SLICETYPE_SLOT
      * Connect data::Image::s_MODIFIED_SIG of s_SLICE_INDEX_MODIFIED_SIG to s_SLICEINDEX_SLOT
-     * Connect data::Image::s_MODIFIED_SIG of s_VISIBILITY_MODIFIED_SIG to s_UPDATE_VISIBILITY_SLOT
-     * Connect data::Image::s_MODIFIED_SIG of s_TRANSPARENCY_MODIFIED_SIG to s_UPDATE_VISIBILITY_SLOT
      */
     MODULE_VIZ_SCENE3D_API service::IService::KeyConnectionsMap getAutoConnections() const override;
 
     /// Requests rendering of the scene.
     MODULE_VIZ_SCENE3D_API void updating() override;
 
-    /**
-     * @brief Notifies that the TF is swapped.
-     * @param _key key of the swapped data.
-     */
-    MODULE_VIZ_SCENE3D_API void swapping(std::string_view key) override;
-
     /// Stops the service, disconnects connections.
     MODULE_VIZ_SCENE3D_API void stopping() override;
 
@@ -165,7 +154,7 @@ private:
      * @param _dx the cursor's width displacement since the last event.
      * @param _dy the cursor's height displacement since the last event.
      */
-    void mouseMoveEvent(MouseButton _button, Modifier, int _x, int _y, int _dx, int _dy) override;
+    void mouseMoveEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y, int _dx, int _dy) override;
 
     /**
      * @brief Attempts to pick the negato and starts interactions if picking was successful.
@@ -173,10 +162,10 @@ private:
      * @param _x current width coordinate of the mouse cursor.
      * @param _y current height coordinate of the mouse cursor.
      */
-    void buttonPressEvent(MouseButton _button, Modifier, int _x, int _y) override;
+    void buttonPressEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y) override;
 
     /// Ends all interactions, regardless of the input.
-    void buttonReleaseEvent(MouseButton, Modifier, int, int) override;
+    void buttonReleaseEvent(MouseButton /*_button*/, Modifier /*_mods*/, int /*_x*/, int /*_y*/) override;
 
     /**
      * @brief Sets the slice intersection at the (_x, _y) screen position if possible.
@@ -211,7 +200,7 @@ private:
     void newImage();
 
     /// SLOT: updates the image slice type.
-    void changeSliceType(int, int);
+    void changeSliceType(int /*unused*/, int /*unused*/);
 
     /**
      * @brief SLOT: updates the image slice index.
@@ -221,15 +210,8 @@ private:
      */
     void changeSliceIndex(int _axialIndex, int _frontalIndex, int _sagittalIndex);
 
-    /**
-     * @brief Makes the planes process their meshes.
-     * @param _spacing spacing of the input image.
-     * @param _origin origin of the input image.
-     */
-    void createPlanes(const Ogre::Vector3& _spacing, const Ogre::Vector3& _origin);
-
     /// SLOT: sets the planes's opacity.
-    void setPlanesOpacity();
+    void setTransparency(double _transparency);
 
     /// Sets the picking flags on all three negato planes.
     void setPlanesQueryFlags(std::uint32_t _flags);
@@ -237,9 +219,6 @@ private:
     /// Attemps to pick the negato planes, returns the world space position of the intersection if successful.
     std::optional<Ogre::Vector3> getPickedSlices(int _x, int _y);
 
-    /// Updates the intensity picking widget's position.
-    void updatePickingCross(const Ogre::Vector3& _pickedPos, const Ogre::Vector3& _imgOrigin);
-
     /// Enables whether the camera must be auto reset when a mesh is updated or not.
     bool m_autoResetCamera {true};
 
@@ -253,10 +232,10 @@ private:
     int m_priority {1};
 
     /// Contains the ogre texture which will be displayed on the negato.
-    Ogre::TexturePtr m_3DOgreTexture {nullptr};
+    sight::viz::scene3d::Texture::sptr m_3DOgreTexture;
 
     /// Contains and manages the Ogre textures used to store the transfer function (GPU point of view).
-    std::unique_ptr<sight::viz::scene3d::TransferFunction> m_gpuTF {nullptr};
+    sight::viz::scene3d::TransferFunction::uptr m_gpuTF {nullptr};
 
     /// Stores the planes on which we will apply our texture.
     std::array<sight::viz::scene3d::Plane::sptr, 3> m_planes;
@@ -265,22 +244,19 @@ private:
     sight::viz::scene3d::Plane::sptr m_pickedPlane {nullptr};
 
     /// Contains the widget displayed to pick intensities.
-    Ogre::ManualObject* m_pickingCross {nullptr};
+    std::unique_ptr<sight::viz::scene3d::PickingCross> m_pickingCross;
 
     /// Contains the scene node allowing to move the entire negato.
     Ogre::SceneNode* m_negatoSceneNode {nullptr};
 
     /// Defines the filtering type for this negato.
-    sight::viz::scene3d::Plane::FilteringEnumType m_filtering {sight::viz::scene3d::Plane::FilteringEnumType::NONE};
-
-    /// Helps interfacing with the transfer function input.
-    data::helper::TransferFunction m_helperTF;
+    sight::viz::scene3d::Plane::filter_t m_filtering {sight::viz::scene3d::Plane::filter_t::NONE};
 
     /// Defines the transfer function window value at the time the interaction started.
-    double m_initialWindow {0.f};
+    double m_initialWindow {0.F};
 
     /// Defines the transfer function level value at the time the interaction started.
-    double m_initialLevel {0.f};
+    double m_initialLevel {0.F};
 
     /// Defines the mouse position at the time the windowing interaction started.
     Ogre::Vector2i m_initialPos {-1, -1};
@@ -295,11 +271,11 @@ private:
     using PickedVoxelSigType = core::com::Signal<void (std::string)>;
     PickedVoxelSigType::sptr m_pickedVoxelSignal {nullptr};
 
-    static constexpr std::string_view s_IMAGE_INOUT = "image";
-    data::ptr<data::Image, data::Access::inout> m_image {this, s_IMAGE_INOUT, true};
+    static constexpr std::string_view s_IMAGE_IN = "image";
+    data::ptr<data::Image, data::Access::in> m_image {this, s_IMAGE_IN, true};
 
     static constexpr std::string_view s_TF_INOUT = "tf";
-    data::ptr<data::TransferFunction, data::Access::inout> m_tf {this, s_TF_INOUT, false, true};
+    data::ptr<data::TransferFunction, data::Access::inout> m_tf {this, s_TF_INOUT, true};
 };
 
 //------------------------------------------------------------------------------
