@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -35,7 +35,6 @@
 #include <service/op/Add.hpp>
 #include <service/op/Get.hpp>
 
-#include <viz/scene3d/helper/Font.hpp>
 #include <viz/scene3d/helper/Scene.hpp>
 #include <viz/scene3d/R2VBRenderable.hpp>
 #include <viz/scene3d/SRender.hpp>
@@ -51,21 +50,6 @@ namespace sight::module::viz::scene3d::adaptor
 
 //-----------------------------------------------------------------------------
 
-static const std::string s_COLOR_CONFIG             = "color";
-static const std::string s_VISIBLE_CONFIG           = "visible";
-static const std::string s_AUTORESET_CAMERA_CONFIG  = "autoresetcamera";
-static const std::string s_MATERIAL_TEMPLATE_CONFIG = "materialTemplate";
-static const std::string s_FIXED_SIZE_CONFIG        = "fixedSize";
-static const std::string s_TEXTURE_NAME_CONFIG      = "textureName";
-static const std::string s_QUERY_CONFIG             = "queryFlags";
-static const std::string s_RADIUS_CONFIG            = "radius";
-static const std::string s_DISPLAY_LABEL_CONFIG     = "displayLabel";
-static const std::string s_LABEL_COLOR_CONFIG       = "labelColor";
-static const std::string s_FONT_SOURCE_CONFIG       = "fontSource";
-static const std::string s_FONT_SIZE_CONFIG         = "fontSize";
-
-//-----------------------------------------------------------------------------
-
 SPointList::SPointList() noexcept
 {
     m_material = data::Material::New();
@@ -75,7 +59,7 @@ SPointList::SPointList() noexcept
 
 SPointList::~SPointList() noexcept
 {
-    if(m_entity)
+    if(m_entity != nullptr)
     {
         Ogre::SceneManager* sceneMgr = this->getSceneManager();
         sceneMgr->destroyEntity(m_entity);
@@ -86,7 +70,7 @@ SPointList::~SPointList() noexcept
 
 void SPointList::setVisible(bool _visible)
 {
-    if(m_entity)
+    if(m_entity != nullptr)
     {
         this->getRenderService()->makeCurrent();
 
@@ -104,8 +88,20 @@ void SPointList::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
+
+    static const std::string s_COLOR_CONFIG             = s_CONFIG + "color";
+    static const std::string s_VISIBLE_CONFIG           = s_CONFIG + "visible";
+    static const std::string s_AUTORESET_CAMERA_CONFIG  = s_CONFIG + "autoresetcamera";
+    static const std::string s_MATERIAL_TEMPLATE_CONFIG = s_CONFIG + "materialTemplate";
+    static const std::string s_FIXED_SIZE_CONFIG        = s_CONFIG + "fixedSize";
+    static const std::string s_TEXTURE_NAME_CONFIG      = s_CONFIG + "textureName";
+    static const std::string s_QUERY_CONFIG             = s_CONFIG + "queryFlags";
+    static const std::string s_RADIUS_CONFIG            = s_CONFIG + "radius";
+    static const std::string s_DISPLAY_LABEL_CONFIG     = s_CONFIG + "displayLabel";
+    static const std::string s_LABEL_COLOR_CONFIG       = s_CONFIG + "labelColor";
+    static const std::string s_FONT_SOURCE_CONFIG       = s_CONFIG + "fontSource";
+    static const std::string s_FONT_SIZE_CONFIG         = s_CONFIG + "fontSize";
 
     const std::string color = config.get<std::string>(s_COLOR_CONFIG, "");
 
@@ -117,7 +113,7 @@ void SPointList::configuring()
 
     m_autoResetCamera = config.get<bool>(s_AUTORESET_CAMERA_CONFIG, true);
 
-    if(config.count(s_MATERIAL_TEMPLATE_CONFIG))
+    if(config.count(s_MATERIAL_TEMPLATE_CONFIG) != 0U)
     {
         // An existing Ogre material will be used for this mesh
         m_customMaterial       = true;
@@ -203,12 +199,12 @@ void SPointList::starting()
 service::IService::KeyConnectionsMap SPointList::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_POINTLIST_INPUT, data::PointList::s_POINT_ADDED_SIG, s_UPDATE_SLOT);
-    connections.push(s_POINTLIST_INPUT, data::PointList::s_POINT_REMOVED_SIG, s_UPDATE_SLOT);
-    connections.push(s_POINTLIST_INPUT, data::PointList::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_POINTLIST_INPUT, data::PointList::s_POINT_ADDED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_POINTLIST_INPUT, data::PointList::s_POINT_REMOVED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_POINTLIST_INPUT, data::PointList::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
-    connections.push(s_MESH_INPUT, data::Mesh::s_VERTEX_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_MESH_INPUT, data::Mesh::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_MESH_INPUT, data::Mesh::s_VERTEX_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_MESH_INPUT, data::Mesh::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     return connections;
 }
@@ -225,7 +221,7 @@ void SPointList::stopping()
     SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
     m_meshGeometry->clearMesh(*sceneMgr);
 
-    if(m_entity)
+    if(m_entity != nullptr)
     {
         sceneMgr->destroyEntity(m_entity);
         m_entity = nullptr;
@@ -272,16 +268,10 @@ void SPointList::updating()
 
 void SPointList::createLabel(const data::PointList::csptr& _pointList)
 {
-    Ogre::SceneManager* sceneMgr          = this->getSceneManager();
-    Ogre::OverlayContainer* textContainer = this->getLayer()->getOverlayTextPanel();
-    Ogre::Camera* cam                     = this->getLayer()->getDefaultCamera();
-    SIGHT_ASSERT("Ogre::SceneManager is null", sceneMgr);
-
-    const float dpi = this->getRenderService()->getInteractorManager()->getLogicalDotsPerInch();
-
+    auto renderSrv          = this->getRenderService();
     std::size_t i           = 0;
     std::string labelNumber = std::to_string(i);
-    for(auto& point : _pointList->getPoints())
+    for(const auto& point : _pointList->getPoints())
     {
         const auto label = point->getLabel();
         if(!label.empty())
@@ -293,17 +283,8 @@ void SPointList::createLabel(const data::PointList::csptr& _pointList)
             labelNumber = std::to_string(i);
         }
 
-        m_labels.push_back(
-            sight::viz::scene3d::Text::New(
-                this->getID() + labelNumber,
-                sceneMgr,
-                textContainer,
-                m_fontSource,
-                m_fontSize,
-                dpi,
-                cam
-            )
-        );
+        m_labels.push_back(sight::viz::scene3d::IText::New(this->getLayer()));
+        m_labels[i]->setFontSize(m_fontSize);
         m_labels[i]->setText(labelNumber);
         m_labels[i]->setTextColor(
             Ogre::ColourValue(
@@ -313,7 +294,7 @@ void SPointList::createLabel(const data::PointList::csptr& _pointList)
             )
         );
         m_nodes.push_back(m_sceneNode->createChildSceneNode(this->getID() + labelNumber));
-        m_nodes[i]->attachObject(m_labels[i]);
+        m_labels[i]->attachToNode(m_nodes[i], this->getLayer()->getDefaultCamera());
         data::Point::PointCoordArrayType coord = point->getCoord();
         m_nodes[i]->translate(static_cast<float>(coord[0]), static_cast<float>(coord[1]), static_cast<float>(coord[2]));
         i++;
@@ -324,20 +305,10 @@ void SPointList::createLabel(const data::PointList::csptr& _pointList)
 
 void SPointList::destroyLabel()
 {
-    Ogre::SceneManager* sceneMgr = this->getSceneManager();
-
-    for(Ogre::SceneNode* node : m_nodes)
-    {
-        m_sceneNode->removeAndDestroyChild(node);
-    }
-
+    std::ranges::for_each(m_nodes, [this](auto& node){m_sceneNode->removeAndDestroyChild(node);});
     m_nodes.clear();
 
-    for(sight::viz::scene3d::Text* label : m_labels)
-    {
-        sceneMgr->destroyMovableObject(label);
-    }
-
+    std::ranges::for_each(m_labels, [](auto& label){label->detachFromNode();});
     m_labels.clear();
 }
 
@@ -372,7 +343,7 @@ void SPointList::updateMesh(const data::PointList::csptr& _pointList)
     // Create entity and attach it in the scene graph
     //------------------------------------------
 
-    if(!m_entity)
+    if(m_entity == nullptr)
     {
         m_entity = m_meshGeometry->createEntity(*sceneMgr);
         m_entity->setVisible(m_isVisible);
@@ -388,7 +359,7 @@ void SPointList::updateMesh(const data::PointList::csptr& _pointList)
     //------------------------------------------
     // Create sub-services
     //------------------------------------------
-    this->updateMaterialAdaptor();
+    this->updateMaterialAdaptor(_pointList->getID());
 
     this->attachNode(m_entity);
 
@@ -426,7 +397,7 @@ void SPointList::updateMesh(const data::Mesh::csptr& _mesh)
     // Create entity and attach it in the scene graph
     //------------------------------------------
 
-    if(!m_entity)
+    if(m_entity == nullptr)
     {
         m_entity = m_meshGeometry->createEntity(*sceneMgr);
         m_entity->setVisible(m_isVisible);
@@ -443,7 +414,7 @@ void SPointList::updateMesh(const data::Mesh::csptr& _mesh)
     //------------------------------------------
     // Create sub-services
     //------------------------------------------
-    this->updateMaterialAdaptor();
+    this->updateMaterialAdaptor(_mesh->getID());
 
     this->attachNode(m_entity);
 
@@ -457,56 +428,41 @@ void SPointList::updateMesh(const data::Mesh::csptr& _mesh)
 
 //------------------------------------------------------------------------------
 
-scene3d::adaptor::SMaterial::sptr SPointList::createMaterialService(const std::string& _materialSuffix)
+scene3d::adaptor::SMaterial::sptr SPointList::createMaterialService(const std::string& _meshId)
 {
     auto materialAdaptor = this->registerService<module::viz::scene3d::adaptor::SMaterial>(
         "sight::module::viz::scene3d::adaptor::SMaterial"
     );
     materialAdaptor->setInOut(m_material, "material", true);
 
-    materialAdaptor->setID(this->getID() + "_" + materialAdaptor->getID());
-    materialAdaptor->setRenderService(this->getRenderService());
-    materialAdaptor->setLayerID(m_layerID);
+    const auto tplName =
+        !m_materialTemplateName.empty() ? m_materialTemplateName : sight::viz::scene3d::Material::
+        DEFAULT_MATERIAL_TEMPLATE_NAME;
 
-    if(!m_materialTemplateName.empty())
-    {
-        materialAdaptor->setMaterialTemplateName(m_materialTemplateName);
-    }
-
-    std::string meshName;
-    const auto pointList = m_pointList.lock();
-    if(pointList)
-    {
-        meshName = pointList->getID();
-    }
-    else
-    {
-        const auto mesh = m_mesh.lock();
-        if(mesh)
-        {
-            meshName = mesh->getID();
-        }
-    }
-
-    const std::string mtlName = meshName + "_" + materialAdaptor->getID() + _materialSuffix;
-
-    materialAdaptor->setMaterialName(mtlName);
+    materialAdaptor->configure(
+        this->getID() + "_" + materialAdaptor->getID(),
+        _meshId + "_" + materialAdaptor->getID(),
+        this->getRenderService(),
+        m_layerID,
+        "",
+        tplName
+    );
 
     return materialAdaptor;
 }
 
 //------------------------------------------------------------------------------
 
-void SPointList::updateMaterialAdaptor()
+void SPointList::updateMaterialAdaptor(const std::string& _meshId)
 {
     if(!m_materialAdaptor)
     {
-        if(m_entity)
+        if(m_entity != nullptr)
         {
-            m_materialAdaptor = this->createMaterialService();
+            m_materialAdaptor = this->createMaterialService(_meshId);
             m_materialAdaptor->start();
 
-            auto materialFw = m_materialAdaptor->getMaterialFw();
+            auto* materialFw = m_materialAdaptor->getMaterialFw();
             m_meshGeometry->updateMaterial(materialFw, false);
             materialFw->setMeshSize(m_radius);
 
@@ -535,19 +491,19 @@ void SPointList::updateMaterialAdaptor()
     else if(m_materialAdaptor->getInOut<data::Material>(SMaterial::s_MATERIAL_INOUT).lock()
             != m_material)
     {
-        auto materialFw = m_materialAdaptor->getMaterialFw();
+        auto* materialFw = m_materialAdaptor->getMaterialFw();
         m_meshGeometry->updateMaterial(materialFw, false);
         materialFw->setMeshSize(m_radius);
     }
     else
     {
-        auto materialFw = m_materialAdaptor->getMaterialFw();
+        auto* materialFw = m_materialAdaptor->getMaterialFw();
         m_meshGeometry->updateMaterial(materialFw, false);
         materialFw->setMeshSize(m_radius);
 
         m_entity->setMaterialName(m_materialAdaptor->getMaterialName());
 
-        m_materialAdaptor->slot(module::viz::scene3d::adaptor::SMaterial::s_UPDATE_SLOT)->run();
+        m_materialAdaptor->slot(module::viz::scene3d::adaptor::SMaterial::IService::slots::s_UPDATE)->run();
     }
 }
 
@@ -566,11 +522,10 @@ void SPointList::attachNode(Ogre::MovableObject* _node)
 
 void SPointList::detachAndDestroyEntity()
 {
-    if(m_entity)
+    if(m_entity != nullptr)
     {
-        Ogre::SceneManager* const sceneMgr   = this->getSceneManager();
-        Ogre::SceneNode* const rootSceneNode = sceneMgr->getRootSceneNode();
-        if(m_sceneNode)
+        Ogre::SceneManager* const sceneMgr = this->getSceneManager();
+        if(m_sceneNode != nullptr)
         {
             m_sceneNode->detachObject(m_entity);
         }
