@@ -36,31 +36,15 @@
 namespace sight::module::viz::scene3d::adaptor
 {
 
-static const std::string s_MATERIAL_NAME_CONFIG = "materialName";
-
-//------------------------------------------------------------------------------
-
-SShaderParameter::SShaderParameter() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
-SShaderParameter::~SShaderParameter() noexcept
-{
-}
-
 //------------------------------------------------------------------------------
 
 void SShaderParameter::configuring()
 {
     this->IParameter::configuring();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
-    m_materialName = config.get<std::string>(s_MATERIAL_NAME_CONFIG, "");
-    SIGHT_ERROR_IF("'" + s_MATERIAL_NAME_CONFIG + "' attribute not set", m_materialName.empty());
+    m_materialName = config.get<std::string>(s_CONFIG + "materialName");
 }
 
 //------------------------------------------------------------------------------
