@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -38,16 +38,14 @@
 namespace sight::module::viz::scene3d::adaptor
 {
 
-static const core::com::Slots::SlotKeyType s_ENABLE_TOOL_SLOT      = "enableTool";
-static const core::com::Slots::SlotKeyType s_DELETE_LAST_MESH_SLOT = "deleteLastMesh";
+static const core::com::Slots::SlotKeyType s_ENABLE_TOOL_SLOT       = "enableTool";
+static const core::com::Slots::SlotKeyType s_DELETE_LAST_MESH_SLOT  = "deleteLastMesh";
+static const core::com::Slots::SlotKeyType s_CANCEL_LAST_CLICK_SLOT = "cancelLastClick";
+static const core::com::Slots::SlotKeyType s_RESET_SLOT             = "reset";
+static const core::com::Slots::SlotKeyType s_VALIDATE_SLOT          = "validate";
 
 static const core::com::Slots::SlotKeyType s_TOOL_DISABLED_SIG = "toolDisabled";
 
-static const std::string s_PRIORITY_CONFIG   = "priority";
-static const std::string s_EXTRUDE_CONFIG    = "extrude";
-static const std::string s_LINE_COLOR_CONFIG = "lineColor";
-static const std::string s_EDGE_COLOR_CONFIG = "edgeColor";
-
 SShapeExtruder::Triangle2D::Triangle2D(
     const Ogre::Vector2& _a,
     const Ogre::Vector2& _b,
@@ -55,10 +53,9 @@ SShapeExtruder::Triangle2D::Triangle2D(
 ) :
     a(_a),
     b(_b),
-    c(_c)
+    c(_c),
+    id(s_id++)
 {
-    id = s_id++;
-
     // Matrix to rotate of 90 degree over the Z axis.
     const Ogre::Matrix3 quarterRotation {0, -1, 0, 1, 0, 0, 0, 0, 1};
 
@@ -68,13 +65,13 @@ SShapeExtruder::Triangle2D::Triangle2D(
 
     if(a.y != b.y)
     {
-        firstBisectorPos = (a + b) / 2.f;
+        firstBisectorPos = (a + b) / 2.F;
         const Ogre::Vector2 firstEdgeDir = (a - b).normalisedCopy();
         firstBisectorDir = (quarterRotation * Ogre::Vector3(firstEdgeDir.x, firstEdgeDir.y, 0)).xy();
     }
     else
     {
-        firstBisectorPos = (c + b) / 2.f;
+        firstBisectorPos = (c + b) / 2.F;
         const Ogre::Vector2 firstEdgeDir = (c - b).normalisedCopy();
         firstBisectorDir = (quarterRotation * Ogre::Vector3(firstEdgeDir.x, firstEdgeDir.y, 0)).xy();
     }
@@ -84,14 +81,14 @@ SShapeExtruder::Triangle2D::Triangle2D(
 
     if(a.y != c.y)
     {
-        secondBisectorPos = (a + c) / 2.f;
+        secondBisectorPos = (a + c) / 2.F;
         Ogre::Vector2 secondEdgeDir = (a - c).normalisedCopy();
         secondBisectorDir =
             (quarterRotation * Ogre::Vector3(secondEdgeDir.x, secondEdgeDir.y, 0)).xy();
     }
     else
     {
-        secondBisectorPos = (b + c) / 2.f;
+        secondBisectorPos = (b + c) / 2.F;
         Ogre::Vector2 secondEdgeDir = (b - c).normalisedCopy();
         secondBisectorDir =
             (quarterRotation * Ogre::Vector3(secondEdgeDir.x, secondEdgeDir.y, 0)).xy();
@@ -109,8 +106,8 @@ SShapeExtruder::Triangle2D::Triangle2D(
     center = Ogre::Vector2(intersectX, intersectY);
     radius = a.distance(center);
 
-    const Ogre::Vector2 baryDir(((a + b) / 2.f) - c);
-    barycentre = c + 2.f / 3.f * baryDir;
+    const Ogre::Vector2 baryDir(((a + b) / 2.F) - c);
+    barycentre = c + 2.F / 3.F * baryDir;
 }
 
 //------------------------------------------------------------------------------
@@ -130,12 +127,7 @@ bool SShapeExtruder::Edge::intersect(Edge _edge) const
     const float t          = qpXs / rXs;
     const float u          = qpXr / rXs;
 
-    if(rXs != 0 && t >= 0 && t < 1 && u >= 0 && u < 1)
-    {
-        return true;
-    }
-
-    return false;
+    return rXs != 0 && t >= 0 && t < 1 && u >= 0 && u < 1;
 }
 
 //------------------------------------------------------------------------------
@@ -150,41 +142,49 @@ Ogre::Vector3 SShapeExtruder::getCamDirection(const Ogre::Camera* const _cam)
 
 //-----------------------------------------------------------------------------
 
-SShapeExtruder::SShapeExtruder() noexcept
+SShapeExtruder::SShapeExtruder() noexcept :
+    service::INotifier(m_signals)
 {
     newSlot(s_ENABLE_TOOL_SLOT, &SShapeExtruder::enableTool, this);
     newSlot(s_DELETE_LAST_MESH_SLOT, &SShapeExtruder::deleteLastMesh, this);
+    newSlot(s_CANCEL_LAST_CLICK_SLOT, &SShapeExtruder::cancelLastClick, this);
+    newSlot(s_RESET_SLOT, &SShapeExtruder::reset, this);
+    newSlot(s_VALIDATE_SLOT, &SShapeExtruder::validate, this);
+
     m_toolDisabledSig = this->newSignal<core::com::Signal<void()> >(s_TOOL_DISABLED_SIG);
 }
 
 //-----------------------------------------------------------------------------
 
-SShapeExtruder::~SShapeExtruder() noexcept
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void SShapeExtruder::configuring()
 {
     this->configureParams();
 
-    const ConfigType srvConfig = this->getConfigTree();
-    const ConfigType config    = srvConfig.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
-    m_priority = config.get<int>(s_PRIORITY_CONFIG, m_priority);
-    m_extrude  = config.get<bool>(s_EXTRUDE_CONFIG, m_extrude);
+    static const std::string s_PRIORITY_CONFIG         = s_CONFIG + "priority";
+    static const std::string s_EXTRUDE_CONFIG          = s_CONFIG + "extrude";
+    static const std::string s_LINE_COLOR_CONFIG       = s_CONFIG + "lineColor";
+    static const std::string s_EDGE_COLOR_CONFIG       = s_CONFIG + "edgeColor";
+    static const std::string s_DOUBLE_CLICK_VALIDATION = s_CONFIG + "validation_on_double_click";
 
-    const auto divideBy255 = std::bind(std::divides<float>(), std::placeholders::_1, 255.f);
+    m_priority                = config.get<int>(s_PRIORITY_CONFIG, m_priority);
+    m_extrude                 = config.get<bool>(s_EXTRUDE_CONFIG, m_extrude);
+    m_validationByDoubleClick = config.get<bool>(s_DOUBLE_CLICK_VALIDATION, m_validationByDoubleClick);
+
+    const auto divideBy255 = [](auto&& PH1, auto&& ...)
+                             {
+                                 return std::divides<>()(std::forward<decltype(PH1)>(PH1), 255.F);
+                             };
 
     const auto hexaLineColor = config.get<std::string>(s_LINE_COLOR_CONFIG, "#FFFFFF");
-    std::array<std::uint8_t, 4> lineColor;
-    data::tools::Color::hexaStringToRGBA(hexaLineColor, lineColor.data());
+    std::array<std::uint8_t, 4> lineColor {};
+    data::tools::Color::hexaStringToRGBA(hexaLineColor, lineColor);
     std::transform(lineColor.begin(), lineColor.end(), m_lineColor.ptr(), divideBy255);
 
     const auto hexaEdgeColor = config.get<std::string>(s_EDGE_COLOR_CONFIG, "#FFFFFF");
-    std::array<std::uint8_t, 4> edgeColor;
-    data::tools::Color::hexaStringToRGBA(hexaEdgeColor, edgeColor.data());
+    std::array<std::uint8_t, 4> edgeColor {};
+    data::tools::Color::hexaStringToRGBA(hexaEdgeColor, edgeColor);
     std::transform(edgeColor.begin(), edgeColor.end(), m_edgeColor.ptr(), divideBy255);
 }
 
@@ -192,7 +192,7 @@ void SShapeExtruder::configuring()
 
 void SShapeExtruder::starting()
 {
-    this->initialize();
+    this->IAdaptor::initialize();
 
     this->getRenderService()->makeCurrent();
 
@@ -221,12 +221,13 @@ void SShapeExtruder::starting()
         "sight::module::viz::scene3d::adaptor::SMaterial"
     );
     m_materialAdaptor->setInOut(m_material, module::viz::scene3d::adaptor::SMaterial::s_MATERIAL_INOUT, true);
-    m_materialAdaptor->setID(this->getID() + m_materialAdaptor->getID());
-    m_materialAdaptor->setMaterialName(this->getID() + m_materialAdaptor->getID());
-    m_materialAdaptor->setRenderService(this->getRenderService());
-    m_materialAdaptor->setLayerID(m_layerID);
-    m_materialAdaptor->setShadingMode("ambient");
-    m_materialAdaptor->setMaterialTemplateName(sight::viz::scene3d::Material::DEFAULT_MATERIAL_TEMPLATE_NAME);
+    m_materialAdaptor->configure(
+        this->getID() + m_materialAdaptor->getID(),
+        this->getID() + m_materialAdaptor->getID(),
+        this->getRenderService(),
+        m_layerID,
+        "ambient"
+    );
     m_materialAdaptor->start();
     m_materialAdaptor->getMaterialFw()->setHasVertexColor(true);
     m_materialAdaptor->update();
@@ -296,13 +297,13 @@ void SShapeExtruder::deleteLastMesh()
 
     data::ModelSeries::ReconstructionVectorType reconstructions = extrudedMeshes->getReconstructionDB();
 
-    if(reconstructions.size() > 0)
+    if(!reconstructions.empty())
     {
         reconstructions.pop_back();
         extrudedMeshes->setReconstructionDB(reconstructions);
 
         // Send notification
-        this->notify(NotificationType::INFO, "Last extrusion deleted.");
+        this->INotifier::info("Last extrusion deleted.");
 
         // Send the signal.
         auto sig = extrudedMeshes->signal<data::ModelSeries::ReconstructionsRemovedSignalType>(
@@ -312,7 +313,34 @@ void SShapeExtruder::deleteLastMesh()
     }
     else
     {
-        this->notify(NotificationType::FAILURE, "No extrusion to delete.");
+        this->INotifier::failure("No extrusion to delete.");
+    }
+}
+
+//------------------------------------------------------------------------------
+
+void SShapeExtruder::cancelLastClick()
+{
+    modifyLasso(Action::REMOVE);
+}
+
+//------------------------------------------------------------------------------
+
+void SShapeExtruder::reset()
+{
+    // Get the reconstruction list.
+    const auto extrudedMeshes = m_extrudedMeshes.lock();
+
+    data::ModelSeries::ReconstructionVectorType reconstructions = extrudedMeshes->getReconstructionDB();
+
+    if(!reconstructions.empty())
+    {
+        reconstructions.clear();
+        extrudedMeshes->setReconstructionDB(reconstructions);
+
+        // Send the signal.
+        auto sig = extrudedMeshes->signal<data::ModelSeries::ModifiedSignalType>(data::ModelSeries::s_MODIFIED_SIG);
+        sig->asyncEmit();
     }
 }
 
@@ -364,23 +392,11 @@ std::tuple<Ogre::Vector3, Ogre::Vector3, Ogre::Vector3> SShapeExtruder::getNearF
     return {toolPosition, nearPosition, farPosition};
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
-void SShapeExtruder::wheelEvent(Modifier, int, int, int)
+void SShapeExtruder::modifyLasso(Action _action, int _x, int _y)
 {
-    if(m_interactionEnableState)
-    {
-        // Don't change the zoom when the tool interaction is enabled.
-        const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
-        layer->cancelFurtherInteraction();
-    }
-}
-
-//-----------------------------------------------------------------------------
-
-void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int _y)
-{
-    if(m_toolEnableState && (_button == MouseButton::LEFT || _button == MouseButton::RIGHT))
+    if(m_toolEnableState)
     {
         this->getRenderService()->makeCurrent();
 
@@ -412,7 +428,7 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
         const auto toolNearFarPos = this->getNearFarRayPositions(_x, _y);
 
         // Check the interactions.
-        if(_button == MouseButton::LEFT)
+        if(_action == Action::ADD)
         {
             // Check if the point can be added.
             bool near = false;
@@ -438,10 +454,10 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
                 return;
             }
         }
-        else if(_button == MouseButton::RIGHT)
+        else if(_action == Action::REMOVE)
         {
             // Remove the last clicked point.
-            if(m_lassoToolPositions.size() > 0)
+            if(!m_lassoToolPositions.empty())
             {
                 m_lassoEdgePositions.pop_back();
                 do
@@ -450,15 +466,16 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
                     m_lassoNearPositions.pop_back();
                     m_lassoFarPositions.pop_back();
                 }
-                while(m_lassoToolPositions.size() > 0 && m_lassoToolPositions.back() != m_lassoEdgePositions.back());
+                while(!m_lassoToolPositions.empty() && m_lassoToolPositions.back() != m_lassoEdgePositions.back());
             }
 
             // Clear the last line if it's empty.
-            if(m_lassoToolPositions.size() == 0)
+            if(m_lassoToolPositions.empty())
             {
                 m_interactionEnableState = false;
                 m_lastLassoLine->clear();
                 m_lasso->clear();
+                this->requestRender();
                 return;
             }
         }
@@ -469,7 +486,7 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
         // Draw the last lasso line.
         m_lastLassoLine->clear();
 
-        SIGHT_ASSERT("Lasso positions must have at east one point", m_lassoToolPositions.size() > 0);
+        SIGHT_ASSERT("Lasso positions must have at east one point", !m_lassoToolPositions.empty());
 
         m_lastLassoLine->begin(
             m_materialAdaptor->getMaterialName(),
@@ -479,7 +496,10 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
 
         m_lastLassoLine->colour(m_lineColor);
         m_lastLassoLine->position(m_lassoToolPositions.back());
-        m_lastLassoLine->position(std::get<0>(toolNearFarPos));
+        if(_x != -1 && _y != -1)
+        {
+            m_lastLassoLine->position(std::get<0>(toolNearFarPos));
+        }
 
         m_lastLassoLine->end();
 
@@ -488,96 +508,128 @@ void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier, int _x, int
     }
 }
 
-//-----------------------------------------------------------------------------
+//------------------------------------------------------------------------------
 
-void SShapeExtruder::buttonDoublePressEvent(MouseButton _button, Modifier, int _x, int _y)
+void SShapeExtruder::validate()
 {
-    if(m_interactionEnableState && _button == MouseButton::LEFT)
+    this->getRenderService()->makeCurrent();
+
+    // When coming from touch, mouseReleaseEvent is not always called.
+    if(m_leftButtonMoveState)
     {
-        this->getRenderService()->makeCurrent();
+        // Add a new point to the lasso edge list.
+        m_lassoEdgePositions.push_back(m_lassoToolPositions.back());
+        this->drawLasso();
 
-        // Cancel others interactions.
-        const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
-        layer->cancelFurtherInteraction();
-
-        // Get the clicked point in the world space.
-        const auto toolNearFarPos = this->getNearFarRayPositions(_x, _y);
-
-        // Check the interactions.
-        if(_button == MouseButton::LEFT)
-        {
-            // Check if the point can be added.
-            bool near = false;
-            for(const Ogre::Vector3 pos : m_lassoEdgePositions)
-            {
-                if((std::get<0>(toolNearFarPos) - pos).length() < m_lassoEdgeSize)
-                {
-                    near = true;
-                    break;
-                }
-            }
-
-            if(near)
-            {
-                this->triangulatePoints();
-
-                this->enableTool(false);
-                m_toolDisabledSig->asyncEmit();
-
-                // Send a render request.
-                this->requestRender();
-            }
-        }
+        // Cancel the left button move state.
+        m_leftButtonMoveState = false;
     }
+
+    this->triangulatePoints();
+
+    this->enableTool(false);
+    m_toolDisabledSig->asyncEmit();
+
+    // Send a render request.
+    this->requestRender();
 }
 
 //-----------------------------------------------------------------------------
 
-void SShapeExtruder::mouseMoveEvent(MouseButton _button, Modifier, int _x, int _y, int, int)
+void SShapeExtruder::wheelEvent(Modifier /*_mods*/, double /*_angleDelta*/, int /*_x*/, int /*_y*/)
 {
     if(m_interactionEnableState)
     {
-        this->getRenderService()->makeCurrent();
-
-        // Cancel others interactions.
+        // Don't change the zoom when the tool interaction is enabled.
         const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
         layer->cancelFurtherInteraction();
-
-        // Get the clicked point in the world space.
-        const auto toolNearFarPos = this->getNearFarRayPositions(_x, _y);
-
-        // Check the interactions.
-        if(_button == MouseButton::LEFT)
-        {
-            // Add a new position and draws the lasso.
-            m_lassoToolPositions.push_back(std::get<0>(toolNearFarPos));
-            m_lassoNearPositions.push_back(std::get<1>(toolNearFarPos));
-            m_lassoFarPositions.push_back(std::get<2>(toolNearFarPos));
-            this->drawLasso();
-
-            // Enable the left button move state.
-            m_leftButtonMoveState = true;
-        }
-
-        // Draw the last lasso line.
-        SIGHT_ASSERT("Lasso positions must have at east one point", m_lassoToolPositions.size() > 0);
-
-        m_lastLassoLine->beginUpdate(0);
-
-        m_lastLassoLine->colour(m_lineColor);
-        m_lastLassoLine->position(m_lassoToolPositions.back());
-        m_lastLassoLine->position(std::get<0>(toolNearFarPos));
-
-        m_lastLassoLine->end();
-
-        // Send a render request.
-        this->requestRender();
     }
 }
 
 //-----------------------------------------------------------------------------
 
-void SShapeExtruder::buttonReleaseEvent(MouseButton, Modifier, int, int)
+void SShapeExtruder::buttonPressEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y)
+{
+    if(_button == MouseButton::LEFT)
+    {
+        modifyLasso(Action::ADD, _x, _y);
+    }
+    else if(_button == MouseButton::RIGHT)
+    {
+        modifyLasso(Action::REMOVE, _x, _y);
+    }
+}
+
+//-----------------------------------------------------------------------------
+
+void SShapeExtruder::buttonDoublePressEvent(MouseButton _button, Modifier /*_mods*/, int /*_x*/, int /*_y*/)
+{
+    if(m_validationByDoubleClick && m_interactionEnableState && _button == MouseButton::LEFT)
+    {
+        // Cancel others interactions.
+        const sight::viz::scene3d::Layer::sptr layer = this->getLayer();
+        layer->cancelFurtherInteraction();
+
+        this->validate();
+    }
+}
+
+//-----------------------------------------------------------------------------
+
+void SShapeExtruder::mouseMoveEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y, int /*_dx*/, int /*_dy*/)
+{
+    if(!m_interactionEnableState)
+    {
+        return;
+    }
+
+    getRenderService()->makeCurrent();
+
+    // Cancel others interactions.
+    getLayer()->cancelFurtherInteraction();
+
+    // Get the clicked point in the world space.
+    const auto& [toolPosition, nearPosition, farPosition] = getNearFarRayPositions(_x, _y);
+
+    // Check if the mouse is still on the last point.
+    // This should not happen but it's better to check, since adding the same points twice will break everything.
+    if(!m_lassoToolPositions.empty() && m_lassoToolPositions.back() == toolPosition
+       && !m_lassoNearPositions.empty() && m_lassoNearPositions.back() == nearPosition
+       && !m_lassoFarPositions.empty() && m_lassoFarPositions.back() == farPosition)
+    {
+        return;
+    }
+
+    if(_button == MouseButton::LEFT)
+    {
+        // Add a new position and draws the lasso.
+        m_lassoToolPositions.push_back(toolPosition);
+        m_lassoNearPositions.push_back(nearPosition);
+        m_lassoFarPositions.push_back(farPosition);
+        drawLasso();
+
+        // Enable the left button move state.
+        m_leftButtonMoveState = true;
+    }
+
+    // Draw the last lasso line.
+    SIGHT_ASSERT("Lasso positions must have at east one point", !m_lassoToolPositions.empty());
+
+    m_lastLassoLine->beginUpdate(0);
+
+    m_lastLassoLine->colour(m_lineColor);
+    m_lastLassoLine->position(m_lassoToolPositions.back());
+    m_lastLassoLine->position(toolPosition);
+
+    m_lastLassoLine->end();
+
+    // Send a render request.
+    requestRender();
+}
+
+//-----------------------------------------------------------------------------
+
+void SShapeExtruder::buttonReleaseEvent(MouseButton /*_button*/, Modifier /*_mods*/, int /*_x*/, int /*_y*/)
 {
     if(m_interactionEnableState && m_leftButtonMoveState)
     {
@@ -622,7 +674,7 @@ void SShapeExtruder::drawLasso()
 
     // Draw the spheres at the edge of each line.
     const unsigned int sample = 16;
-    const float deltaRing     = static_cast<float>(Ogre::Math::PI / sample);
+    const auto deltaRing      = static_cast<float>(Ogre::Math::PI / sample);
     const float deltaSeg      = 2 * static_cast<float>(Ogre::Math::PI / sample);
 
     for(const Ogre::Vector3 pos : m_lassoEdgePositions)
@@ -687,10 +739,10 @@ void SShapeExtruder::triangulatePoints() const
     }
     else if(m_lassoNearPositions.size() == 3)
     {
-        triangulation.push_back(Triangle3D(m_lassoNearPositions[0], m_lassoNearPositions[1], m_lassoNearPositions[2]));
+        triangulation.emplace_back(m_lassoNearPositions[0], m_lassoNearPositions[1], m_lassoNearPositions[2]);
         if(m_extrude)
         {
-            triangulation.push_back(Triangle3D(m_lassoFarPositions[0], m_lassoFarPositions[1], m_lassoFarPositions[2]));
+            triangulation.emplace_back(m_lassoFarPositions[0], m_lassoFarPositions[1], m_lassoFarPositions[2]);
         }
     }
 
@@ -807,12 +859,12 @@ void SShapeExtruder::generateDelaunayTriangulation(
     std::vector<Ogre::Vector2> points;
     for(const Ogre::Vector3 point : _points)
     {
-        const Ogre::Vector2 viewPoint = (viewMatrix * Ogre::Vector4(point, 1.f)).xy();
+        const Ogre::Vector2 viewPoint = (viewMatrix * Ogre::Vector4(point, 1.F)).xy();
         points.push_back(viewPoint);
     }
 
     // Get the depth of the 2D plane.
-    const float depth = (viewMatrix * Ogre::Vector4(_points[0], 1.f)).z;
+    const float depth = (viewMatrix * Ogre::Vector4(_points[0], 1.F)).z;
 
     // Compute the bounding box of points.
     const float min = std::numeric_limits<float>::lowest();
@@ -834,8 +886,8 @@ void SShapeExtruder::generateDelaunayTriangulation(
 
     // Compute a triangle large enough to contains all points.
     const Ogre::Vector2 bottomLeft = minBound;
-    const Ogre::Vector2 bottomRight(minBound.x + (maxBound.x - minBound.x) * 2.f, minBound.y);
-    const Ogre::Vector2 topLeft(minBound.x, minBound.y + (maxBound.y - minBound.y) * 2.f);
+    const Ogre::Vector2 bottomRight(minBound.x + (maxBound.x - minBound.x) * 2.F, minBound.y);
+    const Ogre::Vector2 topLeft(minBound.x, minBound.y + (maxBound.y - minBound.y) * 2.F);
     const Triangle2D superTriangle(bottomLeft, bottomRight, topLeft);
 
     // Store triangles.
@@ -844,7 +896,7 @@ void SShapeExtruder::generateDelaunayTriangulation(
     // Triangulate points with the Bowyer-Watson algorithm.
     for(const Ogre::Vector2 sommet : points)
     {
-        this->addDelaunayPoint(triangulation, sommet);
+        sight::module::viz::scene3d::adaptor::SShapeExtruder::addDelaunayPoint(triangulation, sommet);
     }
 
     // Some input segment are missing from the triangulation, we insert them.
@@ -871,8 +923,8 @@ void SShapeExtruder::generateDelaunayTriangulation(
     while(count++ < maxIteration && oldPoints.size() != newPoints.size());
 
     // If triangles contains a vertex from original super-triangle, remove them.
-    std::vector<Triangle2D>::const_iterator endTriangulation = triangulation.end();
-    for(std::vector<Triangle2D>::const_iterator it = triangulation.begin() ; it != endTriangulation ; )
+    auto endTriangulation = triangulation.end();
+    for(auto it = triangulation.begin() ; it != endTriangulation ; )
     {
         const bool edgeA = it->a == superTriangle.a || it->a == superTriangle.b || it->a == superTriangle.c;
         const bool edgeB = it->b == superTriangle.a || it->b == superTriangle.b || it->b == superTriangle.c;
@@ -890,7 +942,7 @@ void SShapeExtruder::generateDelaunayTriangulation(
     }
 
     // Remove each triangle that aren't in the shape.
-    for(std::vector<Triangle2D>::const_iterator it = triangulation.begin() ; it != endTriangulation ; )
+    for(auto it = triangulation.begin() ; it != endTriangulation ; )
     {
         const Edge ray(it->barycentre, superTriangle.a);
 
@@ -920,17 +972,17 @@ void SShapeExtruder::generateDelaunayTriangulation(
     // Gets back triangle coordinates to the world space.
     for(const Triangle2D& triangle : triangulation)
     {
-        Ogre::Vector3 a = (viewMatrix.inverse() * Ogre::Vector4(triangle.a.x, triangle.a.y, depth, 1.f)).xyz();
-        Ogre::Vector3 b = (viewMatrix.inverse() * Ogre::Vector4(triangle.b.x, triangle.b.y, depth, 1.f)).xyz();
-        Ogre::Vector3 c = (viewMatrix.inverse() * Ogre::Vector4(triangle.c.x, triangle.c.y, depth, 1.f)).xyz();
+        Ogre::Vector3 a = (viewMatrix.inverse() * Ogre::Vector4(triangle.a.x, triangle.a.y, depth, 1.F)).xyz();
+        Ogre::Vector3 b = (viewMatrix.inverse() * Ogre::Vector4(triangle.b.x, triangle.b.y, depth, 1.F)).xyz();
+        Ogre::Vector3 c = (viewMatrix.inverse() * Ogre::Vector4(triangle.c.x, triangle.c.y, depth, 1.F)).xyz();
 
-        _wordTriangulation.push_back(Triangle3D(a, b, c));
+        _wordTriangulation.emplace_back(a, b, c);
     }
 }
 
 //-----------------------------------------------------------------------------
 
-void SShapeExtruder::addDelaunayPoint(std::vector<Triangle2D>& _triangulation, const Ogre::Vector2& _sommet) const
+void SShapeExtruder::addDelaunayPoint(std::vector<Triangle2D>& _triangulation, const Ogre::Vector2& _sommet)
 {
     // first find all the triangles that are no longer valid due to the insertion.
     std::list<Triangle2D> badTriangles;
@@ -1046,7 +1098,7 @@ std::list<Ogre::Vector2> SShapeExtruder::addConstraints(
     std::list<Ogre::Vector2> addedPoints;
     if(!found)
     {
-        const Ogre::Vector2 midPoint = (_edge.a + _edge.b) / 2.f;
+        const Ogre::Vector2 midPoint = (_edge.a + _edge.b) / 2.F;
         this->addDelaunayPoint(_triangulation, midPoint);
 
         const int depth                     = _depth + 1;
