@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2020-2022 IRCAD France
+ * Copyright (C) 2020-2023 IRCAD France
  * Copyright (C) 2020-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,6 +30,8 @@
 #include <data/Material.hpp>
 #include <data/ModelSeries.hpp>
 
+#include <service/INotifier.hpp>
+
 #include <viz/scene3d/IAdaptor.hpp>
 #include <viz/scene3d/interactor/IInteractor.hpp>
 
@@ -54,6 +56,9 @@ namespace sight::module::viz::scene3d::adaptor
  * @section Slots Slots
  * - \b enableTool(bool): enable or disable the tool, it will be automatically disabled when interactions are finished.
  * - \b deleteLastMesh(): delete the last extruded mesh.
+ * - \b cancelLastClick(): cancel the last point clicked during the extrusion
+ * - \b reset(): delete all extruded meshes.
+ * - \b validate(): validate points and generates the extrusion mesh.
  *
  * @section Signal Signals
  * - \b toolDisabled(): sent when interactions are finished.
@@ -62,7 +67,7 @@ namespace sight::module::viz::scene3d::adaptor
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SShapeExtruder">
         <inout key="extrudedMeshes" uid="..." />
-        <config layer="..." priority="2" extrude="true" />
+        <config priority="2" extrude="true" validation_on_double_click="true" />
     </service>
    @endcode
  *
@@ -70,13 +75,16 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b extrudedMeshes [sight::data::ModelSeries]: model series where all extruded meshes are stored.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string) : defines the layer.
  * - \b extrude (optional, bool, true) : sets if the extrusion is done or not (3D or 2D shape).
  * - \b priority (optional, int, default=2): interaction priority, higher priority interactions are performed first.
+ * - \b validation_on_double_click (optional, bool, default=true): defines if extrusion mesh can be generated by double
+ * click after last points
+ * otherwise the slot validate() should be called (through a button, or connected to another signal).
  */
 class MODULE_VIZ_SCENE3D_CLASS_API SShapeExtruder final :
     public sight::viz::scene3d::IAdaptor,
-    public sight::viz::scene3d::interactor::IInteractor
+    public sight::viz::scene3d::interactor::IInteractor,
+    private service::INotifier
 {
 public:
 
@@ -87,21 +95,21 @@ public:
     MODULE_VIZ_SCENE3D_API SShapeExtruder() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SShapeExtruder() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SShapeExtruder() noexcept final = default;
 
 protected:
 
     /// Configures the service.
-    MODULE_VIZ_SCENE3D_API void configuring() override;
+    MODULE_VIZ_SCENE3D_API void configuring() final;
 
     /// Creates Ogre resources and materials.
-    MODULE_VIZ_SCENE3D_API void starting() override;
+    MODULE_VIZ_SCENE3D_API void starting() final;
 
     /// Does nothing.
-    MODULE_VIZ_SCENE3D_API void updating() override;
+    MODULE_VIZ_SCENE3D_API void updating() final;
 
     /// Destroys all Ogre resources.
-    MODULE_VIZ_SCENE3D_API void stopping() override;
+    MODULE_VIZ_SCENE3D_API void stopping() final;
 
 private:
 
@@ -180,7 +188,7 @@ private:
         inline Edge(const Ogre::Vector2& _a, const Ogre::Vector2& _b);
 
         /// Checks if the segment intersects an other one.
-        bool intersect(Edge _edge) const;
+        [[nodiscard]] bool intersect(Edge _edge) const;
 
         /// Checks if two segments a equals.
         inline bool operator==(const Edge& _edge) const;
@@ -192,8 +200,14 @@ private:
         Ogre::Vector2 b;
     };
 
+    enum class Action
+    {
+        ADD,
+        REMOVE
+    };
+
     /// Computes the camera direction vector.
-    static Ogre::Vector3 getCamDirection(const Ogre::Camera* const _cam);
+    static Ogre::Vector3 getCamDirection(const Ogre::Camera* _cam);
 
     /// Sets if the tool is enabled or not.
     void enableTool(bool _enable);
@@ -201,6 +215,15 @@ private:
     /// Deletes the last extruded mesh.
     void deleteLastMesh();
 
+    /// Cancel the last clicked point during the extrusion
+    void cancelLastClick();
+
+    /// Reset all extrusions
+    void reset();
+
+    /// Validate points and generates the extrusion mesh.
+    void validate();
+
     /**
      * @brief Gets the near and far position of the intersection between the ray starting from the camera
      * and @ref m_lassoNearPlane/@ref m_lassoFarPlane
@@ -211,11 +234,19 @@ private:
      */
     std::tuple<Ogre::Vector3, Ogre::Vector3, Ogre::Vector3> getNearFarRayPositions(int _x, int _y) const;
 
+    /**
+     * @brief Modify the existing lasso
+     * @param _action The option to do on the lasso. Either ADD or REMOVE.
+     * @param _x X screen coordinate.
+     * @param _y Y screen coordinate.
+     */
+    void modifyLasso(Action _action, int _x = -1, int _y = -1);
+
     /**
      * @brief Cancels further interactions.
      * @pre @ref m_interactionEnableState must be true.
      */
-    void wheelEvent(Modifier, int, int, int) override;
+    void wheelEvent(Modifier /*_mods*/, double /*_angleDelta*/, int /*_x*/, int /*_y*/) final;
 
     /**
      * @brief Adds a new point to the lasso.
@@ -224,7 +255,7 @@ private:
      * @param _x X screen coordinate.
      * @param _y Y screen coordinate.
      */
-    void buttonPressEvent(MouseButton _button, Modifier, int _x, int _y) override;
+    void buttonPressEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y) final;
 
     /**
      * @brief Closes the lasso shape.
@@ -233,7 +264,7 @@ private:
      * @param _x X screen coordinate.
      * @param _y Y screen coordinate.
      */
-    void buttonDoublePressEvent(MouseButton _button, Modifier, int _x, int _y) override;
+    void buttonDoublePressEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y) final;
 
     /**
      * @brief Draws the last lasso line or add a point to the lasso in the mouse is dragged.
@@ -242,13 +273,13 @@ private:
      * @param _x X screen coordinate.
      * @param _y Y screen coordinate.
      */
-    void mouseMoveEvent(MouseButton _button, Modifier, int _x, int _y, int, int) override;
+    void mouseMoveEvent(MouseButton _button, Modifier /*_mods*/, int _x, int _y, int /*_dx*/, int /*_dy*/) final;
 
     /**
      * @brief Ends the drag interaction.
      * @pre @ref m_interactionEnableState and @ref m_leftButtonMoveState must be true.
      */
-    void buttonReleaseEvent(MouseButton, Modifier, int, int) override;
+    void buttonReleaseEvent(MouseButton /*_button*/, Modifier /*_mods*/, int /*_x*/, int /*_y*/) final;
 
     /// Draws the lasso from @ref m_lassoNearPositions.
     void drawLasso();
@@ -270,7 +301,7 @@ private:
     ) const;
 
     /// Adds a point to the triangulation with the delaunay constraints.
-    void addDelaunayPoint(std::vector<Triangle2D>& _triangulation, const Ogre::Vector2& _sommet) const;
+    static void addDelaunayPoint(std::vector<Triangle2D>& _triangulation, const Ogre::Vector2& _sommet);
 
     /**
      * @brief Add a constrained edge to the triangulation. IT inserts a new point corresponding to the midpoint of the
@@ -336,7 +367,7 @@ private:
     std::vector<Ogre::Vector3> m_lassoEdgePositions;
 
     /// Defines the radius of each point drawn at edges positions.
-    const float m_lassoEdgeSize {0.005f};
+    const float m_lassoEdgeSize {0.005F};
 
     /// Contains the node where all manual objects that represent the lasso are attached.
     Ogre::SceneNode* m_lassoNode {nullptr};
@@ -351,6 +382,8 @@ private:
     core::com::Signal<void()>::sptr m_toolDisabledSig;
 
     sight::data::ptr<sight::data::ModelSeries, sight::data::Access::inout> m_extrudedMeshes {this, "extrudedMeshes"};
+
+    bool m_validationByDoubleClick {true};
 };
 
 //------------------------------------------------------------------------------
