@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -25,7 +25,7 @@
 #include "modules/viz/scene3d/config.hpp"
 
 #include <viz/scene3d/IAdaptor.hpp>
-#include <viz/scene3d/Text.hpp>
+#include <viz/scene3d/IText.hpp>
 
 #include <OGRE/OgreColourValue.h>
 #include <OGRE/OgreVector.h>
@@ -46,8 +46,7 @@ namespace sight::module::viz::scene3d::adaptor
  * @code{.xml}
     <service type="sight::module::viz::scene3d::adaptor::SText">
         <in key="object" uid="..." />
-        <config layer="default" fontSource="DejaVuSans.ttf" fontSize="32"
-                hAlign="right" vAlign="bottom" color="#ff3396" />
+        <config fontSize="32" hAlign="right" vAlign="bottom" color="#ff3396" />
     </service>
    @endcode
  *
@@ -56,8 +55,7 @@ namespace sight::module::viz::scene3d::adaptor
  * @code{.xml}
     <service type="sight::module::viz::scene3d::adaptor::SText">
         <text>Hello World!</text>
-        <config layer="default" fontSource="DejaVuSans.ttf" fontSize="32"
-                hAlign="right" vAlign="bottom" color="#ff3396" />
+        <config fontSize="32" hAlign="right" vAlign="bottom" color="#ff3396" />
     </service>
    @endcode
  *
@@ -65,7 +63,6 @@ namespace sight::module::viz::scene3d::adaptor
  * - \b object (optional): "GenericField" object that can be casted to a text string.
  *
  * @subsection Configuration Configuration:
- * - \b layer (mandatory, string): not really used but it is needed to be bound to a render service.
  * - \b color (optional, hexadecimal, default=#FFFFFF): the color and opacity of the text.
  * - \b fontSource (optional, string, default=DejaVuSans.ttf): TrueType font (*.ttf) source file.
  * - \b fontSize (optional, unsigned int, default=16): font size in points.
@@ -86,29 +83,29 @@ public:
     MODULE_VIZ_SCENE3D_API SText() noexcept;
 
     /// Destroys the adaptor.
-    MODULE_VIZ_SCENE3D_API ~SText() noexcept override;
+    MODULE_VIZ_SCENE3D_API ~SText() noexcept final = default;
 
 protected:
 
     /// Configures the service.
-    MODULE_VIZ_SCENE3D_API void configuring() override;
+    MODULE_VIZ_SCENE3D_API void configuring() final;
 
     /// Creates the text object and adds it to the scene.
-    MODULE_VIZ_SCENE3D_API void starting() override;
+    MODULE_VIZ_SCENE3D_API void starting() final;
 
     /**
      * @brief Proposals to connect service slots to associated object signals.
      * @return A map of each proposed connection.
      *
-     * Connect data::Object::s_OBJECT_INPUT of s_POINTLIST_INPUT to s_UPDATE_SLOT
+     * Connect data::Object::s_OBJECT_INPUT of s_POINTLIST_INPUT to IService::slots::s_UPDATE
      */
-    MODULE_VIZ_SCENE3D_API KeyConnectionsMap getAutoConnections() const override;
+    MODULE_VIZ_SCENE3D_API KeyConnectionsMap getAutoConnections() const final;
 
     /// Updates the displayed text from the input object.
-    MODULE_VIZ_SCENE3D_API void updating() override;
+    MODULE_VIZ_SCENE3D_API void updating() final;
 
     /// Removes the text from the ogre scene and deletes it.
-    MODULE_VIZ_SCENE3D_API void stopping() override;
+    MODULE_VIZ_SCENE3D_API void stopping() final;
 
 private:
 
@@ -118,20 +115,17 @@ private:
     /// Updates the displayed text from the input object.
     void updateText();
 
-    /// Computes the position of text object relatively to the screen according to the alignment.
-    void updatePositionFromAlignment();
-
     /// Contains the displayed stats in the overlay.
-    sight::viz::scene3d::Text* m_text {nullptr};
+    sight::viz::scene3d::IText::sptr m_text;
 
     /// Defines the text's color.
-    Ogre::ColourValue m_textColor;
+    std::string m_textColor;
 
     /// Defines the font size in points.
-    std::size_t m_fontSize {16};
+    std::size_t m_fontSize {12};
 
     /// Defines the position of the text.
-    Ogre::Vector2 m_position {0.f, 0.f};
+    Ogre::Vector2 m_position {0.F, 0.F};
 
     /// Defines the vertical alignment type (top, center or bottom).
     std::string m_verticalAlignment;
@@ -146,7 +140,7 @@ private:
     std::string m_fontSource {"DejaVuSans.ttf"};
 
     static constexpr std::string_view s_OBJECT_INPUT = "object";
-    sight::data::ptr<sight::data::Object, sight::data::Access::in> m_object {this, s_OBJECT_INPUT};
+    sight::data::ptr<sight::data::Object, sight::data::Access::in> m_object {this, s_OBJECT_INPUT, true};
 };
 
 } // namespace sight::module::viz::scene3d::adaptor.
