@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2019-2022 IRCAD France
+ * Copyright (C) 2019-2023 IRCAD France
  * Copyright (C) 2019-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -30,7 +30,6 @@
 
 #include <service/macros.hpp>
 
-#include <viz/scene3d/helper/Font.hpp>
 #include <viz/scene3d/helper/ManualObject.hpp>
 #include <viz/scene3d/helper/Scene.hpp>
 #include <viz/scene3d/SRender.hpp>
@@ -42,9 +41,6 @@ namespace sight::module::viz::scene3d::adaptor
 
 static const core::com::Slots::SlotKeyType s_UPDATE_LENGTH_SLOT = "updateLength";
 
-static const std::string s_COLOR_CONFIG  = "color";
-static const std::string s_LENGTH_CONFIG = "length";
-
 //-----------------------------------------------------------------------------
 
 SVector::SVector() noexcept
@@ -54,18 +50,11 @@ SVector::SVector() noexcept
 
 //-----------------------------------------------------------------------------
 
-SVector::~SVector() noexcept
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void SVector::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
     const std::string transformId = config.get<std::string>(
         module::viz::scene3d::adaptor::STransform::s_TRANSFORM_CONFIG,
@@ -73,8 +62,8 @@ void SVector::configuring()
     );
 
     this->setTransformId(transformId);
-    m_length = config.get<float>(s_LENGTH_CONFIG, m_length);
-    m_color  = config.get<std::string>(s_COLOR_CONFIG, m_color);
+    m_length = config.get<float>(s_CONFIG + "length", m_length);
+    m_color  = config.get<std::string>(s_CONFIG + "color", m_color);
     SIGHT_ASSERT(
         "Color string should start with '#' and followed by 6 or 8 "
         "hexadecimal digits. Given color: " << m_color,
@@ -102,11 +91,12 @@ void SVector::starting()
         "sight::module::viz::scene3d::adaptor::SMaterial"
     );
     m_materialAdaptor->setInOut(m_material, module::viz::scene3d::adaptor::SMaterial::s_MATERIAL_INOUT, true);
-    m_materialAdaptor->setID(this->getID() + m_materialAdaptor->getID());
-    m_materialAdaptor->setMaterialName(this->getID() + m_materialAdaptor->getID());
-    m_materialAdaptor->setRenderService(this->getRenderService());
-    m_materialAdaptor->setLayerID(m_layerID);
-    m_materialAdaptor->setMaterialTemplateName(sight::viz::scene3d::Material::DEFAULT_MATERIAL_TEMPLATE_NAME);
+    m_materialAdaptor->configure(
+        this->getID() + m_materialAdaptor->getID(),
+        this->getID() + m_materialAdaptor->getID(),
+        this->getRenderService(),
+        m_layerID
+    );
     m_materialAdaptor->start();
 
     m_materialAdaptor->getMaterialFw()->setHasVertexColor(true);
@@ -141,9 +131,8 @@ void SVector::stopping()
 
     this->deleteVector();
 
-    Ogre::SceneManager* sceneMgr   = this->getSceneManager();
     Ogre::SceneNode* transformNode = this->getTransformNode();
-    if(transformNode)
+    if(transformNode != nullptr)
     {
         transformNode->removeAndDestroyChild(this->getID() + "_mainNode");
     }
@@ -164,9 +153,9 @@ void SVector::createVector()
     const unsigned sample      = 64;
 
     // Color
-    std::uint8_t color[4];
+    std::array<std::uint8_t, 4> color {};
     data::tools::Color::hexaStringToRGBA(m_color, color);
-    Ogre::ColourValue ogreColor(color[0] / 255.f, color[1] / 255.f, color[2] / 255.f);
+    Ogre::ColourValue ogreColor(float(color[0]) / 255.F, float(color[1]) / 255.F, float(color[2]) / 255.F);
 
     // Draw
     Ogre::SceneManager* sceneMgr = this->getSceneManager();
@@ -199,7 +188,7 @@ void SVector::createVector()
     Ogre::SceneNode* coneNode = m_sceneNode->createChildSceneNode(this->getID() + "_coneNode");
 
     coneNode->attachObject(m_cone);
-    coneNode->translate(0.f, 0.f, cylinderLength);
+    coneNode->translate(0.F, 0.F, cylinderLength);
     coneNode->yaw(Ogre::Degree(-90));
 }
 
@@ -223,7 +212,7 @@ void SVector::deleteVector()
 
 void SVector::setVisible(bool _visible)
 {
-    if(m_sceneNode)
+    if(m_sceneNode != nullptr)
     {
         m_sceneNode->setVisible(_visible);
     }
