@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -41,7 +41,6 @@
 #include <OGRE/OgreSceneManager.h>
 #include <OGRE/OgreSceneNode.h>
 #include <OGRE/OgreTechnique.h>
-#include <OGRE/OgreTextureManager.h>
 
 namespace sight::module::viz::scene3d::adaptor
 {
@@ -51,20 +50,6 @@ static const core::com::Slots::SlotKeyType s_UPDATE_PL_SLOT     = "updatePL";
 static const core::com::Slots::SlotKeyType s_SET_FILTERING_SLOT = "setFiltering";
 static const core::com::Slots::SlotKeyType s_SCALE_SLOT         = "scale";
 
-static const std::string s_VISIBLE_CONFIG           = "visible";
-static const std::string s_MATERIAL_TEMPLATE_CONFIG = "materialTemplate";
-static const std::string s_TEXTURE_NAME_CONFIG      = "textureName";
-static const std::string s_FILTERING_CONFIG         = "filtering";
-static const std::string s_SCALING_CONFIG           = "scaling";
-static const std::string s_RADIUS_CONFIG            = "radius";
-static const std::string s_DISPLAY_LABEL_CONFIG     = "displayLabel";
-static const std::string s_LABEL_COLOR_CONFIG       = "labelColor";
-static const std::string s_COLOR_CONFIG             = "color";
-static const std::string s_FIXED_SIZE_CONFIG        = "fixedSize";
-static const std::string s_QUERY_CONFIG             = "queryFlags";
-static const std::string s_FONT_SOURCE_CONFIG       = "fontSource";
-static const std::string s_FONT_SIZE_CONFIG         = "fontSize";
-
 static const std::string s_VIDEO_MATERIAL_NAME             = "Video";
 static const std::string s_VIDEO_WITH_TF_MATERIAL_NAME     = "VideoWithTF";
 static const std::string s_VIDEO_WITH_TF_INT_MATERIAL_NAME = "VideoWithTF_Int";
@@ -81,34 +66,27 @@ SVideo::SVideo() noexcept
 
 //------------------------------------------------------------------------------
 
-SVideo::~SVideo() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 void SVideo::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
 
-    const bool visible = config.get<bool>(s_VISIBLE_CONFIG, m_isVisible);
+    const bool visible = config.get<bool>(config::s_VISIBLE, m_isVisible);
     this->updateVisibility(visible);
 
-    m_materialTemplateName = config.get<std::string>(s_MATERIAL_TEMPLATE_CONFIG, m_materialTemplateName);
-    m_textureName          = config.get<std::string>(s_TEXTURE_NAME_CONFIG, m_textureName);
-    m_filtering            = config.get<bool>(s_FILTERING_CONFIG, m_filtering);
-    m_scaling              = config.get<bool>(s_SCALING_CONFIG, m_scaling);
-    m_radius               = config.get<std::string>(s_RADIUS_CONFIG, m_radius);
-    m_displayLabel         = config.get<std::string>(s_DISPLAY_LABEL_CONFIG, m_displayLabel);
-    m_labelColor           = config.get<std::string>(s_LABEL_COLOR_CONFIG, m_labelColor);
-    m_color                = config.get<std::string>(s_COLOR_CONFIG, m_color);
-    m_fixedSize            = config.get<std::string>(s_FIXED_SIZE_CONFIG, m_fixedSize);
-    m_queryFlags           = config.get<std::string>(s_QUERY_CONFIG, m_queryFlags);
-    m_fontSource           = config.get<std::string>(s_FONT_SOURCE_CONFIG, m_fontSource);
-    m_fontSize             = config.get<std::string>(s_FONT_SIZE_CONFIG, m_fontSize);
+    m_materialTemplateName = config.get<std::string>(config::s_MATERIAL_TEMPLATE, m_materialTemplateName);
+    m_textureName          = config.get<std::string>(config::s_TEXTURE_NAME, m_textureName);
+    m_filtering            = config.get<bool>(config::s_FILTERING, m_filtering);
+    m_scaling              = config.get<bool>(config::s_SCALING, m_scaling);
+    m_radius               = config.get<std::string>(config::s_RADIUS, m_radius);
+    m_displayLabel         = config.get<std::string>(config::s_DISPLAY_LABEL, m_displayLabel);
+    m_labelColor           = config.get<std::string>(config::s_LABEL_COLOR, m_labelColor);
+    m_color                = config.get<std::string>(config::s_COLOR, m_color);
+    m_fixedSize            = config.get<std::string>(config::s_FIXED_SIZE, m_fixedSize);
+    m_queryFlags           = config.get<std::string>(config::s_QUERY, m_queryFlags);
+    m_fontSource           = config.get<std::string>(config::s_FONT_SOURCE, m_fontSource);
+    m_fontSize             = config.get<std::string>(config::s_FONT_SIZE, m_fontSize);
 }
 
 //------------------------------------------------------------------------------
@@ -132,56 +110,56 @@ void SVideo::starting()
         m_pointListAdaptor->setInput(m_pointList, s_PL_INPUT, true);
 
         service::IService::ConfigType config;
-        config.add("config.<xmlattr>.layer", this->getLayerID());
-        config.add("config.<xmlattr>.autoresetcamera", "false");
+        config.add(s_CONFIG + "layer", this->getLayerID());
+        config.add(s_CONFIG + "autoresetcamera", "false");
         if(!m_materialTemplateName.empty())
         {
-            config.add("config.<xmlattr>." + s_MATERIAL_TEMPLATE_CONFIG, m_materialTemplateName);
+            config.add(config::s_MATERIAL_TEMPLATE, m_materialTemplateName);
         }
 
         if(!m_textureName.empty())
         {
-            config.add("config.<xmlattr>." + s_TEXTURE_NAME_CONFIG, m_textureName);
+            config.add(config::s_TEXTURE_NAME, m_textureName);
         }
 
         if(!m_radius.empty())
         {
-            config.add("config.<xmlattr>." + s_RADIUS_CONFIG, m_radius);
+            config.add(config::s_RADIUS, m_radius);
         }
 
         if(!m_displayLabel.empty())
         {
-            config.add("config.<xmlattr>." + s_DISPLAY_LABEL_CONFIG, m_displayLabel);
+            config.add(config::s_DISPLAY_LABEL, m_displayLabel);
         }
 
         if(!m_labelColor.empty())
         {
-            config.add("config.<xmlattr>." + s_LABEL_COLOR_CONFIG, m_labelColor);
+            config.add(config::s_LABEL_COLOR, m_labelColor);
         }
 
         if(!m_color.empty())
         {
-            config.add("config.<xmlattr>." + s_COLOR_CONFIG, m_color);
+            config.add(config::s_COLOR, m_color);
         }
 
         if(!m_fixedSize.empty())
         {
-            config.add("config.<xmlattr>." + s_FIXED_SIZE_CONFIG, m_fixedSize);
+            config.add(config::s_FIXED_SIZE, m_fixedSize);
         }
 
         if(!m_queryFlags.empty())
         {
-            config.add("config.<xmlattr>." + s_QUERY_CONFIG, m_queryFlags);
+            config.add(config::s_QUERY, m_queryFlags);
         }
 
         if(!m_fontSource.empty())
         {
-            config.add("config.<xmlattr>." + s_FONT_SOURCE_CONFIG, m_fontSource);
+            config.add(config::s_FONT_SOURCE, m_fontSource);
         }
 
         if(!m_fontSize.empty())
         {
-            config.add("config.<xmlattr>." + s_FONT_SIZE_CONFIG, m_fontSize);
+            config.add(config::s_FONT_SIZE, m_fontSize);
         }
 
         m_pointListAdaptor->setConfiguration(config);
@@ -193,6 +171,11 @@ void SVideo::starting()
 
         SIGHT_ASSERT("SPointList is not started", m_pointListAdaptor->isStarted());
     }
+
+    {
+        const auto image = m_image.lock();
+        m_texture = std::make_shared<sight::viz::scene3d::Texture>(image.get_shared());
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -200,8 +183,8 @@ void SVideo::starting()
 service::IService::KeyConnectionsMap SVideo::getAutoConnections() const
 {
     service::IService::KeyConnectionsMap connections;
-    connections.push(s_IMAGE_INPUT, data::Image::s_BUFFER_MODIFIED_SIG, s_UPDATE_SLOT);
-    connections.push(s_IMAGE_INPUT, data::Image::s_MODIFIED_SIG, s_UPDATE_SLOT);
+    connections.push(s_IMAGE_INPUT, data::Image::s_BUFFER_MODIFIED_SIG, IService::slots::s_UPDATE);
+    connections.push(s_IMAGE_INPUT, data::Image::s_MODIFIED_SIG, IService::slots::s_UPDATE);
 
     connections.push(s_TF_INPUT, data::TransferFunction::s_MODIFIED_SIG, s_UPDATE_TF_SLOT);
     connections.push(s_TF_INPUT, data::TransferFunction::s_POINTS_MODIFIED_SIG, s_UPDATE_TF_SLOT);
@@ -220,34 +203,27 @@ void SVideo::updating()
 {
     this->getRenderService()->makeCurrent();
 
-    // Getting Sight Image
-    const auto imageSight = m_image.lock();
-
-    auto type = imageSight->getType();
+    const auto&& typeAndSize = [this]
+                               {
+                                   const auto image = m_image.lock();
+                                   return std::make_pair(image->getType(), image->getSize());
+                               }();
+    const auto type = typeAndSize.first;
+    const auto size = typeAndSize.second;
+    if(size[0] == 0 || size[1] == 0)
+    {
+        return;
+    }
 
     if(!m_isTextureInit || type != m_previousType)
     {
-        // /////////////////////////////////////////////////////////////////////
-        // Create the appropriate material according to the texture format
-        // /////////////////////////////////////////////////////////////////////
-        if(!m_texture)
-        {
-            auto texture = Ogre::TextureManager::getSingletonPtr()->createOrRetrieve(
-                this->getID() + "_VideoTexture",
-                sight::viz::scene3d::RESOURCE_GROUP,
-                true
-            ).first;
-
-            m_texture = Ogre::dynamic_pointer_cast<Ogre::Texture>(texture);
-        }
-
         auto& mtlMgr  = Ogre::MaterialManager::getSingleton();
         const auto tf = m_tf.lock();
 
         Ogre::MaterialPtr defaultMat;
         if(tf)
         {
-            if(type == core::tools::Type::s_FLOAT || type == core::tools::Type::s_DOUBLE)
+            if(type == core::Type::FLOAT || type == core::Type::DOUBLE)
             {
                 defaultMat = mtlMgr.getByName(s_VIDEO_WITH_TF_MATERIAL_NAME, sight::viz::scene3d::RESOURCE_GROUP);
             }
@@ -274,26 +250,17 @@ void SVideo::updating()
         // Set the texture to the main material pass
         this->updateTextureFiltering();
 
-        Ogre::Pass* pass = m_material->getTechnique(0)->getPass(0);
-        SIGHT_ASSERT("The current pass cannot be retrieved.", pass);
-        Ogre::TextureUnitState* tus = pass->getTextureUnitState("image");
-        SIGHT_ASSERT("The texture unit cannot be retrieved.", tus);
-        tus->setTexture(m_texture);
-
         if(tf)
         {
             // TF texture initialization
-            m_gpuTF = std::make_unique<sight::viz::scene3d::TransferFunction>();
-            m_gpuTF->createTexture(this->getID());
-
+            m_gpuTF = std::make_unique<sight::viz::scene3d::TransferFunction>(tf.get_shared());
             this->updateTF();
         }
 
         m_previousType = type;
     }
 
-    const data::Image::Size size = imageSight->getSize();
-    sight::viz::scene3d::Utils::loadOgreTexture(imageSight.get_shared(), m_texture, Ogre::TEX_TYPE_2D, true);
+    m_texture->update();
 
     const auto layer                     = this->getLayer();
     const Ogre::Viewport* const viewport = layer->getViewport();
@@ -307,6 +274,9 @@ void SVideo::updating()
                || viewport->getActualHeight() != m_previousViewportHeight))
        || m_forcePlaneUpdate)
     {
+        Ogre::Pass* pass = m_material->getTechnique(0)->getPass(0);
+        m_texture->bind(pass, "image");
+
         this->clearEntity();
 
         // /////////////////////////////////////////////////////////////////////
@@ -387,8 +357,8 @@ void SVideo::stopping()
 
     this->clearEntity();
 
-    m_material.reset();
     m_texture.reset();
+    m_material.reset();
     m_gpuTF.reset();
 
     m_isTextureInit = false;
@@ -398,7 +368,7 @@ void SVideo::stopping()
 
 void SVideo::setVisible(bool _visible)
 {
-    if(m_entity)
+    if(m_entity != nullptr)
     {
         m_entity->setVisible(_visible);
 
@@ -410,14 +380,15 @@ void SVideo::setVisible(bool _visible)
 
 void SVideo::updateTF()
 {
-    const auto tf = m_tf.lock();
+    if(m_gpuTF)
+    {
+        m_gpuTF->update();
 
-    m_gpuTF->updateTexture(tf.get_shared());
+        Ogre::Pass* ogrePass = m_material->getTechnique(0)->getPass(0);
+        m_gpuTF->bind(ogrePass, "tf", ogrePass->getFragmentProgramParameters());
 
-    Ogre::Pass* ogrePass = m_material->getTechnique(0)->getPass(0);
-    m_gpuTF->bind(ogrePass, "tf", ogrePass->getFragmentProgramParameters());
-
-    this->requestRender();
+        this->requestRender();
+    }
 }
 
 //------------------------------------------------------------------------------
@@ -432,9 +403,9 @@ void SVideo::updatePL()
     data::PointList::PointListContainer& outPoints = m_pointList->getPoints();
     outPoints.clear();
 
-    for(std::size_t i = 0 ; i < inPoints.size() ; ++i)
+    for(const auto& inPoint : inPoints)
     {
-        const data::Point::PointCoordArrayType& point = inPoints[i]->getCoord();
+        const data::Point::PointCoordArrayType& point = inPoint->getCoord();
         outPoints.push_back(
             data::Point::New(
                 point[0] - static_cast<double>(image->getSize()[0]) * 0.5,
@@ -455,14 +426,14 @@ void SVideo::updatePL()
 
 void SVideo::clearEntity()
 {
-    if(m_entity)
+    if(m_entity != nullptr)
     {
         m_entity->detachFromParent();
         this->getSceneManager()->destroyEntity(m_entity);
         m_entity = nullptr;
     }
 
-    if(m_sceneNode)
+    if(m_sceneNode != nullptr)
     {
         m_sceneNode->removeAndDestroyAllChildren();
         this->getSceneManager()->destroySceneNode(m_sceneNode);
