@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2016-2022 IRCAD France
+ * Copyright (C) 2016-2023 IRCAD France
  * Copyright (C) 2016-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -24,11 +24,6 @@
 
 #include "modules/viz/scene3d/config.hpp"
 
-#include <core/com/Slot.hpp>
-#include <core/com/Slots.hpp>
-
-#include <data/helper/TransferFunction.hpp>
-
 #include <viz/scene3d/IAdaptor.hpp>
 #include <viz/scene3d/IGraphicsWorker.hpp>
 #include <viz/scene3d/interactor/ClippingBoxInteractor.hpp>
@@ -80,24 +75,26 @@ namespace sight::module::viz::scene3d::adaptor
  * @section XML XML Configuration
  * @code{.xml}
     <service uid="..." type="sight::module::viz::scene3d::adaptor::SVolumeRender" >
-        <inout key="image" uid="..." autoConnect="true" />
-        <inout key="tf" uid="..." />
+        <in key="image" uid="..." autoConnect="true" />
+        <in key="mask" uid="..." autoConnect="true" />
+        <in key="tf" uid="..." />
         <inout key="clippingMatrix" uid="..." />
-        <config layer="default"
-                samples="1024" preintegration="true" dynamic="false" ao="false" colorBleeding="false" shadows="false"
+        <config samples="1024" preintegration="true" dynamic="false" ao="false" colorBleeding="false" shadows="false"
                 satSizeRatio="0.25" satShells="3" satShellRadius="7" satConeAngle="0.1" satConeSamples="50"
                 aoFactor="0.5" colorBleedingFactor="0.5" autoresetcamera="true" transform="..."/>
     </service>
    @endcode
  *
- * @subsection In-Out In-Out
+ * @subsection Input Input
  * - \b image [sight::data::Image]: input volume data.
+ * - \b mask [sight::data::Image]: mask used to crop regions.
  * - \b tf [sight::data::TransferFunction] (optional): the current TransferFunction. If it is not defined, we use the
  *      image's default transferFunction (CT-GreyLevel).
+ *
+ * @subsection In-Out In-Out
  * - \b clippingMatrix [sight::data::Matrix4]: matrix used to clip the volume.
  *
  * @subsection Configuration Configuration
- * - \b layer (mandatory, string): id of the layer where this adaptor applies.
  * - \b samples (optional, unsigned int, default=512): maximum number of samples per ray or number of slices.
  * - \b preintegration (optional, true/false, default=false): use pre-integration.
  * - \b dynamic (optional, bool, default=false): enables background buffering for dynamic images.
@@ -146,27 +143,29 @@ protected:
     static inline const sight::core::com::Slots::SlotKeyType s_SET_INT_PARAMETER_SLOT    = "setIntParameter";
     static inline const sight::core::com::Slots::SlotKeyType s_SET_DOUBLE_PARAMETER_SLOT = "setDoubleParameter";
     static inline const sight::core::com::Slots::SlotKeyType s_UPDATE_CLIPPING_BOX_SLOT  = "updateClippingBox";
+    static inline const sight::core::com::Slots::SlotKeyType s_UPDATE_TF_SLOT            = "updateTF";
+    static inline const sight::core::com::Slots::SlotKeyType s_UPDATE_MASK_SLOT          = "updateMask";
 
     ///@brief Internal wrapper holding config defines.
     struct config
     {
-        static inline const std::string AUTORESET_CAMERA      = "autoresetcamera";
-        static inline const std::string PREINTEGRATION        = "preintegration";
-        static inline const std::string DYNAMIC               = "dynamic";
-        static inline const std::string WIDGETS               = "widgets";
-        static inline const std::string PRIORITY              = "priority";
-        static inline const std::string LAYER_ORDER_DEPENDANT = "layerOrderDependant";
-        static inline const std::string SAMPLES               = "samples";
-        static inline const std::string SAT_SIZE_RATIO        = "satSizeRatio";
-        static inline const std::string SAT_SHELLS            = "satShells";
-        static inline const std::string SAT_SHELL_RADIUS      = "satShellRadius";
-        static inline const std::string SAT_CONE_ANGLE        = "satConeAngle";
-        static inline const std::string SAT_CONE_SAMPLES      = "satConeSamples";
-        static inline const std::string AO_FACTOR             = "aoFactor";
-        static inline const std::string COLOR_BLEEDING_FACTOR = "colorBleedingFactor";
-        static inline const std::string AO                    = "ao";
-        static inline const std::string COLOR_BLEEDING        = "colorBleeding";
-        static inline const std::string SHADOWS               = "shadows";
+        static inline const std::string AUTORESET_CAMERA      = s_CONFIG + "autoresetcamera";
+        static inline const std::string PREINTEGRATION        = s_CONFIG + "preintegration";
+        static inline const std::string DYNAMIC               = s_CONFIG + "dynamic";
+        static inline const std::string WIDGETS               = s_CONFIG + "widgets";
+        static inline const std::string PRIORITY              = s_CONFIG + "priority";
+        static inline const std::string LAYER_ORDER_DEPENDANT = s_CONFIG + "layerOrderDependant";
+        static inline const std::string SAMPLES               = s_CONFIG + "samples";
+        static inline const std::string SAT_SIZE_RATIO        = s_CONFIG + "satSizeRatio";
+        static inline const std::string SAT_SHELLS            = s_CONFIG + "satShells";
+        static inline const std::string SAT_SHELL_RADIUS      = s_CONFIG + "satShellRadius";
+        static inline const std::string SAT_CONE_ANGLE        = s_CONFIG + "satConeAngle";
+        static inline const std::string SAT_CONE_SAMPLES      = s_CONFIG + "satConeSamples";
+        static inline const std::string AO_FACTOR             = s_CONFIG + "aoFactor";
+        static inline const std::string COLOR_BLEEDING_FACTOR = s_CONFIG + "colorBleedingFactor";
+        static inline const std::string AO                    = s_CONFIG + "ao";
+        static inline const std::string COLOR_BLEEDING        = s_CONFIG + "colorBleeding";
+        static inline const std::string SHADOWS               = s_CONFIG + "shadows";
     };
 
     /// Internal wrapper holding the inital config
@@ -206,8 +205,9 @@ protected:
     /// Internal wrapper holding object keys
     struct objects
     {
-        static constexpr std::string_view IMAGE_INOUT           = "image";
-        static constexpr std::string_view VOLUME_TF_INOUT       = "tf";
+        static constexpr std::string_view IMAGE_IN              = "image";
+        static constexpr std::string_view MASK_IN               = "mask";
+        static constexpr std::string_view VOLUME_TF_IN          = "tf";
         static constexpr std::string_view CLIPPING_MATRIX_INOUT = "clippingMatrix";
     };
 
@@ -230,12 +230,6 @@ protected:
     /// Does nothing.
     MODULE_VIZ_SCENE3D_API void updating() override;
 
-    /**
-     * @brief Notifies that the TF is swapped.
-     * @param _key key of the swapped data.
-     */
-    MODULE_VIZ_SCENE3D_API void swapping(std::string_view _key) override;
-
     /// Cleans up scene objects.
     MODULE_VIZ_SCENE3D_API void stopping() override;
 
@@ -267,6 +261,9 @@ private:
     /// Updates renderer and the GPU volume texture with the new input image data.
     void updateImage();
 
+    /// Updates renderer and the GPU volume texture with the new mask data.
+    void updateMask();
+
     /// Starts a parallel task to copy the updated image buffer into the texture buffer.
     void bufferImage();
 
@@ -440,9 +437,6 @@ private:
     /// Implements a simple GPU ray-tracing renderer.
     std::unique_ptr<sight::viz::scene3d::vr::RayTracingVolumeRenderer> m_volumeRenderer {nullptr};
 
-    /// Helps to manage updates of the transfer function.
-    data::helper::TransferFunction m_helperVolumeTF;
-
     /// Fills the incoming image texture in a parallel thread.
     std::unique_ptr<sight::viz::scene3d::IGraphicsWorker> m_bufferingWorker;
 
@@ -455,14 +449,15 @@ private:
     /// Stores the widgets used for clipping.
     std::shared_ptr<sight::viz::scene3d::interactor::ClippingBoxInteractor> m_widget;
 
-    sight::data::ptr<sight::data::Image, sight::data::Access::inout> m_image {this, objects::IMAGE_INOUT};
-    sight::data::ptr<sight::data::TransferFunction, sight::data::Access::inout> m_tf {this, objects::VOLUME_TF_INOUT,
-                                                                                      false, true
-    };
+    sight::data::ptr<sight::data::Image, sight::data::Access::in> m_image {this, objects::IMAGE_IN, true};
+    sight::data::ptr<sight::data::Image, sight::data::Access::in> m_mask {this, objects::MASK_IN, true};
+    sight::data::ptr<sight::data::TransferFunction, sight::data::Access::in> m_tf {this, objects::VOLUME_TF_IN, true};
     sight::data::ptr<sight::data::Matrix4, sight::data::Access::inout> m_clippingMatrix
     {
         this,
-        objects::CLIPPING_MATRIX_INOUT
+        objects::CLIPPING_MATRIX_INOUT,
+        true,
+        true
     };
 };
 
