@@ -38,12 +38,6 @@ const core::com::Slots::SlotKeyType s_SLICETYPE_SLOT = "sliceType";
 
 static const core::com::Signals::SignalKeyType s_PICKED_SIG = "picked";
 
-static const std::string s_PRIORITY_CONFIG              = "priority";
-static const std::string s_ORIENTATION_CONFIG           = "orientation";
-static const std::string s_MODE_CONFIG                  = "mode";
-static const std::string s_LAYER_ORDER_DEPENDANT_CONFIG = "layerOrderDependant";
-static const std::string s_MOVE_ON_PICK_CONFIG          = "moveOnPick";
-
 //-----------------------------------------------------------------------------
 
 SVoxelPicker::SVoxelPicker() noexcept
@@ -55,18 +49,17 @@ SVoxelPicker::SVoxelPicker() noexcept
 
 //-----------------------------------------------------------------------------
 
-SVoxelPicker::~SVoxelPicker() noexcept
-{
-}
-
-//-----------------------------------------------------------------------------
-
 void SVoxelPicker::configuring()
 {
     this->configureParams();
 
-    const ConfigType configType = this->getConfigTree();
-    const ConfigType config     = configType.get_child("config.<xmlattr>");
+    const ConfigType config = this->getConfiguration();
+
+    static const std::string s_PRIORITY_CONFIG              = s_CONFIG + "priority";
+    static const std::string s_ORIENTATION_CONFIG           = s_CONFIG + "orientation";
+    static const std::string s_MODE_CONFIG                  = s_CONFIG + "mode";
+    static const std::string s_LAYER_ORDER_DEPENDANT_CONFIG = s_CONFIG + "layerOrderDependant";
+    static const std::string s_MOVE_ON_PICK_CONFIG          = s_CONFIG + "moveOnPick";
 
     m_priority            = config.get<int>(s_PRIORITY_CONFIG, m_priority);
     m_layerOrderDependant = config.get<bool>(s_LAYER_ORDER_DEPENDANT_CONFIG, m_layerOrderDependant);
@@ -152,7 +145,7 @@ void SVoxelPicker::pick(MouseButton _button, Modifier _mod, int _x, int _y, bool
     {
         if(auto layer = m_layer.lock())
         {
-            if(!this->isInLayer(_x, _y, layer, m_layerOrderDependant))
+            if(!sight::module::viz::scene3d::adaptor::SVoxelPicker::isInLayer(_x, _y, layer, m_layerOrderDependant))
             {
                 return;
             }
@@ -261,9 +254,9 @@ std::pair<bool, Ogre::Vector3> SVoxelPicker::computeRayImageIntersection(
     const auto frontalIdx  = imHelper::getSliceIndex(*_image, imHelper::orientation_t::FRONTAL).value_or(0);
     const auto sagittalIdx = imHelper::getSliceIndex(*_image, imHelper::orientation_t::SAGITTAL).value_or(0);
 
-    const Ogre::Real axialIndex    = static_cast<Ogre::Real>(axialIdx);
-    const Ogre::Real frontalIndex  = static_cast<Ogre::Real>(frontalIdx);
-    const Ogre::Real sagittalIndex = static_cast<Ogre::Real>(sagittalIdx);
+    const auto axialIndex    = static_cast<Ogre::Real>(axialIdx);
+    const auto frontalIndex  = static_cast<Ogre::Real>(frontalIdx);
+    const auto sagittalIndex = static_cast<Ogre::Real>(sagittalIdx);
 
     const auto size = _image->getSize();
 
@@ -432,7 +425,7 @@ std::pair<bool, Ogre::Vector3> SVoxelPicker::computeRayImageIntersection(
         }
     }
 
-    return std::make_pair(false, Ogre::Vector3());
+    return std::make_pair(false, Ogre::Vector3 {0.0, 0.0, 0.0});
 }
 
 //-----------------------------------------------------------------------------
