@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2022 IRCAD France
+ * Copyright (C) 2018-2023 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,12 +22,12 @@
 
 #include "modules/viz/scene3dQt/OffScreenWindowInteractor.hpp"
 
-#include "modules/viz/scene3dQt/OpenGLWorker.hpp"
+#include <modules/viz/scene3dQt/init.hpp>
+#include <modules/viz/scene3dQt/OpenGLWorker.hpp>
 
 #include <viz/scene3d/ogre.hpp>
 #include <viz/scene3d/registry/macros.hpp>
 #include <viz/scene3d/SRender.hpp>
-#include <viz/scene3d/WindowManager.hpp>
 
 #define FW_PROFILING_DISABLED
 #include <core/Profiling.hpp>
@@ -38,7 +38,7 @@
 
 //-----------------------------------------------------------------------------
 
-fwRenderOgreRegisterOffscreenMgrMacro(
+SIGHT_REGISTER_SCENE3D_OFFSCREEN(
     sight::module::viz::scene3dQt::OffScreenWindowInteractor,
     sight::viz::scene3d::IWindowInteractor::OFFSCREEN_REGISTRY_KEY
 );
@@ -51,7 +51,7 @@ int OffScreenWindowInteractor::m_counter = 0;
 //-----------------------------------------------------------------------------
 
 OffScreenWindowInteractor::OffScreenWindowInteractor(
-    sight::viz::scene3d::IWindowInteractor::OffscreenMgrKey,
+    sight::viz::scene3d::IWindowInteractor::OffscreenMgrKey /*unused*/,
     unsigned int _width,
     unsigned int _height
 ) :
@@ -64,8 +64,7 @@ OffScreenWindowInteractor::OffScreenWindowInteractor(
 //-----------------------------------------------------------------------------
 
 OffScreenWindowInteractor::~OffScreenWindowInteractor()
-{
-}
+= default;
 
 //-----------------------------------------------------------------------------
 
@@ -83,7 +82,11 @@ void OffScreenWindowInteractor::requestRender()
 
 //-----------------------------------------------------------------------------
 
-void OffScreenWindowInteractor::createContainer(sight::ui::base::container::fwContainer::sptr, bool)
+void OffScreenWindowInteractor::createContainer(
+    sight::ui::base::container::fwContainer::sptr /*_parent*/,
+    bool /*fullscreen*/,
+    const std::string& /*id*/
+)
 {
     m_ogreRoot = sight::viz::scene3d::Utils::getOgreRoot();
 
@@ -92,30 +95,12 @@ void OffScreenWindowInteractor::createContainer(sight::ui::base::container::fwCo
         m_ogreRoot->getRenderSystem()->getName().find("GL") != std::string::npos
     );
 
-    Ogre::NameValuePairList parameters;
-
-    sight::viz::scene3d::WindowManager::sptr mgr = sight::viz::scene3d::WindowManager::get();
-
     // We share the OpenGL context on all windows. The first window will create the context, the other ones will
     // reuse the current context.
     m_offscreenSurface = std::make_unique<QOffscreenSurface>();
-    m_glContext        = OpenGLContext::getGlobalOgreOpenGLContext();
     this->makeCurrent();
 
-    parameters["currentGLContext"] = "true";
-
-    // We create the renderWindow with a dummy size of 1 by 1
-    m_ogreRenderWindow = m_ogreRoot->createRenderWindow(
-        "OffScreenWindow_" + std::to_string(m_id),
-        1,
-        1,
-        false,
-        &parameters
-    );
-    mgr->registerWindow(m_ogreRenderWindow);
-
-    m_ogreRenderWindow->setHidden(true);
-    m_ogreRenderWindow->setAutoUpdated(false);
+    initResources();
 
     auto& texMgr = Ogre::TextureManager::getSingleton();
     m_ogreTexture = texMgr.createManual(
@@ -129,6 +114,25 @@ void OffScreenWindowInteractor::createContainer(sight::ui::base::container::fwCo
         Ogre::TU_RENDERTARGET
     );
     m_ogreRenderTarget = m_ogreTexture->getBuffer()->getRenderTarget();
+
+    const auto renderService = sight::viz::scene3d::SRender::dynamicCast(m_renderService.lock());
+    SIGHT_ASSERT("RenderService wrongly instantiated. ", renderService);
+
+    std::map<int, sight::viz::scene3d::Layer::wptr> orderedLayers;
+    for(auto& layer : renderService->getLayers())
+    {
+        orderedLayers[layer.second->getOrder()] = layer.second;
+    }
+
+    for(auto& layer : orderedLayers)
+    {
+        const auto l = layer.second.lock();
+        l->setRenderTarget(m_ogreRenderTarget);
+        if(!l->initialized())
+        {
+            l->createScene();
+        }
+    }
 }
 
 //-----------------------------------------------------------------------------
@@ -143,13 +147,6 @@ void OffScreenWindowInteractor::disconnectInteractor()
 {
     m_ogreRenderTarget = nullptr;
 
-    if(m_ogreRenderWindow)
-    {
-        sight::viz::scene3d::WindowManager::sptr mgr = sight::viz::scene3d::WindowManager::get();
-        mgr->unregisterWindow(m_ogreRenderWindow);
-        m_ogreRenderWindow = nullptr;
-    }
-
     if(m_ogreTexture)
     {
         auto& texMgr = Ogre::TextureManager::getSingleton();
@@ -164,33 +161,29 @@ void OffScreenWindowInteractor::disconnectInteractor()
 
 void OffScreenWindowInteractor::makeCurrent()
 {
-    if(m_glContext)
     {
-        m_glContext->makeCurrent(m_offscreenSurface.get());
+        QOpenGLContext::globalShareContext()->makeCurrent(m_offscreenSurface.get());
 
-        if(m_ogreRenderWindow)
+        Ogre::RenderSystem* renderSystem = m_ogreRoot->getRenderSystem();
+
+        if(renderSystem != nullptr)
         {
-            Ogre::RenderSystem* renderSystem = m_ogreRoot->getRenderSystem();
+            // Use this trick to apply the current OpenGL context
+            //
+            // Actually this method does the following :
+            // void GLRenderSystem::postExtraThreadsStarted()
+            // {
+            //   OGRE_LOCK_MUTEX(mThreadInitMutex);
+            //   if(mCurrentContext)
+            //     mCurrentContext->setCurrent();
+            // }
+            //
+            // This is actually want we want to do, even if this is not the initial purpose of this method
+            //
+            renderSystem->postExtraThreadsStarted();
 
-            if(renderSystem)
-            {
-                // This allows to set the current OpenGL context in Ogre internal state
-                renderSystem->_setRenderTarget(m_ogreRenderTarget);
-
-                // Use this trick to apply the current OpenGL context
-                //
-                // Actually this method does the following :
-                // void GLRenderSystem::postExtraThreadsStarted()
-                // {
-                //   OGRE_LOCK_MUTEX(mThreadInitMutex);
-                //   if(mCurrentContext)
-                //     mCurrentContext->setCurrent();
-                // }
-                //
-                // This is actually want we want to do, even if this is not the initial purpose of this method
-                //
-                renderSystem->postExtraThreadsStarted();
-            }
+            // This allows to set the current OpenGL context in Ogre internal state
+            renderSystem->_setRenderTarget(m_ogreRenderTarget);
         }
     }
 }
@@ -199,14 +192,8 @@ void OffScreenWindowInteractor::makeCurrent()
 
 void OffScreenWindowInteractor::render()
 {
-    if(m_ogreRenderWindow == nullptr)
-    {
-        return;
-    }
-
     service::IService::sptr renderService                = m_renderService.lock();
     sight::viz::scene3d::SRender::sptr ogreRenderService = sight::viz::scene3d::SRender::dynamicCast(renderService);
-    ogreRenderService->slot(sight::viz::scene3d::SRender::s_COMPUTE_CAMERA_CLIPPING_SLOT)->asyncRun();
 
     ++m_frameId;
     /*
@@ -223,14 +210,15 @@ void OffScreenWindowInteractor::render()
     FW_PROFILE_AVG("Ogre", 3);
     this->makeCurrent();
 
-    m_ogreRenderTarget->update();
+    m_ogreRenderTarget->update(false);
 }
 
 //-----------------------------------------------------------------------------
 
 sight::viz::scene3d::IGraphicsWorker* OffScreenWindowInteractor::createGraphicsWorker()
 {
-    return new OpenGLWorker(m_offscreenSurface.get());
+    SIGHT_ASSERT("Not supported", false);
+    return nullptr;
 }
 
 //-----------------------------------------------------------------------------
