@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -26,12 +26,11 @@
 #include "modules/viz/scene3dQt/OpenGLContext.hpp"
 
 #include <viz/scene3d/IWindowInteractor.hpp>
+#include <viz/scene3d/Layer.hpp>
 
 #include <Ogre.h>
-
-#include <Overlay/OgreOverlay.h>
-#include <Overlay/OgreOverlaySystem.h>
-
+#include <QGestureEvent>
+#include <QOpenGLWidget>
 #include <QPoint>
 #include <QScreen>
 
@@ -45,9 +44,7 @@
 namespace sight::module::viz::scene3dQt
 {
 
-class Window final :
-    public QWindow,
-    public Ogre::RenderTargetListener
+class Window final : public QOpenGLWidget
 {
 Q_OBJECT
 
@@ -55,29 +52,17 @@ public:
 
     /**
      * @brief Initializes members and connect screenChanged to onScreenChanged.
-     * @param _parent the parent container of the widget.
      */
-    Window(QWindow* _parent = nullptr);
+    Window();
 
     /// Destroys associated pointers by calling @ref destroy().
-    ~Window() override;
+    ~Window() override = default;
 
-    /**
-     * @brief Does nothing.
-     * In case any drawing surface backing stores (QRasterWindow or QOpenGLWindow) of Qt are supplied to this
-     * class in any way we inform Qt that they will be unused.
-     */
-    void render(QPainter*);
-
-    /// Creates the Ogre render window associated to this window,
-    /// called by renderNow() once the window is first exposed.
-    void initialize();
-
-    /// Returns the Ogre render window.
-    Ogre::RenderWindow* getOgreRenderWindow() const;
+    void registerLayer(sight::viz::scene3d::Layer::wptr _layer);
+    void createRenderTextures(int w, int h);
 
     /// Gets this window ID.
-    int getId() const;
+    [[nodiscard]] int getId() const;
 
     /// Makes the OpenGL context as current one on this thread against this window.
     void makeCurrent();
@@ -86,7 +71,7 @@ public:
     void destroyWindow();
 
     /// Returns current frame number of the render window.
-    int getFrameId() const;
+    [[nodiscard]] int getFrameId() const;
 
     /// Renders immediately the frame.
     void renderNow();
@@ -99,11 +84,11 @@ Q_SIGNALS:
     /// Emits when the user interacts with the scene using the mouse and keyboard.
     void interacted(sight::viz::scene3d::IWindowInteractor::InteractionInfo);
 
-    /// Emits to recompute the camera's clipping range.
-    void cameraClippingComputation();
-
 private:
 
+    /// Manages events
+    bool event(QEvent* e) override;
+
     /// Manages keyboard action.
     void keyPressEvent(QKeyEvent* _e) override;
 
@@ -125,35 +110,31 @@ private:
     /// Manages mouse click on release.
     void mouseReleaseEvent(QMouseEvent* _e) override;
 
-    /// Manages when window visibility in the windowing system changes.
-    void exposeEvent(QExposeEvent*) override;
+    /// Manages mouse leaving the widget
+    void leaveEvent(QEvent* _e) override;
 
-    /// Manages when window is moved.
-    void moveEvent(QMoveEvent*) override;
+    /// Manages mouse entering the widget
+    void enterEvent(QEvent* _e) override;
 
-    /// Manages generic events.
-    bool event(QEvent* _event) override;
+    /// Manages gestures.
+    void gestureEvent(QGestureEvent* _e);
 
     using InteractionInfo = sight::viz::scene3d::IWindowInteractor::InteractionInfo;
 
     /// Converts the mouse event to be able to handle it with ogre.
     InteractionInfo convertMouseEvent(
-        const QMouseEvent* const _evt,
+        const QMouseEvent* _evt,
         InteractionInfo::InteractionEnum _interactionType
     ) const;
 
-    /**
-     * @brief Renders immediately the frame.
-     * Calls OgreRoot renderOneFrame to update the current renderWindow.
-     * If you want to update this window, call requestRender().
-     */
-    void render();
-
-    /// Renders the frame as soon as possible.
-    void renderLater();
+    /// Creates the Ogre render window associated to this window,
+    /// called by renderNow() once the window is first exposed.
+    void initializeGL() override;
+    void resizeGL(int w, int h) override;
+    void paintGL() override;
 
     /// Forwards the resize event.
-    /// @param _newSize size in hidpi, you must multiplicate with devicePixelRatio to get the real pixel value
+    /// @param _newSize size in hidpi, you must multiplicate with devicePixelRatioF to get the real pixel value
     void ogreResize(const QSize& _newSize);
 
     /// Defines a counter to get the widget ID.
@@ -165,9 +146,6 @@ private:
     /// Contains the Ogre root.
     Ogre::Root* m_ogreRoot {nullptr};
 
-    /// Contains the Ogre render window.
-    Ogre::RenderWindow* m_ogreRenderWindow {nullptr};
-
     /// Tells if an update is requested
     bool m_update_pending {false};
 
@@ -178,15 +156,32 @@ private:
     int m_frameId {0};
 
     /// Contains the OpenGL context used for offscreen rendering.
-    std::shared_ptr<QOpenGLContext> m_glContext;
+    // std::shared_ptr<QOpenGLContext> m_glContext;
 
     /// Defines the last size sent to Ogre. In hidpi
     QSize m_ogreSize;
 
-private Q_SLOTS:
+    /// Workaround to fix multiple scenes rendering with NVidia Prime
+    bool m_init {false};
 
-    /// Called when the screen changes.
-    void onScreenChanged(QScreen*);
+    Ogre::MeshPtr m_fsQuadPlane {};
+
+    struct RenderTarget
+    {
+        sight::viz::scene3d::Layer::wptr layer;
+        Ogre::MaterialPtr material;
+        Ogre::TexturePtr texture;
+    };
+    std::vector<RenderTarget> m_renderTargets;
+
+    enum class GestureState : std::uint8_t
+    {
+        NoGesture = 0,
+        PanGesture,
+        PinchGesture
+    };
+
+    GestureState m_gestureState {GestureState::NoGesture};
 };
 
 //-----------------------------------------------------------------------------
