@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2014-2022 IRCAD France
+ * Copyright (C) 2014-2023 IRCAD France
  * Copyright (C) 2014-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -34,17 +34,12 @@
 #include <QObject>
 #include <QPointer>
 
-namespace sight::ui::qt
-{
-
-namespace container
+namespace sight::ui::qt::container
 {
 
 class QtContainer;
 
-}
-
-}
+} // namespace sight::ui::qt::container
 
 namespace sight::module::viz::scene3dQt
 {
@@ -79,7 +74,8 @@ public:
      */
     MODULE_VIZ_SCENE3DQT_API void createContainer(
         ui::base::container::fwContainer::sptr _parent,
-        bool _fullscreen
+        bool _fullscreen,
+        const std::string& serviceID
     ) final;
 
     /// Connects the widget and the SRender signals and slots.
@@ -97,9 +93,6 @@ public:
     /// Makes the OpenGL context as current one on this thread against this window.
     MODULE_VIZ_SCENE3DQT_API void makeCurrent() final;
 
-    /// Gets the Ogre render target.
-    MODULE_VIZ_SCENE3DQT_API Ogre::RenderTarget* getRenderTarget() final;
-
     /// Returns a nullptr. This is due to the fact that this manager doesn't write to a texture.
     MODULE_VIZ_SCENE3DQT_API Ogre::TexturePtr getRenderTexture() final;
 
@@ -117,27 +110,21 @@ public:
      */
     MODULE_VIZ_SCENE3DQT_API void setFullscreen(bool _fullscreen, int _screenNumber) final;
 
+    QWidget* getQtWidget() const;
+
 private Q_SLOTS:
 
     /// Called when the user interacts with the scene using the mouse and keyboard, connected to @ref m_qOgreWidget.
     void onInteracted(sight::viz::scene3d::IWindowInteractor::InteractionInfo _info);
 
-    /// Called when the clipping range has to match the last updating of the scene bounding box
-    void onCameraClippingComputation();
-
 private:
 
-    /// Disables fullscreen rendering.
-    void disableFullscreen();
-
+    bool m_isFullScreen {false};
     /// Contains Qt element of the Widget.
     QPointer<module::viz::scene3dQt::Window> m_qOgreWidget;
 
     /// Contains the parent of the widget.
     SPTR(ui::qt::container::QtContainer) m_parentContainer;
-
-    /// Contains the window container.
-    QWidget* m_windowContainer {nullptr};
 };
 
 //-----------------------------------------------------------------------------
@@ -145,7 +132,14 @@ private:
 inline Ogre::TexturePtr WindowInteractor::getRenderTexture()
 {
     SIGHT_ERROR("'WindowInteractor' doesn't render in a texture.");
-    return Ogre::TexturePtr();
+    return {};
+}
+
+//-----------------------------------------------------------------------------
+
+inline QWidget* WindowInteractor::getQtWidget() const
+{
+    return m_qOgreWidget;
 }
 
 } // namespace sight::module::viz::scene3dQt.
