@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2021 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -23,8 +23,13 @@
 #include "modules/viz/scene3dTest/Plugin.hpp"
 
 #include <viz/scene3d/Utils.hpp>
+#include <viz/scene3d/WindowManager.hpp>
 
+#include <OGRE/OgreHardwarePixelBuffer.h>
 #include <OGRE/OgreLogManager.h>
+#include <OGRE/OgreRenderTexture.h>
+#include <OGRE/OgreRenderWindow.h>
+#include <OGRE/OgreTextureManager.h>
 
 namespace sight::module::viz::scene3d::test
 {
@@ -33,9 +38,8 @@ SIGHT_REGISTER_PLUGIN("sight::module::viz::scene3d::test::Plugin");
 
 //-----------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //-----------------------------------------------------------------------------
 
@@ -43,9 +47,24 @@ void Plugin::start()
 {
     m_ogreRoot = sight::viz::scene3d::Utils::getOgreRoot();
 
-    // Don't output the log to the terminal and delete the file when the test is done.
-    Ogre::LogManager* logMgr = Ogre::LogManager::getSingletonPtr();
-    logMgr->createLog("OgreTest.log", true, false, true);
+    Ogre::NameValuePairList const params {
+        {"hidden", "true"},
+    };
+
+    // Use a size > 120 because windows will anyway switch to a larger size
+    auto* window = m_ogreRoot->createRenderWindow(
+        "test",
+        static_cast<unsigned int>(200),
+        static_cast<unsigned int>(200),
+        false,
+        &params
+    );
+    sight::viz::scene3d::WindowManager::sptr mgr = sight::viz::scene3d::WindowManager::get();
+    mgr->add(window);
+
+    window->setVisible(false);
+    window->setAutoUpdated(false);
+    Ogre::ResourceGroupManager::getSingleton().initialiseAllResourceGroups();
 }
 
 //-----------------------------------------------------------------------------
