@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2018-2021 IRCAD France
+ * Copyright (C) 2018-2022 IRCAD France
  * Copyright (C) 2018-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -22,38 +22,31 @@
 
 #include "Plugin.hpp"
 
-#include <core/runtime/operations.hpp>
+#include <core/runtime/path.hpp>
 
 #include <ui/qml/QmlEngine.hpp>
 
 namespace Tuto06GuiQml
 {
 
-using namespace sight;
+namespace ui   = sight::ui;
+namespace core = sight::core;
 
 SIGHT_REGISTER_PLUGIN("Tuto06GuiQml::Plugin");
 
 //------------------------------------------------------------------------------
 
-Plugin::Plugin() noexcept
-{
-}
+Plugin::Plugin() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
-Plugin::~Plugin() noexcept
-{
-}
+Plugin::~Plugin() noexcept =
+    default;
 
 //------------------------------------------------------------------------------
 
 void Plugin::start()
-{
-}
-
-//------------------------------------------------------------------------------
-
-void Plugin::initialize()
 {
     // get the qml engine
     SPTR(ui::qml::QmlEngine) engine = ui::qml::QmlEngine::getDefault();
@@ -73,10 +66,4 @@ void Plugin::stop() noexcept
 
 //------------------------------------------------------------------------------
 
-void Plugin::uninitialize() noexcept
-{
-}
-
-//------------------------------------------------------------------------------
-
 } // namespace Tuto06GuiQml
