@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * Copyright (C) 2009-2022 IRCAD France
+ * Copyright (C) 2009-2023 IRCAD France
  * Copyright (C) 2012-2020 IHU Strasbourg
  *
  * This file is part of Sight.
@@ -20,18 +20,24 @@
  *
  ***********************************************************************/
 
+// cspell:ignore SEM_NOGPFAULTERRORBOX
+
 #ifdef _WIN32
 #include <windows.h>
 #endif
 
-#include <core/runtime/operations.hpp>
-#include <core/runtime/profile/Profile.hpp>
+#include <core/runtime/runtime.hpp>
+
 #include <core/crypto/PasswordKeeper.hpp>
+#include <core/runtime/profile/Profile.hpp>
+#include <core/tools/Os.hpp>
 
 #include <boost/program_options/options_description.hpp>
 #include <boost/program_options/parsers.hpp>
 #include <boost/program_options/positional_options.hpp>
 #include <boost/program_options/variables_map.hpp>
+#include <boost/property_tree/xml_parser.hpp>
+#include <boost/property_tree/ptree.hpp>
 
 #include <csignal>
 #include <filesystem>
@@ -46,25 +52,21 @@ namespace po = boost::program_options;
 
 using sight::core::crypto::PasswordKeeper;
 using sight::core::crypto::secure_string;
-namespace std
-{
 
 //------------------------------------------------------------------------------
 
 template<class A1, class A2>
-inline ostream& operator<<(ostream& s, vector<A1, A2> const& vec)
+inline static std::ostream& operator<<(std::ostream& s, std::vector<A1, A2> const& vec)
 {
-    copy(vec.begin(), vec.end(), ostream_iterator<A1>(s, " "));
+    copy(vec.begin(), vec.end(), std::ostream_iterator<A1>(s, " "));
     return s;
 }
 
-}
-
 //-----------------------------------------------------------------------------
 
 /// Wrapper for std::filesystem::absolute, needed by clang 3.0 in use with
 /// std::transform
-std::filesystem::path absolute(const std::filesystem::path& path)
+inline static std::filesystem::path absolute(const std::filesystem::path& path)
 {
     return std::filesystem::weakly_canonical(path);
 }
@@ -74,15 +76,18 @@ std::filesystem::path absolute(const std::filesystem::path& path)
 volatile sig_atomic_t gSignalStatus = 0;
 //------------------------------------------------------------------------------
 
-void signal_handler(int signal)
+void signalHandler(int signal)
 {
     gSignalStatus = signal;
 
     try
     {
         const auto& profile = sight::core::runtime::getCurrentProfile();
-        profile->cleanup();
-        profile->stop();
+
+        if(profile != nullptr)
+        {
+            profile->stop();
+        }
     }
     catch(const std::exception& e)
     {
@@ -98,6 +103,71 @@ void signal_handler(int signal)
     exit(0);
 }
 
+//------------------------------------------------------------------------------
+
+inline static std::filesystem::path buildLogFilePath(const std::filesystem::path& log_dir, bool encrypted_log)
+{
+    // Use the default log file name as base
+    std::filesystem::path log_file_path = encrypted_log
+                                          ? sight::core::log::ENCRYPTED_LOG_FILE
+                                          : sight::core::log::LOG_FILE;
+
+    // Prepend the log directory
+    if(!log_dir.empty())
+    {
+        std::filesystem::create_directories(log_dir);
+        log_file_path = log_dir / log_file_path;
+    }
+
+    // Test if the directory is writable. An exception will be thrown if not
+    {
+        std::ofstream ostream;
+        ostream.open(log_file_path, std::ios::out | std::ios::binary | std::ios::trunc);
+    }
+
+    // Cleanup
+    std::filesystem::remove_all(log_file_path);
+
+    return log_file_path;
+}
+
+//------------------------------------------------------------------------------
+
+inline static std::filesystem::path findLogFilePath(
+    const std::filesystem::path& log_file,
+    const std::filesystem::path& profile_file,
+    bool encrypted_log
+)
+{
+    if(log_file.empty())
+    {
+        // Parse the profile.xml to get the name
+        boost::property_tree::ptree profile_tree;
+        boost::property_tree::read_xml(profile_file.string(), profile_tree);
+        const auto& profile_name = profile_tree.get<std::string>("profile.<xmlattr>.name");
+
+        try
+        {
+            // Try the user cache directory
+            return buildLogFilePath(
+                sight::core::tools::os::getUserCacheDir(profile_name),
+                encrypted_log
+            );
+        }
+        catch(...)
+        {
+            // Fallback: take temporary directory
+            return buildLogFilePath(
+                std::filesystem::temp_directory_path() / "sight" / profile_name,
+                encrypted_log
+            );
+        }
+    }
+
+    // Take the user choice
+    return log_file;
+}
+
 //-----------------------------------------------------------------------------
 
 int main(int argc, char* argv[])
@@ -124,17 +194,14 @@ int main(int argc, char* argv[])
     bool ask_password        = false;
 #endif
 
-#if defined(WIN32)
+    /// @warning file_log cannot work with console_log on
+    /// @todo fix this
     bool console_log = false;
     bool file_log    = true;
-#else
-    bool console_log = !encrypted_log;
-    bool file_log    = encrypted_log;
-#endif
 
     std::string log_file;
 
-    typedef sight::core::log::SpyLogger SpyLogger;
+    using SpyLogger = sight::core::log::SpyLogger;
     int log_level = SpyLogger::SL_WARN;
 
     po::options_description logOptions("Log options");
@@ -149,7 +216,7 @@ int main(int argc, char* argv[])
     (
         "clog",
         po::value(&console_log)->implicit_value(true)->zero_tokens(),
-        "Enable log output to console"
+        "Enable log output to console. Will disable file log."
     )
     (
         "no-clog",
@@ -159,7 +226,7 @@ int main(int argc, char* argv[])
     (
         "flog",
         po::value(&file_log)->implicit_value(true)->zero_tokens(),
-        "Enable log output to file"
+        "Enable log output to file. Will disable console log."
     )
     (
         "no-flog",
@@ -168,9 +235,7 @@ int main(int argc, char* argv[])
     )
     (
         "log-output",
-        po::value(&log_file)->default_value(
-            encrypted_log ? sight::core::log::ENCRYPTED_LOG_FILE : sight::core::log::LOG_FILE
-        ),
+        po::value(&log_file),
         "Log output filename"
     )
     (
@@ -205,10 +270,21 @@ int main(int argc, char* argv[])
     );
 
     // Hidden options
+    bool macroMode = false;
+#ifdef WIN32
+    bool enableAbortDialog = true;
+#endif
+
     po::options_description hidden("Hidden options");
     hidden.add_options()
         ("profile", po::value(&profileFile)->default_value("profile.xml"), "Profile file")
         ("profile-args", po::value(&profileArgs)->multitoken(), "Profile args")
+        ("macro", po::value(&macroMode)->implicit_value(true)->zero_tokens(), "Enable macro mode")
+        ("no-macro", po::value(&macroMode)->implicit_value(false)->zero_tokens(), "Disable macro mode")
+#ifdef WIN32
+    ("abort-dialog", po::value(&enableAbortDialog)->implicit_value(true)->zero_tokens(), "Enable abort dialog")
+        ("no-abort-dialog", po::value(&enableAbortDialog)->implicit_value(false)->zero_tokens(), "Disable abort dialog")
+#endif
     ;
 
     // Set options
@@ -231,6 +307,12 @@ int main(int argc, char* argv[])
             vm
         );
         po::notify(vm);
+
+        if(vm.count("flog") > 0 && vm.count("clog") > 0)
+        {
+            throw po::error("Cannot enable both file and console log");
+            return 1;
+        }
     }
     catch(const po::error& e)
     {
@@ -239,7 +321,7 @@ int main(int argc, char* argv[])
     }
 
     // If help
-    if(vm.count("help"))
+    if(vm.count("help") != 0U)
     {
         std::cout << "usage: " << argv[0] << " [options] [profile(=profile.xml)] [profile-args ...]" << std::endl;
         std::cout << "  use '--' to stop processing args for sightrun" << std::endl << std::endl;
@@ -247,16 +329,48 @@ int main(int argc, char* argv[])
         return 0;
     }
 
+    // If we enable console log, but not file log, we disable file log (which is enabled by default)
+    if(console_log)
+    {
+        file_log = false;
+    }
+
+#ifdef WIN32
+    if(!enableAbortDialog)
+    {
+        _set_error_mode(_OUT_TO_STDERR);
+        SetErrorMode(SEM_FAILCRITICALERRORS | SEM_NOGPFAULTERRORBOX);
+        _set_abort_behavior(0, _WRITE_ABORT_MSG | _CALL_REPORTFAULT);
+        _CrtSetReportMode(_CRT_ASSERT, _CRTDBG_MODE_FILE | _CRTDBG_MODE_DEBUG);
+        _CrtSetReportFile(_CRT_ASSERT, _CRTDBG_FILE_STDERR);
+        _CrtSetReportMode(_CRT_ERROR, _CRTDBG_MODE_FILE | _CRTDBG_MODE_DEBUG);
+        _CrtSetReportFile(_CRT_ERROR, _CRTDBG_FILE_STDERR);
+    }
+#endif
+
+    SIGHT_INFO_IF("Profile path: " << profileFile << " => " << ::absolute(profileFile), vm.count("profile"));
+    SIGHT_INFO_IF("Profile-args: " << profileArgs, vm.count("profile-args"));
+
+    // Check if profile path exist
+    profileFile = ::absolute(profileFile);
+
+    SIGHT_FATAL_IF(
+        "Profile file " << profileFile << " do not exists or is not a regular file.",
+        !std::filesystem::is_regular_file(profileFile)
+    );
+
     // Log file
     SpyLogger& logger = SpyLogger::get();
 
     if(console_log)
     {
-        logger.add_console_log(std::clog, static_cast<SpyLogger::LevelType>(log_level));
+        SpyLogger::add_console_log(std::clog, static_cast<SpyLogger::LevelType>(log_level));
     }
 
     if(file_log)
     {
+        std::filesystem::path log_file_path = findLogFilePath(log_file, profileFile, encrypted_log);
+
         if(encrypted_log)
         {
             const secure_string& password =
@@ -265,7 +379,7 @@ int main(int argc, char* argv[])
                 : secure_string();
 
             logger.start_encrypted_logger(
-                log_file,
+                log_file_path,
                 static_cast<SpyLogger::LevelType>(log_level),
                 password,
                 ask_password
@@ -273,24 +387,10 @@ int main(int argc, char* argv[])
         }
         else
         {
-            logger.start_logger(log_file, static_cast<SpyLogger::LevelType>(log_level));
+            logger.start_logger(log_file_path, static_cast<SpyLogger::LevelType>(log_level));
         }
     }
 
-    SIGHT_INFO_IF("Profile path: " << profileFile << " => " << ::absolute(profileFile), vm.count("profile"));
-    SIGHT_INFO_IF("Profile-args: " << profileArgs, vm.count("profile-args"));
-
-    // Check if path exist
-    SIGHT_FATAL_IF(
-        "Profile path doesn't exist: " << profileFile.string() << " => " << ::absolute(
-            profileFile
-        ),
-        !std::filesystem::exists(profileFile.string())
-    );
-
-    std::transform(modulePaths.begin(), modulePaths.end(), modulePaths.begin(), ::absolute);
-    profileFile = ::absolute(profileFile);
-
     // Automatically adds the module folders where the profile.xml is located if it was not already there
     const auto profileModulePath = profileFile.parent_path().parent_path();
     bool findProfileModulePath   = false;
@@ -316,71 +416,70 @@ int main(int argc, char* argv[])
         );
     }
 #endif
-    for(const std::filesystem::path& modulePath : modulePaths)
-    {
-        SIGHT_FATAL_IF(
-            "Module path doesn't exist: " << modulePath.string() << " => " << ::absolute(
-                modulePath
-            ),
-            !std::filesystem::exists(modulePath.string())
-        );
-    }
 
     sight::core::runtime::init();
 
     for(const std::filesystem::path& modulePath : modulePaths)
     {
-        if(std::filesystem::is_directory(modulePath))
-        {
-            sight::core::runtime::addModules(modulePath);
-        }
-        else
-        {
-            SIGHT_ERROR("Module path " << modulePath << " do not exists or is not a directory.");
-        }
+        sight::core::runtime::addModules(modulePath);
     }
 
-    if(std::filesystem::is_regular_file(profileFile))
+    sight::core::runtime::Profile::sptr profile;
+
+    try
     {
-        sight::core::runtime::Profile::sptr profile;
+        profile = sight::core::runtime::io::ProfileReader::createProfile(profileFile);
 
-        try
+        // Install a signal handler
+        if(std::signal(SIGINT, signalHandler) == SIG_ERR)
         {
-            profile = sight::core::runtime::io::ProfileReader::createProfile(profileFile);
+            perror("std::signal(SIGINT)");
+        }
 
-            // Install a signal handler
-            std::signal(SIGINT, signal_handler);
-            std::signal(SIGTERM, signal_handler);
+        if(std::signal(SIGTERM, signalHandler) == SIG_ERR)
+        {
+            perror("std::signal(SIGTERM)");
+        }
 
 #ifndef WIN32
-            std::signal(SIGHUP, signal_handler);
-            std::signal(SIGQUIT, signal_handler);
+        if(std::signal(SIGHUP, signalHandler) == SIG_ERR)
+        {
+            perror("std::signal(SIGHUP)");
+        }
+
+        if(std::signal(SIGQUIT, signalHandler) == SIG_ERR)
+        {
+            perror("std::signal(SIGQUIT)");
+        }
 #endif
+        profile->setParams(profileArgs);
 
-            profile->setParams(profileArgs);
+        profile->start();
+        if(macroMode)
+        {
+            sight::core::runtime::loadModule("sight::module::ui::test");
+        }
 
-            profile->start();
-            profile->run();
-            if(gSignalStatus == 0)
-            {
-                profile->stop();
-            }
-        }
-        catch(const std::exception& e)
+        profile->run();
+        if(gSignalStatus == 0)
         {
-            SIGHT_FATAL(e.what());
-            return 3;
+            profile->stop();
         }
-        catch(...)
+
+        if(macroMode)
         {
-            SIGHT_FATAL("An unrecoverable error has occurred.");
-            return 4;
+            sight::core::runtime::unloadModule("sight::module::ui::test");
         }
     }
-    else
+    catch(const std::exception& e)
     {
-        SIGHT_ERROR("Profile file " << profileFile << " do not exists or is not a regular file.");
-        return 5;
+        SIGHT_FATAL(e.what());
+        return 3;
+    }
+    catch(...)
+    {
+        SIGHT_FATAL("An unrecoverable error has occurred.");
+        return 4;
     }
 
     return 0;
